/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class BlackVolTermStructureHandle {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected BlackVolTermStructureHandle(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(BlackVolTermStructureHandle obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_BlackVolTermStructureHandle(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public BlackVolTermStructureHandle(BlackVolTermStructure arg0) {
    this(QuantLibJNI.new_BlackVolTermStructureHandle__SWIG_0(BlackVolTermStructure.getCPtr(arg0), arg0), true);
  }

  public BlackVolTermStructureHandle() {
    this(QuantLibJNI.new_BlackVolTermStructureHandle__SWIG_1(), true);
  }

  public BlackVolTermStructure __deref__() {
    long cPtr = QuantLibJNI.BlackVolTermStructureHandle___deref__(swigCPtr, this);
    return (cPtr == 0) ? null : new BlackVolTermStructure(cPtr, true);
  }

  public BlackVolTermStructure currentLink() {
    long cPtr = QuantLibJNI.BlackVolTermStructureHandle_currentLink(swigCPtr, this);
    return (cPtr == 0) ? null : new BlackVolTermStructure(cPtr, true);
  }

  public boolean empty() {
    return QuantLibJNI.BlackVolTermStructureHandle_empty(swigCPtr, this);
  }

  public Observable asObservable() {
    long cPtr = QuantLibJNI.BlackVolTermStructureHandle_asObservable(swigCPtr, this);
    return (cPtr == 0) ? null : new Observable(cPtr, true);
  }

  public double blackVol(Date arg0, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVol__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, strike, extrapolate);
  }

  public double blackVol(Date arg0, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVol__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0, strike);
  }

  public double blackVol(double arg0, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVol__SWIG_2(swigCPtr, this, arg0, strike, extrapolate);
  }

  public double blackVol(double arg0, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVol__SWIG_3(swigCPtr, this, arg0, strike);
  }

  public double blackVariance(Date arg0, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVariance__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, strike, extrapolate);
  }

  public double blackVariance(Date arg0, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVariance__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0, strike);
  }

  public double blackVariance(double arg0, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVariance__SWIG_2(swigCPtr, this, arg0, strike, extrapolate);
  }

  public double blackVariance(double arg0, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackVariance__SWIG_3(swigCPtr, this, arg0, strike);
  }

  public double blackForwardVol(Date arg0, Date arg1, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVol__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1, strike, extrapolate);
  }

  public double blackForwardVol(Date arg0, Date arg1, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVol__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1, strike);
  }

  public double blackForwardVol(double arg0, double arg1, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVol__SWIG_2(swigCPtr, this, arg0, arg1, strike, extrapolate);
  }

  public double blackForwardVol(double arg0, double arg1, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVol__SWIG_3(swigCPtr, this, arg0, arg1, strike);
  }

  public double blackForwardVariance(Date arg0, Date arg1, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVariance__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1, strike, extrapolate);
  }

  public double blackForwardVariance(Date arg0, Date arg1, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVariance__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1, strike);
  }

  public double blackForwardVariance(double arg0, double arg1, double strike, boolean extrapolate) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVariance__SWIG_2(swigCPtr, this, arg0, arg1, strike, extrapolate);
  }

  public double blackForwardVariance(double arg0, double arg1, double strike) {
    return QuantLibJNI.BlackVolTermStructureHandle_blackForwardVariance__SWIG_3(swigCPtr, this, arg0, arg1, strike);
  }

  public double minStrike() {
    return QuantLibJNI.BlackVolTermStructureHandle_minStrike(swigCPtr, this);
  }

  public double maxStrike() {
    return QuantLibJNI.BlackVolTermStructureHandle_maxStrike(swigCPtr, this);
  }

  public DayCounter dayCounter() {
    return new DayCounter(QuantLibJNI.BlackVolTermStructureHandle_dayCounter(swigCPtr, this), true);
  }

  public double timeFromReference(Date date) {
    return QuantLibJNI.BlackVolTermStructureHandle_timeFromReference(swigCPtr, this, Date.getCPtr(date), date);
  }

  public Calendar calendar() {
    return new Calendar(QuantLibJNI.BlackVolTermStructureHandle_calendar(swigCPtr, this), true);
  }

  public Date referenceDate() {
    return new Date(QuantLibJNI.BlackVolTermStructureHandle_referenceDate(swigCPtr, this), true);
  }

  public Date maxDate() {
    return new Date(QuantLibJNI.BlackVolTermStructureHandle_maxDate(swigCPtr, this), true);
  }

  public double maxTime() {
    return QuantLibJNI.BlackVolTermStructureHandle_maxTime(swigCPtr, this);
  }

  public void enableExtrapolation() {
    QuantLibJNI.BlackVolTermStructureHandle_enableExtrapolation(swigCPtr, this);
  }

  public void disableExtrapolation() {
    QuantLibJNI.BlackVolTermStructureHandle_disableExtrapolation(swigCPtr, this);
  }

  public boolean allowsExtrapolation() {
    return QuantLibJNI.BlackVolTermStructureHandle_allowsExtrapolation(swigCPtr, this);
  }

}
