/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class Optimizer {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected Optimizer(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(Optimizer obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_Optimizer(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public Array solve(CostFunctionDelegate function, Constraint c, OptimizationMethod m, EndCriteria e, Array iv) {
    return new Array(QuantLibJNI.Optimizer_solve(swigCPtr, this, CostFunctionDelegate.getCPtr(function), function, Constraint.getCPtr(c), c, OptimizationMethod.getCPtr(m), m, EndCriteria.getCPtr(e), e, Array.getCPtr(iv), iv), true);
  }

  public Optimizer() {
    this(QuantLibJNI.new_Optimizer(), true);
  }

}
