/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class Exercise {
  private transient long swigCPtr;
  private transient boolean swigCMemOwn;

  protected Exercise(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(Exercise obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwn = own;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_Exercise(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public Exercise(Exercise.Type type) {
    this(QuantLibJNI.new_Exercise(type.swigValue()), true);
  }

  public Exercise.Type type() {
    return Exercise.Type.swigToEnum(QuantLibJNI.Exercise_type(swigCPtr, this));
  }

  public Date date(long index) {
    return new Date(QuantLibJNI.Exercise_date(swigCPtr, this, index), true);
  }

  public Date dateAt(long index) {
    return new Date(QuantLibJNI.Exercise_dateAt(swigCPtr, this, index), true);
  }

  public DateVector dates() {
    return new DateVector(QuantLibJNI.Exercise_dates(swigCPtr, this), false);
  }

  public Date lastDate() {
    return new Date(QuantLibJNI.Exercise_lastDate(swigCPtr, this), true);
  }

  public Exercise.Type exerciseType() {
    return Exercise.Type.swigToEnum(QuantLibJNI.Exercise_exerciseType(swigCPtr, this));
  }

  public final static class Type {
    public final static Exercise.Type American = new Exercise.Type("American");
    public final static Exercise.Type Bermudan = new Exercise.Type("Bermudan");
    public final static Exercise.Type European = new Exercise.Type("European");

    public final int swigValue() {
      return swigValue;
    }

    public String toString() {
      return swigName;
    }

    public static Type swigToEnum(int swigValue) {
      if (swigValue < swigValues.length && swigValue >= 0 && swigValues[swigValue].swigValue == swigValue)
        return swigValues[swigValue];
      for (int i = 0; i < swigValues.length; i++)
        if (swigValues[i].swigValue == swigValue)
          return swigValues[i];
      throw new IllegalArgumentException("No enum " + Type.class + " with value " + swigValue);
    }

    private Type(String swigName) {
      this.swigName = swigName;
      this.swigValue = swigNext++;
    }

    private Type(String swigName, int swigValue) {
      this.swigName = swigName;
      this.swigValue = swigValue;
      swigNext = swigValue+1;
    }

    private Type(String swigName, Type swigEnum) {
      this.swigName = swigName;
      this.swigValue = swigEnum.swigValue;
      swigNext = this.swigValue+1;
    }

    private static Type[] swigValues = { American, Bermudan, European };
    private static int swigNext = 0;
    private final int swigValue;
    private final String swigName;
  }

}
