/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class FuturesRateHelper extends RateHelper {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected FuturesRateHelper(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.FuturesRateHelper_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(FuturesRateHelper obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_FuturesRateHelper(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter, QuoteHandle convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_0(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter, QuoteHandle convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_1(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_2(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter, double convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_3(price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter, convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter, double convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_4(price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter, convexityAdjustment), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, long nMonths, Calendar calendar, BusinessDayConvention convention, boolean endOfMonth, DayCounter dayCounter) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_5(price, Date.getCPtr(iborStartDate), iborStartDate, nMonths, Calendar.getCPtr(calendar), calendar, convention.swigValue(), endOfMonth, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter, QuoteHandle convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_6(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter, QuoteHandle convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_7(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_8(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter, double convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_9(price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter, convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter, double convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_10(price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter, convexityAdjustment), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, Date iborEndDate, DayCounter dayCounter) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_11(price, Date.getCPtr(iborStartDate), iborStartDate, Date.getCPtr(iborEndDate), iborEndDate, DayCounter.getCPtr(dayCounter), dayCounter), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, IborIndex index, QuoteHandle convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_12(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, IborIndex index, QuoteHandle convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_13(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index, QuoteHandle.getCPtr(convexityAdjustment), convexityAdjustment), true);
  }

  public FuturesRateHelper(QuoteHandle price, Date iborStartDate, IborIndex index) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_14(QuoteHandle.getCPtr(price), price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, IborIndex index, double convexityAdjustment, Futures.Type type) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_15(price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index, convexityAdjustment, type.swigValue()), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, IborIndex index, double convexityAdjustment) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_16(price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index, convexityAdjustment), true);
  }

  public FuturesRateHelper(double price, Date iborStartDate, IborIndex index) {
    this(QuantLibJNI.new_FuturesRateHelper__SWIG_17(price, Date.getCPtr(iborStartDate), iborStartDate, IborIndex.getCPtr(index), index), true);
  }

}
