/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class FdSabrVanillaEngine extends PricingEngine {
  private transient long swigCPtr;
  private transient boolean swigCMemOwnDerived;

  protected FdSabrVanillaEngine(long cPtr, boolean cMemoryOwn) {
    super(QuantLibJNI.FdSabrVanillaEngine_SWIGSmartPtrUpcast(cPtr), true);
    swigCMemOwnDerived = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(FdSabrVanillaEngine obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  protected void swigSetCMemOwn(boolean own) {
    swigCMemOwnDerived = own;
    super.swigSetCMemOwn(own);
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwnDerived) {
        swigCMemOwnDerived = false;
        QuantLibJNI.delete_FdSabrVanillaEngine(swigCPtr);
      }
      swigCPtr = 0;
    }
    super.delete();
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid, long xGrid, long dampingSteps, double scalingFactor, double eps, FdmSchemeDesc schemeDesc) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_0(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid, xGrid, dampingSteps, scalingFactor, eps, FdmSchemeDesc.getCPtr(schemeDesc), schemeDesc), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid, long xGrid, long dampingSteps, double scalingFactor, double eps) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_1(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid, xGrid, dampingSteps, scalingFactor, eps), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid, long xGrid, long dampingSteps, double scalingFactor) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_2(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid, xGrid, dampingSteps, scalingFactor), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid, long xGrid, long dampingSteps) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_3(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid, xGrid, dampingSteps), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid, long xGrid) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_4(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid, xGrid), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid, long fGrid) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_5(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid, fGrid), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS, long tGrid) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_6(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS, tGrid), true);
  }

  public FdSabrVanillaEngine(double f0, double alpha, double beta, double nu, double rho, YieldTermStructureHandle rTS) {
    this(QuantLibJNI.new_FdSabrVanillaEngine__SWIG_7(f0, alpha, beta, nu, rho, YieldTermStructureHandle.getCPtr(rTS), rTS), true);
  }

}
