/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class SampledCurve {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected SampledCurve(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(SampledCurve obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_SampledCurve(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public SampledCurve() {
    this(QuantLibJNI.new_SampledCurve__SWIG_0(), true);
  }

  public SampledCurve(Array arg0) {
    this(QuantLibJNI.new_SampledCurve__SWIG_1(Array.getCPtr(arg0), arg0), true);
  }

  public Array grid() {
    return new Array(QuantLibJNI.SampledCurve_grid(swigCPtr, this), false);
  }

  public Array values() {
    return new Array(QuantLibJNI.SampledCurve_values(swigCPtr, this), false);
  }

  public double gridValue(long i) {
    return QuantLibJNI.SampledCurve_gridValue(swigCPtr, this, i);
  }

  public double value(long i) {
    return QuantLibJNI.SampledCurve_value(swigCPtr, this, i);
  }

  public long size() {
    return QuantLibJNI.SampledCurve_size(swigCPtr, this);
  }

  public boolean empty() {
    return QuantLibJNI.SampledCurve_empty(swigCPtr, this);
  }

  public void setGrid(Array arg0) {
    QuantLibJNI.SampledCurve_setGrid(swigCPtr, this, Array.getCPtr(arg0), arg0);
  }

  public void setValues(Array arg0) {
    QuantLibJNI.SampledCurve_setValues(swigCPtr, this, Array.getCPtr(arg0), arg0);
  }

  public void swap(SampledCurve arg0) {
    QuantLibJNI.SampledCurve_swap(swigCPtr, this, SampledCurve.getCPtr(arg0), arg0);
  }

  public void setLogGrid(double min, double max) {
    QuantLibJNI.SampledCurve_setLogGrid(swigCPtr, this, min, max);
  }

  public void regridLogGrid(double min, double max) {
    QuantLibJNI.SampledCurve_regridLogGrid(swigCPtr, this, min, max);
  }

  public void shiftGrid(double s) {
    QuantLibJNI.SampledCurve_shiftGrid(swigCPtr, this, s);
  }

  public void scaleGrid(double s) {
    QuantLibJNI.SampledCurve_scaleGrid(swigCPtr, this, s);
  }

  public void regrid(Array arg0) {
    QuantLibJNI.SampledCurve_regrid(swigCPtr, this, Array.getCPtr(arg0), arg0);
  }

}
