//------------------------------------------------------------------------------
// <auto-generated />
//
// This file was automatically generated by SWIG (http://www.swig.org).
// Version 4.0.2
//
// Do not make changes to this file unless you know what you are doing--modify
// the SWIG interface file instead.
//------------------------------------------------------------------------------

namespace QuantLib {

public class OdeFctDelegate : global::System.IDisposable {
  private global::System.Runtime.InteropServices.HandleRef swigCPtr;
  protected bool swigCMemOwn;

  internal OdeFctDelegate(global::System.IntPtr cPtr, bool cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = new global::System.Runtime.InteropServices.HandleRef(this, cPtr);
  }

  internal static global::System.Runtime.InteropServices.HandleRef getCPtr(OdeFctDelegate obj) {
    return (obj == null) ? new global::System.Runtime.InteropServices.HandleRef(null, global::System.IntPtr.Zero) : obj.swigCPtr;
  }

  ~OdeFctDelegate() {
    Dispose(false);
  }

  public void Dispose() {
    Dispose(true);
    global::System.GC.SuppressFinalize(this);
  }

  protected virtual void Dispose(bool disposing) {
    lock(this) {
      if (swigCPtr.Handle != global::System.IntPtr.Zero) {
        if (swigCMemOwn) {
          swigCMemOwn = false;
          NQuantLibcPINVOKE.delete_OdeFctDelegate(swigCPtr);
        }
        swigCPtr = new global::System.Runtime.InteropServices.HandleRef(null, global::System.IntPtr.Zero);
      }
    }
  }

  public virtual DoubleVector value(double x, DoubleVector y) {
    DoubleVector ret = new DoubleVector((SwigDerivedClassHasMethod("value", swigMethodTypes0) ? NQuantLibcPINVOKE.OdeFctDelegate_valueSwigExplicitOdeFctDelegate(swigCPtr, x, DoubleVector.getCPtr(y)) : NQuantLibcPINVOKE.OdeFctDelegate_value(swigCPtr, x, DoubleVector.getCPtr(y))), true);
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
    return ret;
  }

  public OdeFctDelegate() : this(NQuantLibcPINVOKE.new_OdeFctDelegate(), true) {
    if (NQuantLibcPINVOKE.SWIGPendingException.Pending) throw NQuantLibcPINVOKE.SWIGPendingException.Retrieve();
    SwigDirectorConnect();
  }

  private void SwigDirectorConnect() {
    if (SwigDerivedClassHasMethod("value", swigMethodTypes0))
      swigDelegate0 = new SwigDelegateOdeFctDelegate_0(SwigDirectorMethodvalue);
    NQuantLibcPINVOKE.OdeFctDelegate_director_connect(swigCPtr, swigDelegate0);
  }

  private bool SwigDerivedClassHasMethod(string methodName, global::System.Type[] methodTypes) {
    global::System.Reflection.MethodInfo methodInfo = this.GetType().GetMethod(methodName, global::System.Reflection.BindingFlags.Public | global::System.Reflection.BindingFlags.NonPublic | global::System.Reflection.BindingFlags.Instance, null, methodTypes, null);
    bool hasDerivedMethod = methodInfo.DeclaringType.IsSubclassOf(typeof(OdeFctDelegate));
    return hasDerivedMethod;
  }

  private global::System.IntPtr SwigDirectorMethodvalue(double x, global::System.IntPtr y) {
    return DoubleVector.getCPtr(value(x, new DoubleVector(y, false))).Handle;
  }

  public delegate global::System.IntPtr SwigDelegateOdeFctDelegate_0(double x, global::System.IntPtr y);

  private SwigDelegateOdeFctDelegate_0 swigDelegate0;

  private static global::System.Type[] swigMethodTypes0 = new global::System.Type[] { typeof(double), typeof(DoubleVector) };
}

}
