/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class DefaultProbabilityTermStructureHandle {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected DefaultProbabilityTermStructureHandle(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(DefaultProbabilityTermStructureHandle obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_DefaultProbabilityTermStructureHandle(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public DefaultProbabilityTermStructureHandle(DefaultProbabilityTermStructure arg0) {
    this(QuantLibJNI.new_DefaultProbabilityTermStructureHandle__SWIG_0(DefaultProbabilityTermStructure.getCPtr(arg0), arg0), true);
  }

  public DefaultProbabilityTermStructureHandle() {
    this(QuantLibJNI.new_DefaultProbabilityTermStructureHandle__SWIG_1(), true);
  }

  public DefaultProbabilityTermStructure __deref__() {
    long cPtr = QuantLibJNI.DefaultProbabilityTermStructureHandle___deref__(swigCPtr, this);
    return (cPtr == 0) ? null : new DefaultProbabilityTermStructure(cPtr, true);
  }

  public DefaultProbabilityTermStructure currentLink() {
    long cPtr = QuantLibJNI.DefaultProbabilityTermStructureHandle_currentLink(swigCPtr, this);
    return (cPtr == 0) ? null : new DefaultProbabilityTermStructure(cPtr, true);
  }

  public boolean empty() {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_empty(swigCPtr, this);
  }

  public Observable asObservable() {
    long cPtr = QuantLibJNI.DefaultProbabilityTermStructureHandle_asObservable(swigCPtr, this);
    return (cPtr == 0) ? null : new Observable(cPtr, true);
  }

  public double defaultProbability(Date arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, extrapolate);
  }

  public double defaultProbability(Date arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0);
  }

  public double defaultProbability(double arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_2(swigCPtr, this, arg0, extrapolate);
  }

  public double defaultProbability(double arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_3(swigCPtr, this, arg0);
  }

  public double defaultProbability(Date arg0, Date arg1, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_4(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1, extrapolate);
  }

  public double defaultProbability(Date arg0, Date arg1) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_5(swigCPtr, this, Date.getCPtr(arg0), arg0, Date.getCPtr(arg1), arg1);
  }

  public double defaultProbability(double arg0, double arg1, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_6(swigCPtr, this, arg0, arg1, extrapolate);
  }

  public double defaultProbability(double arg0, double arg1) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_7(swigCPtr, this, arg0, arg1);
  }

  public double survivalProbability(Date arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, extrapolate);
  }

  public double survivalProbability(Date arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0);
  }

  public double survivalProbability(double arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_2(swigCPtr, this, arg0, extrapolate);
  }

  public double survivalProbability(double arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_3(swigCPtr, this, arg0);
  }

  public double defaultDensity(Date arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, extrapolate);
  }

  public double defaultDensity(Date arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0);
  }

  public double defaultDensity(double arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_2(swigCPtr, this, arg0, extrapolate);
  }

  public double defaultDensity(double arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_3(swigCPtr, this, arg0);
  }

  public double hazardRate(Date arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_hazardRate__SWIG_0(swigCPtr, this, Date.getCPtr(arg0), arg0, extrapolate);
  }

  public double hazardRate(Date arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_hazardRate__SWIG_1(swigCPtr, this, Date.getCPtr(arg0), arg0);
  }

  public double hazardRate(double arg0, boolean extrapolate) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_hazardRate__SWIG_2(swigCPtr, this, arg0, extrapolate);
  }

  public double hazardRate(double arg0) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_hazardRate__SWIG_3(swigCPtr, this, arg0);
  }

  public DayCounter dayCounter() {
    return new DayCounter(QuantLibJNI.DefaultProbabilityTermStructureHandle_dayCounter(swigCPtr, this), true);
  }

  public double timeFromReference(Date date) {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_timeFromReference(swigCPtr, this, Date.getCPtr(date), date);
  }

  public Calendar calendar() {
    return new Calendar(QuantLibJNI.DefaultProbabilityTermStructureHandle_calendar(swigCPtr, this), true);
  }

  public Date referenceDate() {
    return new Date(QuantLibJNI.DefaultProbabilityTermStructureHandle_referenceDate(swigCPtr, this), true);
  }

  public Date maxDate() {
    return new Date(QuantLibJNI.DefaultProbabilityTermStructureHandle_maxDate(swigCPtr, this), true);
  }

  public double maxTime() {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_maxTime(swigCPtr, this);
  }

  public void enableExtrapolation() {
    QuantLibJNI.DefaultProbabilityTermStructureHandle_enableExtrapolation(swigCPtr, this);
  }

  public void disableExtrapolation() {
    QuantLibJNI.DefaultProbabilityTermStructureHandle_disableExtrapolation(swigCPtr, this);
  }

  public boolean allowsExtrapolation() {
    return QuantLibJNI.DefaultProbabilityTermStructureHandle_allowsExtrapolation(swigCPtr, this);
  }

}
