/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class Settings {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected Settings(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(Settings obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_Settings(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public static Settings instance() {
    return new Settings(QuantLibJNI.Settings_instance(), false);
  }

  public Date getEvaluationDate() {
    return new Date(QuantLibJNI.Settings_getEvaluationDate(swigCPtr, this), true);
  }

  public void setEvaluationDate(Date d) {
    QuantLibJNI.Settings_setEvaluationDate(swigCPtr, this, Date.getCPtr(d), d);
  }

  public void includeReferenceDateEvents(boolean b) {
    QuantLibJNI.Settings_includeReferenceDateEvents(swigCPtr, this, b);
  }

  public void includeTodaysCashFlows(boolean b) {
    QuantLibJNI.Settings_includeTodaysCashFlows(swigCPtr, this, b);
  }

  public void setEnforcesTodaysHistoricFixings(boolean b) {
    QuantLibJNI.Settings_setEnforcesTodaysHistoricFixings(swigCPtr, this, b);
  }

  public boolean getEnforcesTodaysHistoricFixings() {
    return QuantLibJNI.Settings_getEnforcesTodaysHistoricFixings(swigCPtr, this);
  }

}
