/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class HestonSLVMCModel {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected HestonSLVMCModel(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(HestonSLVMCModel obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_HestonSLVMCModel(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate, long timeStepsPerYear, long nBins, long calibrationPaths, DateVector mandatoryDates, double mixingFactor) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_0(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate, timeStepsPerYear, nBins, calibrationPaths, DateVector.getCPtr(mandatoryDates), mandatoryDates, mixingFactor), true);
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate, long timeStepsPerYear, long nBins, long calibrationPaths, DateVector mandatoryDates) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_1(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate, timeStepsPerYear, nBins, calibrationPaths, DateVector.getCPtr(mandatoryDates), mandatoryDates), true);
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate, long timeStepsPerYear, long nBins, long calibrationPaths) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_2(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate, timeStepsPerYear, nBins, calibrationPaths), true);
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate, long timeStepsPerYear, long nBins) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_3(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate, timeStepsPerYear, nBins), true);
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate, long timeStepsPerYear) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_4(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate, timeStepsPerYear), true);
  }

  public HestonSLVMCModel(LocalVolTermStructure localVol, HestonModel model, BrownianGeneratorFactory brownianGeneratorFactory, Date endDate) {
    this(QuantLibJNI.new_HestonSLVMCModel__SWIG_5(LocalVolTermStructure.getCPtr(localVol), localVol, HestonModel.getCPtr(model), model, BrownianGeneratorFactory.getCPtr(brownianGeneratorFactory), brownianGeneratorFactory, Date.getCPtr(endDate), endDate), true);
  }

  public HestonProcess hestonProcess() {
    long cPtr = QuantLibJNI.HestonSLVMCModel_hestonProcess(swigCPtr, this);
    return (cPtr == 0) ? null : new HestonProcess(cPtr, true);
  }

  public LocalVolTermStructure localVol() {
    long cPtr = QuantLibJNI.HestonSLVMCModel_localVol(swigCPtr, this);
    return (cPtr == 0) ? null : new LocalVolTermStructure(cPtr, true);
  }

  public LocalVolTermStructure leverageFunction() {
    long cPtr = QuantLibJNI.HestonSLVMCModel_leverageFunction(swigCPtr, this);
    return (cPtr == 0) ? null : new LocalVolTermStructure(cPtr, true);
  }

}
