/* ----------------------------------------------------------------------------
 * This file was automatically generated by SWIG (http://www.swig.org).
 * Version 4.0.2
 *
 * Do not make changes to this file unless you know what you are doing--modify
 * the SWIG interface file instead.
 * ----------------------------------------------------------------------------- */

package org.quantlib;

public class Matrix {
  private transient long swigCPtr;
  protected transient boolean swigCMemOwn;

  protected Matrix(long cPtr, boolean cMemoryOwn) {
    swigCMemOwn = cMemoryOwn;
    swigCPtr = cPtr;
  }

  protected static long getCPtr(Matrix obj) {
    return (obj == null) ? 0 : obj.swigCPtr;
  }

  @SuppressWarnings("deprecation")
  protected void finalize() {
    delete();
  }

  public synchronized void delete() {
    if (swigCPtr != 0) {
      if (swigCMemOwn) {
        swigCMemOwn = false;
        QuantLibJNI.delete_Matrix(swigCPtr);
      }
      swigCPtr = 0;
    }
  }

  public Matrix() {
    this(QuantLibJNI.new_Matrix__SWIG_0(), true);
  }

  public Matrix(long rows, long columns, double fill) {
    this(QuantLibJNI.new_Matrix__SWIG_1(rows, columns, fill), true);
  }

  public Matrix(long rows, long columns) {
    this(QuantLibJNI.new_Matrix__SWIG_2(rows, columns), true);
  }

  public Matrix(Matrix arg0) {
    this(QuantLibJNI.new_Matrix__SWIG_3(Matrix.getCPtr(arg0), arg0), true);
  }

  public long rows() {
    return QuantLibJNI.Matrix_rows(swigCPtr, this);
  }

  public long columns() {
    return QuantLibJNI.Matrix_columns(swigCPtr, this);
  }

  public String toString() {
    return QuantLibJNI.Matrix_toString(swigCPtr, this);
  }

  public double get(long i, long j) {
    return QuantLibJNI.Matrix_get(swigCPtr, this, i, j);
  }

  public void set(long i, long j, double x) {
    QuantLibJNI.Matrix_set(swigCPtr, this, i, j, x);
  }

}
