//------------------------------------------------------------------------------
// <auto-generated />
//
// This file was automatically generated by SWIG (http://www.swig.org).
// Version 4.0.2
//
// Do not make changes to this file unless you know what you are doing--modify
// the SWIG interface file instead.
//------------------------------------------------------------------------------

namespace QuantLib {

class NQuantLibcPINVOKE {

  protected class SWIGExceptionHelper {

    public delegate void ExceptionDelegate(string message);
    public delegate void ExceptionArgumentDelegate(string message, string paramName);

    static ExceptionDelegate applicationDelegate = new ExceptionDelegate(SetPendingApplicationException);
    static ExceptionDelegate arithmeticDelegate = new ExceptionDelegate(SetPendingArithmeticException);
    static ExceptionDelegate divideByZeroDelegate = new ExceptionDelegate(SetPendingDivideByZeroException);
    static ExceptionDelegate indexOutOfRangeDelegate = new ExceptionDelegate(SetPendingIndexOutOfRangeException);
    static ExceptionDelegate invalidCastDelegate = new ExceptionDelegate(SetPendingInvalidCastException);
    static ExceptionDelegate invalidOperationDelegate = new ExceptionDelegate(SetPendingInvalidOperationException);
    static ExceptionDelegate ioDelegate = new ExceptionDelegate(SetPendingIOException);
    static ExceptionDelegate nullReferenceDelegate = new ExceptionDelegate(SetPendingNullReferenceException);
    static ExceptionDelegate outOfMemoryDelegate = new ExceptionDelegate(SetPendingOutOfMemoryException);
    static ExceptionDelegate overflowDelegate = new ExceptionDelegate(SetPendingOverflowException);
    static ExceptionDelegate systemDelegate = new ExceptionDelegate(SetPendingSystemException);

    static ExceptionArgumentDelegate argumentDelegate = new ExceptionArgumentDelegate(SetPendingArgumentException);
    static ExceptionArgumentDelegate argumentNullDelegate = new ExceptionArgumentDelegate(SetPendingArgumentNullException);
    static ExceptionArgumentDelegate argumentOutOfRangeDelegate = new ExceptionArgumentDelegate(SetPendingArgumentOutOfRangeException);

    [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="SWIGRegisterExceptionCallbacks_NQuantLibc")]
    public static extern void SWIGRegisterExceptionCallbacks_NQuantLibc(
                                ExceptionDelegate applicationDelegate,
                                ExceptionDelegate arithmeticDelegate,
                                ExceptionDelegate divideByZeroDelegate, 
                                ExceptionDelegate indexOutOfRangeDelegate, 
                                ExceptionDelegate invalidCastDelegate,
                                ExceptionDelegate invalidOperationDelegate,
                                ExceptionDelegate ioDelegate,
                                ExceptionDelegate nullReferenceDelegate,
                                ExceptionDelegate outOfMemoryDelegate, 
                                ExceptionDelegate overflowDelegate, 
                                ExceptionDelegate systemExceptionDelegate);

    [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="SWIGRegisterExceptionArgumentCallbacks_NQuantLibc")]
    public static extern void SWIGRegisterExceptionCallbacksArgument_NQuantLibc(
                                ExceptionArgumentDelegate argumentDelegate,
                                ExceptionArgumentDelegate argumentNullDelegate,
                                ExceptionArgumentDelegate argumentOutOfRangeDelegate);

    static void SetPendingApplicationException(string message) {
      SWIGPendingException.Set(new global::System.ApplicationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArithmeticException(string message) {
      SWIGPendingException.Set(new global::System.ArithmeticException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingDivideByZeroException(string message) {
      SWIGPendingException.Set(new global::System.DivideByZeroException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIndexOutOfRangeException(string message) {
      SWIGPendingException.Set(new global::System.IndexOutOfRangeException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidCastException(string message) {
      SWIGPendingException.Set(new global::System.InvalidCastException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingInvalidOperationException(string message) {
      SWIGPendingException.Set(new global::System.InvalidOperationException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingIOException(string message) {
      SWIGPendingException.Set(new global::System.IO.IOException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingNullReferenceException(string message) {
      SWIGPendingException.Set(new global::System.NullReferenceException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOutOfMemoryException(string message) {
      SWIGPendingException.Set(new global::System.OutOfMemoryException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingOverflowException(string message) {
      SWIGPendingException.Set(new global::System.OverflowException(message, SWIGPendingException.Retrieve()));
    }
    static void SetPendingSystemException(string message) {
      SWIGPendingException.Set(new global::System.SystemException(message, SWIGPendingException.Retrieve()));
    }

    static void SetPendingArgumentException(string message, string paramName) {
      SWIGPendingException.Set(new global::System.ArgumentException(message, paramName, SWIGPendingException.Retrieve()));
    }
    static void SetPendingArgumentNullException(string message, string paramName) {
      global::System.Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new global::System.ArgumentNullException(paramName, message));
    }
    static void SetPendingArgumentOutOfRangeException(string message, string paramName) {
      global::System.Exception e = SWIGPendingException.Retrieve();
      if (e != null) message = message + " Inner Exception: " + e.Message;
      SWIGPendingException.Set(new global::System.ArgumentOutOfRangeException(paramName, message));
    }

    static SWIGExceptionHelper() {
      SWIGRegisterExceptionCallbacks_NQuantLibc(
                                applicationDelegate,
                                arithmeticDelegate,
                                divideByZeroDelegate,
                                indexOutOfRangeDelegate,
                                invalidCastDelegate,
                                invalidOperationDelegate,
                                ioDelegate,
                                nullReferenceDelegate,
                                outOfMemoryDelegate,
                                overflowDelegate,
                                systemDelegate);

      SWIGRegisterExceptionCallbacksArgument_NQuantLibc(
                                argumentDelegate,
                                argumentNullDelegate,
                                argumentOutOfRangeDelegate);
    }
  }

  protected static SWIGExceptionHelper swigExceptionHelper = new SWIGExceptionHelper();

  public class SWIGPendingException {
    [global::System.ThreadStatic]
    private static global::System.Exception pendingException = null;
    private static int numExceptionsPending = 0;
    private static global::System.Object exceptionsLock = null;

    public static bool Pending {
      get {
        bool pending = false;
        if (numExceptionsPending > 0)
          if (pendingException != null)
            pending = true;
        return pending;
      } 
    }

    public static void Set(global::System.Exception e) {
      if (pendingException != null)
        throw new global::System.ApplicationException("FATAL: An earlier pending exception from unmanaged code was missed and thus not thrown (" + pendingException.ToString() + ")", e);
      pendingException = e;
      lock(exceptionsLock) {
        numExceptionsPending++;
      }
    }

    public static global::System.Exception Retrieve() {
      global::System.Exception e = null;
      if (numExceptionsPending > 0) {
        if (pendingException != null) {
          e = pendingException;
          pendingException = null;
          lock(exceptionsLock) {
            numExceptionsPending--;
          }
        }
      }
      return e;
    }

    static SWIGPendingException() {
      exceptionsLock = new global::System.Object();
    }
  }


  protected class SWIGStringHelper {

    public delegate string SWIGStringDelegate(string message);
    static SWIGStringDelegate stringDelegate = new SWIGStringDelegate(CreateString);

    [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="SWIGRegisterStringCallback_NQuantLibc")]
    public static extern void SWIGRegisterStringCallback_NQuantLibc(SWIGStringDelegate stringDelegate);

    static string CreateString(string cString) {
      return cString;
    }

    static SWIGStringHelper() {
      SWIGRegisterStringCallback_NQuantLibc(stringDelegate);
    }
  }

  static protected SWIGStringHelper swigStringHelper = new SWIGStringHelper();


  static NQuantLibcPINVOKE() {
  }


  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Period__SWIG_0")]
  public static extern global::System.IntPtr new_Period__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Period__SWIG_1")]
  public static extern global::System.IntPtr new_Period__SWIG_1(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Period__SWIG_2")]
  public static extern global::System.IntPtr new_Period__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Period_length")]
  public static extern int Period_length(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Period_units")]
  public static extern int Period_units(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Period_frequency")]
  public static extern int Period_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Period__SWIG_3")]
  public static extern global::System.IntPtr new_Period__SWIG_3(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Period___str__")]
  public static extern string Period___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Period___repr__")]
  public static extern string Period___repr__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Period")]
  public static extern void delete_Period(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Clear")]
  public static extern void PeriodVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Add")]
  public static extern void PeriodVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_size")]
  public static extern uint PeriodVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_capacity")]
  public static extern uint PeriodVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_reserve")]
  public static extern void PeriodVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PeriodVector__SWIG_0")]
  public static extern global::System.IntPtr new_PeriodVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PeriodVector__SWIG_1")]
  public static extern global::System.IntPtr new_PeriodVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PeriodVector__SWIG_2")]
  public static extern global::System.IntPtr new_PeriodVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_getitemcopy")]
  public static extern global::System.IntPtr PeriodVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_getitem")]
  public static extern global::System.IntPtr PeriodVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_setitem")]
  public static extern void PeriodVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_AddRange")]
  public static extern void PeriodVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_GetRange")]
  public static extern global::System.IntPtr PeriodVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Insert")]
  public static extern void PeriodVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_InsertRange")]
  public static extern void PeriodVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_RemoveAt")]
  public static extern void PeriodVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_RemoveRange")]
  public static extern void PeriodVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Repeat")]
  public static extern global::System.IntPtr PeriodVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Reverse__SWIG_0")]
  public static extern void PeriodVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_Reverse__SWIG_1")]
  public static extern void PeriodVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodVector_SetRange")]
  public static extern void PeriodVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PeriodVector")]
  public static extern void delete_PeriodVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_0")]
  public static extern global::System.IntPtr new_Date__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_1")]
  public static extern global::System.IntPtr new_Date__SWIG_1(int jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_2")]
  public static extern global::System.IntPtr new_Date__SWIG_2(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_3")]
  public static extern global::System.IntPtr new_Date__SWIG_3(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_4")]
  public static extern global::System.IntPtr new_Date__SWIG_4(int jarg1, int jarg2, int jarg3, int jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_5")]
  public static extern global::System.IntPtr new_Date__SWIG_5(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_weekday")]
  public static extern int Date_weekday(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_dayOfMonth")]
  public static extern int Date_dayOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_dayOfYear")]
  public static extern int Date_dayOfYear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_month")]
  public static extern int Date_month(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_year")]
  public static extern int Date_year(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_hours")]
  public static extern int Date_hours(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_minutes")]
  public static extern int Date_minutes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_seconds")]
  public static extern int Date_seconds(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_milliseconds")]
  public static extern int Date_milliseconds(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_microseconds")]
  public static extern int Date_microseconds(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_fractionOfDay")]
  public static extern double Date_fractionOfDay(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_fractionOfSecond")]
  public static extern double Date_fractionOfSecond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_serialNumber")]
  public static extern int Date_serialNumber(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_isLeap")]
  public static extern bool Date_isLeap(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_minDate")]
  public static extern global::System.IntPtr Date_minDate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_maxDate")]
  public static extern global::System.IntPtr Date_maxDate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_todaysDate")]
  public static extern global::System.IntPtr Date_todaysDate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_localDateTime")]
  public static extern global::System.IntPtr Date_localDateTime();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_universalDateTime")]
  public static extern global::System.IntPtr Date_universalDateTime();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_endOfMonth")]
  public static extern global::System.IntPtr Date_endOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_isEndOfMonth")]
  public static extern bool Date_isEndOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_nextWeekday")]
  public static extern global::System.IntPtr Date_nextWeekday(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_nthWeekday")]
  public static extern global::System.IntPtr Date_nthWeekday(uint jarg1, int jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_Add__SWIG_0")]
  public static extern global::System.IntPtr Date_Add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_Subtract__SWIG_0")]
  public static extern global::System.IntPtr Date_Subtract__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_Add__SWIG_1")]
  public static extern global::System.IntPtr Date_Add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_Subtract__SWIG_1")]
  public static extern global::System.IntPtr Date_Subtract__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Date__SWIG_6")]
  public static extern global::System.IntPtr new_Date__SWIG_6(string jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_weekdayNumber")]
  public static extern int Date_weekdayNumber(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date___str__")]
  public static extern string Date___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date___repr__")]
  public static extern string Date___repr__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Date_ISO")]
  public static extern string Date_ISO(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Date")]
  public static extern void delete_Date(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateParser_parseFormatted")]
  public static extern global::System.IntPtr DateParser_parseFormatted(string jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateParser_parseISO")]
  public static extern global::System.IntPtr DateParser_parseISO(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateParser_parse")]
  public static extern global::System.IntPtr DateParser_parse(string jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DateParser")]
  public static extern global::System.IntPtr new_DateParser();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DateParser")]
  public static extern void delete_DateParser(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PeriodParser_parse")]
  public static extern global::System.IntPtr PeriodParser_parse(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PeriodParser")]
  public static extern global::System.IntPtr new_PeriodParser();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PeriodParser")]
  public static extern void delete_PeriodParser(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Clear")]
  public static extern void DateVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Add")]
  public static extern void DateVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_size")]
  public static extern uint DateVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_capacity")]
  public static extern uint DateVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_reserve")]
  public static extern void DateVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DateVector__SWIG_0")]
  public static extern global::System.IntPtr new_DateVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DateVector__SWIG_1")]
  public static extern global::System.IntPtr new_DateVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DateVector__SWIG_2")]
  public static extern global::System.IntPtr new_DateVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_getitemcopy")]
  public static extern global::System.IntPtr DateVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_getitem")]
  public static extern global::System.IntPtr DateVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_setitem")]
  public static extern void DateVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_AddRange")]
  public static extern void DateVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_GetRange")]
  public static extern global::System.IntPtr DateVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Insert")]
  public static extern void DateVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_InsertRange")]
  public static extern void DateVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_RemoveAt")]
  public static extern void DateVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_RemoveRange")]
  public static extern void DateVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Repeat")]
  public static extern global::System.IntPtr DateVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Reverse__SWIG_0")]
  public static extern void DateVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_Reverse__SWIG_1")]
  public static extern void DateVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DateVector_SetRange")]
  public static extern void DateVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DateVector")]
  public static extern void delete_DateVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_daysBetween")]
  public static extern double daysBetween(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_isIMMdate__SWIG_0")]
  public static extern bool IMM_isIMMdate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_isIMMdate__SWIG_1")]
  public static extern bool IMM_isIMMdate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_isIMMcode__SWIG_0")]
  public static extern bool IMM_isIMMcode__SWIG_0(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_isIMMcode__SWIG_1")]
  public static extern bool IMM_isIMMcode__SWIG_1(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_code")]
  public static extern string IMM_code(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_date__SWIG_0")]
  public static extern global::System.IntPtr IMM_date__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_date__SWIG_1")]
  public static extern global::System.IntPtr IMM_date__SWIG_1(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_0")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_1")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_2")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_3")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_3(string jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_4")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_4(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextDate__SWIG_5")]
  public static extern global::System.IntPtr IMM_nextDate__SWIG_5(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_0")]
  public static extern string IMM_nextCode__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_1")]
  public static extern string IMM_nextCode__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_2")]
  public static extern string IMM_nextCode__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_3")]
  public static extern string IMM_nextCode__SWIG_3(string jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_4")]
  public static extern string IMM_nextCode__SWIG_4(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IMM_nextCode__SWIG_5")]
  public static extern string IMM_nextCode__SWIG_5(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IMM")]
  public static extern global::System.IntPtr new_IMM();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IMM")]
  public static extern void delete_IMM(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_isASXdate__SWIG_0")]
  public static extern bool ASX_isASXdate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_isASXdate__SWIG_1")]
  public static extern bool ASX_isASXdate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_isASXcode__SWIG_0")]
  public static extern bool ASX_isASXcode__SWIG_0(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_isASXcode__SWIG_1")]
  public static extern bool ASX_isASXcode__SWIG_1(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_code")]
  public static extern string ASX_code(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_date__SWIG_0")]
  public static extern global::System.IntPtr ASX_date__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_date__SWIG_1")]
  public static extern global::System.IntPtr ASX_date__SWIG_1(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_0")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_1")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_2")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_3")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_3(string jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_4")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_4(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextDate__SWIG_5")]
  public static extern global::System.IntPtr ASX_nextDate__SWIG_5(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_0")]
  public static extern string ASX_nextCode__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_1")]
  public static extern string ASX_nextCode__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_2")]
  public static extern string ASX_nextCode__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_3")]
  public static extern string ASX_nextCode__SWIG_3(string jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_4")]
  public static extern string ASX_nextCode__SWIG_4(string jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ASX_nextCode__SWIG_5")]
  public static extern string ASX_nextCode__SWIG_5(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ASX")]
  public static extern global::System.IntPtr new_ASX();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ASX")]
  public static extern void delete_ASX(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Clear")]
  public static extern void IntVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Add")]
  public static extern void IntVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_size")]
  public static extern uint IntVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_capacity")]
  public static extern uint IntVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_reserve")]
  public static extern void IntVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntVector__SWIG_0")]
  public static extern global::System.IntPtr new_IntVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntVector__SWIG_1")]
  public static extern global::System.IntPtr new_IntVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntVector__SWIG_2")]
  public static extern global::System.IntPtr new_IntVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_getitemcopy")]
  public static extern int IntVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_getitem")]
  public static extern int IntVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_setitem")]
  public static extern void IntVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_AddRange")]
  public static extern void IntVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_GetRange")]
  public static extern global::System.IntPtr IntVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Insert")]
  public static extern void IntVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_InsertRange")]
  public static extern void IntVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_RemoveAt")]
  public static extern void IntVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_RemoveRange")]
  public static extern void IntVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Repeat")]
  public static extern global::System.IntPtr IntVector_Repeat(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Reverse__SWIG_0")]
  public static extern void IntVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Reverse__SWIG_1")]
  public static extern void IntVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_SetRange")]
  public static extern void IntVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Contains")]
  public static extern bool IntVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_IndexOf")]
  public static extern int IntVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_LastIndexOf")]
  public static extern int IntVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntVector_Remove")]
  public static extern bool IntVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntVector")]
  public static extern void delete_IntVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Clear")]
  public static extern void UnsignedIntVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Add")]
  public static extern void UnsignedIntVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_size")]
  public static extern uint UnsignedIntVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_capacity")]
  public static extern uint UnsignedIntVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_reserve")]
  public static extern void UnsignedIntVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnsignedIntVector__SWIG_0")]
  public static extern global::System.IntPtr new_UnsignedIntVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnsignedIntVector__SWIG_1")]
  public static extern global::System.IntPtr new_UnsignedIntVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnsignedIntVector__SWIG_2")]
  public static extern global::System.IntPtr new_UnsignedIntVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_getitemcopy")]
  public static extern uint UnsignedIntVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_getitem")]
  public static extern uint UnsignedIntVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_setitem")]
  public static extern void UnsignedIntVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_AddRange")]
  public static extern void UnsignedIntVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_GetRange")]
  public static extern global::System.IntPtr UnsignedIntVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Insert")]
  public static extern void UnsignedIntVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_InsertRange")]
  public static extern void UnsignedIntVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_RemoveAt")]
  public static extern void UnsignedIntVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_RemoveRange")]
  public static extern void UnsignedIntVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Repeat")]
  public static extern global::System.IntPtr UnsignedIntVector_Repeat(uint jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Reverse__SWIG_0")]
  public static extern void UnsignedIntVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Reverse__SWIG_1")]
  public static extern void UnsignedIntVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_SetRange")]
  public static extern void UnsignedIntVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Contains")]
  public static extern bool UnsignedIntVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_IndexOf")]
  public static extern int UnsignedIntVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_LastIndexOf")]
  public static extern int UnsignedIntVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnsignedIntVector_Remove")]
  public static extern bool UnsignedIntVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UnsignedIntVector")]
  public static extern void delete_UnsignedIntVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Clear")]
  public static extern void DoubleVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Add")]
  public static extern void DoubleVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_size")]
  public static extern uint DoubleVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_capacity")]
  public static extern uint DoubleVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_reserve")]
  public static extern void DoubleVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoubleVector__SWIG_0")]
  public static extern global::System.IntPtr new_DoubleVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoubleVector__SWIG_1")]
  public static extern global::System.IntPtr new_DoubleVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoubleVector__SWIG_2")]
  public static extern global::System.IntPtr new_DoubleVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_getitemcopy")]
  public static extern double DoubleVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_getitem")]
  public static extern double DoubleVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_setitem")]
  public static extern void DoubleVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_AddRange")]
  public static extern void DoubleVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_GetRange")]
  public static extern global::System.IntPtr DoubleVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Insert")]
  public static extern void DoubleVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_InsertRange")]
  public static extern void DoubleVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_RemoveAt")]
  public static extern void DoubleVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_RemoveRange")]
  public static extern void DoubleVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Repeat")]
  public static extern global::System.IntPtr DoubleVector_Repeat(double jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Reverse__SWIG_0")]
  public static extern void DoubleVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Reverse__SWIG_1")]
  public static extern void DoubleVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_SetRange")]
  public static extern void DoubleVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Contains")]
  public static extern bool DoubleVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_IndexOf")]
  public static extern int DoubleVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_LastIndexOf")]
  public static extern int DoubleVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleVector_Remove")]
  public static extern bool DoubleVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DoubleVector")]
  public static extern void delete_DoubleVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Clear")]
  public static extern void StrVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Add")]
  public static extern void StrVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_size")]
  public static extern uint StrVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_capacity")]
  public static extern uint StrVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_reserve")]
  public static extern void StrVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StrVector__SWIG_0")]
  public static extern global::System.IntPtr new_StrVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StrVector__SWIG_1")]
  public static extern global::System.IntPtr new_StrVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StrVector__SWIG_2")]
  public static extern global::System.IntPtr new_StrVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_getitemcopy")]
  public static extern string StrVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_getitem")]
  public static extern string StrVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_setitem")]
  public static extern void StrVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_AddRange")]
  public static extern void StrVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_GetRange")]
  public static extern global::System.IntPtr StrVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Insert")]
  public static extern void StrVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, string jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_InsertRange")]
  public static extern void StrVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_RemoveAt")]
  public static extern void StrVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_RemoveRange")]
  public static extern void StrVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Repeat")]
  public static extern global::System.IntPtr StrVector_Repeat(string jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Reverse__SWIG_0")]
  public static extern void StrVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Reverse__SWIG_1")]
  public static extern void StrVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_SetRange")]
  public static extern void StrVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Contains")]
  public static extern bool StrVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_IndexOf")]
  public static extern int StrVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_LastIndexOf")]
  public static extern int StrVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrVector_Remove")]
  public static extern bool StrVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StrVector")]
  public static extern void delete_StrVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Clear")]
  public static extern void BoolVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Add")]
  public static extern void BoolVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_size")]
  public static extern uint BoolVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_capacity")]
  public static extern uint BoolVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_reserve")]
  public static extern void BoolVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoolVector__SWIG_0")]
  public static extern global::System.IntPtr new_BoolVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoolVector__SWIG_1")]
  public static extern global::System.IntPtr new_BoolVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoolVector__SWIG_2")]
  public static extern global::System.IntPtr new_BoolVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_getitemcopy")]
  public static extern bool BoolVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_getitem")]
  public static extern bool BoolVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_setitem")]
  public static extern void BoolVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_AddRange")]
  public static extern void BoolVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_GetRange")]
  public static extern global::System.IntPtr BoolVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Insert")]
  public static extern void BoolVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_InsertRange")]
  public static extern void BoolVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_RemoveAt")]
  public static extern void BoolVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_RemoveRange")]
  public static extern void BoolVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Repeat")]
  public static extern global::System.IntPtr BoolVector_Repeat(bool jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Reverse__SWIG_0")]
  public static extern void BoolVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Reverse__SWIG_1")]
  public static extern void BoolVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_SetRange")]
  public static extern void BoolVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Contains")]
  public static extern bool BoolVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_IndexOf")]
  public static extern int BoolVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_LastIndexOf")]
  public static extern int BoolVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoolVector_Remove")]
  public static extern bool BoolVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BoolVector")]
  public static extern void delete_BoolVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePair__SWIG_0")]
  public static extern global::System.IntPtr new_DoublePair__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePair__SWIG_1")]
  public static extern global::System.IntPtr new_DoublePair__SWIG_1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePair__SWIG_2")]
  public static extern global::System.IntPtr new_DoublePair__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePair_first_set")]
  public static extern void DoublePair_first_set(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePair_first_get")]
  public static extern double DoublePair_first_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePair_second_set")]
  public static extern void DoublePair_second_set(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePair_second_get")]
  public static extern double DoublePair_second_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DoublePair")]
  public static extern void delete_DoublePair(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Clear")]
  public static extern void DoublePairVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Add")]
  public static extern void DoublePairVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_size")]
  public static extern uint DoublePairVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_capacity")]
  public static extern uint DoublePairVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_reserve")]
  public static extern void DoublePairVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePairVector__SWIG_0")]
  public static extern global::System.IntPtr new_DoublePairVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePairVector__SWIG_1")]
  public static extern global::System.IntPtr new_DoublePairVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoublePairVector__SWIG_2")]
  public static extern global::System.IntPtr new_DoublePairVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_getitemcopy")]
  public static extern global::System.IntPtr DoublePairVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_getitem")]
  public static extern global::System.IntPtr DoublePairVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_setitem")]
  public static extern void DoublePairVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_AddRange")]
  public static extern void DoublePairVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_GetRange")]
  public static extern global::System.IntPtr DoublePairVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Insert")]
  public static extern void DoublePairVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_InsertRange")]
  public static extern void DoublePairVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_RemoveAt")]
  public static extern void DoublePairVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_RemoveRange")]
  public static extern void DoublePairVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Repeat")]
  public static extern global::System.IntPtr DoublePairVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Reverse__SWIG_0")]
  public static extern void DoublePairVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_Reverse__SWIG_1")]
  public static extern void DoublePairVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoublePairVector_SetRange")]
  public static extern void DoublePairVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DoublePairVector")]
  public static extern void delete_DoublePairVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PairDoubleVector__SWIG_0")]
  public static extern global::System.IntPtr new_PairDoubleVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PairDoubleVector__SWIG_1")]
  public static extern global::System.IntPtr new_PairDoubleVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PairDoubleVector__SWIG_2")]
  public static extern global::System.IntPtr new_PairDoubleVector__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PairDoubleVector_first_set")]
  public static extern void PairDoubleVector_first_set(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PairDoubleVector_first_get")]
  public static extern global::System.IntPtr PairDoubleVector_first_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PairDoubleVector_second_set")]
  public static extern void PairDoubleVector_second_set(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PairDoubleVector_second_get")]
  public static extern global::System.IntPtr PairDoubleVector_second_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PairDoubleVector")]
  public static extern void delete_PairDoubleVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodePair__SWIG_0")]
  public static extern global::System.IntPtr new_NodePair__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodePair__SWIG_1")]
  public static extern global::System.IntPtr new_NodePair__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodePair__SWIG_2")]
  public static extern global::System.IntPtr new_NodePair__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodePair_first_set")]
  public static extern void NodePair_first_set(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodePair_first_get")]
  public static extern global::System.IntPtr NodePair_first_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodePair_second_set")]
  public static extern void NodePair_second_set(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodePair_second_get")]
  public static extern double NodePair_second_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NodePair")]
  public static extern void delete_NodePair(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Clear")]
  public static extern void NodeVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Add")]
  public static extern void NodeVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_size")]
  public static extern uint NodeVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_capacity")]
  public static extern uint NodeVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_reserve")]
  public static extern void NodeVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodeVector__SWIG_0")]
  public static extern global::System.IntPtr new_NodeVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodeVector__SWIG_1")]
  public static extern global::System.IntPtr new_NodeVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NodeVector__SWIG_2")]
  public static extern global::System.IntPtr new_NodeVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_getitemcopy")]
  public static extern global::System.IntPtr NodeVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_getitem")]
  public static extern global::System.IntPtr NodeVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_setitem")]
  public static extern void NodeVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_AddRange")]
  public static extern void NodeVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_GetRange")]
  public static extern global::System.IntPtr NodeVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Insert")]
  public static extern void NodeVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_InsertRange")]
  public static extern void NodeVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_RemoveAt")]
  public static extern void NodeVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_RemoveRange")]
  public static extern void NodeVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Repeat")]
  public static extern global::System.IntPtr NodeVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Reverse__SWIG_0")]
  public static extern void NodeVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Reverse__SWIG_1")]
  public static extern void NodeVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_SetRange")]
  public static extern void NodeVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Contains")]
  public static extern bool NodeVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_IndexOf")]
  public static extern int NodeVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_LastIndexOf")]
  public static extern int NodeVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NodeVector_Remove")]
  public static extern bool NodeVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NodeVector")]
  public static extern void delete_NodeVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Exercise")]
  public static extern global::System.IntPtr new_Exercise(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Exercise_type")]
  public static extern int Exercise_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Exercise_date")]
  public static extern global::System.IntPtr Exercise_date(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Exercise_dateAt")]
  public static extern global::System.IntPtr Exercise_dateAt(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Exercise_dates")]
  public static extern global::System.IntPtr Exercise_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Exercise_lastDate")]
  public static extern global::System.IntPtr Exercise_lastDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Exercise")]
  public static extern void delete_Exercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuropeanExercise")]
  public static extern global::System.IntPtr new_EuropeanExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuropeanExercise")]
  public static extern void delete_EuropeanExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmericanExercise__SWIG_0")]
  public static extern global::System.IntPtr new_AmericanExercise__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmericanExercise__SWIG_1")]
  public static extern global::System.IntPtr new_AmericanExercise__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AmericanExercise")]
  public static extern void delete_AmericanExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BermudanExercise__SWIG_0")]
  public static extern global::System.IntPtr new_BermudanExercise__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BermudanExercise__SWIG_1")]
  public static extern global::System.IntPtr new_BermudanExercise__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BermudanExercise")]
  public static extern void delete_BermudanExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RebatedExercise__SWIG_0")]
  public static extern global::System.IntPtr new_RebatedExercise__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RebatedExercise__SWIG_1")]
  public static extern global::System.IntPtr new_RebatedExercise__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RebatedExercise__SWIG_2")]
  public static extern global::System.IntPtr new_RebatedExercise__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RebatedExercise__SWIG_3")]
  public static extern global::System.IntPtr new_RebatedExercise__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RebatedExercise")]
  public static extern void delete_RebatedExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwingExercise")]
  public static extern global::System.IntPtr new_SwingExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwingExercise")]
  public static extern void delete_SwingExercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Observable")]
  public static extern global::System.IntPtr new_Observable();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Observable")]
  public static extern void delete_Observable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QlArray__SWIG_0")]
  public static extern global::System.IntPtr new_QlArray__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QlArray__SWIG_1")]
  public static extern global::System.IntPtr new_QlArray__SWIG_1(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QlArray__SWIG_2")]
  public static extern global::System.IntPtr new_QlArray__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QlArray__SWIG_3")]
  public static extern global::System.IntPtr new_QlArray__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QlArray_size")]
  public static extern uint QlArray_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QlArray___str__")]
  public static extern string QlArray___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QlArray_get")]
  public static extern double QlArray_get(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QlArray_set")]
  public static extern void QlArray_set(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QlArray")]
  public static extern void delete_QlArray(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LexicographicalView_xSize")]
  public static extern uint LexicographicalView_xSize(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LexicographicalView_ySize")]
  public static extern uint LexicographicalView_ySize(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LexicographicalView")]
  public static extern global::System.IntPtr new_LexicographicalView(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LexicographicalView___str__")]
  public static extern string LexicographicalView___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LexicographicalView")]
  public static extern void delete_LexicographicalView(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Matrix__SWIG_0")]
  public static extern global::System.IntPtr new_Matrix__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Matrix__SWIG_1")]
  public static extern global::System.IntPtr new_Matrix__SWIG_1(uint jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Matrix__SWIG_2")]
  public static extern global::System.IntPtr new_Matrix__SWIG_2(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Matrix__SWIG_3")]
  public static extern global::System.IntPtr new_Matrix__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Matrix_rows")]
  public static extern uint Matrix_rows(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Matrix_columns")]
  public static extern uint Matrix_columns(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Matrix___str__")]
  public static extern string Matrix___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Matrix_get")]
  public static extern double Matrix_get(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Matrix_set")]
  public static extern void Matrix_set(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Matrix")]
  public static extern void delete_Matrix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SalvagingAlgorithm")]
  public static extern global::System.IntPtr new_SalvagingAlgorithm();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SalvagingAlgorithm")]
  public static extern void delete_SalvagingAlgorithm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_inverse")]
  public static extern global::System.IntPtr inverse(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_transpose")]
  public static extern global::System.IntPtr transpose(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_outerProduct")]
  public static extern global::System.IntPtr outerProduct(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_pseudoSqrt")]
  public static extern global::System.IntPtr pseudoSqrt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SVD")]
  public static extern global::System.IntPtr new_SVD(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SVD_U")]
  public static extern global::System.IntPtr SVD_U(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SVD_V")]
  public static extern global::System.IntPtr SVD_V(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SVD_S")]
  public static extern global::System.IntPtr SVD_S(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SVD_singularValues")]
  public static extern global::System.IntPtr SVD_singularValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SVD")]
  public static extern void delete_SVD(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MatrixMultiplicationDelegate")]
  public static extern void delete_MatrixMultiplicationDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MatrixMultiplicationDelegate_apply")]
  public static extern global::System.IntPtr MatrixMultiplicationDelegate_apply(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MatrixMultiplicationDelegate")]
  public static extern global::System.IntPtr new_MatrixMultiplicationDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BiCGstab_solve__SWIG_0")]
  public static extern global::System.IntPtr BiCGstab_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BiCGstab_solve__SWIG_1")]
  public static extern global::System.IntPtr BiCGstab_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BiCGstab__SWIG_0")]
  public static extern global::System.IntPtr new_BiCGstab__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BiCGstab__SWIG_1")]
  public static extern global::System.IntPtr new_BiCGstab__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BiCGstab")]
  public static extern void delete_BiCGstab(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GMRES_solve__SWIG_0")]
  public static extern global::System.IntPtr GMRES_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GMRES_solve__SWIG_1")]
  public static extern global::System.IntPtr GMRES_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GMRES_solveWithRestart__SWIG_0")]
  public static extern global::System.IntPtr GMRES_solveWithRestart__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GMRES_solveWithRestart__SWIG_1")]
  public static extern global::System.IntPtr GMRES_solveWithRestart__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GMRES__SWIG_0")]
  public static extern global::System.IntPtr new_GMRES__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GMRES__SWIG_1")]
  public static extern global::System.IntPtr new_GMRES__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GMRES")]
  public static extern void delete_GMRES(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_close__SWIG_0")]
  public static extern bool close__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_close__SWIG_1")]
  public static extern bool close__SWIG_1(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_close_enough__SWIG_0")]
  public static extern bool close_enough__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_close_enough__SWIG_1")]
  public static extern bool close_enough__SWIG_1(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnaryFunction")]
  public static extern global::System.IntPtr new_UnaryFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnaryFunction_call")]
  public static extern double UnaryFunction_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UnaryFunction")]
  public static extern void delete_UnaryFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UnaryFunctionDelegate")]
  public static extern void delete_UnaryFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnaryFunctionDelegate_value")]
  public static extern double UnaryFunctionDelegate_value(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnaryFunctionDelegate_valueSwigExplicitUnaryFunctionDelegate")]
  public static extern double UnaryFunctionDelegate_valueSwigExplicitUnaryFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnaryFunctionDelegate")]
  public static extern global::System.IntPtr new_UnaryFunctionDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnaryFunctionDelegate_director_connect")]
  public static extern void UnaryFunctionDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, UnaryFunctionDelegate.SwigDelegateUnaryFunctionDelegate_0 delegate0);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinaryFunction")]
  public static extern global::System.IntPtr new_BinaryFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinaryFunction_call")]
  public static extern double BinaryFunction_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinaryFunction")]
  public static extern void delete_BinaryFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinaryFunctionDelegate")]
  public static extern void delete_BinaryFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinaryFunctionDelegate_value")]
  public static extern double BinaryFunctionDelegate_value(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinaryFunctionDelegate_valueSwigExplicitBinaryFunctionDelegate")]
  public static extern double BinaryFunctionDelegate_valueSwigExplicitBinaryFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinaryFunctionDelegate")]
  public static extern global::System.IntPtr new_BinaryFunctionDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinaryFunctionDelegate_director_connect")]
  public static extern void BinaryFunctionDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, BinaryFunctionDelegate.SwigDelegateBinaryFunctionDelegate_0 delegate0);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DotNetCostFunction")]
  public static extern global::System.IntPtr new_DotNetCostFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DotNetCostFunction")]
  public static extern void delete_DotNetCostFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DotNetCostFunction_value")]
  public static extern double DotNetCostFunction_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DotNetCostFunction_values")]
  public static extern global::System.IntPtr DotNetCostFunction_values(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CostFunctionDelegate")]
  public static extern void delete_CostFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CostFunctionDelegate_value")]
  public static extern double CostFunctionDelegate_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CostFunctionDelegate_valueSwigExplicitCostFunctionDelegate")]
  public static extern double CostFunctionDelegate_valueSwigExplicitCostFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CostFunctionDelegate_values")]
  public static extern global::System.IntPtr CostFunctionDelegate_values(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CostFunctionDelegate_valuesSwigExplicitCostFunctionDelegate")]
  public static extern global::System.IntPtr CostFunctionDelegate_valuesSwigExplicitCostFunctionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CostFunctionDelegate")]
  public static extern global::System.IntPtr new_CostFunctionDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CostFunctionDelegate_director_connect")]
  public static extern void CostFunctionDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, CostFunctionDelegate.SwigDelegateCostFunctionDelegate_0 delegate0, CostFunctionDelegate.SwigDelegateCostFunctionDelegate_1 delegate1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Quote_value")]
  public static extern double Quote_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Quote_isValid")]
  public static extern bool Quote_isValid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Quote")]
  public static extern void delete_Quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandle__SWIG_0")]
  public static extern global::System.IntPtr new_QuoteHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandle__SWIG_1")]
  public static extern global::System.IntPtr new_QuoteHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle___deref__")]
  public static extern global::System.IntPtr QuoteHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle_currentLink")]
  public static extern global::System.IntPtr QuoteHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle_empty")]
  public static extern bool QuoteHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle_asObservable")]
  public static extern global::System.IntPtr QuoteHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuoteHandle")]
  public static extern void delete_QuoteHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle_value")]
  public static extern double QuoteHandle_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandle_isValid")]
  public static extern bool QuoteHandle_isValid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandle_linkTo")]
  public static extern void RelinkableQuoteHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandle_reset")]
  public static extern void RelinkableQuoteHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableQuoteHandle")]
  public static extern void delete_RelinkableQuoteHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimpleQuote")]
  public static extern global::System.IntPtr new_SimpleQuote(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SimpleQuote_setValue")]
  public static extern void SimpleQuote_setValue(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SimpleQuote")]
  public static extern void delete_SimpleQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Clear")]
  public static extern void QuoteVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Add")]
  public static extern void QuoteVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_size")]
  public static extern uint QuoteVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_capacity")]
  public static extern uint QuoteVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_reserve")]
  public static extern void QuoteVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVector__SWIG_0")]
  public static extern global::System.IntPtr new_QuoteVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVector__SWIG_1")]
  public static extern global::System.IntPtr new_QuoteVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVector__SWIG_2")]
  public static extern global::System.IntPtr new_QuoteVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_getitemcopy")]
  public static extern global::System.IntPtr QuoteVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_getitem")]
  public static extern global::System.IntPtr QuoteVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_setitem")]
  public static extern void QuoteVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_AddRange")]
  public static extern void QuoteVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_GetRange")]
  public static extern global::System.IntPtr QuoteVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Insert")]
  public static extern void QuoteVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_InsertRange")]
  public static extern void QuoteVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_RemoveAt")]
  public static extern void QuoteVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_RemoveRange")]
  public static extern void QuoteVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Repeat")]
  public static extern global::System.IntPtr QuoteVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Reverse__SWIG_0")]
  public static extern void QuoteVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Reverse__SWIG_1")]
  public static extern void QuoteVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_SetRange")]
  public static extern void QuoteVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Contains")]
  public static extern bool QuoteVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_IndexOf")]
  public static extern int QuoteVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_LastIndexOf")]
  public static extern int QuoteVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVector_Remove")]
  public static extern bool QuoteVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuoteVector")]
  public static extern void delete_QuoteVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Clear")]
  public static extern void QuoteVectorVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Add")]
  public static extern void QuoteVectorVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_size")]
  public static extern uint QuoteVectorVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_capacity")]
  public static extern uint QuoteVectorVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_reserve")]
  public static extern void QuoteVectorVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVectorVector__SWIG_0")]
  public static extern global::System.IntPtr new_QuoteVectorVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVectorVector__SWIG_1")]
  public static extern global::System.IntPtr new_QuoteVectorVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteVectorVector__SWIG_2")]
  public static extern global::System.IntPtr new_QuoteVectorVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_getitemcopy")]
  public static extern global::System.IntPtr QuoteVectorVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_getitem")]
  public static extern global::System.IntPtr QuoteVectorVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_setitem")]
  public static extern void QuoteVectorVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_AddRange")]
  public static extern void QuoteVectorVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_GetRange")]
  public static extern global::System.IntPtr QuoteVectorVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Insert")]
  public static extern void QuoteVectorVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_InsertRange")]
  public static extern void QuoteVectorVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_RemoveAt")]
  public static extern void QuoteVectorVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_RemoveRange")]
  public static extern void QuoteVectorVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Repeat")]
  public static extern global::System.IntPtr QuoteVectorVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Reverse__SWIG_0")]
  public static extern void QuoteVectorVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_Reverse__SWIG_1")]
  public static extern void QuoteVectorVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteVectorVector_SetRange")]
  public static extern void QuoteVectorVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuoteVectorVector")]
  public static extern void delete_QuoteVectorVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Clear")]
  public static extern void QuoteHandleVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Add")]
  public static extern void QuoteHandleVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_size")]
  public static extern uint QuoteHandleVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_capacity")]
  public static extern uint QuoteHandleVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_reserve")]
  public static extern void QuoteHandleVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVector__SWIG_0")]
  public static extern global::System.IntPtr new_QuoteHandleVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVector__SWIG_1")]
  public static extern global::System.IntPtr new_QuoteHandleVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVector__SWIG_2")]
  public static extern global::System.IntPtr new_QuoteHandleVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_getitemcopy")]
  public static extern global::System.IntPtr QuoteHandleVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_getitem")]
  public static extern global::System.IntPtr QuoteHandleVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_setitem")]
  public static extern void QuoteHandleVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_AddRange")]
  public static extern void QuoteHandleVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_GetRange")]
  public static extern global::System.IntPtr QuoteHandleVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Insert")]
  public static extern void QuoteHandleVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_InsertRange")]
  public static extern void QuoteHandleVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_RemoveAt")]
  public static extern void QuoteHandleVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_RemoveRange")]
  public static extern void QuoteHandleVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Repeat")]
  public static extern global::System.IntPtr QuoteHandleVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Reverse__SWIG_0")]
  public static extern void QuoteHandleVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Reverse__SWIG_1")]
  public static extern void QuoteHandleVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_SetRange")]
  public static extern void QuoteHandleVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Contains")]
  public static extern bool QuoteHandleVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_IndexOf")]
  public static extern int QuoteHandleVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_LastIndexOf")]
  public static extern int QuoteHandleVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVector_Remove")]
  public static extern bool QuoteHandleVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuoteHandleVector")]
  public static extern void delete_QuoteHandleVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Clear")]
  public static extern void QuoteHandleVectorVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Add")]
  public static extern void QuoteHandleVectorVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_size")]
  public static extern uint QuoteHandleVectorVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_capacity")]
  public static extern uint QuoteHandleVectorVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_reserve")]
  public static extern void QuoteHandleVectorVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVectorVector__SWIG_0")]
  public static extern global::System.IntPtr new_QuoteHandleVectorVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVectorVector__SWIG_1")]
  public static extern global::System.IntPtr new_QuoteHandleVectorVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuoteHandleVectorVector__SWIG_2")]
  public static extern global::System.IntPtr new_QuoteHandleVectorVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_getitemcopy")]
  public static extern global::System.IntPtr QuoteHandleVectorVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_getitem")]
  public static extern global::System.IntPtr QuoteHandleVectorVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_setitem")]
  public static extern void QuoteHandleVectorVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_AddRange")]
  public static extern void QuoteHandleVectorVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_GetRange")]
  public static extern global::System.IntPtr QuoteHandleVectorVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Insert")]
  public static extern void QuoteHandleVectorVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_InsertRange")]
  public static extern void QuoteHandleVectorVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_RemoveAt")]
  public static extern void QuoteHandleVectorVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_RemoveRange")]
  public static extern void QuoteHandleVectorVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Repeat")]
  public static extern global::System.IntPtr QuoteHandleVectorVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Reverse__SWIG_0")]
  public static extern void QuoteHandleVectorVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_Reverse__SWIG_1")]
  public static extern void QuoteHandleVectorVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuoteHandleVectorVector_SetRange")]
  public static extern void QuoteHandleVectorVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuoteHandleVectorVector")]
  public static extern void delete_QuoteHandleVectorVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Clear")]
  public static extern void RelinkableQuoteHandleVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Add")]
  public static extern void RelinkableQuoteHandleVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_size")]
  public static extern uint RelinkableQuoteHandleVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_capacity")]
  public static extern uint RelinkableQuoteHandleVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_reserve")]
  public static extern void RelinkableQuoteHandleVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVector__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVector__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVector__SWIG_2")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_getitemcopy")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_getitem")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_setitem")]
  public static extern void RelinkableQuoteHandleVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_AddRange")]
  public static extern void RelinkableQuoteHandleVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_GetRange")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Insert")]
  public static extern void RelinkableQuoteHandleVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_InsertRange")]
  public static extern void RelinkableQuoteHandleVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_RemoveAt")]
  public static extern void RelinkableQuoteHandleVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_RemoveRange")]
  public static extern void RelinkableQuoteHandleVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Repeat")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Reverse__SWIG_0")]
  public static extern void RelinkableQuoteHandleVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Reverse__SWIG_1")]
  public static extern void RelinkableQuoteHandleVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_SetRange")]
  public static extern void RelinkableQuoteHandleVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Contains")]
  public static extern bool RelinkableQuoteHandleVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_IndexOf")]
  public static extern int RelinkableQuoteHandleVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_LastIndexOf")]
  public static extern int RelinkableQuoteHandleVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVector_Remove")]
  public static extern bool RelinkableQuoteHandleVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableQuoteHandleVector")]
  public static extern void delete_RelinkableQuoteHandleVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Clear")]
  public static extern void RelinkableQuoteHandleVectorVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Add")]
  public static extern void RelinkableQuoteHandleVectorVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_size")]
  public static extern uint RelinkableQuoteHandleVectorVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_capacity")]
  public static extern uint RelinkableQuoteHandleVectorVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_reserve")]
  public static extern void RelinkableQuoteHandleVectorVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVectorVector__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVectorVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVectorVector__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVectorVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableQuoteHandleVectorVector__SWIG_2")]
  public static extern global::System.IntPtr new_RelinkableQuoteHandleVectorVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_getitemcopy")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVectorVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_getitem")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVectorVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_setitem")]
  public static extern void RelinkableQuoteHandleVectorVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_AddRange")]
  public static extern void RelinkableQuoteHandleVectorVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_GetRange")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVectorVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Insert")]
  public static extern void RelinkableQuoteHandleVectorVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_InsertRange")]
  public static extern void RelinkableQuoteHandleVectorVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_RemoveAt")]
  public static extern void RelinkableQuoteHandleVectorVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_RemoveRange")]
  public static extern void RelinkableQuoteHandleVectorVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Repeat")]
  public static extern global::System.IntPtr RelinkableQuoteHandleVectorVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Reverse__SWIG_0")]
  public static extern void RelinkableQuoteHandleVectorVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_Reverse__SWIG_1")]
  public static extern void RelinkableQuoteHandleVectorVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandleVectorVector_SetRange")]
  public static extern void RelinkableQuoteHandleVectorVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableQuoteHandleVectorVector")]
  public static extern void delete_RelinkableQuoteHandleVectorVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_isWeekend")]
  public static extern bool Calendar_isWeekend(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_endOfMonth")]
  public static extern global::System.IntPtr Calendar_endOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_isBusinessDay")]
  public static extern bool Calendar_isBusinessDay(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_isHoliday")]
  public static extern bool Calendar_isHoliday(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_isEndOfMonth")]
  public static extern bool Calendar_isEndOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_addHoliday")]
  public static extern void Calendar_addHoliday(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_removeHoliday")]
  public static extern void Calendar_removeHoliday(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_adjust__SWIG_0")]
  public static extern global::System.IntPtr Calendar_adjust__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_adjust__SWIG_1")]
  public static extern global::System.IntPtr Calendar_adjust__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_0")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_1")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_2")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_3")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_4")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_advance__SWIG_5")]
  public static extern global::System.IntPtr Calendar_advance__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_businessDaysBetween__SWIG_0")]
  public static extern int Calendar_businessDaysBetween__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_businessDaysBetween__SWIG_1")]
  public static extern int Calendar_businessDaysBetween__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_businessDaysBetween__SWIG_2")]
  public static extern int Calendar_businessDaysBetween__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_holidayList__SWIG_0")]
  public static extern global::System.IntPtr Calendar_holidayList__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_holidayList__SWIG_1")]
  public static extern global::System.IntPtr Calendar_holidayList__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_businessDayList")]
  public static extern global::System.IntPtr Calendar_businessDayList(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar_name")]
  public static extern string Calendar_name(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Calendar___str__")]
  public static extern string Calendar___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Calendar")]
  public static extern void delete_Calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Argentina__SWIG_0")]
  public static extern global::System.IntPtr new_Argentina__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Argentina__SWIG_1")]
  public static extern global::System.IntPtr new_Argentina__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Argentina")]
  public static extern void delete_Argentina(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Australia")]
  public static extern global::System.IntPtr new_Australia();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Australia")]
  public static extern void delete_Australia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Brazil__SWIG_0")]
  public static extern global::System.IntPtr new_Brazil__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Brazil__SWIG_1")]
  public static extern global::System.IntPtr new_Brazil__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Brazil")]
  public static extern void delete_Brazil(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Canada__SWIG_0")]
  public static extern global::System.IntPtr new_Canada__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Canada__SWIG_1")]
  public static extern global::System.IntPtr new_Canada__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Canada")]
  public static extern void delete_Canada(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_China__SWIG_0")]
  public static extern global::System.IntPtr new_China__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_China__SWIG_1")]
  public static extern global::System.IntPtr new_China__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_China")]
  public static extern void delete_China(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CzechRepublic__SWIG_0")]
  public static extern global::System.IntPtr new_CzechRepublic__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CzechRepublic__SWIG_1")]
  public static extern global::System.IntPtr new_CzechRepublic__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CzechRepublic")]
  public static extern void delete_CzechRepublic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Denmark")]
  public static extern global::System.IntPtr new_Denmark();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Denmark")]
  public static extern void delete_Denmark(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Finland")]
  public static extern global::System.IntPtr new_Finland();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Finland")]
  public static extern void delete_Finland(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_France__SWIG_0")]
  public static extern global::System.IntPtr new_France__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_France__SWIG_1")]
  public static extern global::System.IntPtr new_France__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_France")]
  public static extern void delete_France(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Germany__SWIG_0")]
  public static extern global::System.IntPtr new_Germany__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Germany__SWIG_1")]
  public static extern global::System.IntPtr new_Germany__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Germany")]
  public static extern void delete_Germany(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HongKong__SWIG_0")]
  public static extern global::System.IntPtr new_HongKong__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HongKong__SWIG_1")]
  public static extern global::System.IntPtr new_HongKong__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HongKong")]
  public static extern void delete_HongKong(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Hungary")]
  public static extern global::System.IntPtr new_Hungary();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Hungary")]
  public static extern void delete_Hungary(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Iceland__SWIG_0")]
  public static extern global::System.IntPtr new_Iceland__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Iceland__SWIG_1")]
  public static extern global::System.IntPtr new_Iceland__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Iceland")]
  public static extern void delete_Iceland(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_India__SWIG_0")]
  public static extern global::System.IntPtr new_India__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_India__SWIG_1")]
  public static extern global::System.IntPtr new_India__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_India")]
  public static extern void delete_India(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Indonesia__SWIG_0")]
  public static extern global::System.IntPtr new_Indonesia__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Indonesia__SWIG_1")]
  public static extern global::System.IntPtr new_Indonesia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Indonesia")]
  public static extern void delete_Indonesia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Israel__SWIG_0")]
  public static extern global::System.IntPtr new_Israel__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Israel__SWIG_1")]
  public static extern global::System.IntPtr new_Israel__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Israel")]
  public static extern void delete_Israel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Italy__SWIG_0")]
  public static extern global::System.IntPtr new_Italy__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Italy__SWIG_1")]
  public static extern global::System.IntPtr new_Italy__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Italy")]
  public static extern void delete_Italy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Japan")]
  public static extern global::System.IntPtr new_Japan();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Japan")]
  public static extern void delete_Japan(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Mexico__SWIG_0")]
  public static extern global::System.IntPtr new_Mexico__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Mexico__SWIG_1")]
  public static extern global::System.IntPtr new_Mexico__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Mexico")]
  public static extern void delete_Mexico(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NewZealand")]
  public static extern global::System.IntPtr new_NewZealand();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NewZealand")]
  public static extern void delete_NewZealand(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Norway")]
  public static extern global::System.IntPtr new_Norway();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Norway")]
  public static extern void delete_Norway(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Poland")]
  public static extern global::System.IntPtr new_Poland();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Poland")]
  public static extern void delete_Poland(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Russia__SWIG_0")]
  public static extern global::System.IntPtr new_Russia__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Russia__SWIG_1")]
  public static extern global::System.IntPtr new_Russia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Russia")]
  public static extern void delete_Russia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Romania")]
  public static extern global::System.IntPtr new_Romania();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Romania")]
  public static extern void delete_Romania(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SaudiArabia__SWIG_0")]
  public static extern global::System.IntPtr new_SaudiArabia__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SaudiArabia__SWIG_1")]
  public static extern global::System.IntPtr new_SaudiArabia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SaudiArabia")]
  public static extern void delete_SaudiArabia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Singapore__SWIG_0")]
  public static extern global::System.IntPtr new_Singapore__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Singapore__SWIG_1")]
  public static extern global::System.IntPtr new_Singapore__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Singapore")]
  public static extern void delete_Singapore(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Slovakia__SWIG_0")]
  public static extern global::System.IntPtr new_Slovakia__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Slovakia__SWIG_1")]
  public static extern global::System.IntPtr new_Slovakia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Slovakia")]
  public static extern void delete_Slovakia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SouthAfrica")]
  public static extern global::System.IntPtr new_SouthAfrica();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SouthAfrica")]
  public static extern void delete_SouthAfrica(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SouthKorea__SWIG_0")]
  public static extern global::System.IntPtr new_SouthKorea__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SouthKorea__SWIG_1")]
  public static extern global::System.IntPtr new_SouthKorea__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SouthKorea")]
  public static extern void delete_SouthKorea(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Sweden")]
  public static extern global::System.IntPtr new_Sweden();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Sweden")]
  public static extern void delete_Sweden(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Switzerland")]
  public static extern global::System.IntPtr new_Switzerland();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Switzerland")]
  public static extern void delete_Switzerland(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Taiwan__SWIG_0")]
  public static extern global::System.IntPtr new_Taiwan__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Taiwan__SWIG_1")]
  public static extern global::System.IntPtr new_Taiwan__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Taiwan")]
  public static extern void delete_Taiwan(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TARGET")]
  public static extern global::System.IntPtr new_TARGET();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TARGET")]
  public static extern void delete_TARGET(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Thailand")]
  public static extern global::System.IntPtr new_Thailand();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Thailand")]
  public static extern void delete_Thailand(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Turkey")]
  public static extern global::System.IntPtr new_Turkey();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Turkey")]
  public static extern void delete_Turkey(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Ukraine__SWIG_0")]
  public static extern global::System.IntPtr new_Ukraine__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Ukraine__SWIG_1")]
  public static extern global::System.IntPtr new_Ukraine__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Ukraine")]
  public static extern void delete_Ukraine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnitedKingdom__SWIG_0")]
  public static extern global::System.IntPtr new_UnitedKingdom__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnitedKingdom__SWIG_1")]
  public static extern global::System.IntPtr new_UnitedKingdom__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UnitedKingdom")]
  public static extern void delete_UnitedKingdom(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnitedStates__SWIG_0")]
  public static extern global::System.IntPtr new_UnitedStates__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UnitedStates__SWIG_1")]
  public static extern global::System.IntPtr new_UnitedStates__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UnitedStates")]
  public static extern void delete_UnitedStates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NullCalendar")]
  public static extern global::System.IntPtr new_NullCalendar();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NullCalendar")]
  public static extern void delete_NullCalendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_WeekendsOnly")]
  public static extern global::System.IntPtr new_WeekendsOnly();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_WeekendsOnly")]
  public static extern void delete_WeekendsOnly(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_0")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_1")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_2")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_3")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_4")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JointCalendar__SWIG_5")]
  public static extern global::System.IntPtr new_JointCalendar__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JointCalendar")]
  public static extern void delete_JointCalendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BespokeCalendar")]
  public static extern global::System.IntPtr new_BespokeCalendar(string jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BespokeCalendar_addWeekend")]
  public static extern void BespokeCalendar_addWeekend(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BespokeCalendar")]
  public static extern void delete_BespokeCalendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_nullInt")]
  public static extern int nullInt();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_nullDouble")]
  public static extern double nullDouble();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter_dayCount")]
  public static extern int DayCounter_dayCount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter_yearFraction__SWIG_0")]
  public static extern double DayCounter_yearFraction__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter_yearFraction__SWIG_1")]
  public static extern double DayCounter_yearFraction__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter_yearFraction__SWIG_2")]
  public static extern double DayCounter_yearFraction__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter_name")]
  public static extern string DayCounter_name(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DayCounter___str__")]
  public static extern string DayCounter___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DayCounter")]
  public static extern void delete_DayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Actual360__SWIG_0")]
  public static extern global::System.IntPtr new_Actual360__SWIG_0(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Actual360__SWIG_1")]
  public static extern global::System.IntPtr new_Actual360__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Actual360")]
  public static extern void delete_Actual360(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Actual364")]
  public static extern global::System.IntPtr new_Actual364();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Actual364")]
  public static extern void delete_Actual364(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Actual365Fixed__SWIG_0")]
  public static extern global::System.IntPtr new_Actual365Fixed__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Actual365Fixed__SWIG_1")]
  public static extern global::System.IntPtr new_Actual365Fixed__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Actual365Fixed")]
  public static extern void delete_Actual365Fixed(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Thirty360__SWIG_0")]
  public static extern global::System.IntPtr new_Thirty360__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Thirty360__SWIG_1")]
  public static extern global::System.IntPtr new_Thirty360__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Thirty360")]
  public static extern void delete_Thirty360(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Thirty365")]
  public static extern global::System.IntPtr new_Thirty365();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Thirty365")]
  public static extern void delete_Thirty365(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ActualActual__SWIG_0")]
  public static extern global::System.IntPtr new_ActualActual__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ActualActual__SWIG_1")]
  public static extern global::System.IntPtr new_ActualActual__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ActualActual__SWIG_2")]
  public static extern global::System.IntPtr new_ActualActual__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ActualActual")]
  public static extern void delete_ActualActual(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OneDayCounter")]
  public static extern global::System.IntPtr new_OneDayCounter();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OneDayCounter")]
  public static extern void delete_OneDayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimpleDayCounter")]
  public static extern global::System.IntPtr new_SimpleDayCounter();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SimpleDayCounter")]
  public static extern void delete_SimpleDayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Business252__SWIG_0")]
  public static extern global::System.IntPtr new_Business252__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Business252__SWIG_1")]
  public static extern global::System.IntPtr new_Business252__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Business252")]
  public static extern void delete_Business252(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterestRate__SWIG_0")]
  public static extern global::System.IntPtr new_InterestRate__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterestRate__SWIG_1")]
  public static extern global::System.IntPtr new_InterestRate__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_rate")]
  public static extern double InterestRate_rate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_dayCounter")]
  public static extern global::System.IntPtr InterestRate_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_compounding")]
  public static extern int InterestRate_compounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_frequency")]
  public static extern int InterestRate_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_discountFactor__SWIG_0")]
  public static extern double InterestRate_discountFactor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_discountFactor__SWIG_1")]
  public static extern double InterestRate_discountFactor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_discountFactor__SWIG_2")]
  public static extern double InterestRate_discountFactor__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_discountFactor__SWIG_3")]
  public static extern double InterestRate_discountFactor__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_compoundFactor__SWIG_0")]
  public static extern double InterestRate_compoundFactor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_compoundFactor__SWIG_1")]
  public static extern double InterestRate_compoundFactor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_compoundFactor__SWIG_2")]
  public static extern double InterestRate_compoundFactor__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_compoundFactor__SWIG_3")]
  public static extern double InterestRate_compoundFactor__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_impliedRate__SWIG_0")]
  public static extern global::System.IntPtr InterestRate_impliedRate__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_impliedRate__SWIG_1")]
  public static extern global::System.IntPtr InterestRate_impliedRate__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_impliedRate__SWIG_2")]
  public static extern global::System.IntPtr InterestRate_impliedRate__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_impliedRate__SWIG_3")]
  public static extern global::System.IntPtr InterestRate_impliedRate__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_equivalentRate__SWIG_0")]
  public static extern global::System.IntPtr InterestRate_equivalentRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_equivalentRate__SWIG_1")]
  public static extern global::System.IntPtr InterestRate_equivalentRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_equivalentRate__SWIG_2")]
  public static extern global::System.IntPtr InterestRate_equivalentRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate_equivalentRate__SWIG_3")]
  public static extern global::System.IntPtr InterestRate_equivalentRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRate___str__")]
  public static extern string InterestRate___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InterestRate")]
  public static extern void delete_InterestRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Clear")]
  public static extern void InterestRateVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Add")]
  public static extern void InterestRateVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_size")]
  public static extern uint InterestRateVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_capacity")]
  public static extern uint InterestRateVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_reserve")]
  public static extern void InterestRateVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterestRateVector__SWIG_0")]
  public static extern global::System.IntPtr new_InterestRateVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterestRateVector__SWIG_1")]
  public static extern global::System.IntPtr new_InterestRateVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterestRateVector__SWIG_2")]
  public static extern global::System.IntPtr new_InterestRateVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_getitemcopy")]
  public static extern global::System.IntPtr InterestRateVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_getitem")]
  public static extern global::System.IntPtr InterestRateVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_setitem")]
  public static extern void InterestRateVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_AddRange")]
  public static extern void InterestRateVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_GetRange")]
  public static extern global::System.IntPtr InterestRateVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Insert")]
  public static extern void InterestRateVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_InsertRange")]
  public static extern void InterestRateVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_RemoveAt")]
  public static extern void InterestRateVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_RemoveRange")]
  public static extern void InterestRateVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Repeat")]
  public static extern global::System.IntPtr InterestRateVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Reverse__SWIG_0")]
  public static extern void InterestRateVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_Reverse__SWIG_1")]
  public static extern void InterestRateVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateVector_SetRange")]
  public static extern void InterestRateVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InterestRateVector")]
  public static extern void delete_InterestRateVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Rounding")]
  public static extern global::System.IntPtr new_Rounding();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Rounding_apply")]
  public static extern double Rounding_apply(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Rounding")]
  public static extern void delete_Rounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpRounding__SWIG_0")]
  public static extern global::System.IntPtr new_UpRounding__SWIG_0(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpRounding__SWIG_1")]
  public static extern global::System.IntPtr new_UpRounding__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UpRounding")]
  public static extern void delete_UpRounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DownRounding__SWIG_0")]
  public static extern global::System.IntPtr new_DownRounding__SWIG_0(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DownRounding__SWIG_1")]
  public static extern global::System.IntPtr new_DownRounding__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DownRounding")]
  public static extern void delete_DownRounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ClosestRounding__SWIG_0")]
  public static extern global::System.IntPtr new_ClosestRounding__SWIG_0(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ClosestRounding__SWIG_1")]
  public static extern global::System.IntPtr new_ClosestRounding__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ClosestRounding")]
  public static extern void delete_ClosestRounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CeilingTruncation__SWIG_0")]
  public static extern global::System.IntPtr new_CeilingTruncation__SWIG_0(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CeilingTruncation__SWIG_1")]
  public static extern global::System.IntPtr new_CeilingTruncation__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CeilingTruncation")]
  public static extern void delete_CeilingTruncation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloorTruncation__SWIG_0")]
  public static extern global::System.IntPtr new_FloorTruncation__SWIG_0(int jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloorTruncation__SWIG_1")]
  public static extern global::System.IntPtr new_FloorTruncation__SWIG_1(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloorTruncation")]
  public static extern void delete_FloorTruncation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_name")]
  public static extern string Currency_name(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_code")]
  public static extern string Currency_code(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_numericCode")]
  public static extern int Currency_numericCode(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_symbol")]
  public static extern string Currency_symbol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_fractionSymbol")]
  public static extern string Currency_fractionSymbol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_fractionsPerUnit")]
  public static extern int Currency_fractionsPerUnit(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_rounding")]
  public static extern global::System.IntPtr Currency_rounding(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_format")]
  public static extern string Currency_format(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_empty")]
  public static extern bool Currency_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency_triangulationCurrency")]
  public static extern global::System.IntPtr Currency_triangulationCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Currency___str__")]
  public static extern string Currency___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Currency")]
  public static extern global::System.IntPtr new_Currency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Currency")]
  public static extern void delete_Currency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ARSCurrency")]
  public static extern global::System.IntPtr new_ARSCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ARSCurrency")]
  public static extern void delete_ARSCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ATSCurrency")]
  public static extern global::System.IntPtr new_ATSCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ATSCurrency")]
  public static extern void delete_ATSCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AUDCurrency")]
  public static extern global::System.IntPtr new_AUDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AUDCurrency")]
  public static extern void delete_AUDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BDTCurrency")]
  public static extern global::System.IntPtr new_BDTCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BDTCurrency")]
  public static extern void delete_BDTCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BEFCurrency")]
  public static extern global::System.IntPtr new_BEFCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BEFCurrency")]
  public static extern void delete_BEFCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BGLCurrency")]
  public static extern global::System.IntPtr new_BGLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BGLCurrency")]
  public static extern void delete_BGLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BRLCurrency")]
  public static extern global::System.IntPtr new_BRLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BRLCurrency")]
  public static extern void delete_BRLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BYRCurrency")]
  public static extern global::System.IntPtr new_BYRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BYRCurrency")]
  public static extern void delete_BYRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CADCurrency")]
  public static extern global::System.IntPtr new_CADCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CADCurrency")]
  public static extern void delete_CADCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CHFCurrency")]
  public static extern global::System.IntPtr new_CHFCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CHFCurrency")]
  public static extern void delete_CHFCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CLPCurrency")]
  public static extern global::System.IntPtr new_CLPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CLPCurrency")]
  public static extern void delete_CLPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CNYCurrency")]
  public static extern global::System.IntPtr new_CNYCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CNYCurrency")]
  public static extern void delete_CNYCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_COPCurrency")]
  public static extern global::System.IntPtr new_COPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_COPCurrency")]
  public static extern void delete_COPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CYPCurrency")]
  public static extern global::System.IntPtr new_CYPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CYPCurrency")]
  public static extern void delete_CYPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CZKCurrency")]
  public static extern global::System.IntPtr new_CZKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CZKCurrency")]
  public static extern void delete_CZKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DEMCurrency")]
  public static extern global::System.IntPtr new_DEMCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DEMCurrency")]
  public static extern void delete_DEMCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DKKCurrency")]
  public static extern global::System.IntPtr new_DKKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DKKCurrency")]
  public static extern void delete_DKKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EEKCurrency")]
  public static extern global::System.IntPtr new_EEKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EEKCurrency")]
  public static extern void delete_EEKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ESPCurrency")]
  public static extern global::System.IntPtr new_ESPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ESPCurrency")]
  public static extern void delete_ESPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURCurrency")]
  public static extern global::System.IntPtr new_EURCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURCurrency")]
  public static extern void delete_EURCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FIMCurrency")]
  public static extern global::System.IntPtr new_FIMCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FIMCurrency")]
  public static extern void delete_FIMCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FRFCurrency")]
  public static extern global::System.IntPtr new_FRFCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FRFCurrency")]
  public static extern void delete_FRFCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBPCurrency")]
  public static extern global::System.IntPtr new_GBPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GBPCurrency")]
  public static extern void delete_GBPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GRDCurrency")]
  public static extern global::System.IntPtr new_GRDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GRDCurrency")]
  public static extern void delete_GRDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HKDCurrency")]
  public static extern global::System.IntPtr new_HKDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HKDCurrency")]
  public static extern void delete_HKDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HUFCurrency")]
  public static extern global::System.IntPtr new_HUFCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HUFCurrency")]
  public static extern void delete_HUFCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IEPCurrency")]
  public static extern global::System.IntPtr new_IEPCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IEPCurrency")]
  public static extern void delete_IEPCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IDRCurrency")]
  public static extern global::System.IntPtr new_IDRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IDRCurrency")]
  public static extern void delete_IDRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ILSCurrency")]
  public static extern global::System.IntPtr new_ILSCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ILSCurrency")]
  public static extern void delete_ILSCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_INRCurrency")]
  public static extern global::System.IntPtr new_INRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_INRCurrency")]
  public static extern void delete_INRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IQDCurrency")]
  public static extern global::System.IntPtr new_IQDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IQDCurrency")]
  public static extern void delete_IQDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IRRCurrency")]
  public static extern global::System.IntPtr new_IRRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IRRCurrency")]
  public static extern void delete_IRRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ISKCurrency")]
  public static extern global::System.IntPtr new_ISKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ISKCurrency")]
  public static extern void delete_ISKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ITLCurrency")]
  public static extern global::System.IntPtr new_ITLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ITLCurrency")]
  public static extern void delete_ITLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JPYCurrency")]
  public static extern global::System.IntPtr new_JPYCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JPYCurrency")]
  public static extern void delete_JPYCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KRWCurrency")]
  public static extern global::System.IntPtr new_KRWCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KRWCurrency")]
  public static extern void delete_KRWCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KWDCurrency")]
  public static extern global::System.IntPtr new_KWDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KWDCurrency")]
  public static extern void delete_KWDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LTLCurrency")]
  public static extern global::System.IntPtr new_LTLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LTLCurrency")]
  public static extern void delete_LTLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LUFCurrency")]
  public static extern global::System.IntPtr new_LUFCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LUFCurrency")]
  public static extern void delete_LUFCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LVLCurrency")]
  public static extern global::System.IntPtr new_LVLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LVLCurrency")]
  public static extern void delete_LVLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MTLCurrency")]
  public static extern global::System.IntPtr new_MTLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MTLCurrency")]
  public static extern void delete_MTLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MXNCurrency")]
  public static extern global::System.IntPtr new_MXNCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MXNCurrency")]
  public static extern void delete_MXNCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MYRCurrency")]
  public static extern global::System.IntPtr new_MYRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MYRCurrency")]
  public static extern void delete_MYRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NLGCurrency")]
  public static extern global::System.IntPtr new_NLGCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NLGCurrency")]
  public static extern void delete_NLGCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NOKCurrency")]
  public static extern global::System.IntPtr new_NOKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NOKCurrency")]
  public static extern void delete_NOKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NPRCurrency")]
  public static extern global::System.IntPtr new_NPRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NPRCurrency")]
  public static extern void delete_NPRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NZDCurrency")]
  public static extern global::System.IntPtr new_NZDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NZDCurrency")]
  public static extern void delete_NZDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PEHCurrency")]
  public static extern global::System.IntPtr new_PEHCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PEHCurrency")]
  public static extern void delete_PEHCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PEICurrency")]
  public static extern global::System.IntPtr new_PEICurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PEICurrency")]
  public static extern void delete_PEICurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PENCurrency")]
  public static extern global::System.IntPtr new_PENCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PENCurrency")]
  public static extern void delete_PENCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PKRCurrency")]
  public static extern global::System.IntPtr new_PKRCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PKRCurrency")]
  public static extern void delete_PKRCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PLNCurrency")]
  public static extern global::System.IntPtr new_PLNCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PLNCurrency")]
  public static extern void delete_PLNCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PTECurrency")]
  public static extern global::System.IntPtr new_PTECurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PTECurrency")]
  public static extern void delete_PTECurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ROLCurrency")]
  public static extern global::System.IntPtr new_ROLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ROLCurrency")]
  public static extern void delete_ROLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RONCurrency")]
  public static extern global::System.IntPtr new_RONCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RONCurrency")]
  public static extern void delete_RONCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RUBCurrency")]
  public static extern global::System.IntPtr new_RUBCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RUBCurrency")]
  public static extern void delete_RUBCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SARCurrency")]
  public static extern global::System.IntPtr new_SARCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SARCurrency")]
  public static extern void delete_SARCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SEKCurrency")]
  public static extern global::System.IntPtr new_SEKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SEKCurrency")]
  public static extern void delete_SEKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SGDCurrency")]
  public static extern global::System.IntPtr new_SGDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SGDCurrency")]
  public static extern void delete_SGDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SITCurrency")]
  public static extern global::System.IntPtr new_SITCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SITCurrency")]
  public static extern void delete_SITCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SKKCurrency")]
  public static extern global::System.IntPtr new_SKKCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SKKCurrency")]
  public static extern void delete_SKKCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_THBCurrency")]
  public static extern global::System.IntPtr new_THBCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_THBCurrency")]
  public static extern void delete_THBCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TRLCurrency")]
  public static extern global::System.IntPtr new_TRLCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TRLCurrency")]
  public static extern void delete_TRLCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TRYCurrency")]
  public static extern global::System.IntPtr new_TRYCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TRYCurrency")]
  public static extern void delete_TRYCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TTDCurrency")]
  public static extern global::System.IntPtr new_TTDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TTDCurrency")]
  public static extern void delete_TTDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TWDCurrency")]
  public static extern global::System.IntPtr new_TWDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TWDCurrency")]
  public static extern void delete_TWDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USDCurrency")]
  public static extern global::System.IntPtr new_USDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_USDCurrency")]
  public static extern void delete_USDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VEBCurrency")]
  public static extern global::System.IntPtr new_VEBCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VEBCurrency")]
  public static extern void delete_VEBCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VNDCurrency")]
  public static extern global::System.IntPtr new_VNDCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VNDCurrency")]
  public static extern void delete_VNDCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZARCurrency")]
  public static extern global::System.IntPtr new_ZARCurrency();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZARCurrency")]
  public static extern void delete_ZARCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brent_setMaxEvaluations")]
  public static extern void Brent_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brent_setLowerBound")]
  public static extern void Brent_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brent_setUpperBound")]
  public static extern void Brent_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brent_solve__SWIG_0")]
  public static extern double Brent_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brent_solve__SWIG_1")]
  public static extern double Brent_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Brent")]
  public static extern global::System.IntPtr new_Brent();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Brent")]
  public static extern void delete_Brent(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bisection_setMaxEvaluations")]
  public static extern void Bisection_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bisection_setLowerBound")]
  public static extern void Bisection_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bisection_setUpperBound")]
  public static extern void Bisection_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bisection_solve__SWIG_0")]
  public static extern double Bisection_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bisection_solve__SWIG_1")]
  public static extern double Bisection_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bisection")]
  public static extern global::System.IntPtr new_Bisection();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bisection")]
  public static extern void delete_Bisection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FalsePosition_setMaxEvaluations")]
  public static extern void FalsePosition_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FalsePosition_setLowerBound")]
  public static extern void FalsePosition_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FalsePosition_setUpperBound")]
  public static extern void FalsePosition_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FalsePosition_solve__SWIG_0")]
  public static extern double FalsePosition_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FalsePosition_solve__SWIG_1")]
  public static extern double FalsePosition_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FalsePosition")]
  public static extern global::System.IntPtr new_FalsePosition();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FalsePosition")]
  public static extern void delete_FalsePosition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ridder_setMaxEvaluations")]
  public static extern void Ridder_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ridder_setLowerBound")]
  public static extern void Ridder_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ridder_setUpperBound")]
  public static extern void Ridder_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ridder_solve__SWIG_0")]
  public static extern double Ridder_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ridder_solve__SWIG_1")]
  public static extern double Ridder_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Ridder")]
  public static extern global::System.IntPtr new_Ridder();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Ridder")]
  public static extern void delete_Ridder(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Secant_setMaxEvaluations")]
  public static extern void Secant_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Secant_setLowerBound")]
  public static extern void Secant_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Secant_setUpperBound")]
  public static extern void Secant_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Secant_solve__SWIG_0")]
  public static extern double Secant_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Secant_solve__SWIG_1")]
  public static extern double Secant_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Secant")]
  public static extern global::System.IntPtr new_Secant();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Secant")]
  public static extern void delete_Secant(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Newton_setMaxEvaluations")]
  public static extern void Newton_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Newton_setLowerBound")]
  public static extern void Newton_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Newton_setUpperBound")]
  public static extern void Newton_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Newton_solve__SWIG_0")]
  public static extern double Newton_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Newton_solve__SWIG_1")]
  public static extern double Newton_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Newton")]
  public static extern global::System.IntPtr new_Newton();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Newton")]
  public static extern void delete_Newton(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewtonSafe_setMaxEvaluations")]
  public static extern void NewtonSafe_setMaxEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewtonSafe_setLowerBound")]
  public static extern void NewtonSafe_setLowerBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewtonSafe_setUpperBound")]
  public static extern void NewtonSafe_setUpperBound(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewtonSafe_solve__SWIG_0")]
  public static extern double NewtonSafe_solve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewtonSafe_solve__SWIG_1")]
  public static extern double NewtonSafe_solve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NewtonSafe")]
  public static extern global::System.IntPtr new_NewtonSafe();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NewtonSafe")]
  public static extern void delete_NewtonSafe(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Constraint")]
  public static extern void delete_Constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoundaryConstraint")]
  public static extern global::System.IntPtr new_BoundaryConstraint(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BoundaryConstraint")]
  public static extern void delete_BoundaryConstraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoConstraint")]
  public static extern global::System.IntPtr new_NoConstraint();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NoConstraint")]
  public static extern void delete_NoConstraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PositiveConstraint")]
  public static extern global::System.IntPtr new_PositiveConstraint();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PositiveConstraint")]
  public static extern void delete_PositiveConstraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CompositeConstraint")]
  public static extern global::System.IntPtr new_CompositeConstraint(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CompositeConstraint")]
  public static extern void delete_CompositeConstraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonhomogeneousBoundaryConstraint")]
  public static extern global::System.IntPtr new_NonhomogeneousBoundaryConstraint(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NonhomogeneousBoundaryConstraint")]
  public static extern void delete_NonhomogeneousBoundaryConstraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EndCriteria")]
  public static extern global::System.IntPtr new_EndCriteria(uint jarg1, uint jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EndCriteria_call")]
  public static extern bool EndCriteria_call(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, double jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EndCriteria")]
  public static extern void delete_EndCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OptimizationMethod")]
  public static extern void delete_OptimizationMethod(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConjugateGradient")]
  public static extern global::System.IntPtr new_ConjugateGradient();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConjugateGradient")]
  public static extern void delete_ConjugateGradient(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Simplex")]
  public static extern global::System.IntPtr new_Simplex(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Simplex_lambda")]
  public static extern double Simplex_lambda(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Simplex")]
  public static extern void delete_Simplex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SteepestDescent")]
  public static extern global::System.IntPtr new_SteepestDescent();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SteepestDescent")]
  public static extern void delete_SteepestDescent(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BFGS")]
  public static extern global::System.IntPtr new_BFGS();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BFGS")]
  public static extern void delete_BFGS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LevenbergMarquardt__SWIG_0")]
  public static extern global::System.IntPtr new_LevenbergMarquardt__SWIG_0(double jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LevenbergMarquardt__SWIG_1")]
  public static extern global::System.IntPtr new_LevenbergMarquardt__SWIG_1(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LevenbergMarquardt__SWIG_2")]
  public static extern global::System.IntPtr new_LevenbergMarquardt__SWIG_2(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LevenbergMarquardt__SWIG_3")]
  public static extern global::System.IntPtr new_LevenbergMarquardt__SWIG_3(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LevenbergMarquardt__SWIG_4")]
  public static extern global::System.IntPtr new_LevenbergMarquardt__SWIG_4();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LevenbergMarquardt")]
  public static extern void delete_LevenbergMarquardt(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DifferentialEvolution")]
  public static extern global::System.IntPtr new_DifferentialEvolution();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DifferentialEvolution")]
  public static extern void delete_DifferentialEvolution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerGaussian__SWIG_0")]
  public static extern global::System.IntPtr new_SamplerGaussian__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerGaussian__SWIG_1")]
  public static extern global::System.IntPtr new_SamplerGaussian__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SamplerGaussian")]
  public static extern void delete_SamplerGaussian(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerLogNormal__SWIG_0")]
  public static extern global::System.IntPtr new_SamplerLogNormal__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerLogNormal__SWIG_1")]
  public static extern global::System.IntPtr new_SamplerLogNormal__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SamplerLogNormal")]
  public static extern void delete_SamplerLogNormal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerMirrorGaussian__SWIG_0")]
  public static extern global::System.IntPtr new_SamplerMirrorGaussian__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SamplerMirrorGaussian__SWIG_1")]
  public static extern global::System.IntPtr new_SamplerMirrorGaussian__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SamplerMirrorGaussian")]
  public static extern void delete_SamplerMirrorGaussian(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ProbabilityBoltzmannDownhill__SWIG_0")]
  public static extern global::System.IntPtr new_ProbabilityBoltzmannDownhill__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ProbabilityBoltzmannDownhill__SWIG_1")]
  public static extern global::System.IntPtr new_ProbabilityBoltzmannDownhill__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ProbabilityBoltzmannDownhill")]
  public static extern void delete_ProbabilityBoltzmannDownhill(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TemperatureExponential__SWIG_0")]
  public static extern global::System.IntPtr new_TemperatureExponential__SWIG_0(double jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TemperatureExponential__SWIG_1")]
  public static extern global::System.IntPtr new_TemperatureExponential__SWIG_1(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TemperatureExponential")]
  public static extern void delete_TemperatureExponential(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ReannealingTrivial")]
  public static extern global::System.IntPtr new_ReannealingTrivial();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ReannealingTrivial")]
  public static extern void delete_ReannealingTrivial(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_0")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_1")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_2")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_3")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_4")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_5")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSimulatedAnnealing__SWIG_6")]
  public static extern global::System.IntPtr new_GaussianSimulatedAnnealing__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianSimulatedAnnealing")]
  public static extern void delete_GaussianSimulatedAnnealing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_0")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_1")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_2")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_3")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_4")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_5")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MirrorGaussianSimulatedAnnealing__SWIG_6")]
  public static extern global::System.IntPtr new_MirrorGaussianSimulatedAnnealing__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MirrorGaussianSimulatedAnnealing")]
  public static extern void delete_MirrorGaussianSimulatedAnnealing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_0")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_1")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_2")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_3")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_4")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_5")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogNormalSimulatedAnnealing__SWIG_6")]
  public static extern global::System.IntPtr new_LogNormalSimulatedAnnealing__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogNormalSimulatedAnnealing")]
  public static extern void delete_LogNormalSimulatedAnnealing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Optimizer_solve")]
  public static extern global::System.IntPtr Optimizer_solve(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Optimizer")]
  public static extern global::System.IntPtr new_Optimizer();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Optimizer")]
  public static extern void delete_Optimizer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolation")]
  public static extern global::System.IntPtr new_LinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearInterpolation_call__SWIG_0")]
  public static extern double LinearInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearInterpolation_call__SWIG_1")]
  public static extern double LinearInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LinearInterpolation")]
  public static extern void delete_LinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearInterpolation")]
  public static extern global::System.IntPtr new_LogLinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearInterpolation_call__SWIG_0")]
  public static extern double LogLinearInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearInterpolation_call__SWIG_1")]
  public static extern double LogLinearInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogLinearInterpolation")]
  public static extern void delete_LogLinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BackwardFlatInterpolation")]
  public static extern global::System.IntPtr new_BackwardFlatInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BackwardFlatInterpolation_call__SWIG_0")]
  public static extern double BackwardFlatInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BackwardFlatInterpolation_call__SWIG_1")]
  public static extern double BackwardFlatInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BackwardFlatInterpolation")]
  public static extern void delete_BackwardFlatInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardFlatInterpolation")]
  public static extern global::System.IntPtr new_ForwardFlatInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardFlatInterpolation_call__SWIG_0")]
  public static extern double ForwardFlatInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardFlatInterpolation_call__SWIG_1")]
  public static extern double ForwardFlatInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardFlatInterpolation")]
  public static extern void delete_ForwardFlatInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicNaturalSpline")]
  public static extern global::System.IntPtr new_CubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_call__SWIG_0")]
  public static extern double CubicNaturalSpline_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_call__SWIG_1")]
  public static extern double CubicNaturalSpline_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_derivative__SWIG_0")]
  public static extern double CubicNaturalSpline_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_derivative__SWIG_1")]
  public static extern double CubicNaturalSpline_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_secondDerivative__SWIG_0")]
  public static extern double CubicNaturalSpline_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_secondDerivative__SWIG_1")]
  public static extern double CubicNaturalSpline_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_primitive__SWIG_0")]
  public static extern double CubicNaturalSpline_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicNaturalSpline_primitive__SWIG_1")]
  public static extern double CubicNaturalSpline_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CubicNaturalSpline")]
  public static extern void delete_CubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicNaturalSpline")]
  public static extern global::System.IntPtr new_LogCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_call__SWIG_0")]
  public static extern double LogCubicNaturalSpline_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_call__SWIG_1")]
  public static extern double LogCubicNaturalSpline_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_derivative__SWIG_0")]
  public static extern double LogCubicNaturalSpline_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_derivative__SWIG_1")]
  public static extern double LogCubicNaturalSpline_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_secondDerivative__SWIG_0")]
  public static extern double LogCubicNaturalSpline_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_secondDerivative__SWIG_1")]
  public static extern double LogCubicNaturalSpline_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_primitive__SWIG_0")]
  public static extern double LogCubicNaturalSpline_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicNaturalSpline_primitive__SWIG_1")]
  public static extern double LogCubicNaturalSpline_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogCubicNaturalSpline")]
  public static extern void delete_LogCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicNaturalSpline")]
  public static extern global::System.IntPtr new_MonotonicCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_call__SWIG_0")]
  public static extern double MonotonicCubicNaturalSpline_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_call__SWIG_1")]
  public static extern double MonotonicCubicNaturalSpline_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_derivative__SWIG_0")]
  public static extern double MonotonicCubicNaturalSpline_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_derivative__SWIG_1")]
  public static extern double MonotonicCubicNaturalSpline_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_secondDerivative__SWIG_0")]
  public static extern double MonotonicCubicNaturalSpline_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_secondDerivative__SWIG_1")]
  public static extern double MonotonicCubicNaturalSpline_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_primitive__SWIG_0")]
  public static extern double MonotonicCubicNaturalSpline_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicNaturalSpline_primitive__SWIG_1")]
  public static extern double MonotonicCubicNaturalSpline_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicCubicNaturalSpline")]
  public static extern void delete_MonotonicCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogCubicNaturalSpline")]
  public static extern global::System.IntPtr new_MonotonicLogCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_call__SWIG_0")]
  public static extern double MonotonicLogCubicNaturalSpline_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_call__SWIG_1")]
  public static extern double MonotonicLogCubicNaturalSpline_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_derivative__SWIG_0")]
  public static extern double MonotonicLogCubicNaturalSpline_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_derivative__SWIG_1")]
  public static extern double MonotonicLogCubicNaturalSpline_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_0")]
  public static extern double MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_1")]
  public static extern double MonotonicLogCubicNaturalSpline_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_primitive__SWIG_0")]
  public static extern double MonotonicLogCubicNaturalSpline_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicNaturalSpline_primitive__SWIG_1")]
  public static extern double MonotonicLogCubicNaturalSpline_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicLogCubicNaturalSpline")]
  public static extern void delete_MonotonicLogCubicNaturalSpline(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KrugerCubic")]
  public static extern global::System.IntPtr new_KrugerCubic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_call__SWIG_0")]
  public static extern double KrugerCubic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_call__SWIG_1")]
  public static extern double KrugerCubic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_derivative__SWIG_0")]
  public static extern double KrugerCubic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_derivative__SWIG_1")]
  public static extern double KrugerCubic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_secondDerivative__SWIG_0")]
  public static extern double KrugerCubic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_secondDerivative__SWIG_1")]
  public static extern double KrugerCubic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_primitive__SWIG_0")]
  public static extern double KrugerCubic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerCubic_primitive__SWIG_1")]
  public static extern double KrugerCubic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KrugerCubic")]
  public static extern void delete_KrugerCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KrugerLogCubic")]
  public static extern global::System.IntPtr new_KrugerLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_call__SWIG_0")]
  public static extern double KrugerLogCubic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_call__SWIG_1")]
  public static extern double KrugerLogCubic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_derivative__SWIG_0")]
  public static extern double KrugerLogCubic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_derivative__SWIG_1")]
  public static extern double KrugerLogCubic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_secondDerivative__SWIG_0")]
  public static extern double KrugerLogCubic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_secondDerivative__SWIG_1")]
  public static extern double KrugerLogCubic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_primitive__SWIG_0")]
  public static extern double KrugerLogCubic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KrugerLogCubic_primitive__SWIG_1")]
  public static extern double KrugerLogCubic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KrugerLogCubic")]
  public static extern void delete_KrugerLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FritschButlandCubic")]
  public static extern global::System.IntPtr new_FritschButlandCubic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_call__SWIG_0")]
  public static extern double FritschButlandCubic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_call__SWIG_1")]
  public static extern double FritschButlandCubic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_derivative__SWIG_0")]
  public static extern double FritschButlandCubic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_derivative__SWIG_1")]
  public static extern double FritschButlandCubic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_secondDerivative__SWIG_0")]
  public static extern double FritschButlandCubic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_secondDerivative__SWIG_1")]
  public static extern double FritschButlandCubic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_primitive__SWIG_0")]
  public static extern double FritschButlandCubic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandCubic_primitive__SWIG_1")]
  public static extern double FritschButlandCubic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FritschButlandCubic")]
  public static extern void delete_FritschButlandCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FritschButlandLogCubic")]
  public static extern global::System.IntPtr new_FritschButlandLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_call__SWIG_0")]
  public static extern double FritschButlandLogCubic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_call__SWIG_1")]
  public static extern double FritschButlandLogCubic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_derivative__SWIG_0")]
  public static extern double FritschButlandLogCubic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_derivative__SWIG_1")]
  public static extern double FritschButlandLogCubic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_secondDerivative__SWIG_0")]
  public static extern double FritschButlandLogCubic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_secondDerivative__SWIG_1")]
  public static extern double FritschButlandLogCubic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_primitive__SWIG_0")]
  public static extern double FritschButlandLogCubic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FritschButlandLogCubic_primitive__SWIG_1")]
  public static extern double FritschButlandLogCubic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FritschButlandLogCubic")]
  public static extern void delete_FritschButlandLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Parabolic")]
  public static extern global::System.IntPtr new_Parabolic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_call__SWIG_0")]
  public static extern double Parabolic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_call__SWIG_1")]
  public static extern double Parabolic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_derivative__SWIG_0")]
  public static extern double Parabolic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_derivative__SWIG_1")]
  public static extern double Parabolic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_secondDerivative__SWIG_0")]
  public static extern double Parabolic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_secondDerivative__SWIG_1")]
  public static extern double Parabolic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_primitive__SWIG_0")]
  public static extern double Parabolic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parabolic_primitive__SWIG_1")]
  public static extern double Parabolic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Parabolic")]
  public static extern void delete_Parabolic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogParabolic")]
  public static extern global::System.IntPtr new_LogParabolic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_call__SWIG_0")]
  public static extern double LogParabolic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_call__SWIG_1")]
  public static extern double LogParabolic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_derivative__SWIG_0")]
  public static extern double LogParabolic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_derivative__SWIG_1")]
  public static extern double LogParabolic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_secondDerivative__SWIG_0")]
  public static extern double LogParabolic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_secondDerivative__SWIG_1")]
  public static extern double LogParabolic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_primitive__SWIG_0")]
  public static extern double LogParabolic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogParabolic_primitive__SWIG_1")]
  public static extern double LogParabolic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogParabolic")]
  public static extern void delete_LogParabolic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicParabolic")]
  public static extern global::System.IntPtr new_MonotonicParabolic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_call__SWIG_0")]
  public static extern double MonotonicParabolic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_call__SWIG_1")]
  public static extern double MonotonicParabolic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_derivative__SWIG_0")]
  public static extern double MonotonicParabolic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_derivative__SWIG_1")]
  public static extern double MonotonicParabolic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_secondDerivative__SWIG_0")]
  public static extern double MonotonicParabolic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_secondDerivative__SWIG_1")]
  public static extern double MonotonicParabolic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_primitive__SWIG_0")]
  public static extern double MonotonicParabolic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicParabolic_primitive__SWIG_1")]
  public static extern double MonotonicParabolic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicParabolic")]
  public static extern void delete_MonotonicParabolic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogParabolic")]
  public static extern global::System.IntPtr new_MonotonicLogParabolic(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_call__SWIG_0")]
  public static extern double MonotonicLogParabolic_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_call__SWIG_1")]
  public static extern double MonotonicLogParabolic_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_derivative__SWIG_0")]
  public static extern double MonotonicLogParabolic_derivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_derivative__SWIG_1")]
  public static extern double MonotonicLogParabolic_derivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_secondDerivative__SWIG_0")]
  public static extern double MonotonicLogParabolic_secondDerivative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_secondDerivative__SWIG_1")]
  public static extern double MonotonicLogParabolic_secondDerivative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_primitive__SWIG_0")]
  public static extern double MonotonicLogParabolic_primitive__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogParabolic_primitive__SWIG_1")]
  public static extern double MonotonicLogParabolic_primitive__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicLogParabolic")]
  public static extern void delete_MonotonicLogParabolic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BilinearInterpolation")]
  public static extern global::System.IntPtr new_BilinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BilinearInterpolation_call__SWIG_0")]
  public static extern double BilinearInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BilinearInterpolation_call__SWIG_1")]
  public static extern double BilinearInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BilinearInterpolation")]
  public static extern void delete_BilinearInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BicubicSpline")]
  public static extern global::System.IntPtr new_BicubicSpline(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BicubicSpline_call__SWIG_0")]
  public static extern double BicubicSpline_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BicubicSpline_call__SWIG_1")]
  public static extern double BicubicSpline_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BicubicSpline")]
  public static extern void delete_BicubicSpline(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BackwardFlat")]
  public static extern global::System.IntPtr new_BackwardFlat();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BackwardFlat")]
  public static extern void delete_BackwardFlat(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardFlat")]
  public static extern global::System.IntPtr new_ForwardFlat();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardFlat")]
  public static extern void delete_ForwardFlat(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Linear")]
  public static extern global::System.IntPtr new_Linear();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Linear")]
  public static extern void delete_Linear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinear")]
  public static extern global::System.IntPtr new_LogLinear();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogLinear")]
  public static extern void delete_LogLinear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Cubic")]
  public static extern global::System.IntPtr new_Cubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Cubic")]
  public static extern void delete_Cubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bicubic")]
  public static extern global::System.IntPtr new_Bicubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bicubic")]
  public static extern void delete_Bicubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubic")]
  public static extern global::System.IntPtr new_MonotonicCubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicCubic")]
  public static extern void delete_MonotonicCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultLogCubic")]
  public static extern global::System.IntPtr new_DefaultLogCubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultLogCubic")]
  public static extern void delete_DefaultLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogCubic")]
  public static extern global::System.IntPtr new_MonotonicLogCubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicLogCubic")]
  public static extern void delete_MonotonicLogCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubic")]
  public static extern global::System.IntPtr new_SplineCubic();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SplineCubic")]
  public static extern void delete_SplineCubic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Kruger")]
  public static extern global::System.IntPtr new_Kruger();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Kruger")]
  public static extern void delete_Kruger(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KrugerLog")]
  public static extern global::System.IntPtr new_KrugerLog();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KrugerLog")]
  public static extern void delete_KrugerLog(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotone__SWIG_0")]
  public static extern global::System.IntPtr new_ConvexMonotone__SWIG_0(double jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotone__SWIG_1")]
  public static extern global::System.IntPtr new_ConvexMonotone__SWIG_1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotone__SWIG_2")]
  public static extern global::System.IntPtr new_ConvexMonotone__SWIG_2(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotone__SWIG_3")]
  public static extern global::System.IntPtr new_ConvexMonotone__SWIG_3();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConvexMonotone")]
  public static extern void delete_ConvexMonotone(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_0")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, double jarg16, bool jarg17, uint jarg18, double jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_1")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, double jarg16, bool jarg17, uint jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_2")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, double jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_3")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, double jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_4")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_5")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_6")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SABRInterpolation__SWIG_7")]
  public static extern global::System.IntPtr new_SABRInterpolation__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, bool jarg9, bool jarg10, bool jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_call__SWIG_0")]
  public static extern double SABRInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_call__SWIG_1")]
  public static extern double SABRInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_alpha")]
  public static extern double SABRInterpolation_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_beta")]
  public static extern double SABRInterpolation_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_rho")]
  public static extern double SABRInterpolation_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SABRInterpolation_nu")]
  public static extern double SABRInterpolation_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SABRInterpolation")]
  public static extern void delete_SABRInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RichardsonExtrapolation_call__SWIG_0")]
  public static extern double RichardsonExtrapolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RichardsonExtrapolation_call__SWIG_1")]
  public static extern double RichardsonExtrapolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RichardsonExtrapolation_call__SWIG_2")]
  public static extern double RichardsonExtrapolation_call__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RichardsonExtrapolation__SWIG_0")]
  public static extern global::System.IntPtr new_RichardsonExtrapolation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RichardsonExtrapolation__SWIG_1")]
  public static extern global::System.IntPtr new_RichardsonExtrapolation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RichardsonExtrapolation")]
  public static extern void delete_RichardsonExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotoneInterpolation__SWIG_0")]
  public static extern global::System.IntPtr new_ConvexMonotoneInterpolation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotoneInterpolation__SWIG_1")]
  public static extern global::System.IntPtr new_ConvexMonotoneInterpolation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotoneInterpolation__SWIG_2")]
  public static extern global::System.IntPtr new_ConvexMonotoneInterpolation__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvexMonotoneInterpolation__SWIG_3")]
  public static extern global::System.IntPtr new_ConvexMonotoneInterpolation__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConvexMonotoneInterpolation_call__SWIG_0")]
  public static extern double ConvexMonotoneInterpolation_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConvexMonotoneInterpolation_call__SWIG_1")]
  public static extern double ConvexMonotoneInterpolation_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConvexMonotoneInterpolation")]
  public static extern void delete_ConvexMonotoneInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_dayCounter")]
  public static extern global::System.IntPtr TermStructure_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_timeFromReference")]
  public static extern double TermStructure_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_calendar")]
  public static extern global::System.IntPtr TermStructure_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_referenceDate")]
  public static extern global::System.IntPtr TermStructure_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_maxDate")]
  public static extern global::System.IntPtr TermStructure_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_maxTime")]
  public static extern double TermStructure_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_enableExtrapolation")]
  public static extern void TermStructure_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_disableExtrapolation")]
  public static extern void TermStructure_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_allowsExtrapolation")]
  public static extern bool TermStructure_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TermStructure")]
  public static extern void delete_TermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_discount__SWIG_0")]
  public static extern double YieldTermStructure_discount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_discount__SWIG_1")]
  public static extern double YieldTermStructure_discount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_discount__SWIG_2")]
  public static extern double YieldTermStructure_discount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_discount__SWIG_3")]
  public static extern double YieldTermStructure_discount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_0")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_1")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_2")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_3")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, int jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_4")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_zeroRate__SWIG_5")]
  public static extern global::System.IntPtr YieldTermStructure_zeroRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_0")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_1")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_2")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_3")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_4")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_forwardRate__SWIG_5")]
  public static extern global::System.IntPtr YieldTermStructure_forwardRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YieldTermStructure")]
  public static extern void delete_YieldTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YieldTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_YieldTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YieldTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_YieldTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle___deref__")]
  public static extern global::System.IntPtr YieldTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr YieldTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_empty")]
  public static extern bool YieldTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr YieldTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YieldTermStructureHandle")]
  public static extern void delete_YieldTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_discount__SWIG_0")]
  public static extern double YieldTermStructureHandle_discount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_discount__SWIG_1")]
  public static extern double YieldTermStructureHandle_discount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_discount__SWIG_2")]
  public static extern double YieldTermStructureHandle_discount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_discount__SWIG_3")]
  public static extern double YieldTermStructureHandle_discount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_0")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_1")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_2")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_3")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, int jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_4")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_zeroRate__SWIG_5")]
  public static extern global::System.IntPtr YieldTermStructureHandle_zeroRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_0")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_1")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_2")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_3")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_4")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_forwardRate__SWIG_5")]
  public static extern global::System.IntPtr YieldTermStructureHandle_forwardRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr YieldTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_timeFromReference")]
  public static extern double YieldTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_calendar")]
  public static extern global::System.IntPtr YieldTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr YieldTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr YieldTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_maxTime")]
  public static extern double YieldTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_enableExtrapolation")]
  public static extern void YieldTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_disableExtrapolation")]
  public static extern void YieldTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructureHandle_allowsExtrapolation")]
  public static extern bool YieldTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYieldTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableYieldTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYieldTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableYieldTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYieldTermStructureHandle_linkTo")]
  public static extern void RelinkableYieldTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYieldTermStructureHandle_reset")]
  public static extern void RelinkableYieldTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableYieldTermStructureHandle")]
  public static extern void delete_RelinkableYieldTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ImpliedTermStructure")]
  public static extern global::System.IntPtr new_ImpliedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ImpliedTermStructure")]
  public static extern void delete_ImpliedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroSpreadedTermStructure__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroSpreadedTermStructure__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroSpreadedTermStructure__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroSpreadedTermStructure__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroSpreadedTermStructure__SWIG_2")]
  public static extern global::System.IntPtr new_ZeroSpreadedTermStructure__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroSpreadedTermStructure__SWIG_3")]
  public static extern global::System.IntPtr new_ZeroSpreadedTermStructure__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroSpreadedTermStructure")]
  public static extern void delete_ZeroSpreadedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardSpreadedTermStructure")]
  public static extern global::System.IntPtr new_ForwardSpreadedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardSpreadedTermStructure")]
  public static extern void delete_ForwardSpreadedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_0")]
  public static extern global::System.IntPtr new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_1")]
  public static extern global::System.IntPtr new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_2")]
  public static extern global::System.IntPtr new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_3")]
  public static extern global::System.IntPtr new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_4")]
  public static extern global::System.IntPtr new_SpreadedLinearZeroInterpolatedTermStructure__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SpreadedLinearZeroInterpolatedTermStructure")]
  public static extern void delete_SpreadedLinearZeroInterpolatedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_0")]
  public static extern global::System.IntPtr new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_1")]
  public static extern global::System.IntPtr new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_2")]
  public static extern global::System.IntPtr new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_3")]
  public static extern global::System.IntPtr new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_4")]
  public static extern global::System.IntPtr new_SpreadedBackwardFlatZeroInterpolatedTermStructure__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SpreadedBackwardFlatZeroInterpolatedTermStructure")]
  public static extern void delete_SpreadedBackwardFlatZeroInterpolatedTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_0")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_1")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_2")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_3")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_4")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_5")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_6")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_7")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_8")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_9")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_10")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatForward__SWIG_11")]
  public static extern global::System.IntPtr new_FlatForward__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FlatForward")]
  public static extern void delete_FlatForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RealTimeSeries__SWIG_0")]
  public static extern global::System.IntPtr new_RealTimeSeries__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RealTimeSeries__SWIG_1")]
  public static extern global::System.IntPtr new_RealTimeSeries__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RealTimeSeries_dates")]
  public static extern global::System.IntPtr RealTimeSeries_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RealTimeSeries_values")]
  public static extern global::System.IntPtr RealTimeSeries_values(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RealTimeSeries_size")]
  public static extern uint RealTimeSeries_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RealTimeSeries")]
  public static extern void delete_RealTimeSeries(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPriceTimeSeries__SWIG_0")]
  public static extern global::System.IntPtr new_IntervalPriceTimeSeries__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPriceTimeSeries__SWIG_1")]
  public static extern global::System.IntPtr new_IntervalPriceTimeSeries__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceTimeSeries_dates")]
  public static extern global::System.IntPtr IntervalPriceTimeSeries_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceTimeSeries_values")]
  public static extern global::System.IntPtr IntervalPriceTimeSeries_values(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceTimeSeries_size")]
  public static extern uint IntervalPriceTimeSeries_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntervalPriceTimeSeries")]
  public static extern void delete_IntervalPriceTimeSeries(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Clear")]
  public static extern void IntervalPriceVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Add")]
  public static extern void IntervalPriceVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_size")]
  public static extern uint IntervalPriceVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_capacity")]
  public static extern uint IntervalPriceVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_reserve")]
  public static extern void IntervalPriceVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPriceVector__SWIG_0")]
  public static extern global::System.IntPtr new_IntervalPriceVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPriceVector__SWIG_1")]
  public static extern global::System.IntPtr new_IntervalPriceVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPriceVector__SWIG_2")]
  public static extern global::System.IntPtr new_IntervalPriceVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_getitemcopy")]
  public static extern global::System.IntPtr IntervalPriceVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_getitem")]
  public static extern global::System.IntPtr IntervalPriceVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_setitem")]
  public static extern void IntervalPriceVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_AddRange")]
  public static extern void IntervalPriceVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_GetRange")]
  public static extern global::System.IntPtr IntervalPriceVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Insert")]
  public static extern void IntervalPriceVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_InsertRange")]
  public static extern void IntervalPriceVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_RemoveAt")]
  public static extern void IntervalPriceVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_RemoveRange")]
  public static extern void IntervalPriceVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Repeat")]
  public static extern global::System.IntPtr IntervalPriceVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Reverse__SWIG_0")]
  public static extern void IntervalPriceVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_Reverse__SWIG_1")]
  public static extern void IntervalPriceVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPriceVector_SetRange")]
  public static extern void IntervalPriceVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntervalPriceVector")]
  public static extern void delete_IntervalPriceVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntervalPrice")]
  public static extern global::System.IntPtr new_IntervalPrice(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_setValue")]
  public static extern void IntervalPrice_setValue(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_setValues")]
  public static extern void IntervalPrice_setValues(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_value")]
  public static extern double IntervalPrice_value(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_open")]
  public static extern double IntervalPrice_open(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_close")]
  public static extern double IntervalPrice_close(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_high")]
  public static extern double IntervalPrice_high(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_low")]
  public static extern double IntervalPrice_low(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_makeSeries")]
  public static extern global::System.IntPtr IntervalPrice_makeSeries(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_extractValues")]
  public static extern global::System.IntPtr IntervalPrice_extractValues(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntervalPrice_extractComponent")]
  public static extern global::System.IntPtr IntervalPrice_extractComponent(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntervalPrice")]
  public static extern void delete_IntervalPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_instance")]
  public static extern global::System.IntPtr IndexManager_instance();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_setHistory")]
  public static extern void IndexManager_setHistory(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_getHistory")]
  public static extern global::System.IntPtr IndexManager_getHistory(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_hasHistory")]
  public static extern bool IndexManager_hasHistory(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_histories")]
  public static extern global::System.IntPtr IndexManager_histories(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_clearHistory")]
  public static extern void IndexManager_clearHistory(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexManager_clearHistories")]
  public static extern void IndexManager_clearHistories(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IndexManager")]
  public static extern void delete_IndexManager(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_name")]
  public static extern string Index_name(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_fixingCalendar")]
  public static extern global::System.IntPtr Index_fixingCalendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_isValidFixingDate")]
  public static extern bool Index_isValidFixingDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_fixing__SWIG_0")]
  public static extern double Index_fixing__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_fixing__SWIG_1")]
  public static extern double Index_fixing__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_addFixing__SWIG_0")]
  public static extern void Index_addFixing__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_addFixing__SWIG_1")]
  public static extern void Index_addFixing__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_timeSeries")]
  public static extern global::System.IntPtr Index_timeSeries(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_clearFixings")]
  public static extern void Index_clearFixings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_addFixings__SWIG_0")]
  public static extern void Index_addFixings__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_addFixings__SWIG_1")]
  public static extern void Index_addFixings__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index___str__")]
  public static extern string Index___str__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Index")]
  public static extern void delete_Index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_familyName")]
  public static extern string InterestRateIndex_familyName(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_tenor")]
  public static extern global::System.IntPtr InterestRateIndex_tenor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_fixingDays")]
  public static extern uint InterestRateIndex_fixingDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_fixingDate")]
  public static extern global::System.IntPtr InterestRateIndex_fixingDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_currency")]
  public static extern global::System.IntPtr InterestRateIndex_currency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_dayCounter")]
  public static extern global::System.IntPtr InterestRateIndex_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_maturityDate")]
  public static extern global::System.IntPtr InterestRateIndex_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_valueDate")]
  public static extern global::System.IntPtr InterestRateIndex_valueDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InterestRateIndex")]
  public static extern void delete_InterestRateIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborIndex__SWIG_0")]
  public static extern global::System.IntPtr new_IborIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborIndex__SWIG_1")]
  public static extern global::System.IntPtr new_IborIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborIndex_businessDayConvention")]
  public static extern int IborIndex_businessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborIndex_endOfMonth")]
  public static extern bool IborIndex_endOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborIndex_forwardingTermStructure")]
  public static extern global::System.IntPtr IborIndex_forwardingTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborIndex_clone")]
  public static extern global::System.IntPtr IborIndex_clone(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IborIndex")]
  public static extern void delete_IborIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_iborindex")]
  public static extern global::System.IntPtr as_iborindex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndex__SWIG_0")]
  public static extern global::System.IntPtr new_OvernightIndex__SWIG_0(string jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndex__SWIG_1")]
  public static extern global::System.IntPtr new_OvernightIndex__SWIG_1(string jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndex_clone")]
  public static extern global::System.IntPtr OvernightIndex_clone(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndex")]
  public static extern void delete_OvernightIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Libor__SWIG_0")]
  public static extern global::System.IntPtr new_Libor__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Libor__SWIG_1")]
  public static extern global::System.IntPtr new_Libor__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Libor")]
  public static extern void delete_Libor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DailyTenorLibor__SWIG_0")]
  public static extern global::System.IntPtr new_DailyTenorLibor__SWIG_0(string jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DailyTenorLibor__SWIG_1")]
  public static extern global::System.IntPtr new_DailyTenorLibor__SWIG_1(string jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DailyTenorLibor")]
  public static extern void delete_DailyTenorLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapIndex__SWIG_0")]
  public static extern global::System.IntPtr new_SwapIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapIndex__SWIG_1")]
  public static extern global::System.IntPtr new_SwapIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_fixedLegTenor")]
  public static extern global::System.IntPtr SwapIndex_fixedLegTenor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_fixedLegConvention")]
  public static extern int SwapIndex_fixedLegConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_iborIndex")]
  public static extern global::System.IntPtr SwapIndex_iborIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_forwardingTermStructure")]
  public static extern global::System.IntPtr SwapIndex_forwardingTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_discountingTermStructure")]
  public static extern global::System.IntPtr SwapIndex_discountingTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_clone__SWIG_0")]
  public static extern global::System.IntPtr SwapIndex_clone__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_clone__SWIG_1")]
  public static extern global::System.IntPtr SwapIndex_clone__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_clone__SWIG_2")]
  public static extern global::System.IntPtr SwapIndex_clone__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwapIndex")]
  public static extern void delete_SwapIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Clear")]
  public static extern void SwapIndexVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Add")]
  public static extern void SwapIndexVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_size")]
  public static extern uint SwapIndexVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_capacity")]
  public static extern uint SwapIndexVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_reserve")]
  public static extern void SwapIndexVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapIndexVector__SWIG_0")]
  public static extern global::System.IntPtr new_SwapIndexVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapIndexVector__SWIG_1")]
  public static extern global::System.IntPtr new_SwapIndexVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapIndexVector__SWIG_2")]
  public static extern global::System.IntPtr new_SwapIndexVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_getitemcopy")]
  public static extern global::System.IntPtr SwapIndexVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_getitem")]
  public static extern global::System.IntPtr SwapIndexVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_setitem")]
  public static extern void SwapIndexVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_AddRange")]
  public static extern void SwapIndexVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_GetRange")]
  public static extern global::System.IntPtr SwapIndexVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Insert")]
  public static extern void SwapIndexVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_InsertRange")]
  public static extern void SwapIndexVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_RemoveAt")]
  public static extern void SwapIndexVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_RemoveRange")]
  public static extern void SwapIndexVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Repeat")]
  public static extern global::System.IntPtr SwapIndexVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Reverse__SWIG_0")]
  public static extern void SwapIndexVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Reverse__SWIG_1")]
  public static extern void SwapIndexVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_SetRange")]
  public static extern void SwapIndexVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Contains")]
  public static extern bool SwapIndexVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_IndexOf")]
  public static extern int SwapIndexVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_LastIndexOf")]
  public static extern int SwapIndexVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndexVector_Remove")]
  public static extern bool SwapIndexVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwapIndexVector")]
  public static extern void delete_SwapIndexVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_swap_index")]
  public static extern global::System.IntPtr as_swap_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapSpreadIndex__SWIG_0")]
  public static extern global::System.IntPtr new_SwapSpreadIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapSpreadIndex__SWIG_1")]
  public static extern global::System.IntPtr new_SwapSpreadIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapSpreadIndex__SWIG_2")]
  public static extern global::System.IntPtr new_SwapSpreadIndex__SWIG_2(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_forecastFixing")]
  public static extern double SwapSpreadIndex_forecastFixing(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_pastFixing")]
  public static extern double SwapSpreadIndex_pastFixing(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_swapIndex1")]
  public static extern global::System.IntPtr SwapSpreadIndex_swapIndex1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_swapIndex2")]
  public static extern global::System.IntPtr SwapSpreadIndex_swapIndex2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_gearing1")]
  public static extern double SwapSpreadIndex_gearing1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_gearing2")]
  public static extern double SwapSpreadIndex_gearing2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwapSpreadIndex")]
  public static extern void delete_SwapSpreadIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AUDLibor__SWIG_0")]
  public static extern global::System.IntPtr new_AUDLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AUDLibor__SWIG_1")]
  public static extern global::System.IntPtr new_AUDLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AUDLibor")]
  public static extern void delete_AUDLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CADLibor__SWIG_0")]
  public static extern global::System.IntPtr new_CADLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CADLibor__SWIG_1")]
  public static extern global::System.IntPtr new_CADLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CADLibor")]
  public static extern void delete_CADLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CADLiborON__SWIG_0")]
  public static extern global::System.IntPtr new_CADLiborON__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CADLiborON__SWIG_1")]
  public static extern global::System.IntPtr new_CADLiborON__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CADLiborON")]
  public static extern void delete_CADLiborON(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Cdor__SWIG_0")]
  public static extern global::System.IntPtr new_Cdor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Cdor__SWIG_1")]
  public static extern global::System.IntPtr new_Cdor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Cdor")]
  public static extern void delete_Cdor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CHFLibor__SWIG_0")]
  public static extern global::System.IntPtr new_CHFLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CHFLibor__SWIG_1")]
  public static extern global::System.IntPtr new_CHFLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CHFLibor")]
  public static extern void delete_CHFLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DKKLibor__SWIG_0")]
  public static extern global::System.IntPtr new_DKKLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DKKLibor__SWIG_1")]
  public static extern global::System.IntPtr new_DKKLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DKKLibor")]
  public static extern void delete_DKKLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw")]
  public static extern void delete_Bbsw(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw1M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw1M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw1M")]
  public static extern void delete_Bbsw1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw2M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw2M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw2M")]
  public static extern void delete_Bbsw2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw3M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw3M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw3M")]
  public static extern void delete_Bbsw3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw4M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw4M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw4M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw4M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw4M")]
  public static extern void delete_Bbsw4M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw5M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw5M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw5M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw5M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw5M")]
  public static extern void delete_Bbsw5M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw6M__SWIG_0")]
  public static extern global::System.IntPtr new_Bbsw6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bbsw6M__SWIG_1")]
  public static extern global::System.IntPtr new_Bbsw6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bbsw6M")]
  public static extern void delete_Bbsw6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm")]
  public static extern void delete_Bkbm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm1M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm1M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm1M")]
  public static extern void delete_Bkbm1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm2M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm2M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm2M")]
  public static extern void delete_Bkbm2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm3M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm3M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm3M")]
  public static extern void delete_Bkbm3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm4M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm4M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm4M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm4M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm4M")]
  public static extern void delete_Bkbm4M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm5M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm5M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm5M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm5M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm5M")]
  public static extern void delete_Bkbm5M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm6M__SWIG_0")]
  public static extern global::System.IntPtr new_Bkbm6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bkbm6M__SWIG_1")]
  public static extern global::System.IntPtr new_Bkbm6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bkbm6M")]
  public static extern void delete_Bkbm6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor")]
  public static extern void delete_Euribor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSW__SWIG_0")]
  public static extern global::System.IntPtr new_EuriborSW__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSW__SWIG_1")]
  public static extern global::System.IntPtr new_EuriborSW__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuriborSW")]
  public static extern void delete_EuriborSW(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor2W__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor2W__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor2W__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor2W__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor2W")]
  public static extern void delete_Euribor2W(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor3W__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor3W__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor3W__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor3W__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor3W")]
  public static extern void delete_Euribor3W(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor1M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor1M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor1M")]
  public static extern void delete_Euribor1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor2M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor2M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor2M")]
  public static extern void delete_Euribor2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor3M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor3M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor3M")]
  public static extern void delete_Euribor3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor4M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor4M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor4M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor4M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor4M")]
  public static extern void delete_Euribor4M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor5M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor5M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor5M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor5M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor5M")]
  public static extern void delete_Euribor5M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor6M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor6M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor6M")]
  public static extern void delete_Euribor6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor7M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor7M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor7M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor7M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor7M")]
  public static extern void delete_Euribor7M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor8M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor8M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor8M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor8M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor8M")]
  public static extern void delete_Euribor8M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor9M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor9M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor9M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor9M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor9M")]
  public static extern void delete_Euribor9M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor10M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor10M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor10M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor10M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor10M")]
  public static extern void delete_Euribor10M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor11M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor11M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor11M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor11M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor11M")]
  public static extern void delete_Euribor11M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor1Y__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor1Y__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor1Y__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor1Y__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor1Y")]
  public static extern void delete_Euribor1Y(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365")]
  public static extern void delete_Euribor365(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_SW__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_SW__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_SW__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_SW__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_SW")]
  public static extern void delete_Euribor365_SW(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_2W__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_2W__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_2W__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_2W__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_2W")]
  public static extern void delete_Euribor365_2W(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_3W__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_3W__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_3W__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_3W__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_3W")]
  public static extern void delete_Euribor365_3W(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_1M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_1M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_1M")]
  public static extern void delete_Euribor365_1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_2M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_2M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_2M")]
  public static extern void delete_Euribor365_2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_3M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_3M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_3M")]
  public static extern void delete_Euribor365_3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_4M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_4M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_4M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_4M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_4M")]
  public static extern void delete_Euribor365_4M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_5M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_5M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_5M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_5M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_5M")]
  public static extern void delete_Euribor365_5M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_6M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_6M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_6M")]
  public static extern void delete_Euribor365_6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_7M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_7M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_7M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_7M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_7M")]
  public static extern void delete_Euribor365_7M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_8M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_8M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_8M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_8M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_8M")]
  public static extern void delete_Euribor365_8M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_9M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_9M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_9M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_9M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_9M")]
  public static extern void delete_Euribor365_9M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_10M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_10M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_10M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_10M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_10M")]
  public static extern void delete_Euribor365_10M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_11M__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_11M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_11M__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_11M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_11M")]
  public static extern void delete_Euribor365_11M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_1Y__SWIG_0")]
  public static extern global::System.IntPtr new_Euribor365_1Y__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Euribor365_1Y__SWIG_1")]
  public static extern global::System.IntPtr new_Euribor365_1Y__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Euribor365_1Y")]
  public static extern void delete_Euribor365_1Y(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor")]
  public static extern void delete_EURLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLiborSW__SWIG_0")]
  public static extern global::System.IntPtr new_EURLiborSW__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLiborSW__SWIG_1")]
  public static extern global::System.IntPtr new_EURLiborSW__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLiborSW")]
  public static extern void delete_EURLiborSW(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor2W__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor2W__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor2W__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor2W__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor2W")]
  public static extern void delete_EURLibor2W(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor1M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor1M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor1M")]
  public static extern void delete_EURLibor1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor2M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor2M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor2M")]
  public static extern void delete_EURLibor2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor3M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor3M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor3M")]
  public static extern void delete_EURLibor3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor4M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor4M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor4M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor4M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor4M")]
  public static extern void delete_EURLibor4M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor5M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor5M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor5M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor5M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor5M")]
  public static extern void delete_EURLibor5M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor6M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor6M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor6M")]
  public static extern void delete_EURLibor6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor7M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor7M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor7M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor7M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor7M")]
  public static extern void delete_EURLibor7M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor8M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor8M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor8M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor8M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor8M")]
  public static extern void delete_EURLibor8M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor9M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor9M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor9M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor9M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor9M")]
  public static extern void delete_EURLibor9M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor10M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor10M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor10M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor10M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor10M")]
  public static extern void delete_EURLibor10M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor11M__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor11M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor11M__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor11M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor11M")]
  public static extern void delete_EURLibor11M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor1Y__SWIG_0")]
  public static extern global::System.IntPtr new_EURLibor1Y__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EURLibor1Y__SWIG_1")]
  public static extern global::System.IntPtr new_EURLibor1Y__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EURLibor1Y")]
  public static extern void delete_EURLibor1Y(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBPLibor__SWIG_0")]
  public static extern global::System.IntPtr new_GBPLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBPLibor__SWIG_1")]
  public static extern global::System.IntPtr new_GBPLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GBPLibor")]
  public static extern void delete_GBPLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBPLiborON__SWIG_0")]
  public static extern global::System.IntPtr new_GBPLiborON__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBPLiborON__SWIG_1")]
  public static extern global::System.IntPtr new_GBPLiborON__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GBPLiborON")]
  public static extern void delete_GBPLiborON(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Jibar__SWIG_0")]
  public static extern global::System.IntPtr new_Jibar__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Jibar__SWIG_1")]
  public static extern global::System.IntPtr new_Jibar__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Jibar")]
  public static extern void delete_Jibar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JPYLibor__SWIG_0")]
  public static extern global::System.IntPtr new_JPYLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JPYLibor__SWIG_1")]
  public static extern global::System.IntPtr new_JPYLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JPYLibor")]
  public static extern void delete_JPYLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Mosprime__SWIG_0")]
  public static extern global::System.IntPtr new_Mosprime__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Mosprime__SWIG_1")]
  public static extern global::System.IntPtr new_Mosprime__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Mosprime")]
  public static extern void delete_Mosprime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NZDLibor__SWIG_0")]
  public static extern global::System.IntPtr new_NZDLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NZDLibor__SWIG_1")]
  public static extern global::System.IntPtr new_NZDLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NZDLibor")]
  public static extern void delete_NZDLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Pribor__SWIG_0")]
  public static extern global::System.IntPtr new_Pribor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Pribor__SWIG_1")]
  public static extern global::System.IntPtr new_Pribor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Pribor")]
  public static extern void delete_Pribor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Robor__SWIG_0")]
  public static extern global::System.IntPtr new_Robor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Robor__SWIG_1")]
  public static extern global::System.IntPtr new_Robor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Robor")]
  public static extern void delete_Robor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SEKLibor__SWIG_0")]
  public static extern global::System.IntPtr new_SEKLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SEKLibor__SWIG_1")]
  public static extern global::System.IntPtr new_SEKLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SEKLibor")]
  public static extern void delete_SEKLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Shibor__SWIG_0")]
  public static extern global::System.IntPtr new_Shibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Shibor__SWIG_1")]
  public static extern global::System.IntPtr new_Shibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Shibor")]
  public static extern void delete_Shibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Tibor__SWIG_0")]
  public static extern global::System.IntPtr new_Tibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Tibor__SWIG_1")]
  public static extern global::System.IntPtr new_Tibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Tibor")]
  public static extern void delete_Tibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_THBFIX__SWIG_0")]
  public static extern global::System.IntPtr new_THBFIX__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_THBFIX__SWIG_1")]
  public static extern global::System.IntPtr new_THBFIX__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_THBFIX")]
  public static extern void delete_THBFIX(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TRLibor__SWIG_0")]
  public static extern global::System.IntPtr new_TRLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TRLibor__SWIG_1")]
  public static extern global::System.IntPtr new_TRLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TRLibor")]
  public static extern void delete_TRLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USDLibor__SWIG_0")]
  public static extern global::System.IntPtr new_USDLibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USDLibor__SWIG_1")]
  public static extern global::System.IntPtr new_USDLibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_USDLibor")]
  public static extern void delete_USDLibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USDLiborON__SWIG_0")]
  public static extern global::System.IntPtr new_USDLiborON__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USDLiborON__SWIG_1")]
  public static extern global::System.IntPtr new_USDLiborON__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_USDLiborON")]
  public static extern void delete_USDLiborON(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Wibor__SWIG_0")]
  public static extern global::System.IntPtr new_Wibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Wibor__SWIG_1")]
  public static extern global::System.IntPtr new_Wibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Wibor")]
  public static extern void delete_Wibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Zibor__SWIG_0")]
  public static extern global::System.IntPtr new_Zibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Zibor__SWIG_1")]
  public static extern global::System.IntPtr new_Zibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Zibor")]
  public static extern void delete_Zibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Aonia__SWIG_0")]
  public static extern global::System.IntPtr new_Aonia__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Aonia__SWIG_1")]
  public static extern global::System.IntPtr new_Aonia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Aonia")]
  public static extern void delete_Aonia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Eonia__SWIG_0")]
  public static extern global::System.IntPtr new_Eonia__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Eonia__SWIG_1")]
  public static extern global::System.IntPtr new_Eonia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Eonia")]
  public static extern void delete_Eonia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Sonia__SWIG_0")]
  public static extern global::System.IntPtr new_Sonia__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Sonia__SWIG_1")]
  public static extern global::System.IntPtr new_Sonia__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Sonia")]
  public static extern void delete_Sonia(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FedFunds__SWIG_0")]
  public static extern global::System.IntPtr new_FedFunds__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FedFunds__SWIG_1")]
  public static extern global::System.IntPtr new_FedFunds__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FedFunds")]
  public static extern void delete_FedFunds(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Nzocr__SWIG_0")]
  public static extern global::System.IntPtr new_Nzocr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Nzocr__SWIG_1")]
  public static extern global::System.IntPtr new_Nzocr__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Nzocr")]
  public static extern void delete_Nzocr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Sofr__SWIG_0")]
  public static extern global::System.IntPtr new_Sofr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Sofr__SWIG_1")]
  public static extern global::System.IntPtr new_Sofr__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Sofr")]
  public static extern void delete_Sofr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixA__SWIG_0")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixA__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixA__SWIG_1")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixA__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixA__SWIG_2")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixA__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuriborSwapIsdaFixA")]
  public static extern void delete_EuriborSwapIsdaFixA(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixB__SWIG_0")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixB__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixB__SWIG_1")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixB__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIsdaFixB__SWIG_2")]
  public static extern global::System.IntPtr new_EuriborSwapIsdaFixB__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuriborSwapIsdaFixB")]
  public static extern void delete_EuriborSwapIsdaFixB(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIfrFix__SWIG_0")]
  public static extern global::System.IntPtr new_EuriborSwapIfrFix__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIfrFix__SWIG_1")]
  public static extern global::System.IntPtr new_EuriborSwapIfrFix__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuriborSwapIfrFix__SWIG_2")]
  public static extern global::System.IntPtr new_EuriborSwapIfrFix__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuriborSwapIfrFix")]
  public static extern void delete_EuriborSwapIfrFix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixA__SWIG_0")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixA__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixA__SWIG_1")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixA__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixA__SWIG_2")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixA__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EurLiborSwapIsdaFixA")]
  public static extern void delete_EurLiborSwapIsdaFixA(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixB__SWIG_0")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixB__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixB__SWIG_1")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixB__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIsdaFixB__SWIG_2")]
  public static extern global::System.IntPtr new_EurLiborSwapIsdaFixB__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EurLiborSwapIsdaFixB")]
  public static extern void delete_EurLiborSwapIsdaFixB(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIfrFix__SWIG_0")]
  public static extern global::System.IntPtr new_EurLiborSwapIfrFix__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIfrFix__SWIG_1")]
  public static extern global::System.IntPtr new_EurLiborSwapIfrFix__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EurLiborSwapIfrFix__SWIG_2")]
  public static extern global::System.IntPtr new_EurLiborSwapIfrFix__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EurLiborSwapIfrFix")]
  public static extern void delete_EurLiborSwapIfrFix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ChfLiborSwapIsdaFix__SWIG_0")]
  public static extern global::System.IntPtr new_ChfLiborSwapIsdaFix__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ChfLiborSwapIsdaFix__SWIG_1")]
  public static extern global::System.IntPtr new_ChfLiborSwapIsdaFix__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ChfLiborSwapIsdaFix__SWIG_2")]
  public static extern global::System.IntPtr new_ChfLiborSwapIsdaFix__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ChfLiborSwapIsdaFix")]
  public static extern void delete_ChfLiborSwapIsdaFix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GbpLiborSwapIsdaFix__SWIG_0")]
  public static extern global::System.IntPtr new_GbpLiborSwapIsdaFix__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GbpLiborSwapIsdaFix__SWIG_1")]
  public static extern global::System.IntPtr new_GbpLiborSwapIsdaFix__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GbpLiborSwapIsdaFix__SWIG_2")]
  public static extern global::System.IntPtr new_GbpLiborSwapIsdaFix__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GbpLiborSwapIsdaFix")]
  public static extern void delete_GbpLiborSwapIsdaFix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixAm__SWIG_0")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixAm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixAm__SWIG_1")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixAm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixAm__SWIG_2")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixAm__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JpyLiborSwapIsdaFixAm")]
  public static extern void delete_JpyLiborSwapIsdaFixAm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixPm__SWIG_0")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixPm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixPm__SWIG_1")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixPm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JpyLiborSwapIsdaFixPm__SWIG_2")]
  public static extern global::System.IntPtr new_JpyLiborSwapIsdaFixPm__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JpyLiborSwapIsdaFixPm")]
  public static extern void delete_JpyLiborSwapIsdaFixPm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixAm__SWIG_0")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixAm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixAm__SWIG_1")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixAm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixAm__SWIG_2")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixAm__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UsdLiborSwapIsdaFixAm")]
  public static extern void delete_UsdLiborSwapIsdaFixAm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixPm__SWIG_0")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixPm__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixPm__SWIG_1")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixPm__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UsdLiborSwapIsdaFixPm__SWIG_2")]
  public static extern global::System.IntPtr new_UsdLiborSwapIsdaFixPm__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UsdLiborSwapIsdaFixPm")]
  public static extern void delete_UsdLiborSwapIsdaFixPm(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor")]
  public static extern void delete_Bibor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BiborSW__SWIG_0")]
  public static extern global::System.IntPtr new_BiborSW__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BiborSW__SWIG_1")]
  public static extern global::System.IntPtr new_BiborSW__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BiborSW")]
  public static extern void delete_BiborSW(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor1M__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor1M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor1M__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor1M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor1M")]
  public static extern void delete_Bibor1M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor2M__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor2M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor2M__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor2M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor2M")]
  public static extern void delete_Bibor2M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor3M__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor3M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor3M__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor3M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor3M")]
  public static extern void delete_Bibor3M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor6M__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor6M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor6M__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor6M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor6M")]
  public static extern void delete_Bibor6M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor9M__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor9M__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor9M__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor9M__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor9M")]
  public static extern void delete_Bibor9M(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor1Y__SWIG_0")]
  public static extern global::System.IntPtr new_Bibor1Y__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bibor1Y__SWIG_1")]
  public static extern global::System.IntPtr new_Bibor1Y__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bibor1Y")]
  public static extern void delete_Bibor1Y(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VolatilityTermStructure_minStrike")]
  public static extern double VolatilityTermStructure_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VolatilityTermStructure_maxStrike")]
  public static extern double VolatilityTermStructure_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VolatilityTermStructure")]
  public static extern void delete_VolatilityTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVol__SWIG_0")]
  public static extern double BlackVolTermStructure_blackVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVol__SWIG_1")]
  public static extern double BlackVolTermStructure_blackVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVol__SWIG_2")]
  public static extern double BlackVolTermStructure_blackVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVol__SWIG_3")]
  public static extern double BlackVolTermStructure_blackVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVariance__SWIG_0")]
  public static extern double BlackVolTermStructure_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVariance__SWIG_1")]
  public static extern double BlackVolTermStructure_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVariance__SWIG_2")]
  public static extern double BlackVolTermStructure_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackVariance__SWIG_3")]
  public static extern double BlackVolTermStructure_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVol__SWIG_0")]
  public static extern double BlackVolTermStructure_blackForwardVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVol__SWIG_1")]
  public static extern double BlackVolTermStructure_blackForwardVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVol__SWIG_2")]
  public static extern double BlackVolTermStructure_blackForwardVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVol__SWIG_3")]
  public static extern double BlackVolTermStructure_blackForwardVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVariance__SWIG_0")]
  public static extern double BlackVolTermStructure_blackForwardVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVariance__SWIG_1")]
  public static extern double BlackVolTermStructure_blackForwardVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVariance__SWIG_2")]
  public static extern double BlackVolTermStructure_blackForwardVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_blackForwardVariance__SWIG_3")]
  public static extern double BlackVolTermStructure_blackForwardVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackVolTermStructure")]
  public static extern void delete_BlackVolTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVolTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_BlackVolTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVolTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_BlackVolTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle___deref__")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_empty")]
  public static extern bool BlackVolTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackVolTermStructureHandle")]
  public static extern void delete_BlackVolTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVol__SWIG_0")]
  public static extern double BlackVolTermStructureHandle_blackVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVol__SWIG_1")]
  public static extern double BlackVolTermStructureHandle_blackVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVol__SWIG_2")]
  public static extern double BlackVolTermStructureHandle_blackVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVol__SWIG_3")]
  public static extern double BlackVolTermStructureHandle_blackVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVariance__SWIG_0")]
  public static extern double BlackVolTermStructureHandle_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVariance__SWIG_1")]
  public static extern double BlackVolTermStructureHandle_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVariance__SWIG_2")]
  public static extern double BlackVolTermStructureHandle_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackVariance__SWIG_3")]
  public static extern double BlackVolTermStructureHandle_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVol__SWIG_0")]
  public static extern double BlackVolTermStructureHandle_blackForwardVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVol__SWIG_1")]
  public static extern double BlackVolTermStructureHandle_blackForwardVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVol__SWIG_2")]
  public static extern double BlackVolTermStructureHandle_blackForwardVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVol__SWIG_3")]
  public static extern double BlackVolTermStructureHandle_blackForwardVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVariance__SWIG_0")]
  public static extern double BlackVolTermStructureHandle_blackForwardVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVariance__SWIG_1")]
  public static extern double BlackVolTermStructureHandle_blackForwardVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVariance__SWIG_2")]
  public static extern double BlackVolTermStructureHandle_blackForwardVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_blackForwardVariance__SWIG_3")]
  public static extern double BlackVolTermStructureHandle_blackForwardVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_minStrike")]
  public static extern double BlackVolTermStructureHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_maxStrike")]
  public static extern double BlackVolTermStructureHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_timeFromReference")]
  public static extern double BlackVolTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_calendar")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr BlackVolTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_maxTime")]
  public static extern double BlackVolTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_enableExtrapolation")]
  public static extern void BlackVolTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_disableExtrapolation")]
  public static extern void BlackVolTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructureHandle_allowsExtrapolation")]
  public static extern bool BlackVolTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableBlackVolTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableBlackVolTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableBlackVolTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableBlackVolTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableBlackVolTermStructureHandle_linkTo")]
  public static extern void RelinkableBlackVolTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableBlackVolTermStructureHandle_reset")]
  public static extern void RelinkableBlackVolTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableBlackVolTermStructureHandle")]
  public static extern void delete_RelinkableBlackVolTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructure_localVol__SWIG_0")]
  public static extern double LocalVolTermStructure_localVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructure_localVol__SWIG_1")]
  public static extern double LocalVolTermStructure_localVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructure_localVol__SWIG_2")]
  public static extern double LocalVolTermStructure_localVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructure_localVol__SWIG_3")]
  public static extern double LocalVolTermStructure_localVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LocalVolTermStructure")]
  public static extern void delete_LocalVolTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_LocalVolTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_LocalVolTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle___deref__")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_empty")]
  public static extern bool LocalVolTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LocalVolTermStructureHandle")]
  public static extern void delete_LocalVolTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_localVol__SWIG_0")]
  public static extern double LocalVolTermStructureHandle_localVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_localVol__SWIG_1")]
  public static extern double LocalVolTermStructureHandle_localVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_localVol__SWIG_2")]
  public static extern double LocalVolTermStructureHandle_localVol__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_localVol__SWIG_3")]
  public static extern double LocalVolTermStructureHandle_localVol__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_minStrike")]
  public static extern double LocalVolTermStructureHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_maxStrike")]
  public static extern double LocalVolTermStructureHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_timeFromReference")]
  public static extern double LocalVolTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_calendar")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr LocalVolTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_maxTime")]
  public static extern double LocalVolTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_enableExtrapolation")]
  public static extern void LocalVolTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_disableExtrapolation")]
  public static extern void LocalVolTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructureHandle_allowsExtrapolation")]
  public static extern bool LocalVolTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableLocalVolTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableLocalVolTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableLocalVolTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableLocalVolTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableLocalVolTermStructureHandle_linkTo")]
  public static extern void RelinkableLocalVolTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableLocalVolTermStructureHandle_reset")]
  public static extern void RelinkableLocalVolTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableLocalVolTermStructureHandle")]
  public static extern void delete_RelinkableLocalVolTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_volatility__SWIG_0")]
  public static extern double OptionletVolatilityStructure_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_volatility__SWIG_1")]
  public static extern double OptionletVolatilityStructure_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_volatility__SWIG_2")]
  public static extern double OptionletVolatilityStructure_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_volatility__SWIG_3")]
  public static extern double OptionletVolatilityStructure_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_blackVariance__SWIG_0")]
  public static extern double OptionletVolatilityStructure_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_blackVariance__SWIG_1")]
  public static extern double OptionletVolatilityStructure_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_blackVariance__SWIG_2")]
  public static extern double OptionletVolatilityStructure_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_blackVariance__SWIG_3")]
  public static extern double OptionletVolatilityStructure_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OptionletVolatilityStructure")]
  public static extern void delete_OptionletVolatilityStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_OptionletVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_OptionletVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle___deref__")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_currentLink")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_empty")]
  public static extern bool OptionletVolatilityStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_asObservable")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OptionletVolatilityStructureHandle")]
  public static extern void delete_OptionletVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_volatility__SWIG_0")]
  public static extern double OptionletVolatilityStructureHandle_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_volatility__SWIG_1")]
  public static extern double OptionletVolatilityStructureHandle_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_volatility__SWIG_2")]
  public static extern double OptionletVolatilityStructureHandle_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_volatility__SWIG_3")]
  public static extern double OptionletVolatilityStructureHandle_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_blackVariance__SWIG_0")]
  public static extern double OptionletVolatilityStructureHandle_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_blackVariance__SWIG_1")]
  public static extern double OptionletVolatilityStructureHandle_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_blackVariance__SWIG_2")]
  public static extern double OptionletVolatilityStructureHandle_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_blackVariance__SWIG_3")]
  public static extern double OptionletVolatilityStructureHandle_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_minStrike")]
  public static extern double OptionletVolatilityStructureHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_maxStrike")]
  public static extern double OptionletVolatilityStructureHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_dayCounter")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_timeFromReference")]
  public static extern double OptionletVolatilityStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_calendar")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_referenceDate")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_maxDate")]
  public static extern global::System.IntPtr OptionletVolatilityStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_maxTime")]
  public static extern double OptionletVolatilityStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_enableExtrapolation")]
  public static extern void OptionletVolatilityStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_disableExtrapolation")]
  public static extern void OptionletVolatilityStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructureHandle_allowsExtrapolation")]
  public static extern bool OptionletVolatilityStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableOptionletVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableOptionletVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableOptionletVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableOptionletVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableOptionletVolatilityStructureHandle_linkTo")]
  public static extern void RelinkableOptionletVolatilityStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableOptionletVolatilityStructureHandle_reset")]
  public static extern void RelinkableOptionletVolatilityStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableOptionletVolatilityStructureHandle")]
  public static extern void delete_RelinkableOptionletVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_observationLag")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurface_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_frequency")]
  public static extern double YoYOptionletVolatilitySurface_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_indexIsInterpolated")]
  public static extern bool YoYOptionletVolatilitySurface_indexIsInterpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_baseDate")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurface_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_timeFromBase__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurface_timeFromBase__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_timeFromBase__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurface_timeFromBase__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_minStrike")]
  public static extern double YoYOptionletVolatilitySurface_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_maxStrike")]
  public static extern double YoYOptionletVolatilitySurface_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_baseLevel")]
  public static extern double YoYOptionletVolatilitySurface_baseLevel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_2")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_3")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_4")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_volatility__SWIG_5")]
  public static extern double YoYOptionletVolatilitySurface_volatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_2")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_3")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_4")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_totalVariance__SWIG_5")]
  public static extern double YoYOptionletVolatilitySurface_totalVariance__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionletVolatilitySurface")]
  public static extern void delete_YoYOptionletVolatilitySurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionletVolatilitySurfaceHandle__SWIG_0")]
  public static extern global::System.IntPtr new_YoYOptionletVolatilitySurfaceHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionletVolatilitySurfaceHandle__SWIG_1")]
  public static extern global::System.IntPtr new_YoYOptionletVolatilitySurfaceHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle___deref__")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_currentLink")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_empty")]
  public static extern bool YoYOptionletVolatilitySurfaceHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_asObservable")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionletVolatilitySurfaceHandle")]
  public static extern void delete_YoYOptionletVolatilitySurfaceHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_observationLag")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_frequency")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_indexIsInterpolated")]
  public static extern bool YoYOptionletVolatilitySurfaceHandle_indexIsInterpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_baseDate")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_timeFromBase__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_minStrike")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_maxStrike")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_baseLevel")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_baseLevel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_2")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_3")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_4")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_5")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_volatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_0")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_1")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_2")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_3")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_4")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_5")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_totalVariance__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_dayCounter")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_timeFromReference")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_calendar")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_referenceDate")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_maxDate")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurfaceHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_maxTime")]
  public static extern double YoYOptionletVolatilitySurfaceHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_enableExtrapolation")]
  public static extern void YoYOptionletVolatilitySurfaceHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_disableExtrapolation")]
  public static extern void YoYOptionletVolatilitySurfaceHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurfaceHandle_allowsExtrapolation")]
  public static extern bool YoYOptionletVolatilitySurfaceHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYoYOptionletVolatilitySurface__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableYoYOptionletVolatilitySurface__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYoYOptionletVolatilitySurface__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableYoYOptionletVolatilitySurface__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYOptionletVolatilitySurface_linkTo")]
  public static extern void RelinkableYoYOptionletVolatilitySurface_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYOptionletVolatilitySurface_reset")]
  public static extern void RelinkableYoYOptionletVolatilitySurface_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableYoYOptionletVolatilitySurface")]
  public static extern void delete_RelinkableYoYOptionletVolatilitySurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_minStrike")]
  public static extern double SmileSection_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_maxStrike")]
  public static extern double SmileSection_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_atmLevel")]
  public static extern double SmileSection_atmLevel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_variance")]
  public static extern double SmileSection_variance(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_volatility__SWIG_0")]
  public static extern double SmileSection_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_exerciseDate")]
  public static extern global::System.IntPtr SmileSection_exerciseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_volatilityType")]
  public static extern int SmileSection_volatilityType(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_shift")]
  public static extern double SmileSection_shift(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_referenceDate")]
  public static extern global::System.IntPtr SmileSection_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_exerciseTime")]
  public static extern double SmileSection_exerciseTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_dayCounter")]
  public static extern global::System.IntPtr SmileSection_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_optionPrice__SWIG_0")]
  public static extern double SmileSection_optionPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_optionPrice__SWIG_1")]
  public static extern double SmileSection_optionPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_optionPrice__SWIG_2")]
  public static extern double SmileSection_optionPrice__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_digitalOptionPrice__SWIG_0")]
  public static extern double SmileSection_digitalOptionPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_digitalOptionPrice__SWIG_1")]
  public static extern double SmileSection_digitalOptionPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_digitalOptionPrice__SWIG_2")]
  public static extern double SmileSection_digitalOptionPrice__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_digitalOptionPrice__SWIG_3")]
  public static extern double SmileSection_digitalOptionPrice__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_vega__SWIG_0")]
  public static extern double SmileSection_vega__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_vega__SWIG_1")]
  public static extern double SmileSection_vega__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_density__SWIG_0")]
  public static extern double SmileSection_density__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_density__SWIG_1")]
  public static extern double SmileSection_density__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_density__SWIG_2")]
  public static extern double SmileSection_density__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_volatility__SWIG_1")]
  public static extern double SmileSection_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_volatility__SWIG_2")]
  public static extern double SmileSection_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SmileSection")]
  public static extern void delete_SmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Clear")]
  public static extern void SmileSectionVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Add")]
  public static extern void SmileSectionVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_size")]
  public static extern uint SmileSectionVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_capacity")]
  public static extern uint SmileSectionVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_reserve")]
  public static extern void SmileSectionVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SmileSectionVector__SWIG_0")]
  public static extern global::System.IntPtr new_SmileSectionVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SmileSectionVector__SWIG_1")]
  public static extern global::System.IntPtr new_SmileSectionVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SmileSectionVector__SWIG_2")]
  public static extern global::System.IntPtr new_SmileSectionVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_getitemcopy")]
  public static extern global::System.IntPtr SmileSectionVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_getitem")]
  public static extern global::System.IntPtr SmileSectionVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_setitem")]
  public static extern void SmileSectionVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_AddRange")]
  public static extern void SmileSectionVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_GetRange")]
  public static extern global::System.IntPtr SmileSectionVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Insert")]
  public static extern void SmileSectionVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_InsertRange")]
  public static extern void SmileSectionVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_RemoveAt")]
  public static extern void SmileSectionVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_RemoveRange")]
  public static extern void SmileSectionVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Repeat")]
  public static extern global::System.IntPtr SmileSectionVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Reverse__SWIG_0")]
  public static extern void SmileSectionVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Reverse__SWIG_1")]
  public static extern void SmileSectionVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_SetRange")]
  public static extern void SmileSectionVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Contains")]
  public static extern bool SmileSectionVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_IndexOf")]
  public static extern int SmileSectionVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_LastIndexOf")]
  public static extern int SmileSectionVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSectionVector_Remove")]
  public static extern bool SmileSectionVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SmileSectionVector")]
  public static extern void delete_SmileSectionVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_volatility__SWIG_0")]
  public static extern double SwaptionVolatilityStructure_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_volatility__SWIG_1")]
  public static extern double SwaptionVolatilityStructure_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_volatility__SWIG_2")]
  public static extern double SwaptionVolatilityStructure_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_volatility__SWIG_3")]
  public static extern double SwaptionVolatilityStructure_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_blackVariance__SWIG_0")]
  public static extern double SwaptionVolatilityStructure_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_blackVariance__SWIG_1")]
  public static extern double SwaptionVolatilityStructure_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_blackVariance__SWIG_2")]
  public static extern double SwaptionVolatilityStructure_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_blackVariance__SWIG_3")]
  public static extern double SwaptionVolatilityStructure_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_optionDateFromTenor")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_optionDateFromTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_0")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_1")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_2")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_3")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_4")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_5")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_6")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_7")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_8")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_9")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_10")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_shift__SWIG_11")]
  public static extern double SwaptionVolatilityStructure_shift__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_0")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_1")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_2")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_3")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_4")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_5")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_6")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_7")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_8")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_9")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_10")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_smileSection__SWIG_11")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_smileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolatilityStructure")]
  public static extern void delete_SwaptionVolatilityStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_SwaptionVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_SwaptionVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle___deref__")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_currentLink")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_empty")]
  public static extern bool SwaptionVolatilityStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_asObservable")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolatilityStructureHandle")]
  public static extern void delete_SwaptionVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_volatility__SWIG_0")]
  public static extern double SwaptionVolatilityStructureHandle_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_volatility__SWIG_1")]
  public static extern double SwaptionVolatilityStructureHandle_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_volatility__SWIG_2")]
  public static extern double SwaptionVolatilityStructureHandle_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_volatility__SWIG_3")]
  public static extern double SwaptionVolatilityStructureHandle_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_blackVariance__SWIG_0")]
  public static extern double SwaptionVolatilityStructureHandle_blackVariance__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_blackVariance__SWIG_1")]
  public static extern double SwaptionVolatilityStructureHandle_blackVariance__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_blackVariance__SWIG_2")]
  public static extern double SwaptionVolatilityStructureHandle_blackVariance__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_blackVariance__SWIG_3")]
  public static extern double SwaptionVolatilityStructureHandle_blackVariance__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_optionDateFromTenor")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_optionDateFromTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_0")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_1")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_2")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_3")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_4")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_5")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_6")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_7")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_8")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_9")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_10")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_shift__SWIG_11")]
  public static extern double SwaptionVolatilityStructureHandle_shift__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_0")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_1")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_2")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_3")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_4")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_5")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_6")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_7")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_8")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_9")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_10")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_smileSection__SWIG_11")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_smileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_minStrike")]
  public static extern double SwaptionVolatilityStructureHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_maxStrike")]
  public static extern double SwaptionVolatilityStructureHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_dayCounter")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_timeFromReference")]
  public static extern double SwaptionVolatilityStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_calendar")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_referenceDate")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_maxDate")]
  public static extern global::System.IntPtr SwaptionVolatilityStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_maxTime")]
  public static extern double SwaptionVolatilityStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_enableExtrapolation")]
  public static extern void SwaptionVolatilityStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_disableExtrapolation")]
  public static extern void SwaptionVolatilityStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructureHandle_allowsExtrapolation")]
  public static extern bool SwaptionVolatilityStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableSwaptionVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableSwaptionVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableSwaptionVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableSwaptionVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableSwaptionVolatilityStructureHandle_linkTo")]
  public static extern void RelinkableSwaptionVolatilityStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableSwaptionVolatilityStructureHandle_reset")]
  public static extern void RelinkableSwaptionVolatilityStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableSwaptionVolatilityStructureHandle")]
  public static extern void delete_RelinkableSwaptionVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackConstantVol__SWIG_0")]
  public static extern global::System.IntPtr new_BlackConstantVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackConstantVol__SWIG_1")]
  public static extern global::System.IntPtr new_BlackConstantVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackConstantVol__SWIG_2")]
  public static extern global::System.IntPtr new_BlackConstantVol__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackConstantVol__SWIG_3")]
  public static extern global::System.IntPtr new_BlackConstantVol__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackConstantVol")]
  public static extern void delete_BlackConstantVol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceCurve__SWIG_0")]
  public static extern global::System.IntPtr new_BlackVarianceCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceCurve__SWIG_1")]
  public static extern global::System.IntPtr new_BlackVarianceCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackVarianceCurve")]
  public static extern void delete_BlackVarianceCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceSurface__SWIG_0")]
  public static extern global::System.IntPtr new_BlackVarianceSurface__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, int jarg8, string jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceSurface__SWIG_1")]
  public static extern global::System.IntPtr new_BlackVarianceSurface__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceSurface__SWIG_2")]
  public static extern global::System.IntPtr new_BlackVarianceSurface__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackVarianceSurface__SWIG_3")]
  public static extern global::System.IntPtr new_BlackVarianceSurface__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVarianceSurface_setInterpolation__SWIG_0")]
  public static extern void BlackVarianceSurface_setInterpolation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVarianceSurface_setInterpolation__SWIG_1")]
  public static extern void BlackVarianceSurface_setInterpolation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackVarianceSurface")]
  public static extern void delete_BlackVarianceSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalConstantVol__SWIG_0")]
  public static extern global::System.IntPtr new_LocalConstantVol__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalConstantVol__SWIG_1")]
  public static extern global::System.IntPtr new_LocalConstantVol__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalConstantVol__SWIG_2")]
  public static extern global::System.IntPtr new_LocalConstantVol__SWIG_2(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalConstantVol__SWIG_3")]
  public static extern global::System.IntPtr new_LocalConstantVol__SWIG_3(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LocalConstantVol")]
  public static extern void delete_LocalConstantVol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolSurface__SWIG_0")]
  public static extern global::System.IntPtr new_LocalVolSurface__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolSurface__SWIG_1")]
  public static extern global::System.IntPtr new_LocalVolSurface__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LocalVolSurface")]
  public static extern void delete_LocalVolSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoExceptLocalVolSurface__SWIG_0")]
  public static extern global::System.IntPtr new_NoExceptLocalVolSurface__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoExceptLocalVolSurface__SWIG_1")]
  public static extern global::System.IntPtr new_NoExceptLocalVolSurface__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NoExceptLocalVolSurface")]
  public static extern void delete_NoExceptLocalVolSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_0")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_1")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_2")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_3")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_4")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_5")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_6")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_7")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_8")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_8(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_9")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_9(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_10")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_10(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantOptionletVolatility__SWIG_11")]
  public static extern global::System.IntPtr new_ConstantOptionletVolatility__SWIG_11(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConstantOptionletVolatility")]
  public static extern void delete_ConstantOptionletVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_0")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_1")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_2")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_3")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_4")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_5")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_6")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_7")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_8")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_8(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_9")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_10")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantSwaptionVolatility__SWIG_11")]
  public static extern global::System.IntPtr new_ConstantSwaptionVolatility__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConstantSwaptionVolatility")]
  public static extern void delete_ConstantSwaptionVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_optionTenors")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_optionTenors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_optionDates")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_optionDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_optionTimes")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_optionTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_swapTenors")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_swapTenors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_swapLengths")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_swapLengths(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_optionDateFromTime")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_optionDateFromTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolatilityDiscrete")]
  public static extern void delete_SwaptionVolatilityDiscrete(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_0")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_1")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_2")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_3")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_4")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_5")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_6")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_7")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_8")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_9")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_10")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_11")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_12")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_13")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_14")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolatilityMatrix__SWIG_15")]
  public static extern global::System.IntPtr new_SwaptionVolatilityMatrix__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityMatrix_locate__SWIG_0")]
  public static extern global::System.IntPtr SwaptionVolatilityMatrix_locate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityMatrix_locate__SWIG_1")]
  public static extern global::System.IntPtr SwaptionVolatilityMatrix_locate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityMatrix_volatilityType")]
  public static extern int SwaptionVolatilityMatrix_volatilityType(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolatilityMatrix")]
  public static extern void delete_SwaptionVolatilityMatrix(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SabrSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_SabrSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SabrSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_SabrSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SabrSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_SabrSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SabrSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_SabrSmileSection__SWIG_3(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SabrSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_SabrSmileSection__SWIG_4(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SabrSmileSection_alpha")]
  public static extern double SabrSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SabrSmileSection_beta")]
  public static extern double SabrSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SabrSmileSection_nu")]
  public static extern double SabrSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SabrSmileSection_rho")]
  public static extern double SabrSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SabrSmileSection")]
  public static extern void delete_SabrSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityCube_atmStrike")]
  public static extern double SwaptionVolatilityCube_atmStrike(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolatilityCube")]
  public static extern void delete_SwaptionVolatilityCube(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_0")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, double jarg15, bool jarg16, uint jarg17, bool jarg18, double jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_1")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, double jarg15, bool jarg16, uint jarg17, bool jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_2")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, double jarg15, bool jarg16, uint jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_3")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, double jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_4")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, double jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_5")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_6")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_7")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube1__SWIG_8")]
  public static extern global::System.IntPtr new_SwaptionVolCube1__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_sparseSabrParameters")]
  public static extern global::System.IntPtr SwaptionVolCube1_sparseSabrParameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_denseSabrParameters")]
  public static extern global::System.IntPtr SwaptionVolCube1_denseSabrParameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_marketVolCube")]
  public static extern global::System.IntPtr SwaptionVolCube1_marketVolCube(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_volCubeAtmCalibrated")]
  public static extern global::System.IntPtr SwaptionVolCube1_volCubeAtmCalibrated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_smileSection__SWIG_0")]
  public static extern global::System.IntPtr SwaptionVolCube1_smileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_smileSection__SWIG_1")]
  public static extern global::System.IntPtr SwaptionVolCube1_smileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_smileSection__SWIG_2")]
  public static extern global::System.IntPtr SwaptionVolCube1_smileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_smileSection__SWIG_3")]
  public static extern global::System.IntPtr SwaptionVolCube1_smileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolCube1")]
  public static extern void delete_SwaptionVolCube1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionVolCube2")]
  public static extern global::System.IntPtr new_SwaptionVolCube2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionVolCube2")]
  public static extern void delete_SwaptionVolCube2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantYoYOptionletVolatility__SWIG_0")]
  public static extern global::System.IntPtr new_ConstantYoYOptionletVolatility__SWIG_0(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, bool jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantYoYOptionletVolatility__SWIG_1")]
  public static extern global::System.IntPtr new_ConstantYoYOptionletVolatility__SWIG_1(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, bool jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantYoYOptionletVolatility__SWIG_2")]
  public static extern global::System.IntPtr new_ConstantYoYOptionletVolatility__SWIG_2(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConstantYoYOptionletVolatility")]
  public static extern void delete_ConstantYoYOptionletVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_5(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_6(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_7(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_FlatSmileSection__SWIG_8(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FlatSmileSection")]
  public static extern void delete_FlatSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_6(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_7(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_8(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_20")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_20(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearInterpolatedSmileSection__SWIG_21")]
  public static extern global::System.IntPtr new_LinearInterpolatedSmileSection__SWIG_21(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LinearInterpolatedSmileSection")]
  public static extern void delete_LinearInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_6(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_7(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_8(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_20")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_20(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicInterpolatedSmileSection__SWIG_21")]
  public static extern global::System.IntPtr new_CubicInterpolatedSmileSection__SWIG_21(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CubicInterpolatedSmileSection")]
  public static extern void delete_CubicInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_6(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_7(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_8(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_20")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_20(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicInterpolatedSmileSection__SWIG_21")]
  public static extern global::System.IntPtr new_MonotonicCubicInterpolatedSmileSection__SWIG_21(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicCubicInterpolatedSmileSection")]
  public static extern void delete_MonotonicCubicInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_6(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_7(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_8(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_20")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_20(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SplineCubicInterpolatedSmileSection__SWIG_21")]
  public static extern global::System.IntPtr new_SplineCubicInterpolatedSmileSection__SWIG_21(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SplineCubicInterpolatedSmileSection")]
  public static extern void delete_SplineCubicInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KahaleSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_KahaleSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KahaleSmileSection")]
  public static extern void delete_KahaleSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormal")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormal();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityLognormal")]
  public static extern void delete_ZabrShortMaturityLognormal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormal")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormal();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityNormal")]
  public static extern void delete_ZabrShortMaturityNormal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatility")]
  public static extern global::System.IntPtr new_ZabrLocalVolatility();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrLocalVolatility")]
  public static extern void delete_ZabrLocalVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFd")]
  public static extern global::System.IntPtr new_ZabrFullFd();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrFullFd")]
  public static extern void delete_ZabrFullFd(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_2(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityLognormalSmileSection")]
  public static extern void delete_ZabrShortMaturityLognormalSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_2(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityNormalSmileSection")]
  public static extern void delete_ZabrShortMaturityNormalSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_2(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilitySmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilitySmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrLocalVolatilitySmileSection")]
  public static extern void delete_ZabrLocalVolatilitySmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_2(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrFullFdSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrFullFdSmileSection")]
  public static extern void delete_ZabrFullFdSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_ZabrShortMaturityLognormalInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_alpha")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_beta")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_nu")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_rho")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_rmsError")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_rmsError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_maxError")]
  public static extern double ZabrShortMaturityLognormalInterpolatedSmileSection_maxError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_endCriteria")]
  public static extern int ZabrShortMaturityLognormalInterpolatedSmileSection_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityLognormalInterpolatedSmileSection")]
  public static extern void delete_ZabrShortMaturityLognormalInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_ZabrShortMaturityNormalInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_alpha")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_beta")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_nu")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_rho")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_rmsError")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_rmsError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_maxError")]
  public static extern double ZabrShortMaturityNormalInterpolatedSmileSection_maxError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_endCriteria")]
  public static extern int ZabrShortMaturityNormalInterpolatedSmileSection_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrShortMaturityNormalInterpolatedSmileSection")]
  public static extern void delete_ZabrShortMaturityNormalInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_ZabrLocalVolatilityInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_alpha")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_beta")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_nu")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_rho")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_rmsError")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_rmsError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_maxError")]
  public static extern double ZabrLocalVolatilityInterpolatedSmileSection_maxError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_endCriteria")]
  public static extern int ZabrLocalVolatilityInterpolatedSmileSection_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrLocalVolatilityInterpolatedSmileSection")]
  public static extern void delete_ZabrLocalVolatilityInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, bool jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_18")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZabrFullFdInterpolatedSmileSection__SWIG_19")]
  public static extern global::System.IntPtr new_ZabrFullFdInterpolatedSmileSection__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_alpha")]
  public static extern double ZabrFullFdInterpolatedSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_beta")]
  public static extern double ZabrFullFdInterpolatedSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_nu")]
  public static extern double ZabrFullFdInterpolatedSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_rho")]
  public static extern double ZabrFullFdInterpolatedSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_rmsError")]
  public static extern double ZabrFullFdInterpolatedSmileSection_rmsError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_maxError")]
  public static extern double ZabrFullFdInterpolatedSmileSection_maxError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_endCriteria")]
  public static extern int ZabrFullFdInterpolatedSmileSection_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZabrFullFdInterpolatedSmileSection")]
  public static extern void delete_ZabrFullFdInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_NoArbSabrSmileSection__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_NoArbSabrSmileSection__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_NoArbSabrSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_NoArbSabrSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_NoArbSabrSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NoArbSabrSmileSection")]
  public static extern void delete_NoArbSabrSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_0")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_1")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_2")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_3")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_4")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_5")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_6")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_7")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_8")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_9")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_10")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_11")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_12")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_13")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_14")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_15")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_16")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NoArbSabrInterpolatedSmileSection__SWIG_17")]
  public static extern global::System.IntPtr new_NoArbSabrInterpolatedSmileSection__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_alpha")]
  public static extern double NoArbSabrInterpolatedSmileSection_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_beta")]
  public static extern double NoArbSabrInterpolatedSmileSection_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_nu")]
  public static extern double NoArbSabrInterpolatedSmileSection_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_rho")]
  public static extern double NoArbSabrInterpolatedSmileSection_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_rmsError")]
  public static extern double NoArbSabrInterpolatedSmileSection_rmsError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_maxError")]
  public static extern double NoArbSabrInterpolatedSmileSection_maxError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_endCriteria")]
  public static extern int NoArbSabrInterpolatedSmileSection_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NoArbSabrInterpolatedSmileSection")]
  public static extern void delete_NoArbSabrInterpolatedSmileSection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_sabrVolatility")]
  public static extern double sabrVolatility(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_shiftedSabrVolatility")]
  public static extern double shiftedSabrVolatility(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_sabrFlochKennedyVolatility")]
  public static extern double sabrFlochKennedyVolatility(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationErrorTuple")]
  public static extern global::System.IntPtr new_CalibrationErrorTuple(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationErrorTuple_first")]
  public static extern double CalibrationErrorTuple_first(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationErrorTuple_second")]
  public static extern double CalibrationErrorTuple_second(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationErrorTuple_third")]
  public static extern double CalibrationErrorTuple_third(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibrationErrorTuple")]
  public static extern void delete_CalibrationErrorTuple(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_0")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, uint jarg7, double jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_1")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, uint jarg7, double jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_2")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, uint jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_3")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, uint jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_4")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_5")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_6")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityInterpl__SWIG_7")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityInterpl__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_maxDate")]
  public static extern global::System.IntPtr AndreasenHugeVolatilityInterpl_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_minStrike")]
  public static extern double AndreasenHugeVolatilityInterpl_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_maxStrike")]
  public static extern double AndreasenHugeVolatilityInterpl_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_fwd")]
  public static extern double AndreasenHugeVolatilityInterpl_fwd(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_riskFreeRate")]
  public static extern global::System.IntPtr AndreasenHugeVolatilityInterpl_riskFreeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_calibrationError")]
  public static extern global::System.IntPtr AndreasenHugeVolatilityInterpl_calibrationError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_optionPrice")]
  public static extern double AndreasenHugeVolatilityInterpl_optionPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_localVol")]
  public static extern double AndreasenHugeVolatilityInterpl_localVol(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AndreasenHugeVolatilityInterpl")]
  public static extern void delete_AndreasenHugeVolatilityInterpl(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityAdapter__SWIG_0")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityAdapter__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeVolatilityAdapter__SWIG_1")]
  public static extern global::System.IntPtr new_AndreasenHugeVolatilityAdapter__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AndreasenHugeVolatilityAdapter")]
  public static extern void delete_AndreasenHugeVolatilityAdapter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AndreasenHugeLocalVolAdapter")]
  public static extern global::System.IntPtr new_AndreasenHugeLocalVolAdapter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AndreasenHugeLocalVolAdapter")]
  public static extern void delete_AndreasenHugeLocalVolAdapter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonBlackVolSurface__SWIG_0")]
  public static extern global::System.IntPtr new_HestonBlackVolSurface__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonBlackVolSurface__SWIG_1")]
  public static extern global::System.IntPtr new_HestonBlackVolSurface__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonBlackVolSurface__SWIG_2")]
  public static extern global::System.IntPtr new_HestonBlackVolSurface__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonBlackVolSurface")]
  public static extern void delete_HestonBlackVolSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsMarket")]
  public static extern global::System.IntPtr new_CmsMarket(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_reprice")]
  public static extern void CmsMarket_reprice(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_swapTenors")]
  public static extern global::System.IntPtr CmsMarket_swapTenors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_swapLengths")]
  public static extern global::System.IntPtr CmsMarket_swapLengths(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_impliedCmsSpreads")]
  public static extern global::System.IntPtr CmsMarket_impliedCmsSpreads(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_spreadErrors")]
  public static extern global::System.IntPtr CmsMarket_spreadErrors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_browse")]
  public static extern global::System.IntPtr CmsMarket_browse(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedSpreadError")]
  public static extern double CmsMarket_weightedSpreadError(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedSpotNpvError")]
  public static extern double CmsMarket_weightedSpotNpvError(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedFwdNpvError")]
  public static extern double CmsMarket_weightedFwdNpvError(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedSpreadErrors")]
  public static extern global::System.IntPtr CmsMarket_weightedSpreadErrors(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedSpotNpvErrors")]
  public static extern global::System.IntPtr CmsMarket_weightedSpotNpvErrors(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarket_weightedFwdNpvErrors")]
  public static extern global::System.IntPtr CmsMarket_weightedFwdNpvErrors(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsMarket")]
  public static extern void delete_CmsMarket(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsMarketCalibration")]
  public static extern global::System.IntPtr new_CmsMarketCalibration(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_compute__SWIG_0")]
  public static extern global::System.IntPtr CmsMarketCalibration_compute__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_compute__SWIG_1")]
  public static extern global::System.IntPtr CmsMarketCalibration_compute__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_compute__SWIG_2")]
  public static extern global::System.IntPtr CmsMarketCalibration_compute__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_computeParametric__SWIG_0")]
  public static extern global::System.IntPtr CmsMarketCalibration_computeParametric__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_computeParametric__SWIG_1")]
  public static extern global::System.IntPtr CmsMarketCalibration_computeParametric__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_error")]
  public static extern double CmsMarketCalibration_error(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsMarketCalibration_endCriteria")]
  public static extern int CmsMarketCalibration_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsMarketCalibration")]
  public static extern void delete_CmsMarketCalibration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_size")]
  public static extern uint StochasticProcess_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_factors")]
  public static extern uint StochasticProcess_factors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_initialValues")]
  public static extern global::System.IntPtr StochasticProcess_initialValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_drift")]
  public static extern global::System.IntPtr StochasticProcess_drift(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_diffusion")]
  public static extern global::System.IntPtr StochasticProcess_diffusion(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_expectation")]
  public static extern global::System.IntPtr StochasticProcess_expectation(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_stdDeviation")]
  public static extern global::System.IntPtr StochasticProcess_stdDeviation(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_covariance")]
  public static extern global::System.IntPtr StochasticProcess_covariance(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_evolve")]
  public static extern global::System.IntPtr StochasticProcess_evolve(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StochasticProcess")]
  public static extern void delete_StochasticProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Clear")]
  public static extern void StochasticProcessVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Add")]
  public static extern void StochasticProcessVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_size")]
  public static extern uint StochasticProcessVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_capacity")]
  public static extern uint StochasticProcessVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_reserve")]
  public static extern void StochasticProcessVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcessVector__SWIG_0")]
  public static extern global::System.IntPtr new_StochasticProcessVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcessVector__SWIG_1")]
  public static extern global::System.IntPtr new_StochasticProcessVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcessVector__SWIG_2")]
  public static extern global::System.IntPtr new_StochasticProcessVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_getitemcopy")]
  public static extern global::System.IntPtr StochasticProcessVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_getitem")]
  public static extern global::System.IntPtr StochasticProcessVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_setitem")]
  public static extern void StochasticProcessVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_AddRange")]
  public static extern void StochasticProcessVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_GetRange")]
  public static extern global::System.IntPtr StochasticProcessVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Insert")]
  public static extern void StochasticProcessVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_InsertRange")]
  public static extern void StochasticProcessVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_RemoveAt")]
  public static extern void StochasticProcessVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_RemoveRange")]
  public static extern void StochasticProcessVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Repeat")]
  public static extern global::System.IntPtr StochasticProcessVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Reverse__SWIG_0")]
  public static extern void StochasticProcessVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Reverse__SWIG_1")]
  public static extern void StochasticProcessVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_SetRange")]
  public static extern void StochasticProcessVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Contains")]
  public static extern bool StochasticProcessVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_IndexOf")]
  public static extern int StochasticProcessVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_LastIndexOf")]
  public static extern int StochasticProcessVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessVector_Remove")]
  public static extern bool StochasticProcessVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StochasticProcessVector")]
  public static extern void delete_StochasticProcessVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_x0")]
  public static extern double StochasticProcess1D_x0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_drift")]
  public static extern double StochasticProcess1D_drift(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_diffusion")]
  public static extern double StochasticProcess1D_diffusion(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_expectation")]
  public static extern double StochasticProcess1D_expectation(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_stdDeviation")]
  public static extern double StochasticProcess1D_stdDeviation(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_variance")]
  public static extern double StochasticProcess1D_variance(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_evolve")]
  public static extern double StochasticProcess1D_evolve(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_apply")]
  public static extern double StochasticProcess1D_apply(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StochasticProcess1D")]
  public static extern void delete_StochasticProcess1D(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Clear")]
  public static extern void StochasticProcess1DVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Add")]
  public static extern void StochasticProcess1DVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_size")]
  public static extern uint StochasticProcess1DVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_capacity")]
  public static extern uint StochasticProcess1DVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_reserve")]
  public static extern void StochasticProcess1DVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcess1DVector__SWIG_0")]
  public static extern global::System.IntPtr new_StochasticProcess1DVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcess1DVector__SWIG_1")]
  public static extern global::System.IntPtr new_StochasticProcess1DVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcess1DVector__SWIG_2")]
  public static extern global::System.IntPtr new_StochasticProcess1DVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_getitemcopy")]
  public static extern global::System.IntPtr StochasticProcess1DVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_getitem")]
  public static extern global::System.IntPtr StochasticProcess1DVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_setitem")]
  public static extern void StochasticProcess1DVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_AddRange")]
  public static extern void StochasticProcess1DVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_GetRange")]
  public static extern global::System.IntPtr StochasticProcess1DVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Insert")]
  public static extern void StochasticProcess1DVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_InsertRange")]
  public static extern void StochasticProcess1DVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_RemoveAt")]
  public static extern void StochasticProcess1DVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_RemoveRange")]
  public static extern void StochasticProcess1DVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Repeat")]
  public static extern global::System.IntPtr StochasticProcess1DVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Reverse__SWIG_0")]
  public static extern void StochasticProcess1DVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Reverse__SWIG_1")]
  public static extern void StochasticProcess1DVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_SetRange")]
  public static extern void StochasticProcess1DVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Contains")]
  public static extern bool StochasticProcess1DVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_IndexOf")]
  public static extern int StochasticProcess1DVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_LastIndexOf")]
  public static extern int StochasticProcess1DVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1DVector_Remove")]
  public static extern bool StochasticProcess1DVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StochasticProcess1DVector")]
  public static extern void delete_StochasticProcess1DVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GeneralizedBlackScholesProcess__SWIG_0")]
  public static extern global::System.IntPtr new_GeneralizedBlackScholesProcess__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GeneralizedBlackScholesProcess__SWIG_1")]
  public static extern global::System.IntPtr new_GeneralizedBlackScholesProcess__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeneralizedBlackScholesProcess_stateVariable")]
  public static extern global::System.IntPtr GeneralizedBlackScholesProcess_stateVariable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeneralizedBlackScholesProcess_dividendYield")]
  public static extern global::System.IntPtr GeneralizedBlackScholesProcess_dividendYield(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeneralizedBlackScholesProcess_riskFreeRate")]
  public static extern global::System.IntPtr GeneralizedBlackScholesProcess_riskFreeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeneralizedBlackScholesProcess_blackVolatility")]
  public static extern global::System.IntPtr GeneralizedBlackScholesProcess_blackVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GeneralizedBlackScholesProcess")]
  public static extern void delete_GeneralizedBlackScholesProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackScholesProcess")]
  public static extern global::System.IntPtr new_BlackScholesProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackScholesProcess")]
  public static extern void delete_BlackScholesProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackScholesMertonProcess")]
  public static extern global::System.IntPtr new_BlackScholesMertonProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackScholesMertonProcess")]
  public static extern void delete_BlackScholesMertonProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackProcess")]
  public static extern global::System.IntPtr new_BlackProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackProcess")]
  public static extern void delete_BlackProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKohlagenProcess")]
  public static extern global::System.IntPtr new_GarmanKohlagenProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKohlagenProcess")]
  public static extern void delete_GarmanKohlagenProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Merton76Process")]
  public static extern global::System.IntPtr new_Merton76Process(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Merton76Process")]
  public static extern void delete_Merton76Process(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StochasticProcessArray")]
  public static extern global::System.IntPtr new_StochasticProcessArray(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StochasticProcessArray")]
  public static extern void delete_StochasticProcessArray(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GeometricBrownianMotionProcess")]
  public static extern global::System.IntPtr new_GeometricBrownianMotionProcess(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GeometricBrownianMotionProcess")]
  public static extern void delete_GeometricBrownianMotionProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VarianceGammaProcess")]
  public static extern global::System.IntPtr new_VarianceGammaProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VarianceGammaProcess")]
  public static extern void delete_VarianceGammaProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonProcess__SWIG_0")]
  public static extern global::System.IntPtr new_HestonProcess__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonProcess__SWIG_1")]
  public static extern global::System.IntPtr new_HestonProcess__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonProcess_s0")]
  public static extern global::System.IntPtr HestonProcess_s0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonProcess_dividendYield")]
  public static extern global::System.IntPtr HestonProcess_dividendYield(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonProcess_riskFreeRate")]
  public static extern global::System.IntPtr HestonProcess_riskFreeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonProcess")]
  public static extern void delete_HestonProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BatesProcess")]
  public static extern global::System.IntPtr new_BatesProcess(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BatesProcess")]
  public static extern void delete_BatesProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HullWhiteProcess")]
  public static extern global::System.IntPtr new_HullWhiteProcess(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HullWhiteProcess")]
  public static extern void delete_HullWhiteProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HullWhiteForwardProcess")]
  public static extern global::System.IntPtr new_HullWhiteForwardProcess(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteForwardProcess_alpha")]
  public static extern double HullWhiteForwardProcess_alpha(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteForwardProcess_M_T")]
  public static extern double HullWhiteForwardProcess_M_T(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteForwardProcess_B")]
  public static extern double HullWhiteForwardProcess_B(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteForwardProcess_setForwardMeasureTime")]
  public static extern void HullWhiteForwardProcess_setForwardMeasureTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HullWhiteForwardProcess")]
  public static extern void delete_HullWhiteForwardProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2Process")]
  public static extern global::System.IntPtr new_G2Process(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_G2Process")]
  public static extern void delete_G2Process(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2ForwardProcess")]
  public static extern global::System.IntPtr new_G2ForwardProcess(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2ForwardProcess_setForwardMeasureTime")]
  public static extern void G2ForwardProcess_setForwardMeasureTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_G2ForwardProcess")]
  public static extern void delete_G2ForwardProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GsrProcess__SWIG_0")]
  public static extern global::System.IntPtr new_GsrProcess__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GsrProcess__SWIG_1")]
  public static extern global::System.IntPtr new_GsrProcess__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_sigma")]
  public static extern double GsrProcess_sigma(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_reversion")]
  public static extern double GsrProcess_reversion(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_y")]
  public static extern double GsrProcess_y(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_G")]
  public static extern double GsrProcess_G(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_setForwardMeasureTime")]
  public static extern void GsrProcess_setForwardMeasureTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GsrProcess")]
  public static extern void delete_GsrProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_gsr_process")]
  public static extern global::System.IntPtr as_gsr_process(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OrnsteinUhlenbeckProcess__SWIG_0")]
  public static extern global::System.IntPtr new_OrnsteinUhlenbeckProcess__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OrnsteinUhlenbeckProcess__SWIG_1")]
  public static extern global::System.IntPtr new_OrnsteinUhlenbeckProcess__SWIG_1(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OrnsteinUhlenbeckProcess__SWIG_2")]
  public static extern global::System.IntPtr new_OrnsteinUhlenbeckProcess__SWIG_2(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OrnsteinUhlenbeckProcess_speed")]
  public static extern double OrnsteinUhlenbeckProcess_speed(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OrnsteinUhlenbeckProcess_volatility")]
  public static extern double OrnsteinUhlenbeckProcess_volatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OrnsteinUhlenbeckProcess_level")]
  public static extern double OrnsteinUhlenbeckProcess_level(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OrnsteinUhlenbeckProcess")]
  public static extern void delete_OrnsteinUhlenbeckProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedOrnsteinUhlenbeckProcess__SWIG_0")]
  public static extern global::System.IntPtr new_ExtendedOrnsteinUhlenbeckProcess__SWIG_0(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedOrnsteinUhlenbeckProcess__SWIG_1")]
  public static extern global::System.IntPtr new_ExtendedOrnsteinUhlenbeckProcess__SWIG_1(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedOrnsteinUhlenbeckProcess__SWIG_2")]
  public static extern global::System.IntPtr new_ExtendedOrnsteinUhlenbeckProcess__SWIG_2(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedOrnsteinUhlenbeckProcess__SWIG_3")]
  public static extern global::System.IntPtr new_ExtendedOrnsteinUhlenbeckProcess__SWIG_3(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedOrnsteinUhlenbeckProcess__SWIG_4")]
  public static extern global::System.IntPtr new_ExtendedOrnsteinUhlenbeckProcess__SWIG_4(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExtendedOrnsteinUhlenbeckProcess")]
  public static extern void delete_ExtendedOrnsteinUhlenbeckProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtOUWithJumpsProcess")]
  public static extern global::System.IntPtr new_ExtOUWithJumpsProcess(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExtOUWithJumpsProcess")]
  public static extern void delete_ExtOUWithJumpsProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KlugeExtOUProcess")]
  public static extern global::System.IntPtr new_KlugeExtOUProcess(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KlugeExtOUProcess")]
  public static extern void delete_KlugeExtOUProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GJRGARCHProcess__SWIG_0")]
  public static extern global::System.IntPtr new_GJRGARCHProcess__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GJRGARCHProcess__SWIG_1")]
  public static extern global::System.IntPtr new_GJRGARCHProcess__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GJRGARCHProcess__SWIG_2")]
  public static extern global::System.IntPtr new_GJRGARCHProcess__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHProcess_s0")]
  public static extern global::System.IntPtr GJRGARCHProcess_s0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHProcess_dividendYield")]
  public static extern global::System.IntPtr GJRGARCHProcess_dividendYield(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHProcess_riskFreeRate")]
  public static extern global::System.IntPtr GJRGARCHProcess_riskFreeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GJRGARCHProcess")]
  public static extern void delete_GJRGARCHProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PricingEngine")]
  public static extern void delete_PricingEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_NPV")]
  public static extern double Instrument_NPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_errorEstimate")]
  public static extern double Instrument_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_isExpired")]
  public static extern bool Instrument_isExpired(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_setPricingEngine")]
  public static extern void Instrument_setPricingEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_recalculate")]
  public static extern void Instrument_recalculate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_freeze")]
  public static extern void Instrument_freeze(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_unfreeze")]
  public static extern void Instrument_unfreeze(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Instrument")]
  public static extern void delete_Instrument(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Clear")]
  public static extern void InstrumentVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Add")]
  public static extern void InstrumentVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_size")]
  public static extern uint InstrumentVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_capacity")]
  public static extern uint InstrumentVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_reserve")]
  public static extern void InstrumentVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InstrumentVector__SWIG_0")]
  public static extern global::System.IntPtr new_InstrumentVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InstrumentVector__SWIG_1")]
  public static extern global::System.IntPtr new_InstrumentVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InstrumentVector__SWIG_2")]
  public static extern global::System.IntPtr new_InstrumentVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_getitemcopy")]
  public static extern global::System.IntPtr InstrumentVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_getitem")]
  public static extern global::System.IntPtr InstrumentVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_setitem")]
  public static extern void InstrumentVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_AddRange")]
  public static extern void InstrumentVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_GetRange")]
  public static extern global::System.IntPtr InstrumentVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Insert")]
  public static extern void InstrumentVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_InsertRange")]
  public static extern void InstrumentVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_RemoveAt")]
  public static extern void InstrumentVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_RemoveRange")]
  public static extern void InstrumentVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Repeat")]
  public static extern global::System.IntPtr InstrumentVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Reverse__SWIG_0")]
  public static extern void InstrumentVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Reverse__SWIG_1")]
  public static extern void InstrumentVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_SetRange")]
  public static extern void InstrumentVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Contains")]
  public static extern bool InstrumentVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_IndexOf")]
  public static extern int InstrumentVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_LastIndexOf")]
  public static extern int InstrumentVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InstrumentVector_Remove")]
  public static extern bool InstrumentVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InstrumentVector")]
  public static extern void delete_InstrumentVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Stock")]
  public static extern global::System.IntPtr new_Stock(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Stock")]
  public static extern void delete_Stock(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CompositeInstrument")]
  public static extern global::System.IntPtr new_CompositeInstrument();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeInstrument_add__SWIG_0")]
  public static extern void CompositeInstrument_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeInstrument_add__SWIG_1")]
  public static extern void CompositeInstrument_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeInstrument_subtract__SWIG_0")]
  public static extern void CompositeInstrument_subtract__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeInstrument_subtract__SWIG_1")]
  public static extern void CompositeInstrument_subtract__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CompositeInstrument")]
  public static extern void delete_CompositeInstrument(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DateGeneration")]
  public static extern global::System.IntPtr new_DateGeneration();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DateGeneration")]
  public static extern void delete_DateGeneration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_0")]
  public static extern global::System.IntPtr new_Schedule__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_1")]
  public static extern global::System.IntPtr new_Schedule__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_2")]
  public static extern global::System.IntPtr new_Schedule__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_3")]
  public static extern global::System.IntPtr new_Schedule__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_4")]
  public static extern global::System.IntPtr new_Schedule__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_5")]
  public static extern global::System.IntPtr new_Schedule__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Schedule__SWIG_6")]
  public static extern global::System.IntPtr new_Schedule__SWIG_6();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_size")]
  public static extern uint Schedule_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_date")]
  public static extern global::System.IntPtr Schedule_date(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_previousDate")]
  public static extern global::System.IntPtr Schedule_previousDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_nextDate")]
  public static extern global::System.IntPtr Schedule_nextDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_hasIsRegular")]
  public static extern bool Schedule_hasIsRegular(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_isRegular__SWIG_0")]
  public static extern bool Schedule_isRegular__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_isRegular__SWIG_1")]
  public static extern global::System.IntPtr Schedule_isRegular__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_calendar")]
  public static extern global::System.IntPtr Schedule_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_startDate")]
  public static extern global::System.IntPtr Schedule_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_endDate")]
  public static extern global::System.IntPtr Schedule_endDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_hasTenor")]
  public static extern bool Schedule_hasTenor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_tenor")]
  public static extern global::System.IntPtr Schedule_tenor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_businessDayConvention")]
  public static extern int Schedule_businessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_hasTerminationDateBusinessDayConvention")]
  public static extern bool Schedule_hasTerminationDateBusinessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_terminationDateBusinessDayConvention")]
  public static extern int Schedule_terminationDateBusinessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_hasRule")]
  public static extern bool Schedule_hasRule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_rule")]
  public static extern int Schedule_rule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_hasEndOfMonth")]
  public static extern bool Schedule_hasEndOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_endOfMonth")]
  public static extern bool Schedule_endOfMonth(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Schedule_until")]
  public static extern global::System.IntPtr Schedule_until(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Schedule")]
  public static extern void delete_Schedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MakeSchedule")]
  public static extern global::System.IntPtr new_MakeSchedule();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_from")]
  public static extern global::System.IntPtr MakeSchedule_from(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_to")]
  public static extern global::System.IntPtr MakeSchedule_to(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withTenor")]
  public static extern global::System.IntPtr MakeSchedule_withTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withFrequency")]
  public static extern global::System.IntPtr MakeSchedule_withFrequency(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withCalendar")]
  public static extern global::System.IntPtr MakeSchedule_withCalendar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withConvention")]
  public static extern global::System.IntPtr MakeSchedule_withConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withTerminationDateConvention")]
  public static extern global::System.IntPtr MakeSchedule_withTerminationDateConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withRule")]
  public static extern global::System.IntPtr MakeSchedule_withRule(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_forwards")]
  public static extern global::System.IntPtr MakeSchedule_forwards(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_backwards")]
  public static extern global::System.IntPtr MakeSchedule_backwards(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_endOfMonth__SWIG_0")]
  public static extern global::System.IntPtr MakeSchedule_endOfMonth__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_endOfMonth__SWIG_1")]
  public static extern global::System.IntPtr MakeSchedule_endOfMonth__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withFirstDate")]
  public static extern global::System.IntPtr MakeSchedule_withFirstDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_withNextToLastDate")]
  public static extern global::System.IntPtr MakeSchedule_withNextToLastDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeSchedule_schedule")]
  public static extern global::System.IntPtr MakeSchedule_schedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MakeSchedule")]
  public static extern void delete_MakeSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlow_amount")]
  public static extern double CashFlow_amount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlow_date")]
  public static extern global::System.IntPtr CashFlow_date(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlow_hasOccurred__SWIG_0")]
  public static extern bool CashFlow_hasOccurred__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlow_hasOccurred__SWIG_1")]
  public static extern bool CashFlow_hasOccurred__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CashFlow")]
  public static extern void delete_CashFlow(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Clear")]
  public static extern void Leg_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Add")]
  public static extern void Leg_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_size")]
  public static extern uint Leg_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_capacity")]
  public static extern uint Leg_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_reserve")]
  public static extern void Leg_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Leg__SWIG_0")]
  public static extern global::System.IntPtr new_Leg__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Leg__SWIG_1")]
  public static extern global::System.IntPtr new_Leg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Leg__SWIG_2")]
  public static extern global::System.IntPtr new_Leg__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_getitemcopy")]
  public static extern global::System.IntPtr Leg_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_getitem")]
  public static extern global::System.IntPtr Leg_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_setitem")]
  public static extern void Leg_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_AddRange")]
  public static extern void Leg_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_GetRange")]
  public static extern global::System.IntPtr Leg_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Insert")]
  public static extern void Leg_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_InsertRange")]
  public static extern void Leg_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_RemoveAt")]
  public static extern void Leg_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_RemoveRange")]
  public static extern void Leg_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Repeat")]
  public static extern global::System.IntPtr Leg_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Reverse__SWIG_0")]
  public static extern void Leg_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Reverse__SWIG_1")]
  public static extern void Leg_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_SetRange")]
  public static extern void Leg_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Contains")]
  public static extern bool Leg_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_IndexOf")]
  public static extern int Leg_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_LastIndexOf")]
  public static extern int Leg_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Leg_Remove")]
  public static extern bool Leg_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Leg")]
  public static extern void delete_Leg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimpleCashFlow")]
  public static extern global::System.IntPtr new_SimpleCashFlow(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SimpleCashFlow")]
  public static extern void delete_SimpleCashFlow(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Redemption")]
  public static extern global::System.IntPtr new_Redemption(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Redemption")]
  public static extern void delete_Redemption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingPayment")]
  public static extern global::System.IntPtr new_AmortizingPayment(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AmortizingPayment")]
  public static extern void delete_AmortizingPayment(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IndexedCashFlow__SWIG_0")]
  public static extern global::System.IntPtr new_IndexedCashFlow__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IndexedCashFlow__SWIG_1")]
  public static extern global::System.IntPtr new_IndexedCashFlow__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_notional")]
  public static extern double IndexedCashFlow_notional(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_baseDate")]
  public static extern global::System.IntPtr IndexedCashFlow_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_fixingDate")]
  public static extern global::System.IntPtr IndexedCashFlow_fixingDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_index")]
  public static extern global::System.IntPtr IndexedCashFlow_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_growthOnly")]
  public static extern bool IndexedCashFlow_growthOnly(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IndexedCashFlow")]
  public static extern void delete_IndexedCashFlow(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_indexed_cashflow")]
  public static extern global::System.IntPtr as_indexed_cashflow(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_nominal")]
  public static extern double Coupon_nominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_accrualStartDate")]
  public static extern global::System.IntPtr Coupon_accrualStartDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_accrualEndDate")]
  public static extern global::System.IntPtr Coupon_accrualEndDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_referencePeriodStart")]
  public static extern global::System.IntPtr Coupon_referencePeriodStart(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_referencePeriodEnd")]
  public static extern global::System.IntPtr Coupon_referencePeriodEnd(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_exCouponDate")]
  public static extern global::System.IntPtr Coupon_exCouponDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_rate")]
  public static extern double Coupon_rate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_accrualPeriod")]
  public static extern double Coupon_accrualPeriod(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_accrualDays")]
  public static extern int Coupon_accrualDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_dayCounter")]
  public static extern global::System.IntPtr Coupon_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_accruedAmount")]
  public static extern double Coupon_accruedAmount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Coupon")]
  public static extern void delete_Coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_coupon")]
  public static extern global::System.IntPtr as_coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_FixedRateCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_FixedRateCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_FixedRateCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_FixedRateCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateCoupon_interestRate")]
  public static extern global::System.IntPtr FixedRateCoupon_interestRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FixedRateCoupon")]
  public static extern void delete_FixedRateCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_fixed_rate_coupon")]
  public static extern global::System.IntPtr as_fixed_rate_coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_swapletPrice")]
  public static extern double FloatingRateCouponPricer_swapletPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_swapletRate")]
  public static extern double FloatingRateCouponPricer_swapletRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_capletPrice")]
  public static extern double FloatingRateCouponPricer_capletPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_capletRate")]
  public static extern double FloatingRateCouponPricer_capletRate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_floorletPrice")]
  public static extern double FloatingRateCouponPricer_floorletPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCouponPricer_floorletRate")]
  public static extern double FloatingRateCouponPricer_floorletRate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloatingRateCouponPricer")]
  public static extern void delete_FloatingRateCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_setCouponPricer")]
  public static extern void setCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_fixingDate")]
  public static extern global::System.IntPtr FloatingRateCoupon_fixingDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_fixingDays")]
  public static extern int FloatingRateCoupon_fixingDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_isInArrears")]
  public static extern bool FloatingRateCoupon_isInArrears(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_gearing")]
  public static extern double FloatingRateCoupon_gearing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_spread")]
  public static extern double FloatingRateCoupon_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_indexFixing")]
  public static extern double FloatingRateCoupon_indexFixing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_adjustedFixing")]
  public static extern double FloatingRateCoupon_adjustedFixing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_convexityAdjustment")]
  public static extern double FloatingRateCoupon_convexityAdjustment(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_price")]
  public static extern double FloatingRateCoupon_price(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_index")]
  public static extern global::System.IntPtr FloatingRateCoupon_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_setPricer")]
  public static extern void FloatingRateCoupon_setPricer(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloatingRateCoupon")]
  public static extern void delete_FloatingRateCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_floating_rate_coupon")]
  public static extern global::System.IntPtr as_floating_rate_coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_OvernightIndexedCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedCoupon_fixingDates")]
  public static extern global::System.IntPtr OvernightIndexedCoupon_fixingDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedCoupon_dt")]
  public static extern global::System.IntPtr OvernightIndexedCoupon_dt(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedCoupon_indexFixings")]
  public static extern global::System.IntPtr OvernightIndexedCoupon_indexFixings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedCoupon_valueDates")]
  public static extern global::System.IntPtr OvernightIndexedCoupon_valueDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndexedCoupon")]
  public static extern void delete_OvernightIndexedCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CappedFlooredCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CappedFlooredCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CappedFlooredCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_cap")]
  public static extern double CappedFlooredCoupon_cap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_floor")]
  public static extern double CappedFlooredCoupon_floor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_effectiveCap")]
  public static extern double CappedFlooredCoupon_effectiveCap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_effectiveFloor")]
  public static extern double CappedFlooredCoupon_effectiveFloor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_isCapped")]
  public static extern bool CappedFlooredCoupon_isCapped(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_isFloored")]
  public static extern bool CappedFlooredCoupon_isFloored(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_setPricer")]
  public static extern void CappedFlooredCoupon_setPricer(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CappedFlooredCoupon")]
  public static extern void delete_CappedFlooredCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IborCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_IborCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCoupon_createAtParCoupons")]
  public static extern void IborCoupon_createAtParCoupons();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCoupon_createIndexedCoupons")]
  public static extern void IborCoupon_createIndexedCoupons();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCoupon_usingAtParCoupons")]
  public static extern bool IborCoupon_usingAtParCoupons();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IborCoupon")]
  public static extern void delete_IborCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_8")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredIborCoupon__SWIG_9")]
  public static extern global::System.IntPtr new_CappedFlooredIborCoupon__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CappedFlooredIborCoupon")]
  public static extern void delete_CappedFlooredIborCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCouponPricer_capletVolatility")]
  public static extern global::System.IntPtr IborCouponPricer_capletVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCouponPricer_setCapletVolatility__SWIG_0")]
  public static extern void IborCouponPricer_setCapletVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCouponPricer_setCapletVolatility__SWIG_1")]
  public static extern void IborCouponPricer_setCapletVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IborCouponPricer")]
  public static extern void delete_IborCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackIborCouponPricer__SWIG_0")]
  public static extern global::System.IntPtr new_BlackIborCouponPricer__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackIborCouponPricer__SWIG_1")]
  public static extern global::System.IntPtr new_BlackIborCouponPricer__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackIborCouponPricer__SWIG_2")]
  public static extern global::System.IntPtr new_BlackIborCouponPricer__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackIborCouponPricer__SWIG_3")]
  public static extern global::System.IntPtr new_BlackIborCouponPricer__SWIG_3();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackIborCouponPricer")]
  public static extern void delete_BlackIborCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_CmsCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsCoupon")]
  public static extern void delete_CmsCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsSpreadCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_CmsSpreadCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsSpreadCoupon")]
  public static extern void delete_CmsSpreadCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricer_swaptionVolatility")]
  public static extern global::System.IntPtr CmsCouponPricer_swaptionVolatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricer_setSwaptionVolatility__SWIG_0")]
  public static extern void CmsCouponPricer_setSwaptionVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricer_setSwaptionVolatility__SWIG_1")]
  public static extern void CmsCouponPricer_setSwaptionVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsCouponPricer")]
  public static extern void delete_CmsCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Clear")]
  public static extern void CmsCouponPricerVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Add")]
  public static extern void CmsCouponPricerVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_size")]
  public static extern uint CmsCouponPricerVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_capacity")]
  public static extern uint CmsCouponPricerVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_reserve")]
  public static extern void CmsCouponPricerVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCouponPricerVector__SWIG_0")]
  public static extern global::System.IntPtr new_CmsCouponPricerVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCouponPricerVector__SWIG_1")]
  public static extern global::System.IntPtr new_CmsCouponPricerVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsCouponPricerVector__SWIG_2")]
  public static extern global::System.IntPtr new_CmsCouponPricerVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_getitemcopy")]
  public static extern global::System.IntPtr CmsCouponPricerVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_getitem")]
  public static extern global::System.IntPtr CmsCouponPricerVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_setitem")]
  public static extern void CmsCouponPricerVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_AddRange")]
  public static extern void CmsCouponPricerVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_GetRange")]
  public static extern global::System.IntPtr CmsCouponPricerVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Insert")]
  public static extern void CmsCouponPricerVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_InsertRange")]
  public static extern void CmsCouponPricerVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_RemoveAt")]
  public static extern void CmsCouponPricerVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_RemoveRange")]
  public static extern void CmsCouponPricerVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Repeat")]
  public static extern global::System.IntPtr CmsCouponPricerVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Reverse__SWIG_0")]
  public static extern void CmsCouponPricerVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Reverse__SWIG_1")]
  public static extern void CmsCouponPricerVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_SetRange")]
  public static extern void CmsCouponPricerVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Contains")]
  public static extern bool CmsCouponPricerVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_IndexOf")]
  public static extern int CmsCouponPricerVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_LastIndexOf")]
  public static extern int CmsCouponPricerVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricerVector_Remove")]
  public static extern bool CmsCouponPricerVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsCouponPricerVector")]
  public static extern void delete_CmsCouponPricerVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GFunctionFactory")]
  public static extern void delete_GFunctionFactory(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHaganPricer")]
  public static extern global::System.IntPtr new_AnalyticHaganPricer(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticHaganPricer")]
  public static extern void delete_AnalyticHaganPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NumericHaganPricer__SWIG_0")]
  public static extern global::System.IntPtr new_NumericHaganPricer__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NumericHaganPricer__SWIG_1")]
  public static extern global::System.IntPtr new_NumericHaganPricer__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NumericHaganPricer__SWIG_2")]
  public static extern global::System.IntPtr new_NumericHaganPricer__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NumericHaganPricer__SWIG_3")]
  public static extern global::System.IntPtr new_NumericHaganPricer__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NumericHaganPricer")]
  public static extern void delete_NumericHaganPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_8")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsCoupon__SWIG_9")]
  public static extern global::System.IntPtr new_CappedFlooredCmsCoupon__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CappedFlooredCmsCoupon")]
  public static extern void delete_CappedFlooredCmsCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_0")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_1")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_2")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_3")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_4")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_5")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_6")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_7")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_8")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CappedFlooredCmsSpreadCoupon__SWIG_9")]
  public static extern global::System.IntPtr new_CappedFlooredCmsSpreadCoupon__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CappedFlooredCmsSpreadCoupon")]
  public static extern void delete_CappedFlooredCmsSpreadCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearTsrPricer__SWIG_0")]
  public static extern global::System.IntPtr new_LinearTsrPricer__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearTsrPricer__SWIG_1")]
  public static extern global::System.IntPtr new_LinearTsrPricer__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearTsrPricer__SWIG_2")]
  public static extern global::System.IntPtr new_LinearTsrPricer__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LinearTsrPricer")]
  public static extern void delete_LinearTsrPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LinearTsrPricerSettings")]
  public static extern global::System.IntPtr new_LinearTsrPricerSettings();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withRateBound__SWIG_0")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withRateBound__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withRateBound__SWIG_1")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withRateBound__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withRateBound__SWIG_2")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withRateBound__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withVegaRatio__SWIG_0")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withVegaRatio__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withVegaRatio__SWIG_1")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withVegaRatio__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withVegaRatio__SWIG_2")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withVegaRatio__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withPriceThreshold__SWIG_0")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withPriceThreshold__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withPriceThreshold__SWIG_1")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withPriceThreshold__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withPriceThreshold__SWIG_2")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withPriceThreshold__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withBSStdDevs__SWIG_0")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withBSStdDevs__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withBSStdDevs__SWIG_1")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withBSStdDevs__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricerSettings_withBSStdDevs__SWIG_2")]
  public static extern global::System.IntPtr LinearTsrPricerSettings_withBSStdDevs__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LinearTsrPricerSettings")]
  public static extern void delete_LinearTsrPricerSettings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadCouponPricer_correlation")]
  public static extern global::System.IntPtr CmsSpreadCouponPricer_correlation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadCouponPricer_setCorrelation__SWIG_0")]
  public static extern void CmsSpreadCouponPricer_setCorrelation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadCouponPricer_setCorrelation__SWIG_1")]
  public static extern void CmsSpreadCouponPricer_setCorrelation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsSpreadCouponPricer")]
  public static extern void delete_CmsSpreadCouponPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_0")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_1")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_2")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_3")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_4")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LognormalCmsSpreadPricer__SWIG_5")]
  public static extern global::System.IntPtr new_LognormalCmsSpreadPricer__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_swapletPrice")]
  public static extern double LognormalCmsSpreadPricer_swapletPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_swapletRate")]
  public static extern double LognormalCmsSpreadPricer_swapletRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_capletPrice")]
  public static extern double LognormalCmsSpreadPricer_capletPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_capletRate")]
  public static extern double LognormalCmsSpreadPricer_capletRate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_floorletPrice")]
  public static extern double LognormalCmsSpreadPricer_floorletPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_floorletRate")]
  public static extern double LognormalCmsSpreadPricer_floorletRate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LognormalCmsSpreadPricer")]
  public static extern void delete_LognormalCmsSpreadPricer(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_0")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, bool jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_1")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_2")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_3")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_4")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_5")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateLeg__SWIG_6")]
  public static extern global::System.IntPtr FixedRateLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_0")]
  public static extern global::System.IntPtr IborLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_1")]
  public static extern global::System.IntPtr IborLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_2")]
  public static extern global::System.IntPtr IborLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_3")]
  public static extern global::System.IntPtr IborLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_4")]
  public static extern global::System.IntPtr IborLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_5")]
  public static extern global::System.IntPtr IborLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_6")]
  public static extern global::System.IntPtr IborLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_7")]
  public static extern global::System.IntPtr IborLeg__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_8")]
  public static extern global::System.IntPtr IborLeg__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_9")]
  public static extern global::System.IntPtr IborLeg__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_10")]
  public static extern global::System.IntPtr IborLeg__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_11")]
  public static extern global::System.IntPtr IborLeg__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborLeg__SWIG_12")]
  public static extern global::System.IntPtr IborLeg__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_0")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_1")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_2")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_3")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_4")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightLeg__SWIG_5")]
  public static extern global::System.IntPtr OvernightLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_0")]
  public static extern global::System.IntPtr CmsLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_1")]
  public static extern global::System.IntPtr CmsLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_2")]
  public static extern global::System.IntPtr CmsLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_3")]
  public static extern global::System.IntPtr CmsLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_4")]
  public static extern global::System.IntPtr CmsLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_5")]
  public static extern global::System.IntPtr CmsLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_6")]
  public static extern global::System.IntPtr CmsLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_7")]
  public static extern global::System.IntPtr CmsLeg__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_8")]
  public static extern global::System.IntPtr CmsLeg__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_9")]
  public static extern global::System.IntPtr CmsLeg__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_10")]
  public static extern global::System.IntPtr CmsLeg__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_11")]
  public static extern global::System.IntPtr CmsLeg__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsLeg__SWIG_12")]
  public static extern global::System.IntPtr CmsLeg__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_0")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_1")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_2")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_3")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_4")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_5")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_6")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_7")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_8")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_9")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_10")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsZeroLeg__SWIG_11")]
  public static extern global::System.IntPtr CmsZeroLeg__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_0")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_1")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_2")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_3")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_4")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_5")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_6")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_7")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadLeg__SWIG_8")]
  public static extern global::System.IntPtr CmsSpreadLeg__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Duration")]
  public static extern global::System.IntPtr new_Duration();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Duration")]
  public static extern void delete_Duration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_startDate")]
  public static extern global::System.IntPtr CashFlows_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_maturityDate")]
  public static extern global::System.IntPtr CashFlows_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_previousCashFlowDate__SWIG_0")]
  public static extern global::System.IntPtr CashFlows_previousCashFlowDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_previousCashFlowDate__SWIG_1")]
  public static extern global::System.IntPtr CashFlows_previousCashFlowDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_nextCashFlowDate__SWIG_0")]
  public static extern global::System.IntPtr CashFlows_nextCashFlowDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_nextCashFlowDate__SWIG_1")]
  public static extern global::System.IntPtr CashFlows_nextCashFlowDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_previousCashFlow__SWIG_0")]
  public static extern global::System.IntPtr CashFlows_previousCashFlow__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_previousCashFlow__SWIG_1")]
  public static extern global::System.IntPtr CashFlows_previousCashFlow__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_nextCashFlow__SWIG_0")]
  public static extern global::System.IntPtr CashFlows_nextCashFlow__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_nextCashFlow__SWIG_1")]
  public static extern global::System.IntPtr CashFlows_nextCashFlow__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_0")]
  public static extern double CashFlows_npv__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_1")]
  public static extern double CashFlows_npv__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_2")]
  public static extern double CashFlows_npv__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_3")]
  public static extern double CashFlows_npv__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_4")]
  public static extern double CashFlows_npv__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_5")]
  public static extern double CashFlows_npv__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_6")]
  public static extern double CashFlows_npv__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_7")]
  public static extern double CashFlows_npv__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_8")]
  public static extern double CashFlows_npv__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_9")]
  public static extern double CashFlows_npv__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_10")]
  public static extern double CashFlows_npv__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_npv__SWIG_11")]
  public static extern double CashFlows_npv__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_0")]
  public static extern double CashFlows_bps__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_1")]
  public static extern double CashFlows_bps__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_2")]
  public static extern double CashFlows_bps__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_3")]
  public static extern double CashFlows_bps__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_4")]
  public static extern double CashFlows_bps__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_5")]
  public static extern double CashFlows_bps__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_6")]
  public static extern double CashFlows_bps__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_7")]
  public static extern double CashFlows_bps__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_8")]
  public static extern double CashFlows_bps__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_9")]
  public static extern double CashFlows_bps__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_10")]
  public static extern double CashFlows_bps__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_bps__SWIG_11")]
  public static extern double CashFlows_bps__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_atmRate__SWIG_0")]
  public static extern double CashFlows_atmRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_atmRate__SWIG_1")]
  public static extern double CashFlows_atmRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_atmRate__SWIG_2")]
  public static extern double CashFlows_atmRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_atmRate__SWIG_3")]
  public static extern double CashFlows_atmRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_0")]
  public static extern double CashFlows_yield__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, uint jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_1")]
  public static extern double CashFlows_yield__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, uint jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_2")]
  public static extern double CashFlows_yield__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_3")]
  public static extern double CashFlows_yield__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_4")]
  public static extern double CashFlows_yield__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_yield__SWIG_5")]
  public static extern double CashFlows_yield__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_duration__SWIG_0")]
  public static extern double CashFlows_duration__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, bool jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_duration__SWIG_1")]
  public static extern double CashFlows_duration__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_duration__SWIG_2")]
  public static extern double CashFlows_duration__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_duration__SWIG_3")]
  public static extern double CashFlows_duration__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_duration__SWIG_4")]
  public static extern double CashFlows_duration__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, int jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_0")]
  public static extern double CashFlows_convexity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_1")]
  public static extern double CashFlows_convexity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_2")]
  public static extern double CashFlows_convexity__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_3")]
  public static extern double CashFlows_convexity__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_4")]
  public static extern double CashFlows_convexity__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_convexity__SWIG_5")]
  public static extern double CashFlows_convexity__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_0")]
  public static extern double CashFlows_basisPointValue__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_1")]
  public static extern double CashFlows_basisPointValue__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_2")]
  public static extern double CashFlows_basisPointValue__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_3")]
  public static extern double CashFlows_basisPointValue__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_4")]
  public static extern double CashFlows_basisPointValue__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_basisPointValue__SWIG_5")]
  public static extern double CashFlows_basisPointValue__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_0")]
  public static extern double CashFlows_zSpread__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, uint jarg11, double jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_1")]
  public static extern double CashFlows_zSpread__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_2")]
  public static extern double CashFlows_zSpread__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_3")]
  public static extern double CashFlows_zSpread__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_4")]
  public static extern double CashFlows_zSpread__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlows_zSpread__SWIG_5")]
  public static extern double CashFlows_zSpread__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CashFlows")]
  public static extern void delete_CashFlows(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelper_calibrationError")]
  public static extern double CalibrationHelper_calibrationError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibrationHelper")]
  public static extern void delete_CalibrationHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_setPricingEngine")]
  public static extern void BlackCalibrationHelper_setPricingEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_marketValue")]
  public static extern double BlackCalibrationHelper_marketValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_modelValue")]
  public static extern double BlackCalibrationHelper_modelValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_impliedVolatility")]
  public static extern double BlackCalibrationHelper_impliedVolatility(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, uint jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_blackPrice")]
  public static extern double BlackCalibrationHelper_blackPrice(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_volatility")]
  public static extern global::System.IntPtr BlackCalibrationHelper_volatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_volatilityType")]
  public static extern int BlackCalibrationHelper_volatilityType(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_calibrationError")]
  public static extern double BlackCalibrationHelper_calibrationError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCalibrationHelper")]
  public static extern void delete_BlackCalibrationHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_black_helper")]
  public static extern global::System.IntPtr as_black_helper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_swaption_helper")]
  public static extern global::System.IntPtr as_swaption_helper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_0")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_1")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_2")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_3")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_4")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_5")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_6")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_7")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_8")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_9")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_10")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_11")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_12")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_13")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_14")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_15")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_16")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwaptionHelper__SWIG_17")]
  public static extern global::System.IntPtr new_SwaptionHelper__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_underlyingSwap")]
  public static extern global::System.IntPtr SwaptionHelper_underlyingSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_swaption")]
  public static extern global::System.IntPtr SwaptionHelper_swaption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_times")]
  public static extern global::System.IntPtr SwaptionHelper_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_swaptionExpiryDate")]
  public static extern global::System.IntPtr SwaptionHelper_swaptionExpiryDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_swaptionStrike")]
  public static extern double SwaptionHelper_swaptionStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_swaptionNominal")]
  public static extern double SwaptionHelper_swaptionNominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_swaptionMaturityDate")]
  public static extern global::System.IntPtr SwaptionHelper_swaptionMaturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwaptionHelper")]
  public static extern void delete_SwaptionHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapHelper__SWIG_0")]
  public static extern global::System.IntPtr new_CapHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapHelper__SWIG_1")]
  public static extern global::System.IntPtr new_CapHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapHelper__SWIG_2")]
  public static extern global::System.IntPtr new_CapHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapHelper__SWIG_3")]
  public static extern global::System.IntPtr new_CapHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapHelper_times")]
  public static extern global::System.IntPtr CapHelper_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapHelper")]
  public static extern void delete_CapHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonModelHelper__SWIG_0")]
  public static extern global::System.IntPtr new_HestonModelHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonModelHelper__SWIG_1")]
  public static extern global::System.IntPtr new_HestonModelHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonModelHelper")]
  public static extern void delete_HestonModelHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Clear")]
  public static extern void CalibrationHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Add")]
  public static extern void CalibrationHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_size")]
  public static extern uint CalibrationHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_capacity")]
  public static extern uint CalibrationHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_reserve")]
  public static extern void CalibrationHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_CalibrationHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_CalibrationHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_CalibrationHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_getitemcopy")]
  public static extern global::System.IntPtr CalibrationHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_getitem")]
  public static extern global::System.IntPtr CalibrationHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_setitem")]
  public static extern void CalibrationHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_AddRange")]
  public static extern void CalibrationHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_GetRange")]
  public static extern global::System.IntPtr CalibrationHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Insert")]
  public static extern void CalibrationHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_InsertRange")]
  public static extern void CalibrationHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_RemoveAt")]
  public static extern void CalibrationHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_RemoveRange")]
  public static extern void CalibrationHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Repeat")]
  public static extern global::System.IntPtr CalibrationHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Reverse__SWIG_0")]
  public static extern void CalibrationHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Reverse__SWIG_1")]
  public static extern void CalibrationHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_SetRange")]
  public static extern void CalibrationHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Contains")]
  public static extern bool CalibrationHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_IndexOf")]
  public static extern int CalibrationHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_LastIndexOf")]
  public static extern int CalibrationHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationHelperVector_Remove")]
  public static extern bool CalibrationHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibrationHelperVector")]
  public static extern void delete_CalibrationHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Clear")]
  public static extern void BlackCalibrationHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Add")]
  public static extern void BlackCalibrationHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_size")]
  public static extern uint BlackCalibrationHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_capacity")]
  public static extern uint BlackCalibrationHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_reserve")]
  public static extern void BlackCalibrationHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCalibrationHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_BlackCalibrationHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCalibrationHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_BlackCalibrationHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCalibrationHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_BlackCalibrationHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_getitemcopy")]
  public static extern global::System.IntPtr BlackCalibrationHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_getitem")]
  public static extern global::System.IntPtr BlackCalibrationHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_setitem")]
  public static extern void BlackCalibrationHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_AddRange")]
  public static extern void BlackCalibrationHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_GetRange")]
  public static extern global::System.IntPtr BlackCalibrationHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Insert")]
  public static extern void BlackCalibrationHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_InsertRange")]
  public static extern void BlackCalibrationHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_RemoveAt")]
  public static extern void BlackCalibrationHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_RemoveRange")]
  public static extern void BlackCalibrationHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Repeat")]
  public static extern global::System.IntPtr BlackCalibrationHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Reverse__SWIG_0")]
  public static extern void BlackCalibrationHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Reverse__SWIG_1")]
  public static extern void BlackCalibrationHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_SetRange")]
  public static extern void BlackCalibrationHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Contains")]
  public static extern bool BlackCalibrationHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_IndexOf")]
  public static extern int BlackCalibrationHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_LastIndexOf")]
  public static extern int BlackCalibrationHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelperVector_Remove")]
  public static extern bool BlackCalibrationHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCalibrationHelperVector")]
  public static extern void delete_BlackCalibrationHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_parameters")]
  public static extern global::System.IntPtr CalibratedModel_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_calibrate__SWIG_0")]
  public static extern void CalibratedModel_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_calibrate__SWIG_1")]
  public static extern void CalibratedModel_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_calibrate__SWIG_2")]
  public static extern void CalibratedModel_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_calibrate__SWIG_3")]
  public static extern void CalibratedModel_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_setParams")]
  public static extern void CalibratedModel_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_value")]
  public static extern double CalibratedModel_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_constraint")]
  public static extern global::System.IntPtr CalibratedModel_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_endCriteria")]
  public static extern int CalibratedModel_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_problemValues")]
  public static extern global::System.IntPtr CalibratedModel_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_functionEvaluation")]
  public static extern int CalibratedModel_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibratedModel")]
  public static extern void delete_CalibratedModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructureConsistentModel_termStructure")]
  public static extern global::System.IntPtr TermStructureConsistentModel_termStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TermStructureConsistentModel")]
  public static extern void delete_TermStructureConsistentModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibratedModelHandle__SWIG_0")]
  public static extern global::System.IntPtr new_CalibratedModelHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibratedModelHandle__SWIG_1")]
  public static extern global::System.IntPtr new_CalibratedModelHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle___deref__")]
  public static extern global::System.IntPtr CalibratedModelHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_currentLink")]
  public static extern global::System.IntPtr CalibratedModelHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_empty")]
  public static extern bool CalibratedModelHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_asObservable")]
  public static extern global::System.IntPtr CalibratedModelHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibratedModelHandle")]
  public static extern void delete_CalibratedModelHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_parameters")]
  public static extern global::System.IntPtr CalibratedModelHandle_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_calibrate__SWIG_0")]
  public static extern void CalibratedModelHandle_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_calibrate__SWIG_1")]
  public static extern void CalibratedModelHandle_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_calibrate__SWIG_2")]
  public static extern void CalibratedModelHandle_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_calibrate__SWIG_3")]
  public static extern void CalibratedModelHandle_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_setParams")]
  public static extern void CalibratedModelHandle_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_value")]
  public static extern double CalibratedModelHandle_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_constraint")]
  public static extern global::System.IntPtr CalibratedModelHandle_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_endCriteria")]
  public static extern int CalibratedModelHandle_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_problemValues")]
  public static extern global::System.IntPtr CalibratedModelHandle_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModelHandle_functionEvaluation")]
  public static extern int CalibratedModelHandle_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableCalibratedModelHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableCalibratedModelHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableCalibratedModelHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableCalibratedModelHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCalibratedModelHandle_linkTo")]
  public static extern void RelinkableCalibratedModelHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCalibratedModelHandle_reset")]
  public static extern void RelinkableCalibratedModelHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableCalibratedModelHandle")]
  public static extern void delete_RelinkableCalibratedModelHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeGrid__SWIG_0")]
  public static extern global::System.IntPtr new_TimeGrid__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeGrid__SWIG_1")]
  public static extern global::System.IntPtr new_TimeGrid__SWIG_1(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeGrid__SWIG_2")]
  public static extern global::System.IntPtr new_TimeGrid__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeGrid__SWIG_3")]
  public static extern global::System.IntPtr new_TimeGrid__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeGrid_size")]
  public static extern uint TimeGrid_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TimeGrid")]
  public static extern void delete_TimeGrid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Parameter")]
  public static extern global::System.IntPtr new_Parameter();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_parameters")]
  public static extern global::System.IntPtr Parameter_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_setParam")]
  public static extern void Parameter_setParam(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_testParams")]
  public static extern bool Parameter_testParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_size")]
  public static extern uint Parameter_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_call")]
  public static extern double Parameter_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Parameter_constraint")]
  public static extern global::System.IntPtr Parameter_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Parameter")]
  public static extern void delete_Parameter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantParameter__SWIG_0")]
  public static extern global::System.IntPtr new_ConstantParameter__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantParameter__SWIG_1")]
  public static extern global::System.IntPtr new_ConstantParameter__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConstantParameter")]
  public static extern void delete_ConstantParameter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NullParameter")]
  public static extern global::System.IntPtr new_NullParameter();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NullParameter")]
  public static extern void delete_NullParameter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConstantParameter__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseConstantParameter__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConstantParameter__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseConstantParameter__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseConstantParameter")]
  public static extern void delete_PiecewiseConstantParameter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Payoff_call")]
  public static extern double Payoff_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Payoff")]
  public static extern void delete_Payoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Option_payoff")]
  public static extern global::System.IntPtr Option_payoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Option_exercise")]
  public static extern global::System.IntPtr Option_exercise(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Option")]
  public static extern void delete_Option(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Barrier")]
  public static extern global::System.IntPtr new_Barrier();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Barrier")]
  public static extern void delete_Barrier(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoubleBarrier")]
  public static extern global::System.IntPtr new_DoubleBarrier();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DoubleBarrier")]
  public static extern void delete_DoubleBarrier(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TypePayoff_optionType")]
  public static extern int TypePayoff_optionType(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TypePayoff")]
  public static extern void delete_TypePayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrikedTypePayoff_strike")]
  public static extern double StrikedTypePayoff_strike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StrikedTypePayoff")]
  public static extern void delete_StrikedTypePayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_delta")]
  public static extern double OneAssetOption_delta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_deltaForward")]
  public static extern double OneAssetOption_deltaForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_elasticity")]
  public static extern double OneAssetOption_elasticity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_gamma")]
  public static extern double OneAssetOption_gamma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_theta")]
  public static extern double OneAssetOption_theta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_thetaPerDay")]
  public static extern double OneAssetOption_thetaPerDay(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_vega")]
  public static extern double OneAssetOption_vega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_rho")]
  public static extern double OneAssetOption_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_dividendRho")]
  public static extern double OneAssetOption_dividendRho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_strikeSensitivity")]
  public static extern double OneAssetOption_strikeSensitivity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_itmCashProbability")]
  public static extern double OneAssetOption_itmCashProbability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OneAssetOption")]
  public static extern void delete_OneAssetOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VanillaOption")]
  public static extern global::System.IntPtr new_VanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_impliedVolatility__SWIG_0")]
  public static extern double VanillaOption_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_impliedVolatility__SWIG_1")]
  public static extern double VanillaOption_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_impliedVolatility__SWIG_2")]
  public static extern double VanillaOption_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_impliedVolatility__SWIG_3")]
  public static extern double VanillaOption_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_impliedVolatility__SWIG_4")]
  public static extern double VanillaOption_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_priceCurve")]
  public static extern global::System.IntPtr VanillaOption_priceCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VanillaOption")]
  public static extern void delete_VanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationPair__SWIG_0")]
  public static extern global::System.IntPtr new_CalibrationPair__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationPair__SWIG_1")]
  public static extern global::System.IntPtr new_CalibrationPair__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationPair__SWIG_2")]
  public static extern global::System.IntPtr new_CalibrationPair__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationPair_first_set")]
  public static extern void CalibrationPair_first_set(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationPair_first_get")]
  public static extern global::System.IntPtr CalibrationPair_first_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationPair_second_set")]
  public static extern void CalibrationPair_second_set(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationPair_second_get")]
  public static extern global::System.IntPtr CalibrationPair_second_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibrationPair")]
  public static extern void delete_CalibrationPair(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Clear")]
  public static extern void CalibrationSet_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Add")]
  public static extern void CalibrationSet_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_size")]
  public static extern uint CalibrationSet_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_capacity")]
  public static extern uint CalibrationSet_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_reserve")]
  public static extern void CalibrationSet_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationSet__SWIG_0")]
  public static extern global::System.IntPtr new_CalibrationSet__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationSet__SWIG_1")]
  public static extern global::System.IntPtr new_CalibrationSet__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CalibrationSet__SWIG_2")]
  public static extern global::System.IntPtr new_CalibrationSet__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_getitemcopy")]
  public static extern global::System.IntPtr CalibrationSet_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_getitem")]
  public static extern global::System.IntPtr CalibrationSet_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_setitem")]
  public static extern void CalibrationSet_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_AddRange")]
  public static extern void CalibrationSet_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_GetRange")]
  public static extern global::System.IntPtr CalibrationSet_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Insert")]
  public static extern void CalibrationSet_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_InsertRange")]
  public static extern void CalibrationSet_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_RemoveAt")]
  public static extern void CalibrationSet_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_RemoveRange")]
  public static extern void CalibrationSet_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Repeat")]
  public static extern global::System.IntPtr CalibrationSet_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Reverse__SWIG_0")]
  public static extern void CalibrationSet_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_Reverse__SWIG_1")]
  public static extern void CalibrationSet_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibrationSet_SetRange")]
  public static extern void CalibrationSet_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CalibrationSet")]
  public static extern void delete_CalibrationSet(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EuropeanOption")]
  public static extern global::System.IntPtr new_EuropeanOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EuropeanOption")]
  public static extern void delete_EuropeanOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardVanillaOption")]
  public static extern global::System.IntPtr new_ForwardVanillaOption(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardVanillaOption")]
  public static extern void delete_ForwardVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuantoVanillaOption")]
  public static extern global::System.IntPtr new_QuantoVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoVanillaOption_qvega")]
  public static extern double QuantoVanillaOption_qvega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoVanillaOption_qrho")]
  public static extern double QuantoVanillaOption_qrho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoVanillaOption_qlambda")]
  public static extern double QuantoVanillaOption_qlambda(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuantoVanillaOption")]
  public static extern void delete_QuantoVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuantoForwardVanillaOption")]
  public static extern global::System.IntPtr new_QuantoForwardVanillaOption(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuantoForwardVanillaOption")]
  public static extern void delete_QuantoForwardVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_delta")]
  public static extern double MultiAssetOption_delta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_gamma")]
  public static extern double MultiAssetOption_gamma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_theta")]
  public static extern double MultiAssetOption_theta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_vega")]
  public static extern double MultiAssetOption_vega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_rho")]
  public static extern double MultiAssetOption_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_dividendRho")]
  public static extern double MultiAssetOption_dividendRho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MultiAssetOption")]
  public static extern void delete_MultiAssetOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticEuropeanEngine")]
  public static extern global::System.IntPtr new_AnalyticEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticEuropeanEngine")]
  public static extern void delete_AnalyticEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonModel")]
  public static extern global::System.IntPtr new_HestonModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_theta")]
  public static extern double HestonModel_theta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_kappa")]
  public static extern double HestonModel_kappa(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_sigma")]
  public static extern double HestonModel_sigma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_rho")]
  public static extern double HestonModel_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_v0")]
  public static extern double HestonModel_v0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonModel")]
  public static extern void delete_HestonModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonModelHandle__SWIG_0")]
  public static extern global::System.IntPtr new_HestonModelHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonModelHandle__SWIG_1")]
  public static extern global::System.IntPtr new_HestonModelHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle___deref__")]
  public static extern global::System.IntPtr HestonModelHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_currentLink")]
  public static extern global::System.IntPtr HestonModelHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_empty")]
  public static extern bool HestonModelHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_asObservable")]
  public static extern global::System.IntPtr HestonModelHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonModelHandle")]
  public static extern void delete_HestonModelHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_theta")]
  public static extern double HestonModelHandle_theta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_kappa")]
  public static extern double HestonModelHandle_kappa(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_sigma")]
  public static extern double HestonModelHandle_sigma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_rho")]
  public static extern double HestonModelHandle_rho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_v0")]
  public static extern double HestonModelHandle_v0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_parameters")]
  public static extern global::System.IntPtr HestonModelHandle_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_calibrate__SWIG_0")]
  public static extern void HestonModelHandle_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_calibrate__SWIG_1")]
  public static extern void HestonModelHandle_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_calibrate__SWIG_2")]
  public static extern void HestonModelHandle_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_calibrate__SWIG_3")]
  public static extern void HestonModelHandle_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_setParams")]
  public static extern void HestonModelHandle_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_value")]
  public static extern double HestonModelHandle_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_constraint")]
  public static extern global::System.IntPtr HestonModelHandle_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_endCriteria")]
  public static extern int HestonModelHandle_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_problemValues")]
  public static extern global::System.IntPtr HestonModelHandle_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHandle_functionEvaluation")]
  public static extern int HestonModelHandle_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseTimeDependentHestonModel")]
  public static extern global::System.IntPtr new_PiecewiseTimeDependentHestonModel(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_theta")]
  public static extern double PiecewiseTimeDependentHestonModel_theta(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_kappa")]
  public static extern double PiecewiseTimeDependentHestonModel_kappa(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_sigma")]
  public static extern double PiecewiseTimeDependentHestonModel_sigma(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_rho")]
  public static extern double PiecewiseTimeDependentHestonModel_rho(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_v0")]
  public static extern double PiecewiseTimeDependentHestonModel_v0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_s0")]
  public static extern double PiecewiseTimeDependentHestonModel_s0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_timeGrid")]
  public static extern global::System.IntPtr PiecewiseTimeDependentHestonModel_timeGrid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_dividendYield")]
  public static extern global::System.IntPtr PiecewiseTimeDependentHestonModel_dividendYield(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_riskFreeRate")]
  public static extern global::System.IntPtr PiecewiseTimeDependentHestonModel_riskFreeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseTimeDependentHestonModel")]
  public static extern void delete_PiecewiseTimeDependentHestonModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLaguerre__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLegendre__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLegendre__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLegendre__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLegendre__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussChebyshev2nd__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLobatto__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLobatto__SWIG_0(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLobatto__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussLobatto__SWIG_1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussKronrod__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussKronrod__SWIG_0(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussKronrod__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_gaussKronrod__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_simpson__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_simpson__SWIG_0(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_simpson__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_simpson__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_trapezoid__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_trapezoid__SWIG_0(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_trapezoid__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_trapezoid__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteSimpson__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteSimpson__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteSimpson__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteSimpson__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_0")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_1")]
  public static extern global::System.IntPtr AnalyticHestonEngine_AnalyticHestonEngine_Integration_discreteTrapezoid__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_andersenPiterbargIntegrationLimit")]
  public static extern double AnalyticHestonEngine_AnalyticHestonEngine_Integration_andersenPiterbargIntegrationLimit(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_calculate__SWIG_0")]
  public static extern double AnalyticHestonEngine_AnalyticHestonEngine_Integration_calculate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_calculate__SWIG_1")]
  public static extern double AnalyticHestonEngine_AnalyticHestonEngine_Integration_calculate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_numberOfEvaluations")]
  public static extern uint AnalyticHestonEngine_AnalyticHestonEngine_Integration_numberOfEvaluations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_AnalyticHestonEngine_Integration_isAdaptiveIntegration")]
  public static extern bool AnalyticHestonEngine_AnalyticHestonEngine_Integration_isAdaptiveIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticHestonEngine_AnalyticHestonEngine_Integration")]
  public static extern void delete_AnalyticHestonEngine_AnalyticHestonEngine_Integration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_AnalyticHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_AnalyticHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_AnalyticHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHestonEngine__SWIG_3")]
  public static extern global::System.IntPtr new_AnalyticHestonEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticHestonEngine__SWIG_4")]
  public static extern global::System.IntPtr new_AnalyticHestonEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_chF")]
  public static extern global::System.IntPtr AnalyticHestonEngine_chF(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticHestonEngine")]
  public static extern void delete_AnalyticHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_COSHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_COSHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_COSHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_COSHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_COSHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_COSHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_COSHestonEngine")]
  public static extern void delete_COSHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialFittingHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_ExponentialFittingHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialFittingHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_ExponentialFittingHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialFittingHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_ExponentialFittingHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExponentialFittingHestonEngine")]
  public static extern void delete_ExponentialFittingHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticPTDHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_AnalyticPTDHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticPTDHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_AnalyticPTDHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticPTDHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_AnalyticPTDHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticPTDHestonEngine__SWIG_3")]
  public static extern global::System.IntPtr new_AnalyticPTDHestonEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticPTDHestonEngine__SWIG_4")]
  public static extern global::System.IntPtr new_AnalyticPTDHestonEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticPTDHestonEngine")]
  public static extern void delete_AnalyticPTDHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BatesModel")]
  public static extern global::System.IntPtr new_BatesModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesModel_nu")]
  public static extern double BatesModel_nu(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesModel_delta")]
  public static extern double BatesModel_delta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesModel_lambda")]
  public static extern double BatesModel_lambda(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BatesModel")]
  public static extern void delete_BatesModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BatesEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BatesEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BatesEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BatesEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BatesEngine__SWIG_2")]
  public static extern global::System.IntPtr new_BatesEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BatesEngine")]
  public static extern void delete_BatesEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntegralEngine")]
  public static extern global::System.IntPtr new_IntegralEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntegralEngine")]
  public static extern void delete_IntegralEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDBermudanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FDBermudanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDBermudanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FDBermudanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDBermudanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FDBermudanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDBermudanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FDBermudanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDBermudanEngine")]
  public static extern void delete_FDBermudanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDEuropeanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FDEuropeanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDEuropeanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FDEuropeanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDEuropeanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FDEuropeanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDEuropeanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FDEuropeanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDEuropeanEngine")]
  public static extern void delete_FDEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialCRRVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialCRRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialCRRVanillaEngine")]
  public static extern void delete_BinomialCRRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJRVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialJRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJRVanillaEngine")]
  public static extern void delete_BinomialJRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialEQPVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialEQPVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialEQPVanillaEngine")]
  public static extern void delete_BinomialEQPVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTrigeorgisVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialTrigeorgisVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTrigeorgisVanillaEngine")]
  public static extern void delete_BinomialTrigeorgisVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTianVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialTianVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTianVanillaEngine")]
  public static extern void delete_BinomialTianVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialLRVanillaEngine")]
  public static extern global::System.IntPtr new_BinomialLRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialLRVanillaEngine")]
  public static extern void delete_BinomialLRVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJ4VanillaEngine")]
  public static extern global::System.IntPtr new_BinomialJ4VanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJ4VanillaEngine")]
  public static extern void delete_BinomialJ4VanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LsmBasisSystem")]
  public static extern global::System.IntPtr new_LsmBasisSystem();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LsmBasisSystem")]
  public static extern void delete_LsmBasisSystem(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPREuropeanEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPREuropeanEngine")]
  public static extern void delete_MCPREuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDEuropeanEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDEuropeanEngine")]
  public static extern void delete_MCLDEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, uint jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_10")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_11")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_12")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanEngine__SWIG_13")]
  public static extern global::System.IntPtr new_MCPRAmericanEngine__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRAmericanEngine")]
  public static extern void delete_MCPRAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, uint jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_10")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_11")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_12")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanEngine__SWIG_13")]
  public static extern global::System.IntPtr new_MCLDAmericanEngine__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDAmericanEngine")]
  public static extern void delete_MCLDAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanHestonEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPREuropeanHestonEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPREuropeanHestonEngine")]
  public static extern void delete_MCPREuropeanHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanHestonEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDEuropeanHestonEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDEuropeanHestonEngine")]
  public static extern void delete_MCLDEuropeanHestonEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDAmericanEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FDAmericanEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDAmericanEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FDAmericanEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDAmericanEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FDAmericanEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDAmericanEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FDAmericanEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDAmericanEngine")]
  public static extern void delete_FDAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDShoutEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FDShoutEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDShoutEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FDShoutEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDShoutEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FDShoutEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDShoutEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FDShoutEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDShoutEngine")]
  public static extern void delete_FDShoutEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ContinuousArithmeticAsianLevyEngine")]
  public static extern global::System.IntPtr new_ContinuousArithmeticAsianLevyEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ContinuousArithmeticAsianLevyEngine")]
  public static extern void delete_ContinuousArithmeticAsianLevyEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesAsianEngine")]
  public static extern global::System.IntPtr new_FdBlackScholesAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdBlackScholesAsianEngine")]
  public static extern void delete_FdBlackScholesAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BaroneAdesiWhaleyApproximationEngine")]
  public static extern global::System.IntPtr new_BaroneAdesiWhaleyApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BaroneAdesiWhaleyApproximationEngine")]
  public static extern void delete_BaroneAdesiWhaleyApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BjerksundStenslandApproximationEngine")]
  public static extern global::System.IntPtr new_BjerksundStenslandApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BjerksundStenslandApproximationEngine")]
  public static extern void delete_BjerksundStenslandApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JuQuadraticApproximationEngine")]
  public static extern global::System.IntPtr new_JuQuadraticApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JuQuadraticApproximationEngine")]
  public static extern void delete_JuQuadraticApproximationEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDigitalAmericanEngine")]
  public static extern global::System.IntPtr new_AnalyticDigitalAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDigitalAmericanEngine")]
  public static extern void delete_AnalyticDigitalAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDigitalAmericanKOEngine")]
  public static extern global::System.IntPtr new_AnalyticDigitalAmericanKOEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDigitalAmericanKOEngine")]
  public static extern void delete_AnalyticDigitalAmericanKOEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DividendVanillaOption")]
  public static extern global::System.IntPtr new_DividendVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_impliedVolatility__SWIG_0")]
  public static extern double DividendVanillaOption_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_impliedVolatility__SWIG_1")]
  public static extern double DividendVanillaOption_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_impliedVolatility__SWIG_2")]
  public static extern double DividendVanillaOption_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_impliedVolatility__SWIG_3")]
  public static extern double DividendVanillaOption_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_impliedVolatility__SWIG_4")]
  public static extern double DividendVanillaOption_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DividendVanillaOption")]
  public static extern void delete_DividendVanillaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDividendEuropeanEngine")]
  public static extern global::System.IntPtr new_AnalyticDividendEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDividendEuropeanEngine")]
  public static extern void delete_AnalyticDividendEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendEuropeanEngineT__SWIG_0")]
  public static extern global::System.IntPtr new_FDDividendEuropeanEngineT__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendEuropeanEngineT__SWIG_1")]
  public static extern global::System.IntPtr new_FDDividendEuropeanEngineT__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendEuropeanEngineT__SWIG_2")]
  public static extern global::System.IntPtr new_FDDividendEuropeanEngineT__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendEuropeanEngineT__SWIG_3")]
  public static extern global::System.IntPtr new_FDDividendEuropeanEngineT__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDDividendEuropeanEngine")]
  public static extern void delete_FDDividendEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendAmericanEngineT__SWIG_0")]
  public static extern global::System.IntPtr new_FDDividendAmericanEngineT__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendAmericanEngineT__SWIG_1")]
  public static extern global::System.IntPtr new_FDDividendAmericanEngineT__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendAmericanEngineT__SWIG_2")]
  public static extern global::System.IntPtr new_FDDividendAmericanEngineT__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FDDividendAmericanEngineT__SWIG_3")]
  public static extern global::System.IntPtr new_FDDividendAmericanEngineT__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FDDividendAmericanEngine")]
  public static extern void delete_FDDividendAmericanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BarrierOption")]
  public static extern global::System.IntPtr new_BarrierOption(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_impliedVolatility__SWIG_0")]
  public static extern double BarrierOption_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_impliedVolatility__SWIG_1")]
  public static extern double BarrierOption_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_impliedVolatility__SWIG_2")]
  public static extern double BarrierOption_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_impliedVolatility__SWIG_3")]
  public static extern double BarrierOption_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_impliedVolatility__SWIG_4")]
  public static extern double BarrierOption_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BarrierOption")]
  public static extern void delete_BarrierOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DividendBarrierOption")]
  public static extern global::System.IntPtr new_DividendBarrierOption(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DividendBarrierOption")]
  public static extern void delete_DividendBarrierOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticBarrierEngine")]
  public static extern global::System.IntPtr new_AnalyticBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticBarrierEngine")]
  public static extern void delete_AnalyticBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, bool jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, bool jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRBarrierEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCPRBarrierEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRBarrierEngine")]
  public static extern void delete_MCPRBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, bool jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, bool jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDBarrierEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCLDBarrierEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDBarrierEngine")]
  public static extern void delete_MCLDBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSchemeDesc")]
  public static extern global::System.IntPtr new_FdmSchemeDesc(int jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_type_get")]
  public static extern int FdmSchemeDesc_type_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_theta_get")]
  public static extern double FdmSchemeDesc_theta_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_mu_get")]
  public static extern double FdmSchemeDesc_mu_get(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_Douglas")]
  public static extern global::System.IntPtr FdmSchemeDesc_Douglas();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_CrankNicolson")]
  public static extern global::System.IntPtr FdmSchemeDesc_CrankNicolson();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_ImplicitEuler")]
  public static extern global::System.IntPtr FdmSchemeDesc_ImplicitEuler();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_ExplicitEuler")]
  public static extern global::System.IntPtr FdmSchemeDesc_ExplicitEuler();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_CraigSneyd")]
  public static extern global::System.IntPtr FdmSchemeDesc_CraigSneyd();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_ModifiedCraigSneyd")]
  public static extern global::System.IntPtr FdmSchemeDesc_ModifiedCraigSneyd();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_Hundsdorfer")]
  public static extern global::System.IntPtr FdmSchemeDesc_Hundsdorfer();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_ModifiedHundsdorfer")]
  public static extern global::System.IntPtr FdmSchemeDesc_ModifiedHundsdorfer();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_MethodOfLines__SWIG_0")]
  public static extern global::System.IntPtr FdmSchemeDesc_MethodOfLines__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_MethodOfLines__SWIG_1")]
  public static extern global::System.IntPtr FdmSchemeDesc_MethodOfLines__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_MethodOfLines__SWIG_2")]
  public static extern global::System.IntPtr FdmSchemeDesc_MethodOfLines__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSchemeDesc_TrBDF2")]
  public static extern global::System.IntPtr FdmSchemeDesc_TrBDF2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSchemeDesc")]
  public static extern void delete_FdmSchemeDesc(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmQuantoHelper")]
  public static extern global::System.IntPtr new_FdmQuantoHelper(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmQuantoHelper")]
  public static extern void delete_FdmQuantoHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_8")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_9")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_10")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_11")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_12")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_13")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_14")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesVanillaEngine__SWIG_15")]
  public static extern global::System.IntPtr new_FdBlackScholesVanillaEngine__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdBlackScholesVanillaEngine")]
  public static extern void delete_FdBlackScholesVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdOrnsteinUhlenbeckVanillaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdOrnsteinUhlenbeckVanillaEngine")]
  public static extern void delete_FdOrnsteinUhlenbeckVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBatesVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdBatesVanillaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdBatesVanillaEngine")]
  public static extern void delete_FdBatesVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_8")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_9")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_10")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_11")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_12")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_13")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_14")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonVanillaEngine__SWIG_15")]
  public static extern global::System.IntPtr new_FdHestonVanillaEngine__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdHestonVanillaEngine")]
  public static extern void delete_FdHestonVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticCEVEngine")]
  public static extern global::System.IntPtr new_AnalyticCEVEngine(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticCEVEngine")]
  public static extern void delete_AnalyticCEVEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_0(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7, double jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_1(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_2(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_3(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_4(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_5(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdCEVVanillaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdCEVVanillaEngine__SWIG_6(double jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdCEVVanillaEngine")]
  public static extern void delete_FdCEVVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8, uint jarg9, uint jarg10, double jarg11, double jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8, uint jarg9, uint jarg10, double jarg11, double jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_2(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8, uint jarg9, uint jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_3(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8, uint jarg9, uint jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_4(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_5(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_6(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSabrVanillaEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdSabrVanillaEngine__SWIG_7(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdSabrVanillaEngine")]
  public static extern void delete_FdSabrVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesBarrierEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdBlackScholesBarrierEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdBlackScholesBarrierEngine")]
  public static extern void delete_FdBlackScholesBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdBlackScholesRebateEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdBlackScholesRebateEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdBlackScholesRebateEngine")]
  public static extern void delete_FdBlackScholesRebateEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonBarrierEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdHestonBarrierEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdHestonBarrierEngine")]
  public static extern void delete_FdHestonBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonRebateEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdHestonRebateEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdHestonRebateEngine")]
  public static extern void delete_FdHestonRebateEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticBinaryBarrierEngine")]
  public static extern global::System.IntPtr new_AnalyticBinaryBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticBinaryBarrierEngine")]
  public static extern void delete_AnalyticBinaryBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialCRRBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialCRRBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialCRRBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialCRRBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialCRRBarrierEngine")]
  public static extern void delete_BinomialCRRBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJRBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialJRBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJRBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialJRBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJRBarrierEngine")]
  public static extern void delete_BinomialJRBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialEQPBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialEQPBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialEQPBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialEQPBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialEQPBarrierEngine")]
  public static extern void delete_BinomialEQPBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTrigeorgisBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialTrigeorgisBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTrigeorgisBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialTrigeorgisBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTrigeorgisBarrierEngine")]
  public static extern void delete_BinomialTrigeorgisBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTianBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialTianBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTianBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialTianBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTianBarrierEngine")]
  public static extern void delete_BinomialTianBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialLRBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialLRBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialLRBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialLRBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialLRBarrierEngine")]
  public static extern void delete_BinomialLRBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJ4BarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BinomialJ4BarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJ4BarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BinomialJ4BarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJ4BarrierEngine")]
  public static extern void delete_BinomialJ4BarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardEuropeanEngine")]
  public static extern global::System.IntPtr new_ForwardEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardEuropeanEngine")]
  public static extern void delete_ForwardEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuantoEuropeanEngine")]
  public static extern global::System.IntPtr new_QuantoEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuantoEuropeanEngine")]
  public static extern void delete_QuantoEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuantoForwardEuropeanEngine")]
  public static extern global::System.IntPtr new_QuantoForwardEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuantoForwardEuropeanEngine")]
  public static extern void delete_QuantoForwardEuropeanEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCalculator__SWIG_0")]
  public static extern global::System.IntPtr new_BlackCalculator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCalculator__SWIG_1")]
  public static extern global::System.IntPtr new_BlackCalculator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_value")]
  public static extern double BlackCalculator_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_deltaForward")]
  public static extern double BlackCalculator_deltaForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_delta")]
  public static extern double BlackCalculator_delta(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_elasticityForward")]
  public static extern double BlackCalculator_elasticityForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_elasticity")]
  public static extern double BlackCalculator_elasticity(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_gammaForward")]
  public static extern double BlackCalculator_gammaForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_gamma")]
  public static extern double BlackCalculator_gamma(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_theta")]
  public static extern double BlackCalculator_theta(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_thetaPerDay")]
  public static extern double BlackCalculator_thetaPerDay(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_vega")]
  public static extern double BlackCalculator_vega(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_rho")]
  public static extern double BlackCalculator_rho(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_dividendRho")]
  public static extern double BlackCalculator_dividendRho(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_itmCashProbability")]
  public static extern double BlackCalculator_itmCashProbability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_itmAssetProbability")]
  public static extern double BlackCalculator_itmAssetProbability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_strikeSensitivity")]
  public static extern double BlackCalculator_strikeSensitivity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_alpha")]
  public static extern double BlackCalculator_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalculator_beta")]
  public static extern double BlackCalculator_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCalculator")]
  public static extern void delete_BlackCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Average")]
  public static extern global::System.IntPtr new_Average();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Average")]
  public static extern void delete_Average(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ContinuousAveragingAsianOption")]
  public static extern global::System.IntPtr new_ContinuousAveragingAsianOption(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ContinuousAveragingAsianOption")]
  public static extern void delete_ContinuousAveragingAsianOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscreteAveragingAsianOption")]
  public static extern global::System.IntPtr new_DiscreteAveragingAsianOption(int jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DiscreteAveragingAsianOption")]
  public static extern void delete_DiscreteAveragingAsianOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticContinuousGeometricAveragePriceAsianEngine")]
  public static extern global::System.IntPtr new_AnalyticContinuousGeometricAveragePriceAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticContinuousGeometricAveragePriceAsianEngine")]
  public static extern void delete_AnalyticContinuousGeometricAveragePriceAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDiscreteGeometricAveragePriceAsianEngine")]
  public static extern global::System.IntPtr new_AnalyticDiscreteGeometricAveragePriceAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDiscreteGeometricAveragePriceAsianEngine")]
  public static extern void delete_AnalyticDiscreteGeometricAveragePriceAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDiscreteGeometricAverageStrikeAsianEngine")]
  public static extern global::System.IntPtr new_AnalyticDiscreteGeometricAverageStrikeAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDiscreteGeometricAverageStrikeAsianEngine")]
  public static extern void delete_AnalyticDiscreteGeometricAverageStrikeAsianEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticAPEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticAPEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRDiscreteArithmeticAPEngine")]
  public static extern void delete_MCPRDiscreteArithmeticAPEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticAPEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticAPEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDDiscreteArithmeticAPEngine")]
  public static extern void delete_MCLDDiscreteArithmeticAPEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteArithmeticASEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRDiscreteArithmeticASEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRDiscreteArithmeticASEngine")]
  public static extern void delete_MCPRDiscreteArithmeticASEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteArithmeticASEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDDiscreteArithmeticASEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDDiscreteArithmeticASEngine")]
  public static extern void delete_MCLDDiscreteArithmeticASEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRDiscreteGeometricAPEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRDiscreteGeometricAPEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRDiscreteGeometricAPEngine")]
  public static extern void delete_MCPRDiscreteGeometricAPEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDDiscreteGeometricAPEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDDiscreteGeometricAPEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDDiscreteGeometricAPEngine")]
  public static extern void delete_MCLDDiscreteGeometricAPEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VarianceGammaEngine")]
  public static extern global::System.IntPtr new_VarianceGammaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VarianceGammaEngine")]
  public static extern void delete_VarianceGammaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FFTVarianceGammaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FFTVarianceGammaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FFTVarianceGammaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FFTVarianceGammaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FFTVarianceGammaEngine_precalculate")]
  public static extern void FFTVarianceGammaEngine_precalculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FFTVarianceGammaEngine")]
  public static extern void delete_FFTVarianceGammaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DoubleBarrierOption")]
  public static extern global::System.IntPtr new_DoubleBarrierOption(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DoubleBarrierOption")]
  public static extern void delete_DoubleBarrierOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_QuantoDoubleBarrierOption")]
  public static extern global::System.IntPtr new_QuantoDoubleBarrierOption(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoDoubleBarrierOption_qvega")]
  public static extern double QuantoDoubleBarrierOption_qvega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoDoubleBarrierOption_qrho")]
  public static extern double QuantoDoubleBarrierOption_qrho(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoDoubleBarrierOption_qlambda")]
  public static extern double QuantoDoubleBarrierOption_qlambda(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_QuantoDoubleBarrierOption")]
  public static extern void delete_QuantoDoubleBarrierOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDoubleBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_AnalyticDoubleBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDoubleBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_AnalyticDoubleBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDoubleBarrierEngine")]
  public static extern void delete_AnalyticDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHestonDoubleBarrierEngine__SWIG_7")]
  public static extern global::System.IntPtr new_FdHestonDoubleBarrierEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdHestonDoubleBarrierEngine")]
  public static extern void delete_FdHestonDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_WulinYongDoubleBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_WulinYongDoubleBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_WulinYongDoubleBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_WulinYongDoubleBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_WulinYongDoubleBarrierEngine")]
  public static extern void delete_WulinYongDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DeltaVolQuote__SWIG_0")]
  public static extern global::System.IntPtr new_DeltaVolQuote__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DeltaVolQuote__SWIG_1")]
  public static extern global::System.IntPtr new_DeltaVolQuote__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DeltaVolQuote")]
  public static extern void delete_DeltaVolQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DeltaVolQuoteHandle__SWIG_0")]
  public static extern global::System.IntPtr new_DeltaVolQuoteHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DeltaVolQuoteHandle__SWIG_1")]
  public static extern global::System.IntPtr new_DeltaVolQuoteHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle___deref__")]
  public static extern global::System.IntPtr DeltaVolQuoteHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle_currentLink")]
  public static extern global::System.IntPtr DeltaVolQuoteHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle_empty")]
  public static extern bool DeltaVolQuoteHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle_asObservable")]
  public static extern global::System.IntPtr DeltaVolQuoteHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DeltaVolQuoteHandle")]
  public static extern void delete_DeltaVolQuoteHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle_value")]
  public static extern double DeltaVolQuoteHandle_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuoteHandle_isValid")]
  public static extern bool DeltaVolQuoteHandle_isValid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableDeltaVolQuoteHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableDeltaVolQuoteHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableDeltaVolQuoteHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableDeltaVolQuoteHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDeltaVolQuoteHandle_linkTo")]
  public static extern void RelinkableDeltaVolQuoteHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDeltaVolQuoteHandle_reset")]
  public static extern void RelinkableDeltaVolQuoteHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableDeltaVolQuoteHandle")]
  public static extern void delete_RelinkableDeltaVolQuoteHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaIKDoubleBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_VannaVolgaIKDoubleBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaIKDoubleBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_VannaVolgaIKDoubleBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaIKDoubleBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_VannaVolgaIKDoubleBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaIKDoubleBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_VannaVolgaIKDoubleBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VannaVolgaIKDoubleBarrierEngine")]
  public static extern void delete_VannaVolgaIKDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaWODoubleBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_VannaVolgaWODoubleBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaWODoubleBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_VannaVolgaWODoubleBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaWODoubleBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_VannaVolgaWODoubleBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaWODoubleBarrierEngine__SWIG_3")]
  public static extern global::System.IntPtr new_VannaVolgaWODoubleBarrierEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VannaVolgaWODoubleBarrierEngine")]
  public static extern void delete_VannaVolgaWODoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaBarrierEngine__SWIG_0")]
  public static extern global::System.IntPtr new_VannaVolgaBarrierEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaBarrierEngine__SWIG_1")]
  public static extern global::System.IntPtr new_VannaVolgaBarrierEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VannaVolgaBarrierEngine__SWIG_2")]
  public static extern global::System.IntPtr new_VannaVolgaBarrierEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VannaVolgaBarrierEngine")]
  public static extern void delete_VannaVolgaBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticDoubleBarrierBinaryEngine")]
  public static extern global::System.IntPtr new_AnalyticDoubleBarrierBinaryEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticDoubleBarrierBinaryEngine")]
  public static extern void delete_AnalyticDoubleBarrierBinaryEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialCRRDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialCRRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialCRRDoubleBarrierEngine")]
  public static extern void delete_BinomialCRRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJRDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialJRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJRDoubleBarrierEngine")]
  public static extern void delete_BinomialJRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialEQPDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialEQPDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialEQPDoubleBarrierEngine")]
  public static extern void delete_BinomialEQPDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTrigeorgisDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialTrigeorgisDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTrigeorgisDoubleBarrierEngine")]
  public static extern void delete_BinomialTrigeorgisDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTianDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialTianDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTianDoubleBarrierEngine")]
  public static extern void delete_BinomialTianDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialLRDoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialLRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialLRDoubleBarrierEngine")]
  public static extern void delete_BinomialLRDoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJ4DoubleBarrierEngine")]
  public static extern global::System.IntPtr new_BinomialJ4DoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJ4DoubleBarrierEngine")]
  public static extern void delete_BinomialJ4DoubleBarrierEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VanillaSwingOption")]
  public static extern global::System.IntPtr new_VanillaSwingOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VanillaSwingOption")]
  public static extern void delete_VanillaSwingOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleBSSwingEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdSimpleBSSwingEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleBSSwingEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdSimpleBSSwingEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleBSSwingEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdSimpleBSSwingEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleBSSwingEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdSimpleBSSwingEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdSimpleBSSwingEngine")]
  public static extern void delete_FdSimpleBSSwingEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdSimpleExtOUJumpSwingEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdSimpleExtOUJumpSwingEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdSimpleExtOUJumpSwingEngine")]
  public static extern void delete_FdSimpleExtOUJumpSwingEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GJRGARCHModel")]
  public static extern global::System.IntPtr new_GJRGARCHModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_omega")]
  public static extern double GJRGARCHModel_omega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_alpha")]
  public static extern double GJRGARCHModel_alpha(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_beta")]
  public static extern double GJRGARCHModel_beta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_gamma")]
  public static extern double GJRGARCHModel_gamma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_lambda")]
  public static extern double GJRGARCHModel_lambda(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_v0")]
  public static extern double GJRGARCHModel_v0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GJRGARCHModel")]
  public static extern void delete_GJRGARCHModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticGJRGARCHEngine")]
  public static extern global::System.IntPtr new_AnalyticGJRGARCHEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticGJRGARCHEngine")]
  public static extern void delete_AnalyticGJRGARCHEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanGJRGARCHEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPREuropeanGJRGARCHEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPREuropeanGJRGARCHEngine")]
  public static extern void delete_MCPREuropeanGJRGARCHEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanGJRGARCHEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDEuropeanGJRGARCHEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDEuropeanGJRGARCHEngine")]
  public static extern void delete_MCLDEuropeanGJRGARCHEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadOption")]
  public static extern global::System.IntPtr new_SpreadOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SpreadOption")]
  public static extern void delete_SpreadOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KirkSpreadOptionEngine")]
  public static extern global::System.IntPtr new_KirkSpreadOptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KirkSpreadOptionEngine")]
  public static extern void delete_KirkSpreadOptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PlainVanillaPayoff")]
  public static extern global::System.IntPtr new_PlainVanillaPayoff(int jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PlainVanillaPayoff")]
  public static extern void delete_PlainVanillaPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_plain_vanilla_payoff")]
  public static extern global::System.IntPtr as_plain_vanilla_payoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PercentageStrikePayoff")]
  public static extern global::System.IntPtr new_PercentageStrikePayoff(int jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PercentageStrikePayoff")]
  public static extern void delete_PercentageStrikePayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CashOrNothingPayoff")]
  public static extern global::System.IntPtr new_CashOrNothingPayoff(int jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CashOrNothingPayoff")]
  public static extern void delete_CashOrNothingPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AssetOrNothingPayoff")]
  public static extern global::System.IntPtr new_AssetOrNothingPayoff(int jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AssetOrNothingPayoff")]
  public static extern void delete_AssetOrNothingPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SuperSharePayoff")]
  public static extern global::System.IntPtr new_SuperSharePayoff(int jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SuperSharePayoff")]
  public static extern void delete_SuperSharePayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GapPayoff")]
  public static extern global::System.IntPtr new_GapPayoff(int jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GapPayoff")]
  public static extern void delete_GapPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VanillaForwardPayoff")]
  public static extern global::System.IntPtr new_VanillaForwardPayoff(int jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VanillaForwardPayoff")]
  public static extern void delete_VanillaForwardPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BasketPayoff")]
  public static extern void delete_BasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MinBasketPayoff")]
  public static extern global::System.IntPtr new_MinBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MinBasketPayoff")]
  public static extern void delete_MinBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MaxBasketPayoff")]
  public static extern global::System.IntPtr new_MaxBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MaxBasketPayoff")]
  public static extern void delete_MaxBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AverageBasketPayoff__SWIG_0")]
  public static extern global::System.IntPtr new_AverageBasketPayoff__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AverageBasketPayoff__SWIG_1")]
  public static extern global::System.IntPtr new_AverageBasketPayoff__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AverageBasketPayoff")]
  public static extern void delete_AverageBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadBasketPayoff")]
  public static extern global::System.IntPtr new_SpreadBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SpreadBasketPayoff")]
  public static extern void delete_SpreadBasketPayoff(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BasketOption")]
  public static extern global::System.IntPtr new_BasketOption(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BasketOption")]
  public static extern void delete_BasketOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREuropeanBasketEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPREuropeanBasketEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPREuropeanBasketEngine")]
  public static extern void delete_MCPREuropeanBasketEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEuropeanBasketEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDEuropeanBasketEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDEuropeanBasketEngine")]
  public static extern void delete_MCLDEuropeanBasketEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10, uint jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_10")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRAmericanBasketEngine__SWIG_11")]
  public static extern global::System.IntPtr new_MCPRAmericanBasketEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRAmericanBasketEngine")]
  public static extern void delete_MCPRAmericanBasketEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10, uint jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9, uint jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_9")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_10")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDAmericanBasketEngine__SWIG_11")]
  public static extern global::System.IntPtr new_MCLDAmericanBasketEngine__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDAmericanBasketEngine")]
  public static extern void delete_MCLDAmericanBasketEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StulzEngine")]
  public static extern global::System.IntPtr new_StulzEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StulzEngine")]
  public static extern void delete_StulzEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KirkEngine")]
  public static extern global::System.IntPtr new_KirkEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KirkEngine")]
  public static extern void delete_KirkEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5, uint jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, bool jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5, uint jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, bool jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5, uint jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5, uint jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fd2dBlackScholesVanillaEngine__SWIG_7")]
  public static extern global::System.IntPtr new_Fd2dBlackScholesVanillaEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fd2dBlackScholesVanillaEngine")]
  public static extern void delete_Fd2dBlackScholesVanillaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EverestOption")]
  public static extern global::System.IntPtr new_EverestOption(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EverestOption")]
  public static extern void delete_EverestOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPREverestEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCPREverestEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPREverestEngine")]
  public static extern void delete_MCPREverestEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_7")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDEverestEngine__SWIG_8")]
  public static extern global::System.IntPtr new_MCLDEverestEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDEverestEngine")]
  public static extern void delete_MCLDEverestEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HimalayaOption")]
  public static extern global::System.IntPtr new_HimalayaOption(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HimalayaOption")]
  public static extern void delete_HimalayaOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCPRHimalayaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCPRHimalayaEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCPRHimalayaEngine")]
  public static extern void delete_MCPRHimalayaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_0")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_1")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_2")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_3")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_4")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_5")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MCLDHimalayaEngine__SWIG_6")]
  public static extern global::System.IntPtr new_MCLDHimalayaEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MCLDHimalayaEngine")]
  public static extern void delete_MCLDHimalayaEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormula__SWIG_0")]
  public static extern double blackFormula__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormula__SWIG_1")]
  public static extern double blackFormula__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormula__SWIG_2")]
  public static extern double blackFormula__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_0")]
  public static extern double blackFormulaImpliedStdDev__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_1")]
  public static extern double blackFormulaImpliedStdDev__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_2")]
  public static extern double blackFormulaImpliedStdDev__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_3")]
  public static extern double blackFormulaImpliedStdDev__SWIG_3(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_4")]
  public static extern double blackFormulaImpliedStdDev__SWIG_4(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDev__SWIG_5")]
  public static extern double blackFormulaImpliedStdDev__SWIG_5(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_0")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9, uint jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_1")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_2")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_2(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_3")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_3(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_4")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_4(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_5")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_5(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_6")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_6(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_7")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_8")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_9")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_10")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_11")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_12")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaImpliedStdDevLiRS__SWIG_13")]
  public static extern double blackFormulaImpliedStdDevLiRS__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaCashItmProbability__SWIG_0")]
  public static extern double blackFormulaCashItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaCashItmProbability__SWIG_1")]
  public static extern double blackFormulaCashItmProbability__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaCashItmProbability__SWIG_2")]
  public static extern double blackFormulaCashItmProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaCashItmProbability__SWIG_3")]
  public static extern double blackFormulaCashItmProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaAssetItmProbability__SWIG_0")]
  public static extern double blackFormulaAssetItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaAssetItmProbability__SWIG_1")]
  public static extern double blackFormulaAssetItmProbability__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaAssetItmProbability__SWIG_2")]
  public static extern double blackFormulaAssetItmProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_blackFormulaAssetItmProbability__SWIG_3")]
  public static extern double blackFormulaAssetItmProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormula__SWIG_0")]
  public static extern double bachelierBlackFormula__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormula__SWIG_1")]
  public static extern double bachelierBlackFormula__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormulaImpliedVol__SWIG_0")]
  public static extern double bachelierBlackFormulaImpliedVol__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormulaImpliedVol__SWIG_1")]
  public static extern double bachelierBlackFormulaImpliedVol__SWIG_1(int jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormulaAssetItmProbability__SWIG_0")]
  public static extern double bachelierBlackFormulaAssetItmProbability__SWIG_0(int jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_bachelierBlackFormulaAssetItmProbability__SWIG_1")]
  public static extern double bachelierBlackFormulaAssetItmProbability__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackDeltaCalculator")]
  public static extern global::System.IntPtr new_BlackDeltaCalculator(int jarg1, int jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackDeltaCalculator_deltaFromStrike")]
  public static extern double BlackDeltaCalculator_deltaFromStrike(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackDeltaCalculator_strikeFromDelta")]
  public static extern double BlackDeltaCalculator_strikeFromDelta(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackDeltaCalculator_atmStrike")]
  public static extern double BlackDeltaCalculator_atmStrike(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackDeltaCalculator")]
  public static extern void delete_BlackDeltaCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallabilityPrice")]
  public static extern global::System.IntPtr new_CallabilityPrice(double jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilityPrice_amount")]
  public static extern double CallabilityPrice_amount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilityPrice_type")]
  public static extern int CallabilityPrice_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CallabilityPrice")]
  public static extern void delete_CallabilityPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Callability")]
  public static extern global::System.IntPtr new_Callability(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Callability_price")]
  public static extern global::System.IntPtr Callability_price(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Callability_type")]
  public static extern int Callability_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Callability_date")]
  public static extern global::System.IntPtr Callability_date(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Callability")]
  public static extern void delete_Callability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SoftCallability")]
  public static extern global::System.IntPtr new_SoftCallability(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SoftCallability")]
  public static extern void delete_SoftCallability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Clear")]
  public static extern void CallabilitySchedule_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Add")]
  public static extern void CallabilitySchedule_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_size")]
  public static extern uint CallabilitySchedule_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_capacity")]
  public static extern uint CallabilitySchedule_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_reserve")]
  public static extern void CallabilitySchedule_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallabilitySchedule__SWIG_0")]
  public static extern global::System.IntPtr new_CallabilitySchedule__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallabilitySchedule__SWIG_1")]
  public static extern global::System.IntPtr new_CallabilitySchedule__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallabilitySchedule__SWIG_2")]
  public static extern global::System.IntPtr new_CallabilitySchedule__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_getitemcopy")]
  public static extern global::System.IntPtr CallabilitySchedule_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_getitem")]
  public static extern global::System.IntPtr CallabilitySchedule_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_setitem")]
  public static extern void CallabilitySchedule_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_AddRange")]
  public static extern void CallabilitySchedule_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_GetRange")]
  public static extern global::System.IntPtr CallabilitySchedule_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Insert")]
  public static extern void CallabilitySchedule_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_InsertRange")]
  public static extern void CallabilitySchedule_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_RemoveAt")]
  public static extern void CallabilitySchedule_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_RemoveRange")]
  public static extern void CallabilitySchedule_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Repeat")]
  public static extern global::System.IntPtr CallabilitySchedule_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Reverse__SWIG_0")]
  public static extern void CallabilitySchedule_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Reverse__SWIG_1")]
  public static extern void CallabilitySchedule_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_SetRange")]
  public static extern void CallabilitySchedule_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Contains")]
  public static extern bool CallabilitySchedule_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_IndexOf")]
  public static extern int CallabilitySchedule_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_LastIndexOf")]
  public static extern int CallabilitySchedule_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallabilitySchedule_Remove")]
  public static extern bool CallabilitySchedule_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CallabilitySchedule")]
  public static extern void delete_CallabilitySchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeBasket__SWIG_0")]
  public static extern global::System.IntPtr new_TimeBasket__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeBasket__SWIG_1")]
  public static extern global::System.IntPtr new_TimeBasket__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeBasket_size")]
  public static extern uint TimeBasket_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeBasket_rebin")]
  public static extern global::System.IntPtr TimeBasket_rebin(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TimeBasket")]
  public static extern void delete_TimeBasket(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Swap")]
  public static extern global::System.IntPtr new_Swap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_startDate")]
  public static extern global::System.IntPtr Swap_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_maturityDate")]
  public static extern global::System.IntPtr Swap_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_leg")]
  public static extern global::System.IntPtr Swap_leg(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_legNPV")]
  public static extern double Swap_legNPV(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_legBPS")]
  public static extern double Swap_legBPS(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Swap")]
  public static extern void delete_Swap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_VanillaSwap")]
  public static extern global::System.IntPtr new_VanillaSwap(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fairRate")]
  public static extern double VanillaSwap_fairRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fairSpread")]
  public static extern double VanillaSwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedLegBPS")]
  public static extern double VanillaSwap_fixedLegBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_floatingLegBPS")]
  public static extern double VanillaSwap_floatingLegBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedLegNPV")]
  public static extern double VanillaSwap_fixedLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_floatingLegNPV")]
  public static extern double VanillaSwap_floatingLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedLeg")]
  public static extern global::System.IntPtr VanillaSwap_fixedLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_floatingLeg")]
  public static extern global::System.IntPtr VanillaSwap_floatingLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_nominal")]
  public static extern double VanillaSwap_nominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedSchedule")]
  public static extern global::System.IntPtr VanillaSwap_fixedSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_floatingSchedule")]
  public static extern global::System.IntPtr VanillaSwap_floatingSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedRate")]
  public static extern double VanillaSwap_fixedRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_spread")]
  public static extern double VanillaSwap_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_floatingDayCount")]
  public static extern global::System.IntPtr VanillaSwap_floatingDayCount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_fixedDayCount")]
  public static extern global::System.IntPtr VanillaSwap_fixedDayCount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_VanillaSwap")]
  public static extern void delete_VanillaSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_receiveFixed__SWIG_0")]
  public static extern global::System.IntPtr MakeVanillaSwap_receiveFixed__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_receiveFixed__SWIG_1")]
  public static extern global::System.IntPtr MakeVanillaSwap_receiveFixed__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withType")]
  public static extern global::System.IntPtr MakeVanillaSwap_withType(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withNominal")]
  public static extern global::System.IntPtr MakeVanillaSwap_withNominal(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withSettlementDays")]
  public static extern global::System.IntPtr MakeVanillaSwap_withSettlementDays(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withEffectiveDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withEffectiveDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withTerminationDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withTerminationDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withRule")]
  public static extern global::System.IntPtr MakeVanillaSwap_withRule(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegTenor")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegCalendar")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegCalendar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegConvention")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegTerminationDateConvention")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegTerminationDateConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegRule")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegRule(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_0")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_1")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegEndOfMonth__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegFirstDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegFirstDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegNextToLastDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegNextToLastDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFixedLegDayCount")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFixedLegDayCount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegTenor")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegCalendar")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegCalendar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegConvention")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegTerminationDateConvention")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegTerminationDateConvention(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegRule")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegRule(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_0")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_1")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegEndOfMonth__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegFirstDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegFirstDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegNextToLastDate")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegNextToLastDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegDayCount")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegDayCount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withFloatingLegSpread")]
  public static extern global::System.IntPtr MakeVanillaSwap_withFloatingLegSpread(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withDiscountingTermStructure")]
  public static extern global::System.IntPtr MakeVanillaSwap_withDiscountingTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_withPricingEngine")]
  public static extern global::System.IntPtr MakeVanillaSwap_withPricingEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MakeVanillaSwap")]
  public static extern global::System.IntPtr new_MakeVanillaSwap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeVanillaSwap_makeVanillaSwap")]
  public static extern global::System.IntPtr MakeVanillaSwap_makeVanillaSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MakeVanillaSwap")]
  public static extern void delete_MakeVanillaSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwap__SWIG_0")]
  public static extern global::System.IntPtr new_NonstandardSwap__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, bool jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwap__SWIG_1")]
  public static extern global::System.IntPtr new_NonstandardSwap__SWIG_1(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwap__SWIG_2")]
  public static extern global::System.IntPtr new_NonstandardSwap__SWIG_2(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwap__SWIG_3")]
  public static extern global::System.IntPtr new_NonstandardSwap__SWIG_3(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_type")]
  public static extern int NonstandardSwap_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_fixedNominal")]
  public static extern global::System.IntPtr NonstandardSwap_fixedNominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_floatingNominal")]
  public static extern global::System.IntPtr NonstandardSwap_floatingNominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_fixedSchedule")]
  public static extern global::System.IntPtr NonstandardSwap_fixedSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_fixedRate")]
  public static extern global::System.IntPtr NonstandardSwap_fixedRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_fixedDayCount")]
  public static extern global::System.IntPtr NonstandardSwap_fixedDayCount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_floatingSchedule")]
  public static extern global::System.IntPtr NonstandardSwap_floatingSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_iborIndex")]
  public static extern global::System.IntPtr NonstandardSwap_iborIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_spread")]
  public static extern double NonstandardSwap_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_gearing")]
  public static extern double NonstandardSwap_gearing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_spreads")]
  public static extern global::System.IntPtr NonstandardSwap_spreads(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_gearings")]
  public static extern global::System.IntPtr NonstandardSwap_gearings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_floatingDayCount")]
  public static extern global::System.IntPtr NonstandardSwap_floatingDayCount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_paymentConvention")]
  public static extern int NonstandardSwap_paymentConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_fixedLeg")]
  public static extern global::System.IntPtr NonstandardSwap_fixedLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_floatingLeg")]
  public static extern global::System.IntPtr NonstandardSwap_floatingLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NonstandardSwap")]
  public static extern void delete_NonstandardSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_0")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_1")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_2")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_3")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_4")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingSwapEngine__SWIG_5")]
  public static extern global::System.IntPtr new_DiscountingSwapEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DiscountingSwapEngine")]
  public static extern void delete_DiscountingSwapEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AssetSwap__SWIG_0")]
  public static extern global::System.IntPtr new_AssetSwap__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AssetSwap__SWIG_1")]
  public static extern global::System.IntPtr new_AssetSwap__SWIG_1(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AssetSwap__SWIG_2")]
  public static extern global::System.IntPtr new_AssetSwap__SWIG_2(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AssetSwap__SWIG_3")]
  public static extern global::System.IntPtr new_AssetSwap__SWIG_3(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AssetSwap_fairCleanPrice")]
  public static extern double AssetSwap_fairCleanPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AssetSwap_fairSpread")]
  public static extern double AssetSwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AssetSwap")]
  public static extern void delete_AssetSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_0")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, int jarg20, int jarg21);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_1")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_1(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19, int jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_2")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_2(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, global::System.Runtime.InteropServices.HandleRef jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_3")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_3(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_4")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_4(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_5")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_5(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_6")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_7")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_8")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_9")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_10")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_11")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, bool jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwap__SWIG_12")]
  public static extern global::System.IntPtr new_FloatFloatSwap__SWIG_12(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloatFloatSwap")]
  public static extern void delete_FloatFloatSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_0")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_1")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_2")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_3")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_4")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_5")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_5(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_6")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_7")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_8")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_9")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_10")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwap__SWIG_11")]
  public static extern global::System.IntPtr new_OvernightIndexedSwap__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fixedLegBPS")]
  public static extern double OvernightIndexedSwap_fixedLegBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fixedLegNPV")]
  public static extern double OvernightIndexedSwap_fixedLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fairRate")]
  public static extern double OvernightIndexedSwap_fairRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_overnightLegBPS")]
  public static extern double OvernightIndexedSwap_overnightLegBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_overnightLegNPV")]
  public static extern double OvernightIndexedSwap_overnightLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fairSpread")]
  public static extern double OvernightIndexedSwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_type")]
  public static extern int OvernightIndexedSwap_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_nominal")]
  public static extern double OvernightIndexedSwap_nominal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_nominals")]
  public static extern global::System.IntPtr OvernightIndexedSwap_nominals(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_paymentFrequency")]
  public static extern int OvernightIndexedSwap_paymentFrequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fixedRate")]
  public static extern double OvernightIndexedSwap_fixedRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fixedDayCount")]
  public static extern global::System.IntPtr OvernightIndexedSwap_fixedDayCount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_spread")]
  public static extern double OvernightIndexedSwap_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_fixedLeg")]
  public static extern global::System.IntPtr OvernightIndexedSwap_fixedLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_overnightLeg")]
  public static extern global::System.IntPtr OvernightIndexedSwap_overnightLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndexedSwap")]
  public static extern void delete_OvernightIndexedSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MakeOIS__SWIG_0")]
  public static extern global::System.IntPtr new_MakeOIS__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MakeOIS__SWIG_1")]
  public static extern global::System.IntPtr new_MakeOIS__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MakeOIS__SWIG_2")]
  public static extern global::System.IntPtr new_MakeOIS__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_makeOIS")]
  public static extern global::System.IntPtr MakeOIS_makeOIS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_receiveFixed__SWIG_0")]
  public static extern global::System.IntPtr MakeOIS_receiveFixed__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_receiveFixed__SWIG_1")]
  public static extern global::System.IntPtr MakeOIS_receiveFixed__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withType")]
  public static extern global::System.IntPtr MakeOIS_withType(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withNominal")]
  public static extern global::System.IntPtr MakeOIS_withNominal(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withSettlementDays")]
  public static extern global::System.IntPtr MakeOIS_withSettlementDays(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withEffectiveDate")]
  public static extern global::System.IntPtr MakeOIS_withEffectiveDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withTerminationDate")]
  public static extern global::System.IntPtr MakeOIS_withTerminationDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withRule")]
  public static extern global::System.IntPtr MakeOIS_withRule(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withPaymentFrequency")]
  public static extern global::System.IntPtr MakeOIS_withPaymentFrequency(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withPaymentAdjustment")]
  public static extern global::System.IntPtr MakeOIS_withPaymentAdjustment(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withPaymentLag")]
  public static extern global::System.IntPtr MakeOIS_withPaymentLag(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withPaymentCalendar")]
  public static extern global::System.IntPtr MakeOIS_withPaymentCalendar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withEndOfMonth__SWIG_0")]
  public static extern global::System.IntPtr MakeOIS_withEndOfMonth__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withEndOfMonth__SWIG_1")]
  public static extern global::System.IntPtr MakeOIS_withEndOfMonth__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withFixedLegDayCount")]
  public static extern global::System.IntPtr MakeOIS_withFixedLegDayCount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withOvernightLegSpread")]
  public static extern global::System.IntPtr MakeOIS_withOvernightLegSpread(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withDiscountingTermStructure")]
  public static extern global::System.IntPtr MakeOIS_withDiscountingTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withTelescopicValueDates")]
  public static extern global::System.IntPtr MakeOIS_withTelescopicValueDates(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MakeOIS_withPricingEngine")]
  public static extern global::System.IntPtr MakeOIS_withPricingEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MakeOIS")]
  public static extern void delete_MakeOIS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwapIndex__SWIG_0")]
  public static extern global::System.IntPtr new_OvernightIndexedSwapIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexedSwapIndex__SWIG_1")]
  public static extern global::System.IntPtr new_OvernightIndexedSwapIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwapIndex_overnightIndex")]
  public static extern global::System.IntPtr OvernightIndexedSwapIndex_overnightIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwapIndex_underlyingSwap")]
  public static extern global::System.IntPtr OvernightIndexedSwapIndex_underlyingSwap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndexedSwapIndex")]
  public static extern void delete_OvernightIndexedSwapIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_overnight_swap_index")]
  public static extern global::System.IntPtr as_overnight_swap_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Seasonality_correctZeroRate")]
  public static extern double Seasonality_correctZeroRate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Seasonality_correctYoYRate")]
  public static extern double Seasonality_correctYoYRate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Seasonality_isConsistent")]
  public static extern bool Seasonality_isConsistent(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Seasonality")]
  public static extern void delete_Seasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MultiplicativePriceSeasonality")]
  public static extern global::System.IntPtr new_MultiplicativePriceSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MultiplicativePriceSeasonality")]
  public static extern void delete_MultiplicativePriceSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KerkhofSeasonality")]
  public static extern global::System.IntPtr new_KerkhofSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KerkhofSeasonality")]
  public static extern void delete_KerkhofSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_observationLag")]
  public static extern global::System.IntPtr InflationTermStructure_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_frequency")]
  public static extern int InflationTermStructure_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_indexIsInterpolated")]
  public static extern bool InflationTermStructure_indexIsInterpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_baseRate")]
  public static extern double InflationTermStructure_baseRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_nominalTermStructure")]
  public static extern global::System.IntPtr InflationTermStructure_nominalTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_baseDate")]
  public static extern global::System.IntPtr InflationTermStructure_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_setSeasonality__SWIG_0")]
  public static extern void InflationTermStructure_setSeasonality__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_setSeasonality__SWIG_1")]
  public static extern void InflationTermStructure_setSeasonality__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_seasonality")]
  public static extern global::System.IntPtr InflationTermStructure_seasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_hasSeasonality")]
  public static extern bool InflationTermStructure_hasSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InflationTermStructure")]
  public static extern void delete_InflationTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_0")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_1")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_2")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_3")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_4")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_yoyRate__SWIG_5")]
  public static extern double YoYInflationTermStructure_yoyRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationTermStructure")]
  public static extern void delete_YoYInflationTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_YoYInflationTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_YoYInflationTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle___deref__")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_empty")]
  public static extern bool YoYInflationTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationTermStructureHandle")]
  public static extern void delete_YoYInflationTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_0")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_1")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_2")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_3")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_4")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_yoyRate__SWIG_5")]
  public static extern double YoYInflationTermStructureHandle_yoyRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_observationLag")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_frequency")]
  public static extern int YoYInflationTermStructureHandle_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_indexIsInterpolated")]
  public static extern bool YoYInflationTermStructureHandle_indexIsInterpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_baseRate")]
  public static extern double YoYInflationTermStructureHandle_baseRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_nominalTermStructure")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_nominalTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_baseDate")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_setSeasonality__SWIG_0")]
  public static extern void YoYInflationTermStructureHandle_setSeasonality__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_setSeasonality__SWIG_1")]
  public static extern void YoYInflationTermStructureHandle_setSeasonality__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_seasonality")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_seasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_hasSeasonality")]
  public static extern bool YoYInflationTermStructureHandle_hasSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_timeFromReference")]
  public static extern double YoYInflationTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_calendar")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr YoYInflationTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_maxTime")]
  public static extern double YoYInflationTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_enableExtrapolation")]
  public static extern void YoYInflationTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_disableExtrapolation")]
  public static extern void YoYInflationTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructureHandle_allowsExtrapolation")]
  public static extern bool YoYInflationTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYoYInflationTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableYoYInflationTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableYoYInflationTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableYoYInflationTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYInflationTermStructureHandle_linkTo")]
  public static extern void RelinkableYoYInflationTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYInflationTermStructureHandle_reset")]
  public static extern void RelinkableYoYInflationTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableYoYInflationTermStructureHandle")]
  public static extern void delete_RelinkableYoYInflationTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_0")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_1")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_2")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_3")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_4")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_zeroRate__SWIG_5")]
  public static extern double ZeroInflationTermStructure_zeroRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroInflationTermStructure")]
  public static extern void delete_ZeroInflationTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroInflationTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroInflationTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle___deref__")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_empty")]
  public static extern bool ZeroInflationTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroInflationTermStructureHandle")]
  public static extern void delete_ZeroInflationTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_0")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_1")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_2")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_3")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_4")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_zeroRate__SWIG_5")]
  public static extern double ZeroInflationTermStructureHandle_zeroRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_observationLag")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_frequency")]
  public static extern int ZeroInflationTermStructureHandle_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_indexIsInterpolated")]
  public static extern bool ZeroInflationTermStructureHandle_indexIsInterpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_baseRate")]
  public static extern double ZeroInflationTermStructureHandle_baseRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_nominalTermStructure")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_nominalTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_baseDate")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_baseDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_setSeasonality__SWIG_0")]
  public static extern void ZeroInflationTermStructureHandle_setSeasonality__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_setSeasonality__SWIG_1")]
  public static extern void ZeroInflationTermStructureHandle_setSeasonality__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_seasonality")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_seasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_hasSeasonality")]
  public static extern bool ZeroInflationTermStructureHandle_hasSeasonality(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_timeFromReference")]
  public static extern double ZeroInflationTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_calendar")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr ZeroInflationTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_maxTime")]
  public static extern double ZeroInflationTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_enableExtrapolation")]
  public static extern void ZeroInflationTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_disableExtrapolation")]
  public static extern void ZeroInflationTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructureHandle_allowsExtrapolation")]
  public static extern bool ZeroInflationTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableZeroInflationTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableZeroInflationTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableZeroInflationTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableZeroInflationTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableZeroInflationTermStructureHandle_linkTo")]
  public static extern void RelinkableZeroInflationTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableZeroInflationTermStructureHandle_reset")]
  public static extern void RelinkableZeroInflationTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableZeroInflationTermStructureHandle")]
  public static extern void delete_RelinkableZeroInflationTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Region_name")]
  public static extern string Region_name(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Region_code")]
  public static extern string Region_code(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Region")]
  public static extern void delete_Region(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CustomRegion")]
  public static extern global::System.IntPtr new_CustomRegion(string jarg1, string jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CustomRegion")]
  public static extern void delete_CustomRegion(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_familyName")]
  public static extern string InflationIndex_familyName(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_region")]
  public static extern global::System.IntPtr InflationIndex_region(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_revised")]
  public static extern bool InflationIndex_revised(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_interpolated")]
  public static extern bool InflationIndex_interpolated(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_frequency")]
  public static extern int InflationIndex_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_availabilityLag")]
  public static extern global::System.IntPtr InflationIndex_availabilityLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_currency")]
  public static extern global::System.IntPtr InflationIndex_currency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InflationIndex")]
  public static extern void delete_InflationIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationIndex__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroInflationIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, bool jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationIndex__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroInflationIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, bool jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationIndex_zeroInflationTermStructure")]
  public static extern global::System.IntPtr ZeroInflationIndex_zeroInflationTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationIndex_clone")]
  public static extern global::System.IntPtr ZeroInflationIndex_clone(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroInflationIndex")]
  public static extern void delete_ZeroInflationIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationIndex__SWIG_0")]
  public static extern global::System.IntPtr new_YoYInflationIndex__SWIG_0(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, bool jarg4, bool jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationIndex__SWIG_1")]
  public static extern global::System.IntPtr new_YoYInflationIndex__SWIG_1(string jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3, bool jarg4, bool jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationIndex_ratio")]
  public static extern bool YoYInflationIndex_ratio(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationIndex_yoyInflationTermStructure")]
  public static extern global::System.IntPtr YoYInflationIndex_yoyInflationTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationIndex_clone")]
  public static extern global::System.IntPtr YoYInflationIndex_clone(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationIndex")]
  public static extern void delete_YoYInflationIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EUHICP__SWIG_0")]
  public static extern global::System.IntPtr new_EUHICP__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EUHICP__SWIG_1")]
  public static extern global::System.IntPtr new_EUHICP__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EUHICP")]
  public static extern void delete_EUHICP(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EUHICPXT__SWIG_0")]
  public static extern global::System.IntPtr new_EUHICPXT__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_EUHICPXT__SWIG_1")]
  public static extern global::System.IntPtr new_EUHICPXT__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_EUHICPXT")]
  public static extern void delete_EUHICPXT(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FRHICP__SWIG_0")]
  public static extern global::System.IntPtr new_FRHICP__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FRHICP__SWIG_1")]
  public static extern global::System.IntPtr new_FRHICP__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FRHICP")]
  public static extern void delete_FRHICP(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UKRPI__SWIG_0")]
  public static extern global::System.IntPtr new_UKRPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UKRPI__SWIG_1")]
  public static extern global::System.IntPtr new_UKRPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UKRPI")]
  public static extern void delete_UKRPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USCPI__SWIG_0")]
  public static extern global::System.IntPtr new_USCPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_USCPI__SWIG_1")]
  public static extern global::System.IntPtr new_USCPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_USCPI")]
  public static extern void delete_USCPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZACPI__SWIG_0")]
  public static extern global::System.IntPtr new_ZACPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZACPI__SWIG_1")]
  public static extern global::System.IntPtr new_ZACPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZACPI")]
  public static extern void delete_ZACPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICP__SWIG_0")]
  public static extern global::System.IntPtr new_YYEUHICP__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICP__SWIG_1")]
  public static extern global::System.IntPtr new_YYEUHICP__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYEUHICP")]
  public static extern void delete_YYEUHICP(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICPXT__SWIG_0")]
  public static extern global::System.IntPtr new_YYEUHICPXT__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICPXT__SWIG_1")]
  public static extern global::System.IntPtr new_YYEUHICPXT__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYEUHICPXT")]
  public static extern void delete_YYEUHICPXT(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICPr__SWIG_0")]
  public static extern global::System.IntPtr new_YYEUHICPr__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYEUHICPr__SWIG_1")]
  public static extern global::System.IntPtr new_YYEUHICPr__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYEUHICPr")]
  public static extern void delete_YYEUHICPr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYFRHICP__SWIG_0")]
  public static extern global::System.IntPtr new_YYFRHICP__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYFRHICP__SWIG_1")]
  public static extern global::System.IntPtr new_YYFRHICP__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYFRHICP")]
  public static extern void delete_YYFRHICP(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYFRHICPr__SWIG_0")]
  public static extern global::System.IntPtr new_YYFRHICPr__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYFRHICPr__SWIG_1")]
  public static extern global::System.IntPtr new_YYFRHICPr__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYFRHICPr")]
  public static extern void delete_YYFRHICPr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUKRPI__SWIG_0")]
  public static extern global::System.IntPtr new_YYUKRPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUKRPI__SWIG_1")]
  public static extern global::System.IntPtr new_YYUKRPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYUKRPI")]
  public static extern void delete_YYUKRPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUKRPIr__SWIG_0")]
  public static extern global::System.IntPtr new_YYUKRPIr__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUKRPIr__SWIG_1")]
  public static extern global::System.IntPtr new_YYUKRPIr__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYUKRPIr")]
  public static extern void delete_YYUKRPIr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUSCPI__SWIG_0")]
  public static extern global::System.IntPtr new_YYUSCPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUSCPI__SWIG_1")]
  public static extern global::System.IntPtr new_YYUSCPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYUSCPI")]
  public static extern void delete_YYUSCPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUSCPIr__SWIG_0")]
  public static extern global::System.IntPtr new_YYUSCPIr__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYUSCPIr__SWIG_1")]
  public static extern global::System.IntPtr new_YYUSCPIr__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYUSCPIr")]
  public static extern void delete_YYUSCPIr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYZACPI__SWIG_0")]
  public static extern global::System.IntPtr new_YYZACPI__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYZACPI__SWIG_1")]
  public static extern global::System.IntPtr new_YYZACPI__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYZACPI")]
  public static extern void delete_YYZACPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYZACPIr__SWIG_0")]
  public static extern global::System.IntPtr new_YYZACPIr__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YYZACPIr__SWIG_1")]
  public static extern global::System.IntPtr new_YYZACPIr__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YYZACPIr")]
  public static extern void delete_YYZACPIr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AUCPI__SWIG_0")]
  public static extern global::System.IntPtr new_AUCPI__SWIG_0(int jarg1, bool jarg2, bool jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AUCPI__SWIG_1")]
  public static extern global::System.IntPtr new_AUCPI__SWIG_1(int jarg1, bool jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AUCPI")]
  public static extern void delete_AUCPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPI")]
  public static extern global::System.IntPtr new_CPI();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CPI")]
  public static extern void delete_CPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_fixingDate")]
  public static extern global::System.IntPtr InflationCoupon_fixingDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_fixingDays")]
  public static extern int InflationCoupon_fixingDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_observationLag")]
  public static extern global::System.IntPtr InflationCoupon_observationLag(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_indexFixing")]
  public static extern double InflationCoupon_indexFixing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_index")]
  public static extern global::System.IntPtr InflationCoupon_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InflationCoupon")]
  public static extern void delete_InflationCoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_inflation_coupon")]
  public static extern global::System.IntPtr as_inflation_coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_fixedRate")]
  public static extern double CPICoupon_fixedRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_spread")]
  public static extern double CPICoupon_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_adjustedFixing")]
  public static extern double CPICoupon_adjustedFixing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_baseCPI")]
  public static extern double CPICoupon_baseCPI(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_observationInterpolation")]
  public static extern int CPICoupon_observationInterpolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_cpiIndex")]
  public static extern global::System.IntPtr CPICoupon_cpiIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CPICoupon")]
  public static extern void delete_CPICoupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_cpi_coupon")]
  public static extern global::System.IntPtr as_cpi_coupon(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_quote")]
  public static extern global::System.IntPtr ZeroHelper_quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_latestDate")]
  public static extern global::System.IntPtr ZeroHelper_latestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_earliestDate")]
  public static extern global::System.IntPtr ZeroHelper_earliestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_maturityDate")]
  public static extern global::System.IntPtr ZeroHelper_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_latestRelevantDate")]
  public static extern global::System.IntPtr ZeroHelper_latestRelevantDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_pillarDate")]
  public static extern global::System.IntPtr ZeroHelper_pillarDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_impliedQuote")]
  public static extern double ZeroHelper_impliedQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_quoteError")]
  public static extern double ZeroHelper_quoteError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroHelper")]
  public static extern void delete_ZeroHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_quote")]
  public static extern global::System.IntPtr YoYHelper_quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_latestDate")]
  public static extern global::System.IntPtr YoYHelper_latestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_earliestDate")]
  public static extern global::System.IntPtr YoYHelper_earliestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_maturityDate")]
  public static extern global::System.IntPtr YoYHelper_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_latestRelevantDate")]
  public static extern global::System.IntPtr YoYHelper_latestRelevantDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_pillarDate")]
  public static extern global::System.IntPtr YoYHelper_pillarDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_impliedQuote")]
  public static extern double YoYHelper_impliedQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_quoteError")]
  public static extern double YoYHelper_quoteError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYHelper")]
  public static extern void delete_YoYHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_quote")]
  public static extern global::System.IntPtr YoYOptionHelper_quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_latestDate")]
  public static extern global::System.IntPtr YoYOptionHelper_latestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_earliestDate")]
  public static extern global::System.IntPtr YoYOptionHelper_earliestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_maturityDate")]
  public static extern global::System.IntPtr YoYOptionHelper_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_latestRelevantDate")]
  public static extern global::System.IntPtr YoYOptionHelper_latestRelevantDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_pillarDate")]
  public static extern global::System.IntPtr YoYOptionHelper_pillarDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_impliedQuote")]
  public static extern double YoYOptionHelper_impliedQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_quoteError")]
  public static extern double YoYOptionHelper_quoteError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionHelper")]
  public static extern void delete_YoYOptionHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Clear")]
  public static extern void ZeroHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Add")]
  public static extern void ZeroHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_size")]
  public static extern uint ZeroHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_capacity")]
  public static extern uint ZeroHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_reserve")]
  public static extern void ZeroHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_ZeroHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_getitemcopy")]
  public static extern global::System.IntPtr ZeroHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_getitem")]
  public static extern global::System.IntPtr ZeroHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_setitem")]
  public static extern void ZeroHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_AddRange")]
  public static extern void ZeroHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_GetRange")]
  public static extern global::System.IntPtr ZeroHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Insert")]
  public static extern void ZeroHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_InsertRange")]
  public static extern void ZeroHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_RemoveAt")]
  public static extern void ZeroHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_RemoveRange")]
  public static extern void ZeroHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Repeat")]
  public static extern global::System.IntPtr ZeroHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Reverse__SWIG_0")]
  public static extern void ZeroHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Reverse__SWIG_1")]
  public static extern void ZeroHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_SetRange")]
  public static extern void ZeroHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Contains")]
  public static extern bool ZeroHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_IndexOf")]
  public static extern int ZeroHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_LastIndexOf")]
  public static extern int ZeroHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelperVector_Remove")]
  public static extern bool ZeroHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroHelperVector")]
  public static extern void delete_ZeroHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Clear")]
  public static extern void YoYHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Add")]
  public static extern void YoYHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_size")]
  public static extern uint YoYHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_capacity")]
  public static extern uint YoYHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_reserve")]
  public static extern void YoYHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_YoYHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_YoYHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_YoYHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_getitemcopy")]
  public static extern global::System.IntPtr YoYHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_getitem")]
  public static extern global::System.IntPtr YoYHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_setitem")]
  public static extern void YoYHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_AddRange")]
  public static extern void YoYHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_GetRange")]
  public static extern global::System.IntPtr YoYHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Insert")]
  public static extern void YoYHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_InsertRange")]
  public static extern void YoYHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_RemoveAt")]
  public static extern void YoYHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_RemoveRange")]
  public static extern void YoYHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Repeat")]
  public static extern global::System.IntPtr YoYHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Reverse__SWIG_0")]
  public static extern void YoYHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Reverse__SWIG_1")]
  public static extern void YoYHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_SetRange")]
  public static extern void YoYHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Contains")]
  public static extern bool YoYHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_IndexOf")]
  public static extern int YoYHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_LastIndexOf")]
  public static extern int YoYHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelperVector_Remove")]
  public static extern bool YoYHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYHelperVector")]
  public static extern void delete_YoYHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Clear")]
  public static extern void YoYOptionHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Add")]
  public static extern void YoYOptionHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_size")]
  public static extern uint YoYOptionHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_capacity")]
  public static extern uint YoYOptionHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_reserve")]
  public static extern void YoYOptionHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_YoYOptionHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_YoYOptionHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_YoYOptionHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_getitemcopy")]
  public static extern global::System.IntPtr YoYOptionHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_getitem")]
  public static extern global::System.IntPtr YoYOptionHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_setitem")]
  public static extern void YoYOptionHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_AddRange")]
  public static extern void YoYOptionHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_GetRange")]
  public static extern global::System.IntPtr YoYOptionHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Insert")]
  public static extern void YoYOptionHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_InsertRange")]
  public static extern void YoYOptionHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_RemoveAt")]
  public static extern void YoYOptionHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_RemoveRange")]
  public static extern void YoYOptionHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Repeat")]
  public static extern global::System.IntPtr YoYOptionHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Reverse__SWIG_0")]
  public static extern void YoYOptionHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Reverse__SWIG_1")]
  public static extern void YoYOptionHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_SetRange")]
  public static extern void YoYOptionHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Contains")]
  public static extern bool YoYOptionHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_IndexOf")]
  public static extern int YoYOptionHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_LastIndexOf")]
  public static extern int YoYOptionHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelperVector_Remove")]
  public static extern bool YoYOptionHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionHelperVector")]
  public static extern void delete_YoYOptionHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwapHelper__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwapHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwapHelper__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwapHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroCouponInflationSwapHelper")]
  public static extern void delete_ZeroCouponInflationSwapHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YearOnYearInflationSwapHelper__SWIG_0")]
  public static extern global::System.IntPtr new_YearOnYearInflationSwapHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YearOnYearInflationSwapHelper__SWIG_1")]
  public static extern global::System.IntPtr new_YearOnYearInflationSwapHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YearOnYearInflationSwapHelper")]
  public static extern void delete_YearOnYearInflationSwapHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseZeroInflation__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseZeroInflation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseZeroInflation__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseZeroInflation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseZeroInflation__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseZeroInflation__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseZeroInflation_dates")]
  public static extern global::System.IntPtr PiecewiseZeroInflation_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseZeroInflation_times")]
  public static extern global::System.IntPtr PiecewiseZeroInflation_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseZeroInflation_nodes")]
  public static extern global::System.IntPtr PiecewiseZeroInflation_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseZeroInflation")]
  public static extern void delete_PiecewiseZeroInflation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseYoYInflation__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseYoYInflation__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseYoYInflation__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseYoYInflation__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseYoYInflation__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseYoYInflation__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseYoYInflation_dates")]
  public static extern global::System.IntPtr PiecewiseYoYInflation_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseYoYInflation_times")]
  public static extern global::System.IntPtr PiecewiseYoYInflation_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseYoYInflation_nodes")]
  public static extern global::System.IntPtr PiecewiseYoYInflation_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseYoYInflation")]
  public static extern void delete_PiecewiseYoYInflation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_inflationBaseDate")]
  public static extern global::System.IntPtr inflationBaseDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_0")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_1")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_2")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_3")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_4")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_5")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_yoyInflationLeg__SWIG_6")]
  public static extern global::System.IntPtr yoyInflationLeg__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwap__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwap__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwap__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwap__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwap__SWIG_2")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwap__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponInflationSwap__SWIG_3")]
  public static extern global::System.IntPtr new_ZeroCouponInflationSwap__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_fairRate")]
  public static extern double ZeroCouponInflationSwap_fairRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_fixedLegNPV")]
  public static extern double ZeroCouponInflationSwap_fixedLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_inflationLegNPV")]
  public static extern double ZeroCouponInflationSwap_inflationLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_fixedLeg")]
  public static extern global::System.IntPtr ZeroCouponInflationSwap_fixedLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_inflationLeg")]
  public static extern global::System.IntPtr ZeroCouponInflationSwap_inflationLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_type")]
  public static extern int ZeroCouponInflationSwap_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroCouponInflationSwap")]
  public static extern void delete_ZeroCouponInflationSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YearOnYearInflationSwap__SWIG_0")]
  public static extern global::System.IntPtr new_YearOnYearInflationSwap__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YearOnYearInflationSwap__SWIG_1")]
  public static extern global::System.IntPtr new_YearOnYearInflationSwap__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_fairRate")]
  public static extern double YearOnYearInflationSwap_fairRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_fixedLegNPV")]
  public static extern double YearOnYearInflationSwap_fixedLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_yoyLegNPV")]
  public static extern double YearOnYearInflationSwap_yoyLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_fairSpread")]
  public static extern double YearOnYearInflationSwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_fixedLeg")]
  public static extern global::System.IntPtr YearOnYearInflationSwap_fixedLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_yoyLeg")]
  public static extern global::System.IntPtr YearOnYearInflationSwap_yoyLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YearOnYearInflationSwap")]
  public static extern void delete_YearOnYearInflationSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPISwap__SWIG_0")]
  public static extern global::System.IntPtr new_CPISwap__SWIG_0(int jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, int jarg17, double jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPISwap__SWIG_1")]
  public static extern global::System.IntPtr new_CPISwap__SWIG_1(int jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, int jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPISwap__SWIG_2")]
  public static extern global::System.IntPtr new_CPISwap__SWIG_2(int jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, uint jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_fairRate")]
  public static extern double CPISwap_fairRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_floatLegNPV")]
  public static extern double CPISwap_floatLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_fairSpread")]
  public static extern double CPISwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_fixedLegNPV")]
  public static extern double CPISwap_fixedLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_cpiLeg")]
  public static extern global::System.IntPtr CPISwap_cpiLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_floatLeg")]
  public static extern global::System.IntPtr CPISwap_floatLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CPISwap")]
  public static extern void delete_CPISwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCapFloor")]
  public static extern global::System.IntPtr new_YoYInflationCapFloor(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_impliedVolatility__SWIG_0")]
  public static extern double YoYInflationCapFloor_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_impliedVolatility__SWIG_1")]
  public static extern double YoYInflationCapFloor_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_impliedVolatility__SWIG_2")]
  public static extern double YoYInflationCapFloor_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_impliedVolatility__SWIG_3")]
  public static extern double YoYInflationCapFloor_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_impliedVolatility__SWIG_4")]
  public static extern double YoYInflationCapFloor_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_optionletPrices")]
  public static extern global::System.IntPtr YoYInflationCapFloor_optionletPrices(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationCapFloor")]
  public static extern void delete_YoYInflationCapFloor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCap")]
  public static extern global::System.IntPtr new_YoYInflationCap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationCap")]
  public static extern void delete_YoYInflationCap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationFloor")]
  public static extern global::System.IntPtr new_YoYInflationFloor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationFloor")]
  public static extern void delete_YoYInflationFloor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCollar")]
  public static extern global::System.IntPtr new_YoYInflationCollar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationCollar")]
  public static extern void delete_YoYInflationCollar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationCurve__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroInflationCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroInflationCurve__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroInflationCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_dates")]
  public static extern global::System.IntPtr ZeroInflationCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_times")]
  public static extern global::System.IntPtr ZeroInflationCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_data")]
  public static extern global::System.IntPtr ZeroInflationCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_rates")]
  public static extern global::System.IntPtr ZeroInflationCurve_rates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_nodes")]
  public static extern global::System.IntPtr ZeroInflationCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroInflationCurve")]
  public static extern void delete_ZeroInflationCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCurve__SWIG_0")]
  public static extern global::System.IntPtr new_YoYInflationCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCurve__SWIG_1")]
  public static extern global::System.IntPtr new_YoYInflationCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_dates")]
  public static extern global::System.IntPtr YoYInflationCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_times")]
  public static extern global::System.IntPtr YoYInflationCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_data")]
  public static extern global::System.IntPtr YoYInflationCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_rates")]
  public static extern global::System.IntPtr YoYInflationCurve_rates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_nodes")]
  public static extern global::System.IntPtr YoYInflationCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationCurve")]
  public static extern void delete_YoYInflationCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapTimeRates")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_atmYoYSwapTimeRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapDateRates")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_atmYoYSwapDateRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_YoYTS")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_YoYTS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_yoyIndex")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_yoyIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_businessDayConvention")]
  public static extern int YoYCapFloorTermPriceSurface_businessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_fixingDays")]
  public static extern uint YoYCapFloorTermPriceSurface_fixingDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_price__SWIG_0")]
  public static extern double YoYCapFloorTermPriceSurface_price__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_capPrice__SWIG_0")]
  public static extern double YoYCapFloorTermPriceSurface_capPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_floorPrice__SWIG_0")]
  public static extern double YoYCapFloorTermPriceSurface_floorPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_0")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_1")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_0")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_1")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_2")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_price__SWIG_1")]
  public static extern double YoYCapFloorTermPriceSurface_price__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_capPrice__SWIG_1")]
  public static extern double YoYCapFloorTermPriceSurface_capPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_floorPrice__SWIG_1")]
  public static extern double YoYCapFloorTermPriceSurface_floorPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_2")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_3")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYSwapRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_3")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_4")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_5")]
  public static extern double YoYCapFloorTermPriceSurface_atmYoYRate__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_strikes")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_strikes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_capStrikes")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_capStrikes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_floorStrikes")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_floorStrikes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_maturities")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_maturities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_minStrike")]
  public static extern double YoYCapFloorTermPriceSurface_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_maxStrike")]
  public static extern double YoYCapFloorTermPriceSurface_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_minMaturity")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_minMaturity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_maxMaturity")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_maxMaturity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_yoyOptionDateFromTenor")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_yoyOptionDateFromTenor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYCapFloorTermPriceSurface")]
  public static extern void delete_YoYCapFloorTermPriceSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCapFloorTermPriceSurface__SWIG_0")]
  public static extern global::System.IntPtr new_YoYInflationCapFloorTermPriceSurface__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCapFloorTermPriceSurface__SWIG_1")]
  public static extern global::System.IntPtr new_YoYInflationCapFloorTermPriceSurface__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationCapFloorTermPriceSurface__SWIG_2")]
  public static extern global::System.IntPtr new_YoYInflationCapFloorTermPriceSurface__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationCapFloorTermPriceSurface")]
  public static extern void delete_YoYInflationCapFloorTermPriceSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationBlackCapFloorEngine")]
  public static extern global::System.IntPtr new_YoYInflationBlackCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationBlackCapFloorEngine")]
  public static extern void delete_YoYInflationBlackCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationUnitDisplacedBlackCapFloorEngine")]
  public static extern global::System.IntPtr new_YoYInflationUnitDisplacedBlackCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationUnitDisplacedBlackCapFloorEngine")]
  public static extern void delete_YoYInflationUnitDisplacedBlackCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYInflationBachelierCapFloorEngine")]
  public static extern global::System.IntPtr new_YoYInflationBachelierCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYInflationBachelierCapFloorEngine")]
  public static extern void delete_YoYInflationBachelierCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_YoYOptionletHelper")]
  public static extern global::System.IntPtr new_YoYOptionletHelper(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, uint jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionletHelper")]
  public static extern void delete_YoYOptionletHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletStripper_initialize")]
  public static extern void YoYOptionletStripper_initialize(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletStripper_maxStrike")]
  public static extern double YoYOptionletStripper_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletStripper_strikes")]
  public static extern global::System.IntPtr YoYOptionletStripper_strikes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletStripper_slice")]
  public static extern global::System.IntPtr YoYOptionletStripper_slice(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_YoYOptionletStripper")]
  public static extern void delete_YoYOptionletStripper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterpolatedYoYInflationOptionletStripper")]
  public static extern global::System.IntPtr new_InterpolatedYoYInflationOptionletStripper();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InterpolatedYoYInflationOptionletStripper")]
  public static extern void delete_InterpolatedYoYInflationOptionletStripper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_0")]
  public static extern global::System.IntPtr new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_1")]
  public static extern global::System.IntPtr new_InterpolatedYoYInflationOptionletVolatilityCurve__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InterpolatedYoYInflationOptionletVolatilityCurve")]
  public static extern void delete_InterpolatedYoYInflationOptionletVolatilityCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_0")]
  public static extern global::System.IntPtr new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_1")]
  public static extern global::System.IntPtr new_KInterpolatedYoYInflationOptionletVolatilitySurface__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KInterpolatedYoYInflationOptionletVolatilitySurface_Dslice")]
  public static extern global::System.IntPtr KInterpolatedYoYInflationOptionletVolatilitySurface_Dslice(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KInterpolatedYoYInflationOptionletVolatilitySurface")]
  public static extern void delete_KInterpolatedYoYInflationOptionletVolatilitySurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ShortRateModel")]
  public static extern void delete_ShortRateModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ShortRateModelHandle__SWIG_0")]
  public static extern global::System.IntPtr new_ShortRateModelHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ShortRateModelHandle__SWIG_1")]
  public static extern global::System.IntPtr new_ShortRateModelHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle___deref__")]
  public static extern global::System.IntPtr ShortRateModelHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_currentLink")]
  public static extern global::System.IntPtr ShortRateModelHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_empty")]
  public static extern bool ShortRateModelHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_asObservable")]
  public static extern global::System.IntPtr ShortRateModelHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ShortRateModelHandle")]
  public static extern void delete_ShortRateModelHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_parameters")]
  public static extern global::System.IntPtr ShortRateModelHandle_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_calibrate__SWIG_0")]
  public static extern void ShortRateModelHandle_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_calibrate__SWIG_1")]
  public static extern void ShortRateModelHandle_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_calibrate__SWIG_2")]
  public static extern void ShortRateModelHandle_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_calibrate__SWIG_3")]
  public static extern void ShortRateModelHandle_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_setParams")]
  public static extern void ShortRateModelHandle_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_value")]
  public static extern double ShortRateModelHandle_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_constraint")]
  public static extern global::System.IntPtr ShortRateModelHandle_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_endCriteria")]
  public static extern int ShortRateModelHandle_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_problemValues")]
  public static extern global::System.IntPtr ShortRateModelHandle_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModelHandle_functionEvaluation")]
  public static extern int ShortRateModelHandle_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableShortRateModelHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableShortRateModelHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableShortRateModelHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableShortRateModelHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableShortRateModelHandle_linkTo")]
  public static extern void RelinkableShortRateModelHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableShortRateModelHandle_reset")]
  public static extern void RelinkableShortRateModelHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableShortRateModelHandle")]
  public static extern void delete_RelinkableShortRateModelHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneFactorAffineModel_discountBond__SWIG_0")]
  public static extern double OneFactorAffineModel_discountBond__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneFactorAffineModel_discountBond__SWIG_1")]
  public static extern double OneFactorAffineModel_discountBond__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneFactorAffineModel_discount")]
  public static extern double OneFactorAffineModel_discount(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OneFactorAffineModel")]
  public static extern void delete_OneFactorAffineModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_0")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_1")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_1(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_2")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_2(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_3")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_3(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_4")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_4(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Vasicek__SWIG_5")]
  public static extern global::System.IntPtr new_Vasicek__SWIG_5();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Vasicek")]
  public static extern void delete_Vasicek(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HullWhite__SWIG_0")]
  public static extern global::System.IntPtr new_HullWhite__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HullWhite__SWIG_1")]
  public static extern global::System.IntPtr new_HullWhite__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HullWhite__SWIG_2")]
  public static extern global::System.IntPtr new_HullWhite__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhite_convexityBias")]
  public static extern double HullWhite_convexityBias(double jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhite_termStructure")]
  public static extern global::System.IntPtr HullWhite_termStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HullWhite")]
  public static extern void delete_HullWhite(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackKarasinski__SWIG_0")]
  public static extern global::System.IntPtr new_BlackKarasinski__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackKarasinski__SWIG_1")]
  public static extern global::System.IntPtr new_BlackKarasinski__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackKarasinski__SWIG_2")]
  public static extern global::System.IntPtr new_BlackKarasinski__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackKarasinski_termStructure")]
  public static extern global::System.IntPtr BlackKarasinski_termStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackKarasinski")]
  public static extern void delete_BlackKarasinski(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CoxIngersollRoss__SWIG_0")]
  public static extern global::System.IntPtr new_CoxIngersollRoss__SWIG_0(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CoxIngersollRoss__SWIG_1")]
  public static extern global::System.IntPtr new_CoxIngersollRoss__SWIG_1(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CoxIngersollRoss__SWIG_2")]
  public static extern global::System.IntPtr new_CoxIngersollRoss__SWIG_2(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CoxIngersollRoss__SWIG_3")]
  public static extern global::System.IntPtr new_CoxIngersollRoss__SWIG_3(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CoxIngersollRoss__SWIG_4")]
  public static extern global::System.IntPtr new_CoxIngersollRoss__SWIG_4();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CoxIngersollRoss_discount")]
  public static extern double CoxIngersollRoss_discount(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CoxIngersollRoss")]
  public static extern void delete_CoxIngersollRoss(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedCoxIngersollRoss__SWIG_0")]
  public static extern global::System.IntPtr new_ExtendedCoxIngersollRoss__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedCoxIngersollRoss__SWIG_1")]
  public static extern global::System.IntPtr new_ExtendedCoxIngersollRoss__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedCoxIngersollRoss__SWIG_2")]
  public static extern global::System.IntPtr new_ExtendedCoxIngersollRoss__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedCoxIngersollRoss__SWIG_3")]
  public static extern global::System.IntPtr new_ExtendedCoxIngersollRoss__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExtendedCoxIngersollRoss__SWIG_4")]
  public static extern global::System.IntPtr new_ExtendedCoxIngersollRoss__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExtendedCoxIngersollRoss_discount")]
  public static extern double ExtendedCoxIngersollRoss_discount(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExtendedCoxIngersollRoss")]
  public static extern void delete_ExtendedCoxIngersollRoss(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_0")]
  public static extern global::System.IntPtr new_G2__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_1")]
  public static extern global::System.IntPtr new_G2__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_2")]
  public static extern global::System.IntPtr new_G2__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_3")]
  public static extern global::System.IntPtr new_G2__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_4")]
  public static extern global::System.IntPtr new_G2__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2__SWIG_5")]
  public static extern global::System.IntPtr new_G2__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2_termStructure")]
  public static extern global::System.IntPtr G2_termStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_G2")]
  public static extern void delete_G2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JamshidianSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_JamshidianSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_JamshidianSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_JamshidianSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_JamshidianSwaptionEngine")]
  public static extern void delete_JamshidianSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeSwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_TreeSwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TreeSwaptionEngine")]
  public static extern void delete_TreeSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticCapFloorEngine__SWIG_0")]
  public static extern global::System.IntPtr new_AnalyticCapFloorEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticCapFloorEngine__SWIG_1")]
  public static extern global::System.IntPtr new_AnalyticCapFloorEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticCapFloorEngine")]
  public static extern void delete_AnalyticCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCapFloorEngine__SWIG_0")]
  public static extern global::System.IntPtr new_TreeCapFloorEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCapFloorEngine__SWIG_1")]
  public static extern global::System.IntPtr new_TreeCapFloorEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCapFloorEngine__SWIG_2")]
  public static extern global::System.IntPtr new_TreeCapFloorEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCapFloorEngine__SWIG_3")]
  public static extern global::System.IntPtr new_TreeCapFloorEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TreeCapFloorEngine")]
  public static extern void delete_TreeCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_G2SwaptionEngine")]
  public static extern global::System.IntPtr new_G2SwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_G2SwaptionEngine")]
  public static extern void delete_G2SwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdG2SwaptionEngine__SWIG_6")]
  public static extern global::System.IntPtr new_FdG2SwaptionEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdG2SwaptionEngine")]
  public static extern void delete_FdG2SwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdHullWhiteSwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_FdHullWhiteSwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdHullWhiteSwaptionEngine")]
  public static extern void delete_FdHullWhiteSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AnalyticBSMHullWhiteEngine")]
  public static extern global::System.IntPtr new_AnalyticBSMHullWhiteEngine(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AnalyticBSMHullWhiteEngine")]
  public static extern void delete_AnalyticBSMHullWhiteEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_0")]
  public static extern global::System.IntPtr new_Bond__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_1")]
  public static extern global::System.IntPtr new_Bond__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_2")]
  public static extern global::System.IntPtr new_Bond__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_3")]
  public static extern global::System.IntPtr new_Bond__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_4")]
  public static extern global::System.IntPtr new_Bond__SWIG_4(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Bond__SWIG_5")]
  public static extern global::System.IntPtr new_Bond__SWIG_5(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_nextCouponRate__SWIG_0")]
  public static extern double Bond_nextCouponRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_nextCouponRate__SWIG_1")]
  public static extern double Bond_nextCouponRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_previousCouponRate__SWIG_0")]
  public static extern double Bond_previousCouponRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_previousCouponRate__SWIG_1")]
  public static extern double Bond_previousCouponRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_settlementDays")]
  public static extern uint Bond_settlementDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_settlementDate__SWIG_0")]
  public static extern global::System.IntPtr Bond_settlementDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_settlementDate__SWIG_1")]
  public static extern global::System.IntPtr Bond_settlementDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_startDate")]
  public static extern global::System.IntPtr Bond_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_maturityDate")]
  public static extern global::System.IntPtr Bond_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_issueDate")]
  public static extern global::System.IntPtr Bond_issueDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_cashflows")]
  public static extern global::System.IntPtr Bond_cashflows(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_redemptions")]
  public static extern global::System.IntPtr Bond_redemptions(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_redemption")]
  public static extern global::System.IntPtr Bond_redemption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_calendar")]
  public static extern global::System.IntPtr Bond_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_notionals")]
  public static extern global::System.IntPtr Bond_notionals(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_notional__SWIG_0")]
  public static extern double Bond_notional__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_notional__SWIG_1")]
  public static extern double Bond_notional__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_cleanPrice__SWIG_0")]
  public static extern double Bond_cleanPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_cleanPrice__SWIG_1")]
  public static extern double Bond_cleanPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_cleanPrice__SWIG_2")]
  public static extern double Bond_cleanPrice__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_dirtyPrice__SWIG_0")]
  public static extern double Bond_dirtyPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_dirtyPrice__SWIG_1")]
  public static extern double Bond_dirtyPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_dirtyPrice__SWIG_2")]
  public static extern double Bond_dirtyPrice__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_0")]
  public static extern double Bond_yield__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_1")]
  public static extern double Bond_yield__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_2")]
  public static extern double Bond_yield__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_3")]
  public static extern double Bond_yield__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_4")]
  public static extern double Bond_yield__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_5")]
  public static extern double Bond_yield__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_yield__SWIG_6")]
  public static extern double Bond_yield__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_accruedAmount__SWIG_0")]
  public static extern double Bond_accruedAmount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_accruedAmount__SWIG_1")]
  public static extern double Bond_accruedAmount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_settlementValue__SWIG_0")]
  public static extern double Bond_settlementValue__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_settlementValue__SWIG_1")]
  public static extern double Bond_settlementValue__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Bond")]
  public static extern void delete_Bond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_cleanPriceFromZSpread__SWIG_0")]
  public static extern double cleanPriceFromZSpread__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_cleanPriceFromZSpread__SWIG_1")]
  public static extern double cleanPriceFromZSpread__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponBond__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroCouponBond__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponBond__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroCouponBond__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponBond__SWIG_2")]
  public static extern global::System.IntPtr new_ZeroCouponBond__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCouponBond__SWIG_3")]
  public static extern global::System.IntPtr new_ZeroCouponBond__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroCouponBond")]
  public static extern void delete_ZeroCouponBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_5")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_5(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_6")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_6(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_7")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_7(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_8")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_8(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_9")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_9(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_10")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_10(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_11")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_11(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_12")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_12(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_13")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_13(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_14")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_14(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_15")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_15(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_16")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_16(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_17")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_17(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_18")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_18(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, int jarg19, bool jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_19")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_19(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, int jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_20")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_20(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_21")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_21(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_22")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_22(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_23")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_23(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_24")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_24(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_25")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_25(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_26")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_26(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_27")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_27(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_28")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_28(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_29")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_29(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBond__SWIG_30")]
  public static extern global::System.IntPtr new_FixedRateBond__SWIG_30(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_0")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_1")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_2")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_3")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_4")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_5")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_5(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_6")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_6(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_7")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_7(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_rates__SWIG_8")]
  public static extern global::System.IntPtr FixedRateBond_from_rates__SWIG_8(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_0")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_1")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_2")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_3")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_4")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_5")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_5(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_6")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_6(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_7")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_7(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_interest_rates__SWIG_8")]
  public static extern global::System.IntPtr FixedRateBond_from_interest_rates__SWIG_8(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_0")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, int jarg19, bool jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_1")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_1(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18, int jarg19);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_2")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_2(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17, global::System.Runtime.InteropServices.HandleRef jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_3")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_3(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, global::System.Runtime.InteropServices.HandleRef jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_4")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_4(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_5")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_5(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_6")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_7")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_8")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_9")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_10")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_11")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_from_date_info__SWIG_12")]
  public static extern global::System.IntPtr FixedRateBond_from_date_info__SWIG_12(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_frequency")]
  public static extern int FixedRateBond_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_dayCounter")]
  public static extern global::System.IntPtr FixedRateBond_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FixedRateBond")]
  public static extern void delete_FixedRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, int jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_1(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, int jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_2(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_3(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_4(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_5")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_5(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_6")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_7")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_8")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFixedRateBond__SWIG_9")]
  public static extern global::System.IntPtr new_AmortizingFixedRateBond__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmortizingFixedRateBond_frequency")]
  public static extern int AmortizingFixedRateBond_frequency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmortizingFixedRateBond_dayCounter")]
  public static extern global::System.IntPtr AmortizingFixedRateBond_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AmortizingFixedRateBond")]
  public static extern void delete_AmortizingFixedRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_4(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_5")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_5(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_6")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_7")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_8")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_8(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_9")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_9(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_10")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_10(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_11")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_11(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_AmortizingFloatingRateBond__SWIG_12")]
  public static extern global::System.IntPtr new_AmortizingFloatingRateBond__SWIG_12(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_AmortizingFloatingRateBond")]
  public static extern void delete_AmortizingFloatingRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_0(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, int jarg17, bool jarg18);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_1(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16, int jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_2(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, global::System.Runtime.InteropServices.HandleRef jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_3(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_4(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_5")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_5(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_6")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_6(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_7")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_7(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_8")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_8(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_9")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_9(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_10")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_10(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_11")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_11(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_12")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_12(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatingRateBond__SWIG_13")]
  public static extern global::System.IntPtr new_FloatingRateBond__SWIG_13(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloatingRateBond")]
  public static extern void delete_FloatingRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_CmsRateBond__SWIG_0(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_CmsRateBond__SWIG_1(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_CmsRateBond__SWIG_2(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CmsRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_CmsRateBond__SWIG_3(uint jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CmsRateBond")]
  public static extern void delete_CmsRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountingBondEngine")]
  public static extern global::System.IntPtr new_DiscountingBondEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DiscountingBondEngine")]
  public static extern void delete_DiscountingBondEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_callability")]
  public static extern global::System.IntPtr CallableBond_callability(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_impliedVolatility")]
  public static extern double CallableBond_impliedVolatility(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_OAS__SWIG_0")]
  public static extern double CallableBond_OAS__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, uint jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_OAS__SWIG_1")]
  public static extern double CallableBond_OAS__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_OAS__SWIG_2")]
  public static extern double CallableBond_OAS__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_OAS__SWIG_3")]
  public static extern double CallableBond_OAS__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_OAS__SWIG_4")]
  public static extern double CallableBond_OAS__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_cleanPriceOAS__SWIG_0")]
  public static extern double CallableBond_cleanPriceOAS__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_cleanPriceOAS__SWIG_1")]
  public static extern double CallableBond_cleanPriceOAS__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_effectiveDuration__SWIG_0")]
  public static extern double CallableBond_effectiveDuration__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_effectiveDuration__SWIG_1")]
  public static extern double CallableBond_effectiveDuration__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_effectiveConvexity__SWIG_0")]
  public static extern double CallableBond_effectiveConvexity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_effectiveConvexity__SWIG_1")]
  public static extern double CallableBond_effectiveConvexity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CallableBond")]
  public static extern void delete_CallableBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableFixedRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_CallableFixedRateBond__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableFixedRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_CallableFixedRateBond__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableFixedRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_CallableFixedRateBond__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableFixedRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_CallableFixedRateBond__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableFixedRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_CallableFixedRateBond__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CallableFixedRateBond")]
  public static extern void delete_CallableFixedRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableZeroCouponBond__SWIG_0")]
  public static extern global::System.IntPtr new_CallableZeroCouponBond__SWIG_0(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableZeroCouponBond__SWIG_1")]
  public static extern global::System.IntPtr new_CallableZeroCouponBond__SWIG_1(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableZeroCouponBond__SWIG_2")]
  public static extern global::System.IntPtr new_CallableZeroCouponBond__SWIG_2(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableZeroCouponBond__SWIG_3")]
  public static extern global::System.IntPtr new_CallableZeroCouponBond__SWIG_3(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CallableZeroCouponBond__SWIG_4")]
  public static extern global::System.IntPtr new_CallableZeroCouponBond__SWIG_4(int jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CallableZeroCouponBond")]
  public static extern void delete_CallableZeroCouponBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCallableFixedRateBondEngine__SWIG_0")]
  public static extern global::System.IntPtr new_TreeCallableFixedRateBondEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCallableFixedRateBondEngine__SWIG_1")]
  public static extern global::System.IntPtr new_TreeCallableFixedRateBondEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCallableFixedRateBondEngine__SWIG_2")]
  public static extern global::System.IntPtr new_TreeCallableFixedRateBondEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TreeCallableFixedRateBondEngine__SWIG_3")]
  public static extern global::System.IntPtr new_TreeCallableFixedRateBondEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TreeCallableFixedRateBondEngine")]
  public static extern void delete_TreeCallableFixedRateBondEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCallableFixedRateBondEngine")]
  public static extern global::System.IntPtr new_BlackCallableFixedRateBondEngine(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCallableFixedRateBondEngine")]
  public static extern void delete_BlackCallableFixedRateBondEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_0")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_0(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_1")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_1(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_2")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_2(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_3")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_3(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_4")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_4(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_5")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_5(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_6")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_6(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, int jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CPIBond__SWIG_7")]
  public static extern global::System.IntPtr new_CPIBond__SWIG_7(uint jarg1, double jarg2, bool jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CPIBond")]
  public static extern void delete_CPIBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_startDate")]
  public static extern global::System.IntPtr BondFunctions_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_maturityDate")]
  public static extern global::System.IntPtr BondFunctions_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_isTradable__SWIG_0")]
  public static extern bool BondFunctions_isTradable__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_isTradable__SWIG_1")]
  public static extern bool BondFunctions_isTradable__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCashFlowDate__SWIG_0")]
  public static extern global::System.IntPtr BondFunctions_previousCashFlowDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCashFlowDate__SWIG_1")]
  public static extern global::System.IntPtr BondFunctions_previousCashFlowDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCashFlowDate__SWIG_0")]
  public static extern global::System.IntPtr BondFunctions_nextCashFlowDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCashFlowDate__SWIG_1")]
  public static extern global::System.IntPtr BondFunctions_nextCashFlowDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCashFlowAmount__SWIG_0")]
  public static extern double BondFunctions_previousCashFlowAmount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCashFlowAmount__SWIG_1")]
  public static extern double BondFunctions_previousCashFlowAmount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCashFlowAmount__SWIG_0")]
  public static extern double BondFunctions_nextCashFlowAmount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCashFlowAmount__SWIG_1")]
  public static extern double BondFunctions_nextCashFlowAmount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCouponRate__SWIG_0")]
  public static extern double BondFunctions_previousCouponRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_previousCouponRate__SWIG_1")]
  public static extern double BondFunctions_previousCouponRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCouponRate__SWIG_0")]
  public static extern double BondFunctions_nextCouponRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_nextCouponRate__SWIG_1")]
  public static extern double BondFunctions_nextCouponRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualStartDate__SWIG_0")]
  public static extern global::System.IntPtr BondFunctions_accrualStartDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualStartDate__SWIG_1")]
  public static extern global::System.IntPtr BondFunctions_accrualStartDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualEndDate__SWIG_0")]
  public static extern global::System.IntPtr BondFunctions_accrualEndDate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualEndDate__SWIG_1")]
  public static extern global::System.IntPtr BondFunctions_accrualEndDate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualPeriod__SWIG_0")]
  public static extern double BondFunctions_accrualPeriod__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualPeriod__SWIG_1")]
  public static extern double BondFunctions_accrualPeriod__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualDays__SWIG_0")]
  public static extern int BondFunctions_accrualDays__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accrualDays__SWIG_1")]
  public static extern int BondFunctions_accrualDays__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedPeriod__SWIG_0")]
  public static extern double BondFunctions_accruedPeriod__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedPeriod__SWIG_1")]
  public static extern double BondFunctions_accruedPeriod__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedDays__SWIG_0")]
  public static extern int BondFunctions_accruedDays__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedDays__SWIG_1")]
  public static extern int BondFunctions_accruedDays__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedAmount__SWIG_0")]
  public static extern double BondFunctions_accruedAmount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_accruedAmount__SWIG_1")]
  public static extern double BondFunctions_accruedAmount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_0")]
  public static extern double BondFunctions_cleanPrice__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_1")]
  public static extern double BondFunctions_cleanPrice__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_0")]
  public static extern double BondFunctions_bps__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_1")]
  public static extern double BondFunctions_bps__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_atmRate__SWIG_0")]
  public static extern double BondFunctions_atmRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_atmRate__SWIG_1")]
  public static extern double BondFunctions_atmRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_atmRate__SWIG_2")]
  public static extern double BondFunctions_atmRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_2")]
  public static extern double BondFunctions_cleanPrice__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_3")]
  public static extern double BondFunctions_cleanPrice__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_4")]
  public static extern double BondFunctions_cleanPrice__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_cleanPrice__SWIG_5")]
  public static extern double BondFunctions_cleanPrice__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_2")]
  public static extern double BondFunctions_bps__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_3")]
  public static extern double BondFunctions_bps__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_4")]
  public static extern double BondFunctions_bps__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_bps__SWIG_5")]
  public static extern double BondFunctions_bps__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yield__SWIG_0")]
  public static extern double BondFunctions_yield__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yield__SWIG_1")]
  public static extern double BondFunctions_yield__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, uint jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yield__SWIG_2")]
  public static extern double BondFunctions_yield__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yield__SWIG_3")]
  public static extern double BondFunctions_yield__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yield__SWIG_4")]
  public static extern double BondFunctions_yield__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_0")]
  public static extern double BondFunctions_duration__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_1")]
  public static extern double BondFunctions_duration__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_2")]
  public static extern double BondFunctions_duration__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_3")]
  public static extern double BondFunctions_duration__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_4")]
  public static extern double BondFunctions_duration__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_duration__SWIG_5")]
  public static extern double BondFunctions_duration__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_convexity__SWIG_0")]
  public static extern double BondFunctions_convexity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_convexity__SWIG_1")]
  public static extern double BondFunctions_convexity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_convexity__SWIG_2")]
  public static extern double BondFunctions_convexity__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_convexity__SWIG_3")]
  public static extern double BondFunctions_convexity__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_basisPointValue__SWIG_0")]
  public static extern double BondFunctions_basisPointValue__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_basisPointValue__SWIG_1")]
  public static extern double BondFunctions_basisPointValue__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_basisPointValue__SWIG_2")]
  public static extern double BondFunctions_basisPointValue__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_basisPointValue__SWIG_3")]
  public static extern double BondFunctions_basisPointValue__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldValueBasisPoint__SWIG_0")]
  public static extern double BondFunctions_yieldValueBasisPoint__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldValueBasisPoint__SWIG_1")]
  public static extern double BondFunctions_yieldValueBasisPoint__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldValueBasisPoint__SWIG_2")]
  public static extern double BondFunctions_yieldValueBasisPoint__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldValueBasisPoint__SWIG_3")]
  public static extern double BondFunctions_yieldValueBasisPoint__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_zSpread__SWIG_0")]
  public static extern double BondFunctions_zSpread__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, uint jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_zSpread__SWIG_1")]
  public static extern double BondFunctions_zSpread__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_zSpread__SWIG_2")]
  public static extern double BondFunctions_zSpread__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_zSpread__SWIG_3")]
  public static extern double BondFunctions_zSpread__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_zSpread__SWIG_4")]
  public static extern double BondFunctions_zSpread__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBrent__SWIG_0")]
  public static extern double BondFunctions_yieldBrent__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBrent__SWIG_1")]
  public static extern double BondFunctions_yieldBrent__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBrent__SWIG_2")]
  public static extern double BondFunctions_yieldBrent__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBrent__SWIG_3")]
  public static extern double BondFunctions_yieldBrent__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBisection__SWIG_0")]
  public static extern double BondFunctions_yieldBisection__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBisection__SWIG_1")]
  public static extern double BondFunctions_yieldBisection__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBisection__SWIG_2")]
  public static extern double BondFunctions_yieldBisection__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldBisection__SWIG_3")]
  public static extern double BondFunctions_yieldBisection__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldFalsePosition__SWIG_0")]
  public static extern double BondFunctions_yieldFalsePosition__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldFalsePosition__SWIG_1")]
  public static extern double BondFunctions_yieldFalsePosition__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldFalsePosition__SWIG_2")]
  public static extern double BondFunctions_yieldFalsePosition__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldFalsePosition__SWIG_3")]
  public static extern double BondFunctions_yieldFalsePosition__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldRidder__SWIG_0")]
  public static extern double BondFunctions_yieldRidder__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldRidder__SWIG_1")]
  public static extern double BondFunctions_yieldRidder__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldRidder__SWIG_2")]
  public static extern double BondFunctions_yieldRidder__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldRidder__SWIG_3")]
  public static extern double BondFunctions_yieldRidder__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldSecant__SWIG_0")]
  public static extern double BondFunctions_yieldSecant__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldSecant__SWIG_1")]
  public static extern double BondFunctions_yieldSecant__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldSecant__SWIG_2")]
  public static extern double BondFunctions_yieldSecant__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondFunctions_yieldSecant__SWIG_3")]
  public static extern double BondFunctions_yieldSecant__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondFunctions")]
  public static extern global::System.IntPtr new_BondFunctions();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BondFunctions")]
  public static extern void delete_BondFunctions(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_0")]
  public static extern double CapFloor_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_1")]
  public static extern double CapFloor_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_2")]
  public static extern double CapFloor_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_3")]
  public static extern double CapFloor_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_4")]
  public static extern double CapFloor_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_5")]
  public static extern double CapFloor_impliedVolatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_impliedVolatility__SWIG_6")]
  public static extern double CapFloor_impliedVolatility__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_floatingLeg")]
  public static extern global::System.IntPtr CapFloor_floatingLeg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_capRates")]
  public static extern global::System.IntPtr CapFloor_capRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_floorRates")]
  public static extern global::System.IntPtr CapFloor_floorRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_startDate")]
  public static extern global::System.IntPtr CapFloor_startDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_maturityDate")]
  public static extern global::System.IntPtr CapFloor_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_type")]
  public static extern int CapFloor_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_atmRate")]
  public static extern double CapFloor_atmRate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_vega")]
  public static extern double CapFloor_vega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsPrice")]
  public static extern global::System.IntPtr CapFloor_optionletsPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsVega")]
  public static extern global::System.IntPtr CapFloor_optionletsVega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsDelta")]
  public static extern global::System.IntPtr CapFloor_optionletsDelta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsDiscountFactor")]
  public static extern global::System.IntPtr CapFloor_optionletsDiscountFactor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsAtmForward")]
  public static extern global::System.IntPtr CapFloor_optionletsAtmForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_optionletsStdDev")]
  public static extern global::System.IntPtr CapFloor_optionletsStdDev(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapFloor")]
  public static extern void delete_CapFloor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Cap")]
  public static extern global::System.IntPtr new_Cap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Cap")]
  public static extern void delete_Cap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Floor")]
  public static extern global::System.IntPtr new_Floor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Floor")]
  public static extern void delete_Floor(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Collar")]
  public static extern global::System.IntPtr new_Collar(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Collar")]
  public static extern void delete_Collar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCapFloorEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BlackCapFloorEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCapFloorEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BlackCapFloorEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCapFloorEngine__SWIG_2")]
  public static extern global::System.IntPtr new_BlackCapFloorEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCapFloorEngine__SWIG_3")]
  public static extern global::System.IntPtr new_BlackCapFloorEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCapFloorEngine__SWIG_4")]
  public static extern global::System.IntPtr new_BlackCapFloorEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCapFloorEngine")]
  public static extern void delete_BlackCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BachelierCapFloorEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BachelierCapFloorEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BachelierCapFloorEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BachelierCapFloorEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BachelierCapFloorEngine")]
  public static extern void delete_BachelierCapFloorEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Dividend")]
  public static extern void delete_Dividend(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedDividend")]
  public static extern global::System.IntPtr new_FixedDividend(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FixedDividend")]
  public static extern void delete_FixedDividend(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FractionalDividend")]
  public static extern global::System.IntPtr new_FractionalDividend(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FractionalDividend")]
  public static extern void delete_FractionalDividend(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Clear")]
  public static extern void DividendSchedule_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Add")]
  public static extern void DividendSchedule_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_size")]
  public static extern uint DividendSchedule_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_capacity")]
  public static extern uint DividendSchedule_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_reserve")]
  public static extern void DividendSchedule_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DividendSchedule__SWIG_0")]
  public static extern global::System.IntPtr new_DividendSchedule__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DividendSchedule__SWIG_1")]
  public static extern global::System.IntPtr new_DividendSchedule__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DividendSchedule__SWIG_2")]
  public static extern global::System.IntPtr new_DividendSchedule__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_getitemcopy")]
  public static extern global::System.IntPtr DividendSchedule_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_getitem")]
  public static extern global::System.IntPtr DividendSchedule_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_setitem")]
  public static extern void DividendSchedule_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_AddRange")]
  public static extern void DividendSchedule_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_GetRange")]
  public static extern global::System.IntPtr DividendSchedule_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Insert")]
  public static extern void DividendSchedule_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_InsertRange")]
  public static extern void DividendSchedule_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_RemoveAt")]
  public static extern void DividendSchedule_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_RemoveRange")]
  public static extern void DividendSchedule_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Repeat")]
  public static extern global::System.IntPtr DividendSchedule_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Reverse__SWIG_0")]
  public static extern void DividendSchedule_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Reverse__SWIG_1")]
  public static extern void DividendSchedule_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_SetRange")]
  public static extern void DividendSchedule_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Contains")]
  public static extern bool DividendSchedule_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_IndexOf")]
  public static extern int DividendSchedule_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_LastIndexOf")]
  public static extern int DividendSchedule_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendSchedule_Remove")]
  public static extern bool DividendSchedule_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DividendSchedule")]
  public static extern void delete_DividendSchedule(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleZeroCouponBond__SWIG_0")]
  public static extern global::System.IntPtr new_ConvertibleZeroCouponBond__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleZeroCouponBond__SWIG_1")]
  public static extern global::System.IntPtr new_ConvertibleZeroCouponBond__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConvertibleZeroCouponBond")]
  public static extern void delete_ConvertibleZeroCouponBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_0")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_1")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, int jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_2")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_3")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, double jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_4")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, double jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFixedCouponBond__SWIG_5")]
  public static extern global::System.IntPtr new_ConvertibleFixedCouponBond__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConvertibleFixedCouponBond")]
  public static extern void delete_ConvertibleFixedCouponBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_0")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16, bool jarg17);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_1")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15, int jarg16);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_2")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14, global::System.Runtime.InteropServices.HandleRef jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_3")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_4")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, double jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConvertibleFloatingRateBond__SWIG_5")]
  public static extern global::System.IntPtr new_ConvertibleFloatingRateBond__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConvertibleFloatingRateBond")]
  public static extern void delete_ConvertibleFloatingRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialCRRConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialCRRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialCRRConvertibleEngine")]
  public static extern void delete_BinomialCRRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJRConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialJRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJRConvertibleEngine")]
  public static extern void delete_BinomialJRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialEQPConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialEQPConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialEQPConvertibleEngine")]
  public static extern void delete_BinomialEQPConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTrigeorgisConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialTrigeorgisConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTrigeorgisConvertibleEngine")]
  public static extern void delete_BinomialTrigeorgisConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialTianConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialTianConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialTianConvertibleEngine")]
  public static extern void delete_BinomialTianConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialLRConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialLRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialLRConvertibleEngine")]
  public static extern void delete_BinomialLRConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialJ4ConvertibleEngine")]
  public static extern global::System.IntPtr new_BinomialJ4ConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialJ4ConvertibleEngine")]
  public static extern void delete_BinomialJ4ConvertibleEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Futures")]
  public static extern global::System.IntPtr new_Futures();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Futures")]
  public static extern void delete_Futures(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndexFuture")]
  public static extern void delete_OvernightIndexFuture(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Pillar")]
  public static extern global::System.IntPtr new_Pillar();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Pillar")]
  public static extern void delete_Pillar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_quote")]
  public static extern global::System.IntPtr RateHelper_quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_latestDate")]
  public static extern global::System.IntPtr RateHelper_latestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_earliestDate")]
  public static extern global::System.IntPtr RateHelper_earliestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_maturityDate")]
  public static extern global::System.IntPtr RateHelper_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_latestRelevantDate")]
  public static extern global::System.IntPtr RateHelper_latestRelevantDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_pillarDate")]
  public static extern global::System.IntPtr RateHelper_pillarDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_impliedQuote")]
  public static extern double RateHelper_impliedQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_quoteError")]
  public static extern double RateHelper_quoteError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RateHelper")]
  public static extern void delete_RateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DepositRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_DepositRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DepositRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_DepositRateHelper__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DepositRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_DepositRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DepositRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_DepositRateHelper__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DepositRateHelper")]
  public static extern void delete_DepositRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_4")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_4(double jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_5")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_5(double jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_6")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_6(double jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_7")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_7(double jarg1, uint jarg2, uint jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_8")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_9")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_10")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_10(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_11")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_11(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_12")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_12(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_13")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_13(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_14")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_14(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_15")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_15(double jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_16")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_17")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_18")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_19")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_20")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_20(double jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_21")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_21(double jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_22")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_22(double jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FraRateHelper__SWIG_23")]
  public static extern global::System.IntPtr new_FraRateHelper__SWIG_23(double jarg1, uint jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FraRateHelper")]
  public static extern void delete_FraRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_4")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_5")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, bool jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_6")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_7")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_8")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_9")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_10")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_10(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_11")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_11(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_12")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_13")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_13(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_14")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_15")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_15(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_16")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_16(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FuturesRateHelper__SWIG_17")]
  public static extern global::System.IntPtr new_FuturesRateHelper__SWIG_17(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FuturesRateHelper")]
  public static extern void delete_FuturesRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_4")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_5")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_6")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_7")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_7(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11, int jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_8")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_8(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11, int jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_9")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_9(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_10")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_10(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_11")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_11(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_12")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_12(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_13")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_13(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_14")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_14(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_15")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_15(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_16")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_16(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_17")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_17(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_18")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_18(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_19")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_19(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_20")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_20(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_21")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_21(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_22")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_22(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_23")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_23(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_24")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_24(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SwapRateHelper__SWIG_25")]
  public static extern global::System.IntPtr new_SwapRateHelper__SWIG_25(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapRateHelper_spread")]
  public static extern double SwapRateHelper_spread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapRateHelper_swap")]
  public static extern global::System.IntPtr SwapRateHelper_swap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SwapRateHelper")]
  public static extern void delete_SwapRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondHelper__SWIG_0")]
  public static extern global::System.IntPtr new_BondHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondHelper__SWIG_1")]
  public static extern global::System.IntPtr new_BondHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelper_bond")]
  public static extern global::System.IntPtr BondHelper_bond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BondHelper")]
  public static extern void delete_BondHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_0")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13, bool jarg14, bool jarg15);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_1")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_2")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, int jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_3")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_4")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_5")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_6")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_7")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_8")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondHelper__SWIG_9")]
  public static extern global::System.IntPtr new_FixedRateBondHelper__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBondHelper_fixedRateBond")]
  public static extern global::System.IntPtr FixedRateBondHelper_fixedRateBond(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FixedRateBondHelper")]
  public static extern void delete_FixedRateBondHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, double jarg12, int jarg13, global::System.Runtime.InteropServices.HandleRef jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, double jarg12, int jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, double jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_4")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_4(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_5")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_5(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_6")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_7")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_8")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_8(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_9")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_9(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OISRateHelper__SWIG_10")]
  public static extern global::System.IntPtr new_OISRateHelper__SWIG_10(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OISRateHelper_swap")]
  public static extern global::System.IntPtr OISRateHelper_swap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OISRateHelper")]
  public static extern void delete_OISRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DatedOISRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_DatedOISRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DatedOISRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_DatedOISRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DatedOISRateHelper")]
  public static extern void delete_DatedOISRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FxSwapRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_FxSwapRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FxSwapRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_FxSwapRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, bool jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FxSwapRateHelper")]
  public static extern void delete_FxSwapRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexFutureRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_OvernightIndexFutureRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexFutureRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_OvernightIndexFutureRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OvernightIndexFutureRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_OvernightIndexFutureRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OvernightIndexFutureRateHelper")]
  public static extern void delete_OvernightIndexFutureRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_0")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_1")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_2")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_3")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_3(double jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_4")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_4(double jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SofrFutureRateHelper__SWIG_5")]
  public static extern global::System.IntPtr new_SofrFutureRateHelper__SWIG_5(double jarg1, int jarg2, int jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SofrFutureRateHelper")]
  public static extern void delete_SofrFutureRateHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Clear")]
  public static extern void RateHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Add")]
  public static extern void RateHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_size")]
  public static extern uint RateHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_capacity")]
  public static extern uint RateHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_reserve")]
  public static extern void RateHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RateHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_RateHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RateHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_RateHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RateHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_RateHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_getitemcopy")]
  public static extern global::System.IntPtr RateHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_getitem")]
  public static extern global::System.IntPtr RateHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_setitem")]
  public static extern void RateHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_AddRange")]
  public static extern void RateHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_GetRange")]
  public static extern global::System.IntPtr RateHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Insert")]
  public static extern void RateHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_InsertRange")]
  public static extern void RateHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_RemoveAt")]
  public static extern void RateHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_RemoveRange")]
  public static extern void RateHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Repeat")]
  public static extern global::System.IntPtr RateHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Reverse__SWIG_0")]
  public static extern void RateHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Reverse__SWIG_1")]
  public static extern void RateHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_SetRange")]
  public static extern void RateHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Contains")]
  public static extern bool RateHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_IndexOf")]
  public static extern int RateHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_LastIndexOf")]
  public static extern int RateHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelperVector_Remove")]
  public static extern bool RateHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RateHelperVector")]
  public static extern void delete_RateHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Clear")]
  public static extern void BondHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Add")]
  public static extern void BondHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_size")]
  public static extern uint BondHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_capacity")]
  public static extern uint BondHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_reserve")]
  public static extern void BondHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_BondHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_BondHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BondHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_BondHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_getitemcopy")]
  public static extern global::System.IntPtr BondHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_getitem")]
  public static extern global::System.IntPtr BondHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_setitem")]
  public static extern void BondHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_AddRange")]
  public static extern void BondHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_GetRange")]
  public static extern global::System.IntPtr BondHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Insert")]
  public static extern void BondHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_InsertRange")]
  public static extern void BondHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_RemoveAt")]
  public static extern void BondHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_RemoveRange")]
  public static extern void BondHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Repeat")]
  public static extern global::System.IntPtr BondHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Reverse__SWIG_0")]
  public static extern void BondHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Reverse__SWIG_1")]
  public static extern void BondHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_SetRange")]
  public static extern void BondHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Contains")]
  public static extern bool BondHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_IndexOf")]
  public static extern int BondHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_LastIndexOf")]
  public static extern int BondHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelperVector_Remove")]
  public static extern bool BondHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BondHelperVector")]
  public static extern void delete_BondHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_depositratehelper")]
  public static extern global::System.IntPtr as_depositratehelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_fraratehelper")]
  public static extern global::System.IntPtr as_fraratehelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_swapratehelper")]
  public static extern global::System.IntPtr as_swapratehelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_as_oisratehelper")]
  public static extern global::System.IntPtr as_oisratehelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Discount")]
  public static extern global::System.IntPtr new_Discount();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Discount")]
  public static extern void delete_Discount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroYield")]
  public static extern global::System.IntPtr new_ZeroYield();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroYield")]
  public static extern void delete_ZeroYield(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardRate")]
  public static extern global::System.IntPtr new_ForwardRate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardRate")]
  public static extern void delete_ForwardRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IterativeBootstrap__SWIG_0")]
  public static extern global::System.IntPtr new_IterativeBootstrap__SWIG_0(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IterativeBootstrap__SWIG_1")]
  public static extern global::System.IntPtr new_IterativeBootstrap__SWIG_1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IterativeBootstrap__SWIG_2")]
  public static extern global::System.IntPtr new_IterativeBootstrap__SWIG_2(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IterativeBootstrap__SWIG_3")]
  public static extern global::System.IntPtr new_IterativeBootstrap__SWIG_3();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IterativeBootstrap")]
  public static extern void delete_IterativeBootstrap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatForward__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseFlatForward__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatForward_dates")]
  public static extern global::System.IntPtr PiecewiseFlatForward_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatForward_times")]
  public static extern global::System.IntPtr PiecewiseFlatForward_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatForward_nodes")]
  public static extern global::System.IntPtr PiecewiseFlatForward_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseFlatForward")]
  public static extern void delete_PiecewiseFlatForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogLinearDiscount__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseLogLinearDiscount__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogLinearDiscount_dates")]
  public static extern global::System.IntPtr PiecewiseLogLinearDiscount_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogLinearDiscount_times")]
  public static extern global::System.IntPtr PiecewiseLogLinearDiscount_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogLinearDiscount_nodes")]
  public static extern global::System.IntPtr PiecewiseLogLinearDiscount_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseLogLinearDiscount")]
  public static extern void delete_PiecewiseLogLinearDiscount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearForward__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseLinearForward__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearForward_dates")]
  public static extern global::System.IntPtr PiecewiseLinearForward_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearForward_times")]
  public static extern global::System.IntPtr PiecewiseLinearForward_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearForward_nodes")]
  public static extern global::System.IntPtr PiecewiseLinearForward_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseLinearForward")]
  public static extern void delete_PiecewiseLinearForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLinearZero__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseLinearZero__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearZero_dates")]
  public static extern global::System.IntPtr PiecewiseLinearZero_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearZero_times")]
  public static extern global::System.IntPtr PiecewiseLinearZero_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearZero_nodes")]
  public static extern global::System.IntPtr PiecewiseLinearZero_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseLinearZero")]
  public static extern void delete_PiecewiseLinearZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseCubicZero__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseCubicZero__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseCubicZero_dates")]
  public static extern global::System.IntPtr PiecewiseCubicZero_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseCubicZero_times")]
  public static extern global::System.IntPtr PiecewiseCubicZero_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseCubicZero_nodes")]
  public static extern global::System.IntPtr PiecewiseCubicZero_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseCubicZero")]
  public static extern void delete_PiecewiseCubicZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseLogCubicDiscount__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseLogCubicDiscount__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogCubicDiscount_dates")]
  public static extern global::System.IntPtr PiecewiseLogCubicDiscount_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogCubicDiscount_times")]
  public static extern global::System.IntPtr PiecewiseLogCubicDiscount_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogCubicDiscount_nodes")]
  public static extern global::System.IntPtr PiecewiseLogCubicDiscount_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseLogCubicDiscount")]
  public static extern void delete_PiecewiseLogCubicDiscount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseSplineCubicDiscount__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseSplineCubicDiscount__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseSplineCubicDiscount_dates")]
  public static extern global::System.IntPtr PiecewiseSplineCubicDiscount_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseSplineCubicDiscount_times")]
  public static extern global::System.IntPtr PiecewiseSplineCubicDiscount_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseSplineCubicDiscount_nodes")]
  public static extern global::System.IntPtr PiecewiseSplineCubicDiscount_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseSplineCubicDiscount")]
  public static extern void delete_PiecewiseSplineCubicDiscount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerZero__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseKrugerZero__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerZero_dates")]
  public static extern global::System.IntPtr PiecewiseKrugerZero_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerZero_times")]
  public static extern global::System.IntPtr PiecewiseKrugerZero_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerZero_nodes")]
  public static extern global::System.IntPtr PiecewiseKrugerZero_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseKrugerZero")]
  public static extern void delete_PiecewiseKrugerZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseKrugerLogDiscount__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseKrugerLogDiscount__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerLogDiscount_dates")]
  public static extern global::System.IntPtr PiecewiseKrugerLogDiscount_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerLogDiscount_times")]
  public static extern global::System.IntPtr PiecewiseKrugerLogDiscount_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerLogDiscount_nodes")]
  public static extern global::System.IntPtr PiecewiseKrugerLogDiscount_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseKrugerLogDiscount")]
  public static extern void delete_PiecewiseKrugerLogDiscount(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_8(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_10")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_10(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_11")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_11(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_12")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_12(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseConvexMonotoneZero__SWIG_13")]
  public static extern global::System.IntPtr new_PiecewiseConvexMonotoneZero__SWIG_13(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseConvexMonotoneZero_dates")]
  public static extern global::System.IntPtr PiecewiseConvexMonotoneZero_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseConvexMonotoneZero_times")]
  public static extern global::System.IntPtr PiecewiseConvexMonotoneZero_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseConvexMonotoneZero_nodes")]
  public static extern global::System.IntPtr PiecewiseConvexMonotoneZero_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseConvexMonotoneZero")]
  public static extern void delete_PiecewiseConvexMonotoneZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GlobalBootstrap__SWIG_0")]
  public static extern global::System.IntPtr new_GlobalBootstrap__SWIG_0(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GlobalBootstrap__SWIG_1")]
  public static extern global::System.IntPtr new_GlobalBootstrap__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GlobalBootstrap__SWIG_2")]
  public static extern global::System.IntPtr new_GlobalBootstrap__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GlobalBootstrap__SWIG_3")]
  public static extern global::System.IntPtr new_GlobalBootstrap__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GlobalBootstrap")]
  public static extern void delete_GlobalBootstrap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GlobalLinearSimpleZeroCurve")]
  public static extern global::System.IntPtr new_GlobalLinearSimpleZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GlobalLinearSimpleZeroCurve_dates")]
  public static extern global::System.IntPtr GlobalLinearSimpleZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GlobalLinearSimpleZeroCurve_times")]
  public static extern global::System.IntPtr GlobalLinearSimpleZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GlobalLinearSimpleZeroCurve_nodes")]
  public static extern global::System.IntPtr GlobalLinearSimpleZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GlobalLinearSimpleZeroCurve")]
  public static extern void delete_GlobalLinearSimpleZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_0")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_1")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_2")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_3")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_4")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_5")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_6")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultProbability__SWIG_7")]
  public static extern double DefaultProbabilityTermStructure_defaultProbability__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_survivalProbability__SWIG_0")]
  public static extern double DefaultProbabilityTermStructure_survivalProbability__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_survivalProbability__SWIG_1")]
  public static extern double DefaultProbabilityTermStructure_survivalProbability__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_survivalProbability__SWIG_2")]
  public static extern double DefaultProbabilityTermStructure_survivalProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_survivalProbability__SWIG_3")]
  public static extern double DefaultProbabilityTermStructure_survivalProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultDensity__SWIG_0")]
  public static extern double DefaultProbabilityTermStructure_defaultDensity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultDensity__SWIG_1")]
  public static extern double DefaultProbabilityTermStructure_defaultDensity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultDensity__SWIG_2")]
  public static extern double DefaultProbabilityTermStructure_defaultDensity__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_defaultDensity__SWIG_3")]
  public static extern double DefaultProbabilityTermStructure_defaultDensity__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_hazardRate__SWIG_0")]
  public static extern double DefaultProbabilityTermStructure_hazardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_hazardRate__SWIG_1")]
  public static extern double DefaultProbabilityTermStructure_hazardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_hazardRate__SWIG_2")]
  public static extern double DefaultProbabilityTermStructure_hazardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_hazardRate__SWIG_3")]
  public static extern double DefaultProbabilityTermStructure_hazardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultProbabilityTermStructure")]
  public static extern void delete_DefaultProbabilityTermStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultProbabilityTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_DefaultProbabilityTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultProbabilityTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_DefaultProbabilityTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle___deref__")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_currentLink")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_empty")]
  public static extern bool DefaultProbabilityTermStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_asObservable")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultProbabilityTermStructureHandle")]
  public static extern void delete_DefaultProbabilityTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_0")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_1")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_2")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_3")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_4")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_5")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_6")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_7")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultProbability__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_0")]
  public static extern double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_1")]
  public static extern double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_2")]
  public static extern double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_3")]
  public static extern double DefaultProbabilityTermStructureHandle_survivalProbability__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_0")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_1")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_2")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_3")]
  public static extern double DefaultProbabilityTermStructureHandle_defaultDensity__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_hazardRate__SWIG_0")]
  public static extern double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_hazardRate__SWIG_1")]
  public static extern double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_hazardRate__SWIG_2")]
  public static extern double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_hazardRate__SWIG_3")]
  public static extern double DefaultProbabilityTermStructureHandle_hazardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_dayCounter")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_timeFromReference")]
  public static extern double DefaultProbabilityTermStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_calendar")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_referenceDate")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_maxDate")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_maxTime")]
  public static extern double DefaultProbabilityTermStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_enableExtrapolation")]
  public static extern void DefaultProbabilityTermStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_disableExtrapolation")]
  public static extern void DefaultProbabilityTermStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructureHandle_allowsExtrapolation")]
  public static extern bool DefaultProbabilityTermStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableDefaultProbabilityTermStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDefaultProbabilityTermStructureHandle_linkTo")]
  public static extern void RelinkableDefaultProbabilityTermStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDefaultProbabilityTermStructureHandle_reset")]
  public static extern void RelinkableDefaultProbabilityTermStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableDefaultProbabilityTermStructureHandle")]
  public static extern void delete_RelinkableDefaultProbabilityTermStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatHazardRate__SWIG_0")]
  public static extern global::System.IntPtr new_FlatHazardRate__SWIG_0(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FlatHazardRate__SWIG_1")]
  public static extern global::System.IntPtr new_FlatHazardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FlatHazardRate")]
  public static extern void delete_FlatHazardRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HazardRateCurve__SWIG_0")]
  public static extern global::System.IntPtr new_HazardRateCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HazardRateCurve__SWIG_1")]
  public static extern global::System.IntPtr new_HazardRateCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HazardRateCurve__SWIG_2")]
  public static extern global::System.IntPtr new_HazardRateCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HazardRateCurve_dates")]
  public static extern global::System.IntPtr HazardRateCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HazardRateCurve_hazardRates")]
  public static extern global::System.IntPtr HazardRateCurve_hazardRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HazardRateCurve_nodes")]
  public static extern global::System.IntPtr HazardRateCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HazardRateCurve")]
  public static extern void delete_HazardRateCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultDensityCurve__SWIG_0")]
  public static extern global::System.IntPtr new_DefaultDensityCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultDensityCurve__SWIG_1")]
  public static extern global::System.IntPtr new_DefaultDensityCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultDensityCurve__SWIG_2")]
  public static extern global::System.IntPtr new_DefaultDensityCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultDensityCurve_dates")]
  public static extern global::System.IntPtr DefaultDensityCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultDensityCurve_defaultDensities")]
  public static extern global::System.IntPtr DefaultDensityCurve_defaultDensities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultDensityCurve_nodes")]
  public static extern global::System.IntPtr DefaultDensityCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultDensityCurve")]
  public static extern void delete_DefaultDensityCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SurvivalProbabilityCurve__SWIG_0")]
  public static extern global::System.IntPtr new_SurvivalProbabilityCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SurvivalProbabilityCurve__SWIG_1")]
  public static extern global::System.IntPtr new_SurvivalProbabilityCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SurvivalProbabilityCurve__SWIG_2")]
  public static extern global::System.IntPtr new_SurvivalProbabilityCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SurvivalProbabilityCurve_dates")]
  public static extern global::System.IntPtr SurvivalProbabilityCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SurvivalProbabilityCurve_survivalProbabilities")]
  public static extern global::System.IntPtr SurvivalProbabilityCurve_survivalProbabilities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SurvivalProbabilityCurve_nodes")]
  public static extern global::System.IntPtr SurvivalProbabilityCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SurvivalProbabilityCurve")]
  public static extern void delete_SurvivalProbabilityCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_quote")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_quote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_latestDate")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_latestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_earliestDate")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_earliestDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_maturityDate")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_maturityDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_latestRelevantDate")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_latestRelevantDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_pillarDate")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_pillarDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_impliedQuote")]
  public static extern double DefaultProbabilityHelper_impliedQuote(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_quoteError")]
  public static extern double DefaultProbabilityHelper_quoteError(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultProbabilityHelper")]
  public static extern void delete_DefaultProbabilityHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Clear")]
  public static extern void DefaultProbabilityHelperVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Add")]
  public static extern void DefaultProbabilityHelperVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_size")]
  public static extern uint DefaultProbabilityHelperVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_capacity")]
  public static extern uint DefaultProbabilityHelperVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_reserve")]
  public static extern void DefaultProbabilityHelperVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultProbabilityHelperVector__SWIG_0")]
  public static extern global::System.IntPtr new_DefaultProbabilityHelperVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultProbabilityHelperVector__SWIG_1")]
  public static extern global::System.IntPtr new_DefaultProbabilityHelperVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultProbabilityHelperVector__SWIG_2")]
  public static extern global::System.IntPtr new_DefaultProbabilityHelperVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_getitemcopy")]
  public static extern global::System.IntPtr DefaultProbabilityHelperVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_getitem")]
  public static extern global::System.IntPtr DefaultProbabilityHelperVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_setitem")]
  public static extern void DefaultProbabilityHelperVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_AddRange")]
  public static extern void DefaultProbabilityHelperVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_GetRange")]
  public static extern global::System.IntPtr DefaultProbabilityHelperVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Insert")]
  public static extern void DefaultProbabilityHelperVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_InsertRange")]
  public static extern void DefaultProbabilityHelperVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_RemoveAt")]
  public static extern void DefaultProbabilityHelperVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_RemoveRange")]
  public static extern void DefaultProbabilityHelperVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Repeat")]
  public static extern global::System.IntPtr DefaultProbabilityHelperVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Reverse__SWIG_0")]
  public static extern void DefaultProbabilityHelperVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Reverse__SWIG_1")]
  public static extern void DefaultProbabilityHelperVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_SetRange")]
  public static extern void DefaultProbabilityHelperVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Contains")]
  public static extern bool DefaultProbabilityHelperVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_IndexOf")]
  public static extern int DefaultProbabilityHelperVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_LastIndexOf")]
  public static extern int DefaultProbabilityHelperVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelperVector_Remove")]
  public static extern bool DefaultProbabilityHelperVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultProbabilityHelperVector")]
  public static extern void delete_DefaultProbabilityHelperVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_0")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_1")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_2")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_3")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_4")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_4(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, bool jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SpreadCdsHelper__SWIG_5")]
  public static extern global::System.IntPtr new_SpreadCdsHelper__SWIG_5(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, int jarg6, int jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SpreadCdsHelper")]
  public static extern void delete_SpreadCdsHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_0")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_1")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_2")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_3")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_4")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_4(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12, bool jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_5")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_5(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_6")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_6(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, uint jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UpfrontCdsHelper__SWIG_7")]
  public static extern global::System.IntPtr new_UpfrontCdsHelper__SWIG_7(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, int jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UpfrontCdsHelper")]
  public static extern void delete_UpfrontCdsHelper(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HazardRate")]
  public static extern global::System.IntPtr new_HazardRate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HazardRate")]
  public static extern void delete_HazardRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DefaultDensity")]
  public static extern global::System.IntPtr new_DefaultDensity();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultDensity")]
  public static extern void delete_DefaultDensity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_0")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_1")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_2")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_3")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_4")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_4(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_5")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_5(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_6")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_6(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_7")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_7(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_8")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PiecewiseFlatHazardRate__SWIG_9")]
  public static extern global::System.IntPtr new_PiecewiseFlatHazardRate__SWIG_9(int jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatHazardRate_dates")]
  public static extern global::System.IntPtr PiecewiseFlatHazardRate_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatHazardRate_times")]
  public static extern global::System.IntPtr PiecewiseFlatHazardRate_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatHazardRate_nodes")]
  public static extern global::System.IntPtr PiecewiseFlatHazardRate_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PiecewiseFlatHazardRate")]
  public static extern void delete_PiecewiseFlatHazardRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Protection")]
  public static extern global::System.IntPtr new_Protection();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Protection")]
  public static extern void delete_Protection(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Claim_amount")]
  public static extern double Claim_amount(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Claim")]
  public static extern void delete_Claim(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FaceValueClaim")]
  public static extern global::System.IntPtr new_FaceValueClaim();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FaceValueClaim")]
  public static extern void delete_FaceValueClaim(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FaceValueAccrualClaim")]
  public static extern global::System.IntPtr new_FaceValueAccrualClaim(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FaceValueAccrualClaim")]
  public static extern void delete_FaceValueAccrualClaim(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_0")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_0(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, bool jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_1")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_1(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_2")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_2(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, bool jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_3")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_3(int jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_4")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_4(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13, bool jarg14);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_5")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_5(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12, global::System.Runtime.InteropServices.HandleRef jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_6")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_6(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, global::System.Runtime.InteropServices.HandleRef jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_7")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_7(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_8")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_8(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_9")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_9(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, bool jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_10")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_10(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CreditDefaultSwap__SWIG_11")]
  public static extern global::System.IntPtr new_CreditDefaultSwap__SWIG_11(int jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_side")]
  public static extern int CreditDefaultSwap_side(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_notional")]
  public static extern double CreditDefaultSwap_notional(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_runningSpread")]
  public static extern double CreditDefaultSwap_runningSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_upfront")]
  public static extern double CreditDefaultSwap_upfront(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_settlesAccrual")]
  public static extern bool CreditDefaultSwap_settlesAccrual(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_paysAtDefaultTime")]
  public static extern bool CreditDefaultSwap_paysAtDefaultTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_fairSpread")]
  public static extern double CreditDefaultSwap_fairSpread(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_fairUpfront")]
  public static extern double CreditDefaultSwap_fairUpfront(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_couponLegBPS")]
  public static extern double CreditDefaultSwap_couponLegBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_couponLegNPV")]
  public static extern double CreditDefaultSwap_couponLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_defaultLegNPV")]
  public static extern double CreditDefaultSwap_defaultLegNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_upfrontBPS")]
  public static extern double CreditDefaultSwap_upfrontBPS(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_upfrontNPV")]
  public static extern double CreditDefaultSwap_upfrontNPV(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_impliedHazardRate__SWIG_0")]
  public static extern double CreditDefaultSwap_impliedHazardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_impliedHazardRate__SWIG_1")]
  public static extern double CreditDefaultSwap_impliedHazardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_impliedHazardRate__SWIG_2")]
  public static extern double CreditDefaultSwap_impliedHazardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_impliedHazardRate__SWIG_3")]
  public static extern double CreditDefaultSwap_impliedHazardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_conventionalSpread")]
  public static extern double CreditDefaultSwap_conventionalSpread(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_coupons")]
  public static extern global::System.IntPtr CreditDefaultSwap_coupons(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CreditDefaultSwap")]
  public static extern void delete_CreditDefaultSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MidPointCdsEngine")]
  public static extern global::System.IntPtr new_MidPointCdsEngine(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MidPointCdsEngine")]
  public static extern void delete_MidPointCdsEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntegralCdsEngine__SWIG_0")]
  public static extern global::System.IntPtr new_IntegralCdsEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IntegralCdsEngine__SWIG_1")]
  public static extern global::System.IntPtr new_IntegralCdsEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IntegralCdsEngine")]
  public static extern void delete_IntegralCdsEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IsdaCdsEngine__SWIG_0")]
  public static extern global::System.IntPtr new_IsdaCdsEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, int jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IsdaCdsEngine__SWIG_1")]
  public static extern global::System.IntPtr new_IsdaCdsEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, int jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IsdaCdsEngine__SWIG_2")]
  public static extern global::System.IntPtr new_IsdaCdsEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IsdaCdsEngine__SWIG_3")]
  public static extern global::System.IntPtr new_IsdaCdsEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IsdaCdsEngine__SWIG_4")]
  public static extern global::System.IntPtr new_IsdaCdsEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IsdaCdsEngine")]
  public static extern void delete_IsdaCdsEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CdsOption__SWIG_0")]
  public static extern global::System.IntPtr new_CdsOption__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CdsOption__SWIG_1")]
  public static extern global::System.IntPtr new_CdsOption__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_atmRate")]
  public static extern double CdsOption_atmRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_riskyAnnuity")]
  public static extern double CdsOption_riskyAnnuity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_impliedVolatility__SWIG_0")]
  public static extern double CdsOption_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, double jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_impliedVolatility__SWIG_1")]
  public static extern double CdsOption_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_impliedVolatility__SWIG_2")]
  public static extern double CdsOption_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_impliedVolatility__SWIG_3")]
  public static extern double CdsOption_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_impliedVolatility__SWIG_4")]
  public static extern double CdsOption_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CdsOption")]
  public static extern void delete_CdsOption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackCdsOptionEngine")]
  public static extern global::System.IntPtr new_BlackCdsOptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCdsOptionEngine_termStructure")]
  public static extern global::System.IntPtr BlackCdsOptionEngine_termStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCdsOptionEngine_volatility")]
  public static extern global::System.IntPtr BlackCdsOptionEngine_volatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackCdsOptionEngine")]
  public static extern void delete_BlackCdsOptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountCurve__SWIG_0")]
  public static extern global::System.IntPtr new_DiscountCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountCurve__SWIG_1")]
  public static extern global::System.IntPtr new_DiscountCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DiscountCurve__SWIG_2")]
  public static extern global::System.IntPtr new_DiscountCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_times")]
  public static extern global::System.IntPtr DiscountCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_data")]
  public static extern global::System.IntPtr DiscountCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_dates")]
  public static extern global::System.IntPtr DiscountCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_discounts")]
  public static extern global::System.IntPtr DiscountCurve_discounts(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_nodes")]
  public static extern global::System.IntPtr DiscountCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DiscountCurve")]
  public static extern void delete_DiscountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogCubicDiscountCurve__SWIG_0")]
  public static extern global::System.IntPtr new_MonotonicLogCubicDiscountCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogCubicDiscountCurve__SWIG_1")]
  public static extern global::System.IntPtr new_MonotonicLogCubicDiscountCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicLogCubicDiscountCurve__SWIG_2")]
  public static extern global::System.IntPtr new_MonotonicLogCubicDiscountCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_times")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_data")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_dates")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_discounts")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_discounts(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_nodes")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicLogCubicDiscountCurve")]
  public static extern void delete_MonotonicLogCubicDiscountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicDiscountCurve__SWIG_0")]
  public static extern global::System.IntPtr new_NaturalCubicDiscountCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicDiscountCurve__SWIG_1")]
  public static extern global::System.IntPtr new_NaturalCubicDiscountCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicDiscountCurve__SWIG_2")]
  public static extern global::System.IntPtr new_NaturalCubicDiscountCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_times")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_data")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_dates")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_discounts")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_discounts(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_nodes")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NaturalCubicDiscountCurve")]
  public static extern void delete_NaturalCubicDiscountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NormalDistribution__SWIG_0")]
  public static extern global::System.IntPtr new_NormalDistribution__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NormalDistribution__SWIG_1")]
  public static extern global::System.IntPtr new_NormalDistribution__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NormalDistribution__SWIG_2")]
  public static extern global::System.IntPtr new_NormalDistribution__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NormalDistribution_call")]
  public static extern double NormalDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NormalDistribution_derivative")]
  public static extern double NormalDistribution_derivative(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NormalDistribution")]
  public static extern void delete_NormalDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeNormalDistribution__SWIG_0")]
  public static extern global::System.IntPtr new_CumulativeNormalDistribution__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeNormalDistribution__SWIG_1")]
  public static extern global::System.IntPtr new_CumulativeNormalDistribution__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeNormalDistribution__SWIG_2")]
  public static extern global::System.IntPtr new_CumulativeNormalDistribution__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeNormalDistribution_call")]
  public static extern double CumulativeNormalDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeNormalDistribution_derivative")]
  public static extern double CumulativeNormalDistribution_derivative(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativeNormalDistribution")]
  public static extern void delete_CumulativeNormalDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeNormal__SWIG_0")]
  public static extern global::System.IntPtr new_InverseCumulativeNormal__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeNormal__SWIG_1")]
  public static extern global::System.IntPtr new_InverseCumulativeNormal__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeNormal__SWIG_2")]
  public static extern global::System.IntPtr new_InverseCumulativeNormal__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InverseCumulativeNormal_call")]
  public static extern double InverseCumulativeNormal_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InverseCumulativeNormal")]
  public static extern void delete_InverseCumulativeNormal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInverseCumulativeNormal__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInverseCumulativeNormal__SWIG_0(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInverseCumulativeNormal__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInverseCumulativeNormal__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInverseCumulativeNormal__SWIG_2")]
  public static extern global::System.IntPtr new_MoroInverseCumulativeNormal__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInverseCumulativeNormal_call")]
  public static extern double MoroInverseCumulativeNormal_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInverseCumulativeNormal")]
  public static extern void delete_MoroInverseCumulativeNormal(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BivariateCumulativeNormalDistribution")]
  public static extern global::System.IntPtr new_BivariateCumulativeNormalDistribution(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BivariateCumulativeNormalDistribution_call")]
  public static extern double BivariateCumulativeNormalDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BivariateCumulativeNormalDistribution")]
  public static extern void delete_BivariateCumulativeNormalDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BinomialDistribution")]
  public static extern global::System.IntPtr new_BinomialDistribution(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialDistribution_call")]
  public static extern double BinomialDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BinomialDistribution")]
  public static extern void delete_BinomialDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeBinomialDistribution")]
  public static extern global::System.IntPtr new_CumulativeBinomialDistribution(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeBinomialDistribution_call")]
  public static extern double CumulativeBinomialDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativeBinomialDistribution")]
  public static extern void delete_CumulativeBinomialDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BivariateCumulativeNormalDistributionDr78")]
  public static extern global::System.IntPtr new_BivariateCumulativeNormalDistributionDr78(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BivariateCumulativeNormalDistributionDr78_call")]
  public static extern double BivariateCumulativeNormalDistributionDr78_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BivariateCumulativeNormalDistributionDr78")]
  public static extern void delete_BivariateCumulativeNormalDistributionDr78(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BivariateCumulativeNormalDistributionWe04DP")]
  public static extern global::System.IntPtr new_BivariateCumulativeNormalDistributionWe04DP(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BivariateCumulativeNormalDistributionWe04DP_call")]
  public static extern double BivariateCumulativeNormalDistributionWe04DP_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BivariateCumulativeNormalDistributionWe04DP")]
  public static extern void delete_BivariateCumulativeNormalDistributionWe04DP(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeChiSquareDistribution")]
  public static extern global::System.IntPtr new_CumulativeChiSquareDistribution(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeChiSquareDistribution_call")]
  public static extern double CumulativeChiSquareDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativeChiSquareDistribution")]
  public static extern void delete_CumulativeChiSquareDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonCentralCumulativeChiSquareDistribution")]
  public static extern global::System.IntPtr new_NonCentralCumulativeChiSquareDistribution(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonCentralCumulativeChiSquareDistribution_call")]
  public static extern double NonCentralCumulativeChiSquareDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NonCentralCumulativeChiSquareDistribution")]
  public static extern void delete_NonCentralCumulativeChiSquareDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_0")]
  public static extern global::System.IntPtr new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_0(double jarg1, double jarg2, uint jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_1")]
  public static extern global::System.IntPtr new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_1(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_2")]
  public static extern global::System.IntPtr new_InverseNonCentralCumulativeChiSquareDistribution__SWIG_2(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InverseNonCentralCumulativeChiSquareDistribution_call")]
  public static extern double InverseNonCentralCumulativeChiSquareDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InverseNonCentralCumulativeChiSquareDistribution")]
  public static extern void delete_InverseNonCentralCumulativeChiSquareDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeGammaDistribution")]
  public static extern global::System.IntPtr new_CumulativeGammaDistribution(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeGammaDistribution_call")]
  public static extern double CumulativeGammaDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativeGammaDistribution")]
  public static extern void delete_CumulativeGammaDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GammaFunction_logValue")]
  public static extern double GammaFunction_logValue(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GammaFunction")]
  public static extern global::System.IntPtr new_GammaFunction();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GammaFunction")]
  public static extern void delete_GammaFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_PoissonDistribution")]
  public static extern global::System.IntPtr new_PoissonDistribution(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PoissonDistribution_call")]
  public static extern double PoissonDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_PoissonDistribution")]
  public static extern void delete_PoissonDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativePoissonDistribution")]
  public static extern global::System.IntPtr new_CumulativePoissonDistribution(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativePoissonDistribution_call")]
  public static extern double CumulativePoissonDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativePoissonDistribution")]
  public static extern void delete_CumulativePoissonDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativePoisson")]
  public static extern global::System.IntPtr new_InverseCumulativePoisson(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InverseCumulativePoisson_call")]
  public static extern double InverseCumulativePoisson_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InverseCumulativePoisson")]
  public static extern void delete_InverseCumulativePoisson(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StudentDistribution")]
  public static extern global::System.IntPtr new_StudentDistribution(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StudentDistribution_call")]
  public static extern double StudentDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StudentDistribution")]
  public static extern void delete_StudentDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CumulativeStudentDistribution")]
  public static extern global::System.IntPtr new_CumulativeStudentDistribution(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CumulativeStudentDistribution_call")]
  public static extern double CumulativeStudentDistribution_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CumulativeStudentDistribution")]
  public static extern void delete_CumulativeStudentDistribution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeStudent__SWIG_0")]
  public static extern global::System.IntPtr new_InverseCumulativeStudent__SWIG_0(int jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeStudent__SWIG_1")]
  public static extern global::System.IntPtr new_InverseCumulativeStudent__SWIG_1(int jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InverseCumulativeStudent__SWIG_2")]
  public static extern global::System.IntPtr new_InverseCumulativeStudent__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InverseCumulativeStudent_call")]
  public static extern double InverseCumulativeStudent_call(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InverseCumulativeStudent")]
  public static extern void delete_InverseCumulativeStudent(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Money__SWIG_0")]
  public static extern global::System.IntPtr new_Money__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Money__SWIG_1")]
  public static extern global::System.IntPtr new_Money__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Money_currency")]
  public static extern global::System.IntPtr Money_currency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Money_value")]
  public static extern double Money_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Money_rounded")]
  public static extern global::System.IntPtr Money_rounded(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Money_setConversionType")]
  public static extern void Money_setConversionType(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Money_setBaseCurrency")]
  public static extern void Money_setBaseCurrency(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Money")]
  public static extern void delete_Money(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExchangeRate")]
  public static extern global::System.IntPtr new_ExchangeRate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_source")]
  public static extern global::System.IntPtr ExchangeRate_source(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_target")]
  public static extern global::System.IntPtr ExchangeRate_target(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_type")]
  public static extern int ExchangeRate_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_rate")]
  public static extern double ExchangeRate_rate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_exchange")]
  public static extern global::System.IntPtr ExchangeRate_exchange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRate_chain")]
  public static extern global::System.IntPtr ExchangeRate_chain(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExchangeRate")]
  public static extern void delete_ExchangeRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_instance")]
  public static extern global::System.IntPtr ExchangeRateManager_instance();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_add__SWIG_0")]
  public static extern void ExchangeRateManager_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_add__SWIG_1")]
  public static extern void ExchangeRateManager_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_add__SWIG_2")]
  public static extern void ExchangeRateManager_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_lookup__SWIG_0")]
  public static extern global::System.IntPtr ExchangeRateManager_lookup__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_lookup__SWIG_1")]
  public static extern global::System.IntPtr ExchangeRateManager_lookup__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExchangeRateManager_clear")]
  public static extern void ExchangeRateManager_clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExchangeRateManager")]
  public static extern void delete_ExchangeRateManager(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_instance")]
  public static extern global::System.IntPtr Settings_instance();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_getEvaluationDate")]
  public static extern global::System.IntPtr Settings_getEvaluationDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_setEvaluationDate")]
  public static extern void Settings_setEvaluationDate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_includeReferenceDateEvents")]
  public static extern void Settings_includeReferenceDateEvents(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_includeTodaysCashFlows")]
  public static extern void Settings_includeTodaysCashFlows(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_setEnforcesTodaysHistoricFixings")]
  public static extern void Settings_setEnforcesTodaysHistoricFixings(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Settings_getEnforcesTodaysHistoricFixings")]
  public static extern bool Settings_getEnforcesTodaysHistoricFixings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Settings")]
  public static extern void delete_Settings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm1dMesher")]
  public static extern global::System.IntPtr new_Fdm1dMesher(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesher_size")]
  public static extern uint Fdm1dMesher_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesher_dplus")]
  public static extern double Fdm1dMesher_dplus(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesher_dminus")]
  public static extern double Fdm1dMesher_dminus(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesher_location")]
  public static extern double Fdm1dMesher_location(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesher_locations")]
  public static extern global::System.IntPtr Fdm1dMesher_locations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm1dMesher")]
  public static extern void delete_Fdm1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Clear")]
  public static extern void Fdm1dMesherVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Add")]
  public static extern void Fdm1dMesherVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_size")]
  public static extern uint Fdm1dMesherVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_capacity")]
  public static extern uint Fdm1dMesherVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_reserve")]
  public static extern void Fdm1dMesherVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm1dMesherVector__SWIG_0")]
  public static extern global::System.IntPtr new_Fdm1dMesherVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm1dMesherVector__SWIG_1")]
  public static extern global::System.IntPtr new_Fdm1dMesherVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm1dMesherVector__SWIG_2")]
  public static extern global::System.IntPtr new_Fdm1dMesherVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_getitemcopy")]
  public static extern global::System.IntPtr Fdm1dMesherVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_getitem")]
  public static extern global::System.IntPtr Fdm1dMesherVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_setitem")]
  public static extern void Fdm1dMesherVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_AddRange")]
  public static extern void Fdm1dMesherVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_GetRange")]
  public static extern global::System.IntPtr Fdm1dMesherVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Insert")]
  public static extern void Fdm1dMesherVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_InsertRange")]
  public static extern void Fdm1dMesherVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_RemoveAt")]
  public static extern void Fdm1dMesherVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_RemoveRange")]
  public static extern void Fdm1dMesherVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Repeat")]
  public static extern global::System.IntPtr Fdm1dMesherVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Reverse__SWIG_0")]
  public static extern void Fdm1dMesherVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Reverse__SWIG_1")]
  public static extern void Fdm1dMesherVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_SetRange")]
  public static extern void Fdm1dMesherVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Contains")]
  public static extern bool Fdm1dMesherVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_IndexOf")]
  public static extern int Fdm1dMesherVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_LastIndexOf")]
  public static extern int Fdm1dMesherVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1dMesherVector_Remove")]
  public static extern bool Fdm1dMesherVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm1dMesherVector")]
  public static extern void delete_Fdm1dMesherVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_0")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11, double jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_1")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_2")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_3")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_4")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_4(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_5")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_5(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_6")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_7")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesMesher__SWIG_8")]
  public static extern global::System.IntPtr new_FdmBlackScholesMesher__SWIG_8(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBlackScholesMesher_processHelper")]
  public static extern global::System.IntPtr FdmBlackScholesMesher_processHelper(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBlackScholesMesher")]
  public static extern void delete_FdmBlackScholesMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesherPoint")]
  public static extern global::System.IntPtr new_Concentrating1dMesherPoint(double jarg1, double jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPoint_first")]
  public static extern double Concentrating1dMesherPoint_first(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPoint_second")]
  public static extern double Concentrating1dMesherPoint_second(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPoint_third")]
  public static extern bool Concentrating1dMesherPoint_third(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Concentrating1dMesherPoint")]
  public static extern void delete_Concentrating1dMesherPoint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Clear")]
  public static extern void Concentrating1dMesherPointVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Add")]
  public static extern void Concentrating1dMesherPointVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_size")]
  public static extern uint Concentrating1dMesherPointVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_capacity")]
  public static extern uint Concentrating1dMesherPointVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_reserve")]
  public static extern void Concentrating1dMesherPointVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesherPointVector__SWIG_0")]
  public static extern global::System.IntPtr new_Concentrating1dMesherPointVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesherPointVector__SWIG_1")]
  public static extern global::System.IntPtr new_Concentrating1dMesherPointVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesherPointVector__SWIG_2")]
  public static extern global::System.IntPtr new_Concentrating1dMesherPointVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_getitemcopy")]
  public static extern global::System.IntPtr Concentrating1dMesherPointVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_getitem")]
  public static extern global::System.IntPtr Concentrating1dMesherPointVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_setitem")]
  public static extern void Concentrating1dMesherPointVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_AddRange")]
  public static extern void Concentrating1dMesherPointVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_GetRange")]
  public static extern global::System.IntPtr Concentrating1dMesherPointVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Insert")]
  public static extern void Concentrating1dMesherPointVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_InsertRange")]
  public static extern void Concentrating1dMesherPointVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_RemoveAt")]
  public static extern void Concentrating1dMesherPointVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_RemoveRange")]
  public static extern void Concentrating1dMesherPointVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Repeat")]
  public static extern global::System.IntPtr Concentrating1dMesherPointVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Reverse__SWIG_0")]
  public static extern void Concentrating1dMesherPointVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_Reverse__SWIG_1")]
  public static extern void Concentrating1dMesherPointVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesherPointVector_SetRange")]
  public static extern void Concentrating1dMesherPointVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Concentrating1dMesherPointVector")]
  public static extern void delete_Concentrating1dMesherPointVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesher__SWIG_0")]
  public static extern global::System.IntPtr new_Concentrating1dMesher__SWIG_0(double jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesher__SWIG_1")]
  public static extern global::System.IntPtr new_Concentrating1dMesher__SWIG_1(double jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesher__SWIG_2")]
  public static extern global::System.IntPtr new_Concentrating1dMesher__SWIG_2(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesher__SWIG_3")]
  public static extern global::System.IntPtr new_Concentrating1dMesher__SWIG_3(double jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Concentrating1dMesher__SWIG_4")]
  public static extern global::System.IntPtr new_Concentrating1dMesher__SWIG_4(double jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Concentrating1dMesher")]
  public static extern void delete_Concentrating1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialJump1dMesher__SWIG_0")]
  public static extern global::System.IntPtr new_ExponentialJump1dMesher__SWIG_0(uint jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialJump1dMesher__SWIG_1")]
  public static extern global::System.IntPtr new_ExponentialJump1dMesher__SWIG_1(uint jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExponentialJump1dMesher")]
  public static extern void delete_ExponentialJump1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCEV1dMesher__SWIG_0")]
  public static extern global::System.IntPtr new_FdmCEV1dMesher__SWIG_0(uint jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCEV1dMesher__SWIG_1")]
  public static extern global::System.IntPtr new_FdmCEV1dMesher__SWIG_1(uint jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCEV1dMesher__SWIG_2")]
  public static extern global::System.IntPtr new_FdmCEV1dMesher__SWIG_2(uint jarg1, double jarg2, double jarg3, double jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCEV1dMesher__SWIG_3")]
  public static extern global::System.IntPtr new_FdmCEV1dMesher__SWIG_3(uint jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmCEV1dMesher")]
  public static extern void delete_FdmCEV1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonVarianceMesher__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonVarianceMesher__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonVarianceMesher__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonVarianceMesher__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonVarianceMesher__SWIG_2")]
  public static extern global::System.IntPtr new_FdmHestonVarianceMesher__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonVarianceMesher_volaEstimate")]
  public static extern double FdmHestonVarianceMesher_volaEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonVarianceMesher")]
  public static extern void delete_FdmHestonVarianceMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonLocalVolatilityVarianceMesher__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonLocalVolatilityVarianceMesher__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonLocalVolatilityVarianceMesher__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonLocalVolatilityVarianceMesher__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonLocalVolatilityVarianceMesher__SWIG_2")]
  public static extern global::System.IntPtr new_FdmHestonLocalVolatilityVarianceMesher__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonLocalVolatilityVarianceMesher_volaEstimate")]
  public static extern double FdmHestonLocalVolatilityVarianceMesher_volaEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonLocalVolatilityVarianceMesher")]
  public static extern void delete_FdmHestonLocalVolatilityVarianceMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleProcess1dMesher__SWIG_0")]
  public static extern global::System.IntPtr new_FdmSimpleProcess1dMesher__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, double jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleProcess1dMesher__SWIG_1")]
  public static extern global::System.IntPtr new_FdmSimpleProcess1dMesher__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleProcess1dMesher__SWIG_2")]
  public static extern global::System.IntPtr new_FdmSimpleProcess1dMesher__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleProcess1dMesher__SWIG_3")]
  public static extern global::System.IntPtr new_FdmSimpleProcess1dMesher__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSimpleProcess1dMesher")]
  public static extern void delete_FdmSimpleProcess1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Uniform1dMesher")]
  public static extern global::System.IntPtr new_Uniform1dMesher(double jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Uniform1dMesher")]
  public static extern void delete_Uniform1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Predefined1dMesher")]
  public static extern global::System.IntPtr new_Predefined1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Predefined1dMesher")]
  public static extern void delete_Predefined1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Glued1dMesher")]
  public static extern global::System.IntPtr new_Glued1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Glued1dMesher")]
  public static extern void delete_Glued1dMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLinearOpIterator")]
  public static extern global::System.IntPtr new_FdmLinearOpIterator(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpIterator_coordinates")]
  public static extern global::System.IntPtr FdmLinearOpIterator_coordinates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpIterator_increment")]
  public static extern void FdmLinearOpIterator_increment(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpIterator_notEqual")]
  public static extern bool FdmLinearOpIterator_notEqual(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpIterator_index")]
  public static extern uint FdmLinearOpIterator_index(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOpIterator")]
  public static extern void delete_FdmLinearOpIterator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLinearOpLayout")]
  public static extern global::System.IntPtr new_FdmLinearOpLayout(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_spacing")]
  public static extern global::System.IntPtr FdmLinearOpLayout_spacing(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_dim")]
  public static extern global::System.IntPtr FdmLinearOpLayout_dim(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_index")]
  public static extern uint FdmLinearOpLayout_index(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_begin")]
  public static extern global::System.IntPtr FdmLinearOpLayout_begin(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_end")]
  public static extern global::System.IntPtr FdmLinearOpLayout_end(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_size")]
  public static extern uint FdmLinearOpLayout_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_neighbourhood__SWIG_0")]
  public static extern uint FdmLinearOpLayout_neighbourhood__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_neighbourhood__SWIG_1")]
  public static extern uint FdmLinearOpLayout_neighbourhood__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, int jarg4, uint jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpLayout_iter_neighbourhood")]
  public static extern global::System.IntPtr FdmLinearOpLayout_iter_neighbourhood(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOpLayout")]
  public static extern void delete_FdmLinearOpLayout(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmMesher")]
  public static extern void delete_FdmMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_0")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_1")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_2")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_3")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_4")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmMesherComposite__SWIG_5")]
  public static extern global::System.IntPtr new_FdmMesherComposite__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_dplus")]
  public static extern double FdmMesherComposite_dplus(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_dminus")]
  public static extern double FdmMesherComposite_dminus(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_location")]
  public static extern double FdmMesherComposite_location(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_locations")]
  public static extern global::System.IntPtr FdmMesherComposite_locations(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_layout")]
  public static extern global::System.IntPtr FdmMesherComposite_layout(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_getFdm1dMeshers")]
  public static extern global::System.IntPtr FdmMesherComposite_getFdm1dMeshers(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmMesherComposite")]
  public static extern void delete_FdmMesherComposite(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOp_apply")]
  public static extern global::System.IntPtr FdmLinearOp_apply(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOp")]
  public static extern void delete_FdmLinearOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_size")]
  public static extern uint FdmLinearOpComposite_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_setTime")]
  public static extern void FdmLinearOpComposite_setTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_apply_mixed")]
  public static extern global::System.IntPtr FdmLinearOpComposite_apply_mixed(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_apply_direction")]
  public static extern global::System.IntPtr FdmLinearOpComposite_apply_direction(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_solve_splitting")]
  public static extern global::System.IntPtr FdmLinearOpComposite_solve_splitting(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_preconditioner")]
  public static extern global::System.IntPtr FdmLinearOpComposite_preconditioner(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOpComposite")]
  public static extern void delete_FdmLinearOpComposite(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLinearOpCompositeProxy")]
  public static extern global::System.IntPtr new_FdmLinearOpCompositeProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOpCompositeProxy")]
  public static extern void delete_FdmLinearOpCompositeProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLinearOpCompositeDelegate")]
  public static extern void delete_FdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_size")]
  public static extern uint FdmLinearOpCompositeDelegate_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_sizeSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern uint FdmLinearOpCompositeDelegate_sizeSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_setTime")]
  public static extern void FdmLinearOpCompositeDelegate_setTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_setTimeSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern void FdmLinearOpCompositeDelegate_setTimeSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_apply")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_apply(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_applySwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_applySwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_apply_mixed")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_apply_mixed(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_apply_mixedSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_apply_mixedSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_apply_direction")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_apply_direction(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_apply_directionSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_apply_directionSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_solve_splitting")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_solve_splitting(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_solve_splittingSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_solve_splittingSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_preconditioner")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_preconditioner(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_preconditionerSwigExplicitFdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr FdmLinearOpCompositeDelegate_preconditionerSwigExplicitFdmLinearOpCompositeDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLinearOpCompositeDelegate")]
  public static extern global::System.IntPtr new_FdmLinearOpCompositeDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeDelegate_director_connect")]
  public static extern void FdmLinearOpCompositeDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_0 delegate0, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_1 delegate1, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_2 delegate2, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_3 delegate3, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_4 delegate4, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_5 delegate5, FdmLinearOpCompositeDelegate.SwigDelegateFdmLinearOpCompositeDelegate_6 delegate6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryCondition_applyBeforeApplying")]
  public static extern void FdmBoundaryCondition_applyBeforeApplying(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryCondition_applyAfterApplying")]
  public static extern void FdmBoundaryCondition_applyAfterApplying(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryCondition_applyBeforeSolving")]
  public static extern void FdmBoundaryCondition_applyBeforeSolving(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryCondition_applyAfterSolving")]
  public static extern void FdmBoundaryCondition_applyAfterSolving(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryCondition_setTime")]
  public static extern void FdmBoundaryCondition_setTime(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBoundaryCondition")]
  public static extern void delete_FdmBoundaryCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Clear")]
  public static extern void FdmBoundaryConditionSet_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Add")]
  public static extern void FdmBoundaryConditionSet_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_size")]
  public static extern uint FdmBoundaryConditionSet_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_capacity")]
  public static extern uint FdmBoundaryConditionSet_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_reserve")]
  public static extern void FdmBoundaryConditionSet_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBoundaryConditionSet__SWIG_0")]
  public static extern global::System.IntPtr new_FdmBoundaryConditionSet__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBoundaryConditionSet__SWIG_1")]
  public static extern global::System.IntPtr new_FdmBoundaryConditionSet__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBoundaryConditionSet__SWIG_2")]
  public static extern global::System.IntPtr new_FdmBoundaryConditionSet__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_getitemcopy")]
  public static extern global::System.IntPtr FdmBoundaryConditionSet_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_getitem")]
  public static extern global::System.IntPtr FdmBoundaryConditionSet_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_setitem")]
  public static extern void FdmBoundaryConditionSet_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_AddRange")]
  public static extern void FdmBoundaryConditionSet_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_GetRange")]
  public static extern global::System.IntPtr FdmBoundaryConditionSet_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Insert")]
  public static extern void FdmBoundaryConditionSet_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_InsertRange")]
  public static extern void FdmBoundaryConditionSet_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_RemoveAt")]
  public static extern void FdmBoundaryConditionSet_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_RemoveRange")]
  public static extern void FdmBoundaryConditionSet_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Repeat")]
  public static extern global::System.IntPtr FdmBoundaryConditionSet_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Reverse__SWIG_0")]
  public static extern void FdmBoundaryConditionSet_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Reverse__SWIG_1")]
  public static extern void FdmBoundaryConditionSet_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_SetRange")]
  public static extern void FdmBoundaryConditionSet_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Contains")]
  public static extern bool FdmBoundaryConditionSet_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_IndexOf")]
  public static extern int FdmBoundaryConditionSet_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_LastIndexOf")]
  public static extern int FdmBoundaryConditionSet_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBoundaryConditionSet_Remove")]
  public static extern bool FdmBoundaryConditionSet_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBoundaryConditionSet")]
  public static extern void delete_FdmBoundaryConditionSet(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmDirichletBoundary")]
  public static extern global::System.IntPtr new_FdmDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDirichletBoundary_applyAfterApplying__SWIG_0")]
  public static extern void FdmDirichletBoundary_applyAfterApplying__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDirichletBoundary_applyAfterApplying__SWIG_1")]
  public static extern double FdmDirichletBoundary_applyAfterApplying__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmDirichletBoundary")]
  public static extern void delete_FdmDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmDiscountDirichletBoundary")]
  public static extern global::System.IntPtr new_FdmDiscountDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmDiscountDirichletBoundary")]
  public static extern void delete_FdmDiscountDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmTimeDepDirichletBoundary")]
  public static extern global::System.IntPtr new_FdmTimeDepDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmTimeDepDirichletBoundary")]
  public static extern void delete_FdmTimeDepDirichletBoundary(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBatesOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmBatesOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBatesOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmBatesOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBatesOp")]
  public static extern void delete_FdmBatesOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmBlackScholesOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4, double jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmBlackScholesOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesOp__SWIG_2")]
  public static extern global::System.IntPtr new_FdmBlackScholesOp__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesOp__SWIG_3")]
  public static extern global::System.IntPtr new_FdmBlackScholesOp__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesOp__SWIG_4")]
  public static extern global::System.IntPtr new_FdmBlackScholesOp__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBlackScholesOp")]
  public static extern void delete_FdmBlackScholesOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesOp__SWIG_0")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, bool jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesOp__SWIG_1")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesOp__SWIG_2")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesOp__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm2dBlackScholesOp")]
  public static extern void delete_Fdm2dBlackScholesOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCEVOp")]
  public static extern global::System.IntPtr new_FdmCEVOp(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmCEVOp")]
  public static extern void delete_FdmCEVOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmG2Op")]
  public static extern global::System.IntPtr new_FdmG2Op(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmG2Op")]
  public static extern void delete_FdmG2Op(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonHullWhiteOp")]
  public static extern global::System.IntPtr new_FdmHestonHullWhiteOp(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonHullWhiteOp")]
  public static extern void delete_FdmHestonHullWhiteOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonOp__SWIG_2")]
  public static extern global::System.IntPtr new_FdmHestonOp__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonOp")]
  public static extern void delete_FdmHestonOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHullWhiteOp")]
  public static extern global::System.IntPtr new_FdmHullWhiteOp(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHullWhiteOp")]
  public static extern void delete_FdmHullWhiteOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLocalVolFwdOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmLocalVolFwdOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLocalVolFwdOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmLocalVolFwdOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLocalVolFwdOp")]
  public static extern void delete_FdmLocalVolFwdOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmOrnsteinUhlenbeckOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmOrnsteinUhlenbeckOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmOrnsteinUhlenbeckOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmOrnsteinUhlenbeckOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmOrnsteinUhlenbeckOp")]
  public static extern void delete_FdmOrnsteinUhlenbeckOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSabrOp")]
  public static extern global::System.IntPtr new_FdmSabrOp(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5, double jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSabrOp")]
  public static extern void delete_FdmSabrOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmZabrOp")]
  public static extern global::System.IntPtr new_FdmZabrOp(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmZabrOp")]
  public static extern void delete_FdmZabrOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmDupire1dOp")]
  public static extern global::System.IntPtr new_FdmDupire1dOp(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmDupire1dOp")]
  public static extern void delete_FdmDupire1dOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesFwdOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmBlackScholesFwdOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesFwdOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmBlackScholesFwdOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesFwdOp__SWIG_2")]
  public static extern global::System.IntPtr new_FdmBlackScholesFwdOp__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBlackScholesFwdOp__SWIG_3")]
  public static extern global::System.IntPtr new_FdmBlackScholesFwdOp__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBlackScholesFwdOp")]
  public static extern void delete_FdmBlackScholesFwdOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSquareRootFwdOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmSquareRootFwdOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, uint jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSquareRootFwdOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmSquareRootFwdOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSquareRootFwdOp")]
  public static extern void delete_FdmSquareRootFwdOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonFwdOp__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonFwdOp__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonFwdOp__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonFwdOp__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonFwdOp__SWIG_2")]
  public static extern global::System.IntPtr new_FdmHestonFwdOp__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonFwdOp")]
  public static extern void delete_FdmHestonFwdOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TripleBandLinearOp")]
  public static extern global::System.IntPtr new_TripleBandLinearOp(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_apply")]
  public static extern global::System.IntPtr TripleBandLinearOp_apply(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_solve_splitting__SWIG_0")]
  public static extern global::System.IntPtr TripleBandLinearOp_solve_splitting__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_solve_splitting__SWIG_1")]
  public static extern global::System.IntPtr TripleBandLinearOp_solve_splitting__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_mult")]
  public static extern global::System.IntPtr TripleBandLinearOp_mult(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_multR")]
  public static extern global::System.IntPtr TripleBandLinearOp_multR(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_add__SWIG_0")]
  public static extern global::System.IntPtr TripleBandLinearOp_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_add__SWIG_1")]
  public static extern global::System.IntPtr TripleBandLinearOp_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_axpyb")]
  public static extern void TripleBandLinearOp_axpyb(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_swap")]
  public static extern void TripleBandLinearOp_swap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TripleBandLinearOp")]
  public static extern void delete_TripleBandLinearOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FirstDerivativeOp")]
  public static extern global::System.IntPtr new_FirstDerivativeOp(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FirstDerivativeOp")]
  public static extern void delete_FirstDerivativeOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SecondDerivativeOp")]
  public static extern global::System.IntPtr new_SecondDerivativeOp(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SecondDerivativeOp")]
  public static extern void delete_SecondDerivativeOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NinePointLinearOp")]
  public static extern global::System.IntPtr new_NinePointLinearOp(uint jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NinePointLinearOp")]
  public static extern void delete_NinePointLinearOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SecondOrderMixedDerivativeOp")]
  public static extern global::System.IntPtr new_SecondOrderMixedDerivativeOp(uint jarg1, uint jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SecondOrderMixedDerivativeOp")]
  public static extern void delete_SecondOrderMixedDerivativeOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NthOrderDerivativeOp")]
  public static extern global::System.IntPtr new_NthOrderDerivativeOp(uint jarg1, uint jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NthOrderDerivativeOp")]
  public static extern void delete_NthOrderDerivativeOp(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CraigSneydScheme__SWIG_0")]
  public static extern global::System.IntPtr new_CraigSneydScheme__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CraigSneydScheme__SWIG_1")]
  public static extern global::System.IntPtr new_CraigSneydScheme__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CraigSneydScheme_step")]
  public static extern void CraigSneydScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CraigSneydScheme_setStep")]
  public static extern void CraigSneydScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CraigSneydScheme")]
  public static extern void delete_CraigSneydScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ImplicitEulerScheme__SWIG_0")]
  public static extern global::System.IntPtr new_ImplicitEulerScheme__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ImplicitEulerScheme__SWIG_1")]
  public static extern global::System.IntPtr new_ImplicitEulerScheme__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ImplicitEulerScheme__SWIG_2")]
  public static extern global::System.IntPtr new_ImplicitEulerScheme__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ImplicitEulerScheme__SWIG_3")]
  public static extern global::System.IntPtr new_ImplicitEulerScheme__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ImplicitEulerScheme_step")]
  public static extern void ImplicitEulerScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ImplicitEulerScheme_setStep")]
  public static extern void ImplicitEulerScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ImplicitEulerScheme_numberOfIterations")]
  public static extern uint ImplicitEulerScheme_numberOfIterations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ImplicitEulerScheme")]
  public static extern void delete_ImplicitEulerScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CrankNicolsonScheme__SWIG_0")]
  public static extern global::System.IntPtr new_CrankNicolsonScheme__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, int jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CrankNicolsonScheme__SWIG_1")]
  public static extern global::System.IntPtr new_CrankNicolsonScheme__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CrankNicolsonScheme__SWIG_2")]
  public static extern global::System.IntPtr new_CrankNicolsonScheme__SWIG_2(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CrankNicolsonScheme__SWIG_3")]
  public static extern global::System.IntPtr new_CrankNicolsonScheme__SWIG_3(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CrankNicolsonScheme_step")]
  public static extern void CrankNicolsonScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CrankNicolsonScheme_setStep")]
  public static extern void CrankNicolsonScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CrankNicolsonScheme_numberOfIterations")]
  public static extern uint CrankNicolsonScheme_numberOfIterations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CrankNicolsonScheme")]
  public static extern void delete_CrankNicolsonScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DouglasScheme__SWIG_0")]
  public static extern global::System.IntPtr new_DouglasScheme__SWIG_0(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DouglasScheme__SWIG_1")]
  public static extern global::System.IntPtr new_DouglasScheme__SWIG_1(double jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DouglasScheme_step")]
  public static extern void DouglasScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DouglasScheme_setStep")]
  public static extern void DouglasScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DouglasScheme")]
  public static extern void delete_DouglasScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExplicitEulerScheme__SWIG_0")]
  public static extern global::System.IntPtr new_ExplicitEulerScheme__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExplicitEulerScheme__SWIG_1")]
  public static extern global::System.IntPtr new_ExplicitEulerScheme__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExplicitEulerScheme_step")]
  public static extern void ExplicitEulerScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExplicitEulerScheme_setStep")]
  public static extern void ExplicitEulerScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExplicitEulerScheme")]
  public static extern void delete_ExplicitEulerScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HundsdorferScheme__SWIG_0")]
  public static extern global::System.IntPtr new_HundsdorferScheme__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HundsdorferScheme__SWIG_1")]
  public static extern global::System.IntPtr new_HundsdorferScheme__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HundsdorferScheme_step")]
  public static extern void HundsdorferScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HundsdorferScheme_setStep")]
  public static extern void HundsdorferScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HundsdorferScheme")]
  public static extern void delete_HundsdorferScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MethodOfLinesScheme__SWIG_0")]
  public static extern global::System.IntPtr new_MethodOfLinesScheme__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MethodOfLinesScheme__SWIG_1")]
  public static extern global::System.IntPtr new_MethodOfLinesScheme__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MethodOfLinesScheme_step")]
  public static extern void MethodOfLinesScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MethodOfLinesScheme_setStep")]
  public static extern void MethodOfLinesScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MethodOfLinesScheme")]
  public static extern void delete_MethodOfLinesScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ModifiedCraigSneydScheme__SWIG_0")]
  public static extern global::System.IntPtr new_ModifiedCraigSneydScheme__SWIG_0(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ModifiedCraigSneydScheme__SWIG_1")]
  public static extern global::System.IntPtr new_ModifiedCraigSneydScheme__SWIG_1(double jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ModifiedCraigSneydScheme_step")]
  public static extern void ModifiedCraigSneydScheme_step(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ModifiedCraigSneydScheme_setStep")]
  public static extern void ModifiedCraigSneydScheme_setStep(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ModifiedCraigSneydScheme")]
  public static extern void delete_ModifiedCraigSneydScheme(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepCondition_applyTo")]
  public static extern void FdmStepCondition_applyTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmStepCondition")]
  public static extern void delete_FdmStepCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionProxy")]
  public static extern global::System.IntPtr new_FdmStepConditionProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmStepConditionProxy")]
  public static extern void delete_FdmStepConditionProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmStepConditionDelegate")]
  public static extern void delete_FdmStepConditionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionDelegate_applyTo")]
  public static extern void FdmStepConditionDelegate_applyTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionDelegate_applyToSwigExplicitFdmStepConditionDelegate")]
  public static extern void FdmStepConditionDelegate_applyToSwigExplicitFdmStepConditionDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionDelegate")]
  public static extern global::System.IntPtr new_FdmStepConditionDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionDelegate_director_connect")]
  public static extern void FdmStepConditionDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, FdmStepConditionDelegate.SwigDelegateFdmStepConditionDelegate_0 delegate0);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculator_innerValue")]
  public static extern double FdmInnerValueCalculator_innerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculator_avgInnerValue")]
  public static extern double FdmInnerValueCalculator_avgInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmInnerValueCalculator")]
  public static extern void delete_FdmInnerValueCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmInnerValueCalculatorProxy")]
  public static extern global::System.IntPtr new_FdmInnerValueCalculatorProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmInnerValueCalculatorProxy")]
  public static extern void delete_FdmInnerValueCalculatorProxy(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmInnerValueCalculatorDelegate")]
  public static extern void delete_FdmInnerValueCalculatorDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorDelegate_innerValue")]
  public static extern double FdmInnerValueCalculatorDelegate_innerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorDelegate_innerValueSwigExplicitFdmInnerValueCalculatorDelegate")]
  public static extern double FdmInnerValueCalculatorDelegate_innerValueSwigExplicitFdmInnerValueCalculatorDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorDelegate_avgInnerValue")]
  public static extern double FdmInnerValueCalculatorDelegate_avgInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorDelegate_avgInnerValueSwigExplicitFdmInnerValueCalculatorDelegate")]
  public static extern double FdmInnerValueCalculatorDelegate_avgInnerValueSwigExplicitFdmInnerValueCalculatorDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmInnerValueCalculatorDelegate")]
  public static extern global::System.IntPtr new_FdmInnerValueCalculatorDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorDelegate_director_connect")]
  public static extern void FdmInnerValueCalculatorDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, FdmInnerValueCalculatorDelegate.SwigDelegateFdmInnerValueCalculatorDelegate_0 delegate0, FdmInnerValueCalculatorDelegate.SwigDelegateFdmInnerValueCalculatorDelegate_1 delegate1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCellAveragingInnerValue__SWIG_0")]
  public static extern global::System.IntPtr new_FdmCellAveragingInnerValue__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmCellAveragingInnerValue__SWIG_1")]
  public static extern global::System.IntPtr new_FdmCellAveragingInnerValue__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmCellAveragingInnerValue")]
  public static extern void delete_FdmCellAveragingInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLogInnerValue")]
  public static extern global::System.IntPtr new_FdmLogInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLogInnerValue")]
  public static extern void delete_FdmLogInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmLogBasketInnerValue")]
  public static extern global::System.IntPtr new_FdmLogBasketInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmLogBasketInnerValue")]
  public static extern void delete_FdmLogBasketInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmZeroInnerValue")]
  public static extern global::System.IntPtr new_FdmZeroInnerValue();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmZeroInnerValue")]
  public static extern void delete_FdmZeroInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeToDateMap__SWIG_0")]
  public static extern global::System.IntPtr new_TimeToDateMap__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TimeToDateMap__SWIG_1")]
  public static extern global::System.IntPtr new_TimeToDateMap__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_size")]
  public static extern uint TimeToDateMap_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_empty")]
  public static extern bool TimeToDateMap_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_Clear")]
  public static extern void TimeToDateMap_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_getitem")]
  public static extern global::System.IntPtr TimeToDateMap_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_setitem")]
  public static extern void TimeToDateMap_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_ContainsKey")]
  public static extern bool TimeToDateMap_ContainsKey(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_Add")]
  public static extern void TimeToDateMap_Add(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_Remove")]
  public static extern bool TimeToDateMap_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_create_iterator_begin")]
  public static extern global::System.IntPtr TimeToDateMap_create_iterator_begin(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_get_next_key")]
  public static extern double TimeToDateMap_get_next_key(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.IntPtr jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TimeToDateMap_destroy_iterator")]
  public static extern void TimeToDateMap_destroy_iterator(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.IntPtr jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TimeToDateMap")]
  public static extern void delete_TimeToDateMap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmAffineG2ModelSwapInnerValue")]
  public static extern global::System.IntPtr new_FdmAffineG2ModelSwapInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmAffineG2ModelSwapInnerValue")]
  public static extern void delete_FdmAffineG2ModelSwapInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmAffineHullWhiteModelSwapInnerValue")]
  public static extern global::System.IntPtr new_FdmAffineHullWhiteModelSwapInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmAffineHullWhiteModelSwapInnerValue")]
  public static extern void delete_FdmAffineHullWhiteModelSwapInnerValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSnapshotCondition")]
  public static extern global::System.IntPtr new_FdmSnapshotCondition(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSnapshotCondition_getTime")]
  public static extern double FdmSnapshotCondition_getTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSnapshotCondition_getValues")]
  public static extern global::System.IntPtr FdmSnapshotCondition_getValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSnapshotCondition")]
  public static extern void delete_FdmSnapshotCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Clear")]
  public static extern void FdmStepConditionVector_Clear(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Add")]
  public static extern void FdmStepConditionVector_Add(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_size")]
  public static extern uint FdmStepConditionVector_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_capacity")]
  public static extern uint FdmStepConditionVector_capacity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_reserve")]
  public static extern void FdmStepConditionVector_reserve(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionVector__SWIG_0")]
  public static extern global::System.IntPtr new_FdmStepConditionVector__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionVector__SWIG_1")]
  public static extern global::System.IntPtr new_FdmStepConditionVector__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionVector__SWIG_2")]
  public static extern global::System.IntPtr new_FdmStepConditionVector__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_getitemcopy")]
  public static extern global::System.IntPtr FdmStepConditionVector_getitemcopy(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_getitem")]
  public static extern global::System.IntPtr FdmStepConditionVector_getitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_setitem")]
  public static extern void FdmStepConditionVector_setitem(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_AddRange")]
  public static extern void FdmStepConditionVector_AddRange(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_GetRange")]
  public static extern global::System.IntPtr FdmStepConditionVector_GetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Insert")]
  public static extern void FdmStepConditionVector_Insert(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_InsertRange")]
  public static extern void FdmStepConditionVector_InsertRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_RemoveAt")]
  public static extern void FdmStepConditionVector_RemoveAt(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_RemoveRange")]
  public static extern void FdmStepConditionVector_RemoveRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Repeat")]
  public static extern global::System.IntPtr FdmStepConditionVector_Repeat(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Reverse__SWIG_0")]
  public static extern void FdmStepConditionVector_Reverse__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Reverse__SWIG_1")]
  public static extern void FdmStepConditionVector_Reverse__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_SetRange")]
  public static extern void FdmStepConditionVector_SetRange(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Contains")]
  public static extern bool FdmStepConditionVector_Contains(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_IndexOf")]
  public static extern int FdmStepConditionVector_IndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_LastIndexOf")]
  public static extern int FdmStepConditionVector_LastIndexOf(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionVector_Remove")]
  public static extern bool FdmStepConditionVector_Remove(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmStepConditionVector")]
  public static extern void delete_FdmStepConditionVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmStepConditionComposite")]
  public static extern global::System.IntPtr new_FdmStepConditionComposite(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionComposite_stoppingTimes")]
  public static extern global::System.IntPtr FdmStepConditionComposite_stoppingTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionComposite_conditions")]
  public static extern global::System.IntPtr FdmStepConditionComposite_conditions(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionComposite_joinConditions")]
  public static extern global::System.IntPtr FdmStepConditionComposite_joinConditions(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionComposite_vanillaComposite")]
  public static extern global::System.IntPtr FdmStepConditionComposite_vanillaComposite(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmStepConditionComposite")]
  public static extern void delete_FdmStepConditionComposite(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmAmericanStepCondition")]
  public static extern global::System.IntPtr new_FdmAmericanStepCondition(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmAmericanStepCondition")]
  public static extern void delete_FdmAmericanStepCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmArithmeticAverageCondition")]
  public static extern global::System.IntPtr new_FdmArithmeticAverageCondition(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmArithmeticAverageCondition")]
  public static extern void delete_FdmArithmeticAverageCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBermudanStepCondition")]
  public static extern global::System.IntPtr new_FdmBermudanStepCondition(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBermudanStepCondition_exerciseTimes")]
  public static extern global::System.IntPtr FdmBermudanStepCondition_exerciseTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBermudanStepCondition")]
  public static extern void delete_FdmBermudanStepCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleStorageCondition")]
  public static extern global::System.IntPtr new_FdmSimpleStorageCondition(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSimpleStorageCondition")]
  public static extern void delete_FdmSimpleStorageCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleSwingCondition__SWIG_0")]
  public static extern global::System.IntPtr new_FdmSimpleSwingCondition__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSimpleSwingCondition__SWIG_1")]
  public static extern global::System.IntPtr new_FdmSimpleSwingCondition__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, uint jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSimpleSwingCondition")]
  public static extern void delete_FdmSimpleSwingCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmDividendHandler")]
  public static extern global::System.IntPtr new_FdmDividendHandler(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDividendHandler_dividendTimes")]
  public static extern global::System.IntPtr FdmDividendHandler_dividendTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDividendHandler_dividendDates")]
  public static extern global::System.IntPtr FdmDividendHandler_dividendDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDividendHandler_dividends")]
  public static extern global::System.IntPtr FdmDividendHandler_dividends(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmDividendHandler")]
  public static extern void delete_FdmDividendHandler(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmSolverDesc")]
  public static extern global::System.IntPtr new_FdmSolverDesc(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, uint jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getMesher")]
  public static extern global::System.IntPtr FdmSolverDesc_getMesher(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getBcSet")]
  public static extern global::System.IntPtr FdmSolverDesc_getBcSet(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getStepConditions")]
  public static extern global::System.IntPtr FdmSolverDesc_getStepConditions(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getCalculator")]
  public static extern global::System.IntPtr FdmSolverDesc_getCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getMaturity")]
  public static extern double FdmSolverDesc_getMaturity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getTimeSteps")]
  public static extern uint FdmSolverDesc_getTimeSteps(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSolverDesc_getDampingSteps")]
  public static extern uint FdmSolverDesc_getDampingSteps(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmSolverDesc")]
  public static extern void delete_FdmSolverDesc(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm1DimSolver")]
  public static extern global::System.IntPtr new_Fdm1DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1DimSolver_interpolateAt")]
  public static extern double Fdm1DimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1DimSolver_thetaAt")]
  public static extern double Fdm1DimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1DimSolver_derivativeX")]
  public static extern double Fdm1DimSolver_derivativeX(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm1DimSolver_derivativeXX")]
  public static extern double Fdm1DimSolver_derivativeXX(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm1DimSolver")]
  public static extern void delete_Fdm1DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmBackwardSolver")]
  public static extern global::System.IntPtr new_FdmBackwardSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBackwardSolver_rollback")]
  public static extern void FdmBackwardSolver_rollback(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmBackwardSolver")]
  public static extern void delete_FdmBackwardSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesSolver__SWIG_0")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesSolver__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesSolver__SWIG_1")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesSolver__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, bool jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesSolver__SWIG_2")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesSolver__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2dBlackScholesSolver__SWIG_3")]
  public static extern global::System.IntPtr new_Fdm2dBlackScholesSolver__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_valueAt")]
  public static extern double Fdm2dBlackScholesSolver_valueAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_thetaAt")]
  public static extern double Fdm2dBlackScholesSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_deltaXat")]
  public static extern double Fdm2dBlackScholesSolver_deltaXat(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_deltaYat")]
  public static extern double Fdm2dBlackScholesSolver_deltaYat(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_gammaXat")]
  public static extern double Fdm2dBlackScholesSolver_gammaXat(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_gammaYat")]
  public static extern double Fdm2dBlackScholesSolver_gammaYat(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesSolver_gammaXYat")]
  public static extern double Fdm2dBlackScholesSolver_gammaXYat(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm2dBlackScholesSolver")]
  public static extern void delete_Fdm2dBlackScholesSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm2DimSolver")]
  public static extern global::System.IntPtr new_Fdm2DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_interpolateAt")]
  public static extern double Fdm2DimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_thetaAt")]
  public static extern double Fdm2DimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_derivativeX")]
  public static extern double Fdm2DimSolver_derivativeX(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_derivativeY")]
  public static extern double Fdm2DimSolver_derivativeY(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_derivativeXX")]
  public static extern double Fdm2DimSolver_derivativeXX(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_derivativeYY")]
  public static extern double Fdm2DimSolver_derivativeYY(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2DimSolver_derivativeXY")]
  public static extern double Fdm2DimSolver_derivativeXY(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm2DimSolver")]
  public static extern void delete_Fdm2DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm3DimSolver")]
  public static extern global::System.IntPtr new_Fdm3DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm3DimSolver_performCalculations")]
  public static extern void Fdm3DimSolver_performCalculations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm3DimSolver_interpolateAt")]
  public static extern double Fdm3DimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm3DimSolver_thetaAt")]
  public static extern double Fdm3DimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm3DimSolver")]
  public static extern void delete_Fdm3DimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmG2Solver__SWIG_0")]
  public static extern global::System.IntPtr new_FdmG2Solver__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmG2Solver__SWIG_1")]
  public static extern global::System.IntPtr new_FdmG2Solver__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmG2Solver_valueAt")]
  public static extern double FdmG2Solver_valueAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmG2Solver")]
  public static extern void delete_FdmG2Solver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonHullWhiteSolver__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonHullWhiteSolver__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonHullWhiteSolver__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonHullWhiteSolver__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonHullWhiteSolver_valueAt")]
  public static extern double FdmHestonHullWhiteSolver_valueAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonHullWhiteSolver_thetaAt")]
  public static extern double FdmHestonHullWhiteSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonHullWhiteSolver_deltaAt")]
  public static extern double FdmHestonHullWhiteSolver_deltaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonHullWhiteSolver_gammaAt")]
  public static extern double FdmHestonHullWhiteSolver_gammaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonHullWhiteSolver")]
  public static extern void delete_FdmHestonHullWhiteSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonSolver__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHestonSolver__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonSolver__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHestonSolver__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonSolver__SWIG_2")]
  public static extern global::System.IntPtr new_FdmHestonSolver__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHestonSolver__SWIG_3")]
  public static extern global::System.IntPtr new_FdmHestonSolver__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_valueAt")]
  public static extern double FdmHestonSolver_valueAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_thetaAt")]
  public static extern double FdmHestonSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_deltaAt")]
  public static extern double FdmHestonSolver_deltaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_gammaAt")]
  public static extern double FdmHestonSolver_gammaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_meanVarianceDeltaAt")]
  public static extern double FdmHestonSolver_meanVarianceDeltaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonSolver_meanVarianceGammaAt")]
  public static extern double FdmHestonSolver_meanVarianceGammaAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonSolver")]
  public static extern void delete_FdmHestonSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHullWhiteSolver__SWIG_0")]
  public static extern global::System.IntPtr new_FdmHullWhiteSolver__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmHullWhiteSolver__SWIG_1")]
  public static extern global::System.IntPtr new_FdmHullWhiteSolver__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHullWhiteSolver_valueAt")]
  public static extern double FdmHullWhiteSolver_valueAt(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHullWhiteSolver")]
  public static extern void delete_FdmHullWhiteSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm4dimSolver")]
  public static extern global::System.IntPtr new_Fdm4dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm4dimSolver_interpolateAt")]
  public static extern double Fdm4dimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm4dimSolver_thetaAt")]
  public static extern double Fdm4dimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm4dimSolver")]
  public static extern void delete_Fdm4dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm5dimSolver")]
  public static extern global::System.IntPtr new_Fdm5dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm5dimSolver_interpolateAt")]
  public static extern double Fdm5dimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm5dimSolver_thetaAt")]
  public static extern double Fdm5dimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm5dimSolver")]
  public static extern void delete_Fdm5dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Fdm6dimSolver")]
  public static extern global::System.IntPtr new_Fdm6dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm6dimSolver_interpolateAt")]
  public static extern double Fdm6dimSolver_interpolateAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm6dimSolver_thetaAt")]
  public static extern double Fdm6dimSolver_thetaAt(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Fdm6dimSolver")]
  public static extern void delete_Fdm6dimSolver(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FdmIndicesOnBoundary")]
  public static extern global::System.IntPtr new_FdmIndicesOnBoundary(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmIndicesOnBoundary_getIndices")]
  public static extern global::System.IntPtr FdmIndicesOnBoundary_getIndices(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmIndicesOnBoundary")]
  public static extern void delete_FdmIndicesOnBoundary(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskNeutralDensityCalculator_pdf")]
  public static extern double RiskNeutralDensityCalculator_pdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskNeutralDensityCalculator_cdf")]
  public static extern double RiskNeutralDensityCalculator_cdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskNeutralDensityCalculator_invcdf")]
  public static extern double RiskNeutralDensityCalculator_invcdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RiskNeutralDensityCalculator")]
  public static extern void delete_RiskNeutralDensityCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BSMRNDCalculator")]
  public static extern global::System.IntPtr new_BSMRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BSMRNDCalculator")]
  public static extern void delete_BSMRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CEVRNDCalculator")]
  public static extern global::System.IntPtr new_CEVRNDCalculator(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CEVRNDCalculator_massAtZero")]
  public static extern double CEVRNDCalculator_massAtZero(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CEVRNDCalculator")]
  public static extern void delete_CEVRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GBSMRNDCalculator")]
  public static extern global::System.IntPtr new_GBSMRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GBSMRNDCalculator")]
  public static extern void delete_GBSMRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonRNDCalculator__SWIG_0")]
  public static extern global::System.IntPtr new_HestonRNDCalculator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonRNDCalculator__SWIG_1")]
  public static extern global::System.IntPtr new_HestonRNDCalculator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonRNDCalculator__SWIG_2")]
  public static extern global::System.IntPtr new_HestonRNDCalculator__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonRNDCalculator")]
  public static extern void delete_HestonRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_0")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, double jarg7, double jarg8, uint jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_1")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, double jarg7, double jarg8, uint jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_2")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_3")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_4")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_5")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LocalVolRNDCalculator__SWIG_6")]
  public static extern global::System.IntPtr new_LocalVolRNDCalculator__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolRNDCalculator_mesher")]
  public static extern global::System.IntPtr LocalVolRNDCalculator_mesher(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolRNDCalculator_rescaleTimeSteps")]
  public static extern global::System.IntPtr LocalVolRNDCalculator_rescaleTimeSteps(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LocalVolRNDCalculator")]
  public static extern void delete_LocalVolRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SquareRootProcessRNDCalculator")]
  public static extern global::System.IntPtr new_SquareRootProcessRNDCalculator(double jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SquareRootProcessRNDCalculator_stationary_pdf")]
  public static extern double SquareRootProcessRNDCalculator_stationary_pdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SquareRootProcessRNDCalculator_stationary_cdf")]
  public static extern double SquareRootProcessRNDCalculator_stationary_cdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SquareRootProcessRNDCalculator_stationary_invcdf")]
  public static extern double SquareRootProcessRNDCalculator_stationary_invcdf(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SquareRootProcessRNDCalculator")]
  public static extern void delete_SquareRootProcessRNDCalculator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FittingMethod")]
  public static extern void delete_FittingMethod(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_size")]
  public static extern uint FittingMethod_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_solution")]
  public static extern global::System.IntPtr FittingMethod_solution(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_numberOfIterations")]
  public static extern int FittingMethod_numberOfIterations(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_minimumCostValue")]
  public static extern double FittingMethod_minimumCostValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_constrainAtZero")]
  public static extern bool FittingMethod_constrainAtZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittingMethod_weights")]
  public static extern global::System.IntPtr FittingMethod_weights(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_0")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_1")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_2")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_3")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_4")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_4(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_5")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_6")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, uint jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_7")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_8")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FittedBondDiscountCurve__SWIG_9")]
  public static extern global::System.IntPtr new_FittedBondDiscountCurve__SWIG_9(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittedBondDiscountCurve_fitResults")]
  public static extern global::System.IntPtr FittedBondDiscountCurve_fitResults(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FittedBondDiscountCurve")]
  public static extern void delete_FittedBondDiscountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialSplinesFitting__SWIG_0")]
  public static extern global::System.IntPtr new_ExponentialSplinesFitting__SWIG_0(bool jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialSplinesFitting__SWIG_1")]
  public static extern global::System.IntPtr new_ExponentialSplinesFitting__SWIG_1(bool jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ExponentialSplinesFitting__SWIG_2")]
  public static extern global::System.IntPtr new_ExponentialSplinesFitting__SWIG_2();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ExponentialSplinesFitting")]
  public static extern void delete_ExponentialSplinesFitting(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NelsonSiegelFitting__SWIG_0")]
  public static extern global::System.IntPtr new_NelsonSiegelFitting__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NelsonSiegelFitting__SWIG_1")]
  public static extern global::System.IntPtr new_NelsonSiegelFitting__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NelsonSiegelFitting")]
  public static extern void delete_NelsonSiegelFitting(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SvenssonFitting__SWIG_0")]
  public static extern global::System.IntPtr new_SvenssonFitting__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SvenssonFitting__SWIG_1")]
  public static extern global::System.IntPtr new_SvenssonFitting__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SvenssonFitting")]
  public static extern void delete_SvenssonFitting(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicBSplinesFitting__SWIG_0")]
  public static extern global::System.IntPtr new_CubicBSplinesFitting__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicBSplinesFitting__SWIG_1")]
  public static extern global::System.IntPtr new_CubicBSplinesFitting__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicBSplinesFitting__SWIG_2")]
  public static extern global::System.IntPtr new_CubicBSplinesFitting__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicBSplinesFitting_basisFunction")]
  public static extern double CubicBSplinesFitting_basisFunction(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CubicBSplinesFitting")]
  public static extern void delete_CubicBSplinesFitting(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimplePolynomialFitting__SWIG_0")]
  public static extern global::System.IntPtr new_SimplePolynomialFitting__SWIG_0(uint jarg1, bool jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimplePolynomialFitting__SWIG_1")]
  public static extern global::System.IntPtr new_SimplePolynomialFitting__SWIG_1(uint jarg1, bool jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimplePolynomialFitting__SWIG_2")]
  public static extern global::System.IntPtr new_SimplePolynomialFitting__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SimplePolynomialFitting")]
  public static extern void delete_SimplePolynomialFitting(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardCurve__SWIG_0")]
  public static extern global::System.IntPtr new_ForwardCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardCurve__SWIG_1")]
  public static extern global::System.IntPtr new_ForwardCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardCurve__SWIG_2")]
  public static extern global::System.IntPtr new_ForwardCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardCurve_dates")]
  public static extern global::System.IntPtr ForwardCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardCurve_forwards")]
  public static extern global::System.IntPtr ForwardCurve_forwards(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardCurve_nodes")]
  public static extern global::System.IntPtr ForwardCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardCurve")]
  public static extern void delete_ForwardCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_settlementDate")]
  public static extern global::System.IntPtr Forward_settlementDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_isExpired")]
  public static extern bool Forward_isExpired(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_calendar")]
  public static extern global::System.IntPtr Forward_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_businessDayConvention")]
  public static extern int Forward_businessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_dayCounter")]
  public static extern global::System.IntPtr Forward_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_discountCurve")]
  public static extern global::System.IntPtr Forward_discountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_incomeDiscountCurve")]
  public static extern global::System.IntPtr Forward_incomeDiscountCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_spotValue")]
  public static extern double Forward_spotValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_spotIncome")]
  public static extern double Forward_spotIncome(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_forwardValue")]
  public static extern double Forward_forwardValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_impliedYield")]
  public static extern global::System.IntPtr Forward_impliedYield(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, int jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Forward")]
  public static extern void delete_Forward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondForward__SWIG_0")]
  public static extern global::System.IntPtr new_FixedRateBondForward__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10, global::System.Runtime.InteropServices.HandleRef jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondForward__SWIG_1")]
  public static extern global::System.IntPtr new_FixedRateBondForward__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, global::System.Runtime.InteropServices.HandleRef jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FixedRateBondForward__SWIG_2")]
  public static extern global::System.IntPtr new_FixedRateBondForward__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBondForward_forwardPrice")]
  public static extern double FixedRateBondForward_forwardPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBondForward_cleanForwardPrice")]
  public static extern double FixedRateBondForward_cleanForwardPrice(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FixedRateBondForward")]
  public static extern void delete_FixedRateBondForward(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Position")]
  public static extern global::System.IntPtr new_Position();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Position")]
  public static extern void delete_Position(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardRateAgreement__SWIG_0")]
  public static extern global::System.IntPtr new_ForwardRateAgreement__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardRateAgreement__SWIG_1")]
  public static extern global::System.IntPtr new_ForwardRateAgreement__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ForwardRateAgreement__SWIG_2")]
  public static extern global::System.IntPtr new_ForwardRateAgreement__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, double jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardRateAgreement_fixingDate")]
  public static extern global::System.IntPtr ForwardRateAgreement_fixingDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardRateAgreement_spotIncome")]
  public static extern double ForwardRateAgreement_spotIncome(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardRateAgreement_spotValue")]
  public static extern double ForwardRateAgreement_spotValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardRateAgreement_forwardRate")]
  public static extern global::System.IntPtr ForwardRateAgreement_forwardRate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ForwardRateAgreement")]
  public static extern void delete_ForwardRateAgreement(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_stateProcess")]
  public static extern global::System.IntPtr Gaussian1dModel_stateProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_0")]
  public static extern double Gaussian1dModel_numeraire__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_1")]
  public static extern double Gaussian1dModel_numeraire__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_2")]
  public static extern double Gaussian1dModel_numeraire__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_0")]
  public static extern double Gaussian1dModel_zerobond__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_1")]
  public static extern double Gaussian1dModel_zerobond__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_2")]
  public static extern double Gaussian1dModel_zerobond__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_3")]
  public static extern double Gaussian1dModel_zerobond__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_3")]
  public static extern double Gaussian1dModel_numeraire__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_4")]
  public static extern double Gaussian1dModel_numeraire__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_numeraire__SWIG_5")]
  public static extern double Gaussian1dModel_numeraire__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_4")]
  public static extern double Gaussian1dModel_zerobond__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_5")]
  public static extern double Gaussian1dModel_zerobond__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_6")]
  public static extern double Gaussian1dModel_zerobond__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobond__SWIG_7")]
  public static extern double Gaussian1dModel_zerobond__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_0")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, uint jarg11, bool jarg12, bool jarg13);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_1")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, uint jarg11, bool jarg12);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_2")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10, uint jarg11);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_3")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_4")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_5")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_6")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_zerobondOption__SWIG_7")]
  public static extern double Gaussian1dModel_zerobondOption__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, double jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_forwardRate__SWIG_0")]
  public static extern double Gaussian1dModel_forwardRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_forwardRate__SWIG_1")]
  public static extern double Gaussian1dModel_forwardRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_forwardRate__SWIG_2")]
  public static extern double Gaussian1dModel_forwardRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_forwardRate__SWIG_3")]
  public static extern double Gaussian1dModel_forwardRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapRate__SWIG_0")]
  public static extern double Gaussian1dModel_swapRate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapRate__SWIG_1")]
  public static extern double Gaussian1dModel_swapRate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapRate__SWIG_2")]
  public static extern double Gaussian1dModel_swapRate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapRate__SWIG_3")]
  public static extern double Gaussian1dModel_swapRate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapAnnuity__SWIG_0")]
  public static extern double Gaussian1dModel_swapAnnuity__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapAnnuity__SWIG_1")]
  public static extern double Gaussian1dModel_swapAnnuity__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapAnnuity__SWIG_2")]
  public static extern double Gaussian1dModel_swapAnnuity__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_swapAnnuity__SWIG_3")]
  public static extern double Gaussian1dModel_swapAnnuity__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gaussian1dModel")]
  public static extern void delete_Gaussian1dModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gsr__SWIG_0")]
  public static extern global::System.IntPtr new_Gsr__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gsr__SWIG_1")]
  public static extern global::System.IntPtr new_Gsr__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrateVolatilitiesIterative__SWIG_0")]
  public static extern void Gsr_calibrateVolatilitiesIterative__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrateVolatilitiesIterative__SWIG_1")]
  public static extern void Gsr_calibrateVolatilitiesIterative__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrateVolatilitiesIterative__SWIG_2")]
  public static extern void Gsr_calibrateVolatilitiesIterative__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_reversion")]
  public static extern global::System.IntPtr Gsr_reversion(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_volatility")]
  public static extern global::System.IntPtr Gsr_volatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_parameters")]
  public static extern global::System.IntPtr Gsr_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrate__SWIG_0")]
  public static extern void Gsr_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrate__SWIG_1")]
  public static extern void Gsr_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrate__SWIG_2")]
  public static extern void Gsr_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_calibrate__SWIG_3")]
  public static extern void Gsr_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_setParams")]
  public static extern void Gsr_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_value")]
  public static extern double Gsr_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_constraint")]
  public static extern global::System.IntPtr Gsr_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_endCriteria")]
  public static extern int Gsr_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_problemValues")]
  public static extern global::System.IntPtr Gsr_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_functionEvaluation")]
  public static extern int Gsr_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gsr")]
  public static extern void delete_Gsr(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctional__SWIG_0")]
  public static extern global::System.IntPtr new_MarkovFunctional__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctional__SWIG_1")]
  public static extern global::System.IntPtr new_MarkovFunctional__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctional__SWIG_2")]
  public static extern global::System.IntPtr new_MarkovFunctional__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctional__SWIG_3")]
  public static extern global::System.IntPtr new_MarkovFunctional__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_volatility")]
  public static extern global::System.IntPtr MarkovFunctional_volatility(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_calibrate__SWIG_0")]
  public static extern void MarkovFunctional_calibrate__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_calibrate__SWIG_1")]
  public static extern void MarkovFunctional_calibrate__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_calibrate__SWIG_2")]
  public static extern void MarkovFunctional_calibrate__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_calibrate__SWIG_3")]
  public static extern void MarkovFunctional_calibrate__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_parameters")]
  public static extern global::System.IntPtr MarkovFunctional_parameters(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_setParams")]
  public static extern void MarkovFunctional_setParams(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_value")]
  public static extern double MarkovFunctional_value(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_constraint")]
  public static extern global::System.IntPtr MarkovFunctional_constraint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_endCriteria")]
  public static extern int MarkovFunctional_endCriteria(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_problemValues")]
  public static extern global::System.IntPtr MarkovFunctional_problemValues(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_functionEvaluation")]
  public static extern int MarkovFunctional_functionEvaluation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MarkovFunctional")]
  public static extern void delete_MarkovFunctional(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctionalSettings__SWIG_0")]
  public static extern global::System.IntPtr new_MarkovFunctionalSettings__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctionalSettings__SWIG_1")]
  public static extern global::System.IntPtr new_MarkovFunctionalSettings__SWIG_1(uint jarg1, double jarg2, uint jarg3, double jarg4, double jarg5, double jarg6, double jarg7, int jarg8, global::System.Runtime.InteropServices.HandleRef jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MarkovFunctionalSettings__SWIG_2")]
  public static extern global::System.IntPtr new_MarkovFunctionalSettings__SWIG_2(uint jarg1, double jarg2, uint jarg3, double jarg4, double jarg5, double jarg6, double jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctionalSettings_validate")]
  public static extern void MarkovFunctionalSettings_validate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MarkovFunctionalSettings")]
  public static extern void delete_MarkovFunctionalSettings(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dSwaptionEngine__SWIG_6")]
  public static extern global::System.IntPtr new_Gaussian1dSwaptionEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gaussian1dSwaptionEngine")]
  public static extern void delete_Gaussian1dSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dJamshidianSwaptionEngine")]
  public static extern global::System.IntPtr new_Gaussian1dJamshidianSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gaussian1dJamshidianSwaptionEngine")]
  public static extern void delete_Gaussian1dJamshidianSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, int jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_6")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dNonstandardSwaptionEngine__SWIG_7")]
  public static extern global::System.IntPtr new_Gaussian1dNonstandardSwaptionEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gaussian1dNonstandardSwaptionEngine")]
  public static extern void delete_Gaussian1dNonstandardSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7, bool jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_4")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_5")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_6")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_7")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Gaussian1dFloatFloatSwaptionEngine__SWIG_8")]
  public static extern global::System.IntPtr new_Gaussian1dFloatFloatSwaptionEngine__SWIG_8(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Gaussian1dFloatFloatSwaptionEngine")]
  public static extern void delete_Gaussian1dFloatFloatSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SegmentIntegral")]
  public static extern global::System.IntPtr new_SegmentIntegral(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SegmentIntegral")]
  public static extern void delete_SegmentIntegral(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TrapezoidIntegralDefault")]
  public static extern global::System.IntPtr new_TrapezoidIntegralDefault(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TrapezoidIntegralDefault")]
  public static extern void delete_TrapezoidIntegralDefault(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TrapezoidIntegralMidPoint")]
  public static extern global::System.IntPtr new_TrapezoidIntegralMidPoint(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TrapezoidIntegralMidPoint")]
  public static extern void delete_TrapezoidIntegralMidPoint(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SimpsonIntegral")]
  public static extern global::System.IntPtr new_SimpsonIntegral(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SimpsonIntegral")]
  public static extern void delete_SimpsonIntegral(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussKronrodAdaptive__SWIG_0")]
  public static extern global::System.IntPtr new_GaussKronrodAdaptive__SWIG_0(double jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussKronrodAdaptive__SWIG_1")]
  public static extern global::System.IntPtr new_GaussKronrodAdaptive__SWIG_1(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussKronrodAdaptive")]
  public static extern void delete_GaussKronrodAdaptive(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussKronrodNonAdaptive")]
  public static extern global::System.IntPtr new_GaussKronrodNonAdaptive(double jarg1, uint jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussKronrodNonAdaptive")]
  public static extern void delete_GaussKronrodNonAdaptive(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLobattoIntegral__SWIG_0")]
  public static extern global::System.IntPtr new_GaussLobattoIntegral__SWIG_0(uint jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLobattoIntegral__SWIG_1")]
  public static extern global::System.IntPtr new_GaussLobattoIntegral__SWIG_1(uint jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLobattoIntegral__SWIG_2")]
  public static extern global::System.IntPtr new_GaussLobattoIntegral__SWIG_2(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussLobattoIntegral")]
  public static extern void delete_GaussLobattoIntegral(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLaguerreIntegration__SWIG_0")]
  public static extern global::System.IntPtr new_GaussLaguerreIntegration__SWIG_0(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLaguerreIntegration__SWIG_1")]
  public static extern global::System.IntPtr new_GaussLaguerreIntegration__SWIG_1(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussLaguerreIntegration")]
  public static extern void delete_GaussLaguerreIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussHermiteIntegration__SWIG_0")]
  public static extern global::System.IntPtr new_GaussHermiteIntegration__SWIG_0(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussHermiteIntegration__SWIG_1")]
  public static extern global::System.IntPtr new_GaussHermiteIntegration__SWIG_1(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussHermiteIntegration")]
  public static extern void delete_GaussHermiteIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussJacobiIntegration")]
  public static extern global::System.IntPtr new_GaussJacobiIntegration(uint jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussJacobiIntegration")]
  public static extern void delete_GaussJacobiIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussHyperbolicIntegration")]
  public static extern global::System.IntPtr new_GaussHyperbolicIntegration(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussHyperbolicIntegration")]
  public static extern void delete_GaussHyperbolicIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussLegendreIntegration")]
  public static extern global::System.IntPtr new_GaussLegendreIntegration(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussLegendreIntegration")]
  public static extern void delete_GaussLegendreIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussChebyshevIntegration")]
  public static extern global::System.IntPtr new_GaussChebyshevIntegration(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussChebyshevIntegration")]
  public static extern void delete_GaussChebyshevIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussChebyshev2ndIntegration")]
  public static extern global::System.IntPtr new_GaussChebyshev2ndIntegration(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussChebyshev2ndIntegration")]
  public static extern void delete_GaussChebyshev2ndIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussGegenbauerIntegration")]
  public static extern global::System.IntPtr new_GaussGegenbauerIntegration(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussGegenbauerIntegration")]
  public static extern void delete_GaussGegenbauerIntegration(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleNumber_value")]
  public static extern double SampleNumber_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleNumber_weight")]
  public static extern double SampleNumber_weight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SampleNumber")]
  public static extern void delete_SampleNumber(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleArray_value")]
  public static extern global::System.IntPtr SampleArray_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleArray_weight")]
  public static extern double SampleArray_weight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SampleArray")]
  public static extern void delete_SampleArray(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleRealVector_value")]
  public static extern global::System.IntPtr SampleRealVector_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleRealVector_weight")]
  public static extern double SampleRealVector_weight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SampleRealVector")]
  public static extern void delete_SampleRealVector(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LecuyerUniformRng__SWIG_0")]
  public static extern global::System.IntPtr new_LecuyerUniformRng__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LecuyerUniformRng__SWIG_1")]
  public static extern global::System.IntPtr new_LecuyerUniformRng__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LecuyerUniformRng_next")]
  public static extern global::System.IntPtr LecuyerUniformRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LecuyerUniformRng")]
  public static extern void delete_LecuyerUniformRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KnuthUniformRng__SWIG_0")]
  public static extern global::System.IntPtr new_KnuthUniformRng__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KnuthUniformRng__SWIG_1")]
  public static extern global::System.IntPtr new_KnuthUniformRng__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KnuthUniformRng_next")]
  public static extern global::System.IntPtr KnuthUniformRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KnuthUniformRng")]
  public static extern void delete_KnuthUniformRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MersenneTwisterUniformRng__SWIG_0")]
  public static extern global::System.IntPtr new_MersenneTwisterUniformRng__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MersenneTwisterUniformRng__SWIG_1")]
  public static extern global::System.IntPtr new_MersenneTwisterUniformRng__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MersenneTwisterUniformRng_next")]
  public static extern global::System.IntPtr MersenneTwisterUniformRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MersenneTwisterUniformRng")]
  public static extern void delete_MersenneTwisterUniformRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformRandomGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_UniformRandomGenerator__SWIG_0(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformRandomGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_UniformRandomGenerator__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformRandomGenerator_next")]
  public static extern global::System.IntPtr UniformRandomGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformRandomGenerator_nextValue")]
  public static extern double UniformRandomGenerator_nextValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UniformRandomGenerator")]
  public static extern void delete_UniformRandomGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CentralLimitLecuyerGaussianRng")]
  public static extern global::System.IntPtr new_CentralLimitLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CentralLimitLecuyerGaussianRng_next")]
  public static extern global::System.IntPtr CentralLimitLecuyerGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CentralLimitLecuyerGaussianRng")]
  public static extern void delete_CentralLimitLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CentralLimitKnuthGaussianRng")]
  public static extern global::System.IntPtr new_CentralLimitKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CentralLimitKnuthGaussianRng_next")]
  public static extern global::System.IntPtr CentralLimitKnuthGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CentralLimitKnuthGaussianRng")]
  public static extern void delete_CentralLimitKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CentralLimitMersenneTwisterGaussianRng")]
  public static extern global::System.IntPtr new_CentralLimitMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CentralLimitMersenneTwisterGaussianRng_next")]
  public static extern global::System.IntPtr CentralLimitMersenneTwisterGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CentralLimitMersenneTwisterGaussianRng")]
  public static extern void delete_CentralLimitMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoxMullerLecuyerGaussianRng")]
  public static extern global::System.IntPtr new_BoxMullerLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoxMullerLecuyerGaussianRng_next")]
  public static extern global::System.IntPtr BoxMullerLecuyerGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BoxMullerLecuyerGaussianRng")]
  public static extern void delete_BoxMullerLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoxMullerKnuthGaussianRng")]
  public static extern global::System.IntPtr new_BoxMullerKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoxMullerKnuthGaussianRng_next")]
  public static extern global::System.IntPtr BoxMullerKnuthGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BoxMullerKnuthGaussianRng")]
  public static extern void delete_BoxMullerKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BoxMullerMersenneTwisterGaussianRng")]
  public static extern global::System.IntPtr new_BoxMullerMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoxMullerMersenneTwisterGaussianRng_next")]
  public static extern global::System.IntPtr BoxMullerMersenneTwisterGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BoxMullerMersenneTwisterGaussianRng")]
  public static extern void delete_BoxMullerMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeLecuyerGaussianRng")]
  public static extern global::System.IntPtr new_MoroInvCumulativeLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeLecuyerGaussianRng_next")]
  public static extern global::System.IntPtr MoroInvCumulativeLecuyerGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeLecuyerGaussianRng")]
  public static extern void delete_MoroInvCumulativeLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeKnuthGaussianRng")]
  public static extern global::System.IntPtr new_MoroInvCumulativeKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeKnuthGaussianRng_next")]
  public static extern global::System.IntPtr MoroInvCumulativeKnuthGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeKnuthGaussianRng")]
  public static extern void delete_MoroInvCumulativeKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeMersenneTwisterGaussianRng")]
  public static extern global::System.IntPtr new_MoroInvCumulativeMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeMersenneTwisterGaussianRng_next")]
  public static extern global::System.IntPtr MoroInvCumulativeMersenneTwisterGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeMersenneTwisterGaussianRng")]
  public static extern void delete_MoroInvCumulativeMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeLecuyerGaussianRng")]
  public static extern global::System.IntPtr new_InvCumulativeLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeLecuyerGaussianRng_next")]
  public static extern global::System.IntPtr InvCumulativeLecuyerGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeLecuyerGaussianRng")]
  public static extern void delete_InvCumulativeLecuyerGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeKnuthGaussianRng")]
  public static extern global::System.IntPtr new_InvCumulativeKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeKnuthGaussianRng_next")]
  public static extern global::System.IntPtr InvCumulativeKnuthGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeKnuthGaussianRng")]
  public static extern void delete_InvCumulativeKnuthGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeMersenneTwisterGaussianRng")]
  public static extern global::System.IntPtr new_InvCumulativeMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterGaussianRng_next")]
  public static extern global::System.IntPtr InvCumulativeMersenneTwisterGaussianRng_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeMersenneTwisterGaussianRng")]
  public static extern void delete_InvCumulativeMersenneTwisterGaussianRng(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianRandomGenerator")]
  public static extern global::System.IntPtr new_GaussianRandomGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianRandomGenerator_next")]
  public static extern global::System.IntPtr GaussianRandomGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianRandomGenerator_nextValue")]
  public static extern double GaussianRandomGenerator_nextValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianRandomGenerator")]
  public static extern void delete_GaussianRandomGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HaltonRsg__SWIG_0")]
  public static extern global::System.IntPtr new_HaltonRsg__SWIG_0(uint jarg1, uint jarg2, bool jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HaltonRsg__SWIG_1")]
  public static extern global::System.IntPtr new_HaltonRsg__SWIG_1(uint jarg1, uint jarg2, bool jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HaltonRsg__SWIG_2")]
  public static extern global::System.IntPtr new_HaltonRsg__SWIG_2(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HaltonRsg__SWIG_3")]
  public static extern global::System.IntPtr new_HaltonRsg__SWIG_3(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HaltonRsg_nextSequence")]
  public static extern global::System.IntPtr HaltonRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HaltonRsg_lastSequence")]
  public static extern global::System.IntPtr HaltonRsg_lastSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HaltonRsg_dimension")]
  public static extern uint HaltonRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HaltonRsg")]
  public static extern void delete_HaltonRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolRsg__SWIG_0")]
  public static extern global::System.IntPtr new_SobolRsg__SWIG_0(uint jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolRsg__SWIG_1")]
  public static extern global::System.IntPtr new_SobolRsg__SWIG_1(uint jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolRsg__SWIG_2")]
  public static extern global::System.IntPtr new_SobolRsg__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolRsg_nextSequence")]
  public static extern global::System.IntPtr SobolRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolRsg_lastSequence")]
  public static extern global::System.IntPtr SobolRsg_lastSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolRsg_dimension")]
  public static extern uint SobolRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolRsg_skipTo")]
  public static extern void SobolRsg_skipTo(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolRsg_nextInt32Sequence")]
  public static extern global::System.IntPtr SobolRsg_nextInt32Sequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SobolRsg")]
  public static extern void delete_SobolRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolBrownianBridgeRsg")]
  public static extern global::System.IntPtr new_SobolBrownianBridgeRsg(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolBrownianBridgeRsg_nextSequence")]
  public static extern global::System.IntPtr SobolBrownianBridgeRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolBrownianBridgeRsg_lastSequence")]
  public static extern global::System.IntPtr SobolBrownianBridgeRsg_lastSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolBrownianBridgeRsg_dimension")]
  public static extern uint SobolBrownianBridgeRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SobolBrownianBridgeRsg")]
  public static extern void delete_SobolBrownianBridgeRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LecuyerUniformRsg__SWIG_0")]
  public static extern global::System.IntPtr new_LecuyerUniformRsg__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LecuyerUniformRsg__SWIG_1")]
  public static extern global::System.IntPtr new_LecuyerUniformRsg__SWIG_1(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LecuyerUniformRsg__SWIG_2")]
  public static extern global::System.IntPtr new_LecuyerUniformRsg__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LecuyerUniformRsg_nextSequence")]
  public static extern global::System.IntPtr LecuyerUniformRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LecuyerUniformRsg_dimension")]
  public static extern uint LecuyerUniformRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LecuyerUniformRsg")]
  public static extern void delete_LecuyerUniformRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KnuthUniformRsg__SWIG_0")]
  public static extern global::System.IntPtr new_KnuthUniformRsg__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KnuthUniformRsg__SWIG_1")]
  public static extern global::System.IntPtr new_KnuthUniformRsg__SWIG_1(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_KnuthUniformRsg__SWIG_2")]
  public static extern global::System.IntPtr new_KnuthUniformRsg__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KnuthUniformRsg_nextSequence")]
  public static extern global::System.IntPtr KnuthUniformRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KnuthUniformRsg_dimension")]
  public static extern uint KnuthUniformRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_KnuthUniformRsg")]
  public static extern void delete_KnuthUniformRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MersenneTwisterUniformRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MersenneTwisterUniformRsg__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MersenneTwisterUniformRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MersenneTwisterUniformRsg__SWIG_1(uint jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MersenneTwisterUniformRsg__SWIG_2")]
  public static extern global::System.IntPtr new_MersenneTwisterUniformRsg__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MersenneTwisterUniformRsg_nextSequence")]
  public static extern global::System.IntPtr MersenneTwisterUniformRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MersenneTwisterUniformRsg_dimension")]
  public static extern uint MersenneTwisterUniformRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MersenneTwisterUniformRsg")]
  public static extern void delete_MersenneTwisterUniformRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformRandomSequenceGenerator")]
  public static extern global::System.IntPtr new_UniformRandomSequenceGenerator(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformRandomSequenceGenerator_nextSequence")]
  public static extern global::System.IntPtr UniformRandomSequenceGenerator_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformRandomSequenceGenerator_dimension")]
  public static extern uint UniformRandomSequenceGenerator_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UniformRandomSequenceGenerator")]
  public static extern void delete_UniformRandomSequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformLowDiscrepancySequenceGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_UniformLowDiscrepancySequenceGenerator__SWIG_0(uint jarg1, int jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformLowDiscrepancySequenceGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_UniformLowDiscrepancySequenceGenerator__SWIG_1(uint jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_UniformLowDiscrepancySequenceGenerator__SWIG_2")]
  public static extern global::System.IntPtr new_UniformLowDiscrepancySequenceGenerator__SWIG_2(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformLowDiscrepancySequenceGenerator_nextSequence")]
  public static extern global::System.IntPtr UniformLowDiscrepancySequenceGenerator_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UniformLowDiscrepancySequenceGenerator_dimension")]
  public static extern uint UniformLowDiscrepancySequenceGenerator_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_UniformLowDiscrepancySequenceGenerator")]
  public static extern void delete_UniformLowDiscrepancySequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInvCumulativeLecuyerGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeLecuyerGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr MoroInvCumulativeLecuyerGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeLecuyerGaussianRsg_dimension")]
  public static extern uint MoroInvCumulativeLecuyerGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeLecuyerGaussianRsg")]
  public static extern void delete_MoroInvCumulativeLecuyerGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeKnuthGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInvCumulativeKnuthGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeKnuthGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInvCumulativeKnuthGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeKnuthGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr MoroInvCumulativeKnuthGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeKnuthGaussianRsg_dimension")]
  public static extern uint MoroInvCumulativeKnuthGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeKnuthGaussianRsg")]
  public static extern void delete_MoroInvCumulativeKnuthGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInvCumulativeMersenneTwisterGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeMersenneTwisterGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr MoroInvCumulativeMersenneTwisterGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeMersenneTwisterGaussianRsg_dimension")]
  public static extern uint MoroInvCumulativeMersenneTwisterGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeMersenneTwisterGaussianRsg")]
  public static extern void delete_MoroInvCumulativeMersenneTwisterGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeHaltonGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInvCumulativeHaltonGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeHaltonGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInvCumulativeHaltonGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeHaltonGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr MoroInvCumulativeHaltonGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeHaltonGaussianRsg_dimension")]
  public static extern uint MoroInvCumulativeHaltonGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeHaltonGaussianRsg")]
  public static extern void delete_MoroInvCumulativeHaltonGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeSobolGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_MoroInvCumulativeSobolGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MoroInvCumulativeSobolGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_MoroInvCumulativeSobolGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeSobolGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr MoroInvCumulativeSobolGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MoroInvCumulativeSobolGaussianRsg_dimension")]
  public static extern uint MoroInvCumulativeSobolGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MoroInvCumulativeSobolGaussianRsg")]
  public static extern void delete_MoroInvCumulativeSobolGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeLecuyerGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeLecuyerGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeLecuyerGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeLecuyerGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeLecuyerGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr InvCumulativeLecuyerGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeLecuyerGaussianRsg_dimension")]
  public static extern uint InvCumulativeLecuyerGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeLecuyerGaussianRsg")]
  public static extern void delete_InvCumulativeLecuyerGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeKnuthGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeKnuthGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeKnuthGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeKnuthGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeKnuthGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr InvCumulativeKnuthGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeKnuthGaussianRsg_dimension")]
  public static extern uint InvCumulativeKnuthGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeKnuthGaussianRsg")]
  public static extern void delete_InvCumulativeKnuthGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeMersenneTwisterGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr InvCumulativeMersenneTwisterGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterGaussianRsg_dimension")]
  public static extern uint InvCumulativeMersenneTwisterGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeMersenneTwisterGaussianRsg")]
  public static extern void delete_InvCumulativeMersenneTwisterGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeHaltonGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeHaltonGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeHaltonGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeHaltonGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeHaltonGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr InvCumulativeHaltonGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeHaltonGaussianRsg_dimension")]
  public static extern uint InvCumulativeHaltonGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeHaltonGaussianRsg")]
  public static extern void delete_InvCumulativeHaltonGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeSobolGaussianRsg__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeSobolGaussianRsg__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeSobolGaussianRsg__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeSobolGaussianRsg__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeSobolGaussianRsg_nextSequence")]
  public static extern global::System.IntPtr InvCumulativeSobolGaussianRsg_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeSobolGaussianRsg_dimension")]
  public static extern uint InvCumulativeSobolGaussianRsg_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeSobolGaussianRsg")]
  public static extern void delete_InvCumulativeSobolGaussianRsg(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianRandomSequenceGenerator")]
  public static extern global::System.IntPtr new_GaussianRandomSequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianRandomSequenceGenerator_nextSequence")]
  public static extern global::System.IntPtr GaussianRandomSequenceGenerator_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianRandomSequenceGenerator_dimension")]
  public static extern uint GaussianRandomSequenceGenerator_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianRandomSequenceGenerator")]
  public static extern void delete_GaussianRandomSequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianLowDiscrepancySequenceGenerator")]
  public static extern global::System.IntPtr new_GaussianLowDiscrepancySequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianLowDiscrepancySequenceGenerator_nextSequence")]
  public static extern global::System.IntPtr GaussianLowDiscrepancySequenceGenerator_nextSequence(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianLowDiscrepancySequenceGenerator_dimension")]
  public static extern uint GaussianLowDiscrepancySequenceGenerator_dimension(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianLowDiscrepancySequenceGenerator")]
  public static extern void delete_GaussianLowDiscrepancySequenceGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_getCovariance")]
  public static extern global::System.IntPtr getCovariance(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Path_length")]
  public static extern uint Path_length(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Path_value")]
  public static extern double Path_value(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Path_front")]
  public static extern double Path_front(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Path_back")]
  public static extern double Path_back(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Path_time")]
  public static extern double Path_time(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Path")]
  public static extern void delete_Path(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SamplePath_value")]
  public static extern global::System.IntPtr SamplePath_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SamplePath_weight")]
  public static extern double SamplePath_weight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SamplePath")]
  public static extern void delete_SamplePath(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianPathGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_GaussianPathGenerator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianPathGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_GaussianPathGenerator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianPathGenerator_next")]
  public static extern global::System.IntPtr GaussianPathGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianPathGenerator_antithetic")]
  public static extern global::System.IntPtr GaussianPathGenerator_antithetic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianPathGenerator_size")]
  public static extern uint GaussianPathGenerator_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianPathGenerator_timeGrid")]
  public static extern global::System.IntPtr GaussianPathGenerator_timeGrid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianPathGenerator")]
  public static extern void delete_GaussianPathGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSobolPathGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_GaussianSobolPathGenerator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianSobolPathGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_GaussianSobolPathGenerator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianSobolPathGenerator_next")]
  public static extern global::System.IntPtr GaussianSobolPathGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianSobolPathGenerator_antithetic")]
  public static extern global::System.IntPtr GaussianSobolPathGenerator_antithetic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianSobolPathGenerator_size")]
  public static extern uint GaussianSobolPathGenerator_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianSobolPathGenerator_timeGrid")]
  public static extern global::System.IntPtr GaussianSobolPathGenerator_timeGrid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianSobolPathGenerator")]
  public static extern void delete_GaussianSobolPathGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeMersenneTwisterPathGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_InvCumulativeMersenneTwisterPathGenerator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, uint jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_InvCumulativeMersenneTwisterPathGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_InvCumulativeMersenneTwisterPathGenerator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterPathGenerator_next")]
  public static extern global::System.IntPtr InvCumulativeMersenneTwisterPathGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterPathGenerator_antithetic")]
  public static extern global::System.IntPtr InvCumulativeMersenneTwisterPathGenerator_antithetic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterPathGenerator_size")]
  public static extern uint InvCumulativeMersenneTwisterPathGenerator_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InvCumulativeMersenneTwisterPathGenerator_timeGrid")]
  public static extern global::System.IntPtr InvCumulativeMersenneTwisterPathGenerator_timeGrid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_InvCumulativeMersenneTwisterPathGenerator")]
  public static extern void delete_InvCumulativeMersenneTwisterPathGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiPath_pathSize")]
  public static extern uint MultiPath_pathSize(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiPath_assetNumber")]
  public static extern uint MultiPath_assetNumber(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiPath_at")]
  public static extern global::System.IntPtr MultiPath_at(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MultiPath")]
  public static extern void delete_MultiPath(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleMultiPath_value")]
  public static extern global::System.IntPtr SampleMultiPath_value(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampleMultiPath_weight")]
  public static extern double SampleMultiPath_weight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SampleMultiPath")]
  public static extern void delete_SampleMultiPath(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianMultiPathGenerator__SWIG_0")]
  public static extern global::System.IntPtr new_GaussianMultiPathGenerator__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GaussianMultiPathGenerator__SWIG_1")]
  public static extern global::System.IntPtr new_GaussianMultiPathGenerator__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianMultiPathGenerator_next")]
  public static extern global::System.IntPtr GaussianMultiPathGenerator_next(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianMultiPathGenerator_antithetic")]
  public static extern global::System.IntPtr GaussianMultiPathGenerator_antithetic(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GaussianMultiPathGenerator")]
  public static extern void delete_GaussianMultiPathGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BrownianBridge__SWIG_0")]
  public static extern global::System.IntPtr new_BrownianBridge__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BrownianBridge__SWIG_1")]
  public static extern global::System.IntPtr new_BrownianBridge__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BrownianBridge__SWIG_2")]
  public static extern global::System.IntPtr new_BrownianBridge__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_size")]
  public static extern uint BrownianBridge_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_times")]
  public static extern global::System.IntPtr BrownianBridge_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_leftWeight")]
  public static extern global::System.IntPtr BrownianBridge_leftWeight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_rightWeight")]
  public static extern global::System.IntPtr BrownianBridge_rightWeight(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_stdDeviation")]
  public static extern global::System.IntPtr BrownianBridge_stdDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_transform")]
  public static extern global::System.IntPtr BrownianBridge_transform(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_bridgeIndex")]
  public static extern global::System.IntPtr BrownianBridge_bridgeIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_leftIndex")]
  public static extern global::System.IntPtr BrownianBridge_leftIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BrownianBridge_rightIndex")]
  public static extern global::System.IntPtr BrownianBridge_rightIndex(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BrownianBridge")]
  public static extern void delete_BrownianBridge(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OdeFctDelegate")]
  public static extern void delete_OdeFctDelegate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OdeFctDelegate_value")]
  public static extern global::System.IntPtr OdeFctDelegate_value(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OdeFctDelegate_valueSwigExplicitOdeFctDelegate")]
  public static extern global::System.IntPtr OdeFctDelegate_valueSwigExplicitOdeFctDelegate(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OdeFctDelegate")]
  public static extern global::System.IntPtr new_OdeFctDelegate();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OdeFctDelegate_director_connect")]
  public static extern void OdeFctDelegate_director_connect(global::System.Runtime.InteropServices.HandleRef jarg1, OdeFctDelegate.SwigDelegateOdeFctDelegate_0 delegate0);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RungeKutta__SWIG_0")]
  public static extern global::System.IntPtr new_RungeKutta__SWIG_0(double jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RungeKutta__SWIG_1")]
  public static extern global::System.IntPtr new_RungeKutta__SWIG_1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RungeKutta__SWIG_2")]
  public static extern global::System.IntPtr new_RungeKutta__SWIG_2(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RungeKutta__SWIG_3")]
  public static extern global::System.IntPtr new_RungeKutta__SWIG_3();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RungeKutta_call__SWIG_0")]
  public static extern double RungeKutta_call__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RungeKutta_call__SWIG_1")]
  public static extern global::System.IntPtr RungeKutta_call__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RungeKutta")]
  public static extern void delete_RungeKutta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DefaultBoundaryCondition")]
  public static extern void delete_DefaultBoundaryCondition(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NeumannBC")]
  public static extern global::System.IntPtr new_NeumannBC(double jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NeumannBC")]
  public static extern void delete_NeumannBC(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DirichletBC")]
  public static extern global::System.IntPtr new_DirichletBC(double jarg1, int jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DirichletBC")]
  public static extern void delete_DirichletBC(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_TridiagonalOperator")]
  public static extern global::System.IntPtr new_TridiagonalOperator(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_solveFor")]
  public static extern global::System.IntPtr TridiagonalOperator_solveFor(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_applyTo")]
  public static extern global::System.IntPtr TridiagonalOperator_applyTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_size")]
  public static extern uint TridiagonalOperator_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_setFirstRow")]
  public static extern void TridiagonalOperator_setFirstRow(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_setMidRow")]
  public static extern void TridiagonalOperator_setMidRow(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2, double jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_setMidRows")]
  public static extern void TridiagonalOperator_setMidRows(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_setLastRow")]
  public static extern void TridiagonalOperator_setLastRow(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TridiagonalOperator_identity")]
  public static extern global::System.IntPtr TridiagonalOperator_identity(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_TridiagonalOperator")]
  public static extern void delete_TridiagonalOperator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DPlus")]
  public static extern global::System.IntPtr new_DPlus(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DPlus")]
  public static extern void delete_DPlus(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DMinus")]
  public static extern global::System.IntPtr new_DMinus(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DMinus")]
  public static extern void delete_DMinus(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DZero")]
  public static extern global::System.IntPtr new_DZero(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DZero")]
  public static extern void delete_DZero(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_DPlusDMinus")]
  public static extern global::System.IntPtr new_DPlusDMinus(uint jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_DPlusDMinus")]
  public static extern void delete_DPlusDMinus(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SampledCurve__SWIG_0")]
  public static extern global::System.IntPtr new_SampledCurve__SWIG_0();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SampledCurve__SWIG_1")]
  public static extern global::System.IntPtr new_SampledCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_grid")]
  public static extern global::System.IntPtr SampledCurve_grid(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_values")]
  public static extern global::System.IntPtr SampledCurve_values(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_gridValue")]
  public static extern double SampledCurve_gridValue(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_value")]
  public static extern double SampledCurve_value(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_size")]
  public static extern uint SampledCurve_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_empty")]
  public static extern bool SampledCurve_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_setGrid")]
  public static extern void SampledCurve_setGrid(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_setValues")]
  public static extern void SampledCurve_setValues(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_swap")]
  public static extern void SampledCurve_swap(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_setLogGrid")]
  public static extern void SampledCurve_setLogGrid(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_regridLogGrid")]
  public static extern void SampledCurve_regridLogGrid(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_shiftGrid")]
  public static extern void SampledCurve_shiftGrid(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_scaleGrid")]
  public static extern void SampledCurve_scaleGrid(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SampledCurve_regrid")]
  public static extern void SampledCurve_regrid(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SampledCurve")]
  public static extern void delete_SampledCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVProcess__SWIG_0")]
  public static extern global::System.IntPtr new_HestonSLVProcess__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVProcess__SWIG_1")]
  public static extern global::System.IntPtr new_HestonSLVProcess__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonSLVProcess")]
  public static extern void delete_HestonSLVProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BrownianGeneratorFactory")]
  public static extern void delete_BrownianGeneratorFactory(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MTBrownianGeneratorFactory__SWIG_0")]
  public static extern global::System.IntPtr new_MTBrownianGeneratorFactory__SWIG_0(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MTBrownianGeneratorFactory__SWIG_1")]
  public static extern global::System.IntPtr new_MTBrownianGeneratorFactory__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MTBrownianGeneratorFactory")]
  public static extern void delete_MTBrownianGeneratorFactory(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SobolBrownianGenerator")]
  public static extern void delete_SobolBrownianGenerator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolBrownianGeneratorFactory__SWIG_0")]
  public static extern global::System.IntPtr new_SobolBrownianGeneratorFactory__SWIG_0(int jarg1, uint jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolBrownianGeneratorFactory__SWIG_1")]
  public static extern global::System.IntPtr new_SobolBrownianGeneratorFactory__SWIG_1(int jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SobolBrownianGeneratorFactory__SWIG_2")]
  public static extern global::System.IntPtr new_SobolBrownianGeneratorFactory__SWIG_2(int jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SobolBrownianGeneratorFactory")]
  public static extern void delete_SobolBrownianGeneratorFactory(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_0")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8, double jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_1")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7, global::System.Runtime.InteropServices.HandleRef jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_2")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6, uint jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_3")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_4")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVMCModel__SWIG_5")]
  public static extern global::System.IntPtr new_HestonSLVMCModel__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVMCModel_hestonProcess")]
  public static extern global::System.IntPtr HestonSLVMCModel_hestonProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVMCModel_localVol")]
  public static extern global::System.IntPtr HestonSLVMCModel_localVol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVMCModel_leverageFunction")]
  public static extern global::System.IntPtr HestonSLVMCModel_leverageFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonSLVMCModel")]
  public static extern void delete_HestonSLVMCModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FdmHestonGreensFct")]
  public static extern void delete_FdmHestonGreensFct(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVFokkerPlanckFdmParams")]
  public static extern global::System.IntPtr new_HestonSLVFokkerPlanckFdmParams(uint jarg1, uint jarg2, uint jarg3, uint jarg4, double jarg5, uint jarg6, uint jarg7, double jarg8, double jarg9, uint jarg10, double jarg11, double jarg12, double jarg13, double jarg14, double jarg15, double jarg16, double jarg17, int jarg18, int jarg19, global::System.Runtime.InteropServices.HandleRef jarg20);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonSLVFokkerPlanckFdmParams")]
  public static extern void delete_HestonSLVFokkerPlanckFdmParams(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVFDMModel__SWIG_0")]
  public static extern global::System.IntPtr new_HestonSLVFDMModel__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVFDMModel__SWIG_1")]
  public static extern global::System.IntPtr new_HestonSLVFDMModel__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVFDMModel__SWIG_2")]
  public static extern global::System.IntPtr new_HestonSLVFDMModel__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, bool jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_HestonSLVFDMModel__SWIG_3")]
  public static extern global::System.IntPtr new_HestonSLVFDMModel__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVFDMModel_hestonProcess")]
  public static extern global::System.IntPtr HestonSLVFDMModel_hestonProcess(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVFDMModel_localVol")]
  public static extern global::System.IntPtr HestonSLVFDMModel_localVol(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVFDMModel_leverageFunction")]
  public static extern global::System.IntPtr HestonSLVFDMModel_leverageFunction(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_HestonSLVFDMModel")]
  public static extern void delete_HestonSLVFDMModel(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_samples")]
  public static extern uint Statistics_samples(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_weightSum")]
  public static extern double Statistics_weightSum(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_mean")]
  public static extern double Statistics_mean(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_variance")]
  public static extern double Statistics_variance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_standardDeviation")]
  public static extern double Statistics_standardDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_errorEstimate")]
  public static extern double Statistics_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_skewness")]
  public static extern double Statistics_skewness(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_kurtosis")]
  public static extern double Statistics_kurtosis(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_min")]
  public static extern double Statistics_min(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_max")]
  public static extern double Statistics_max(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_reset")]
  public static extern void Statistics_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_add__SWIG_0")]
  public static extern void Statistics_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_add__SWIG_1")]
  public static extern void Statistics_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_add__SWIG_2")]
  public static extern void Statistics_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Statistics_add__SWIG_3")]
  public static extern void Statistics_add__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Statistics")]
  public static extern global::System.IntPtr new_Statistics();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Statistics")]
  public static extern void delete_Statistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_samples")]
  public static extern uint IncrementalStatistics_samples(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_weightSum")]
  public static extern double IncrementalStatistics_weightSum(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_mean")]
  public static extern double IncrementalStatistics_mean(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_variance")]
  public static extern double IncrementalStatistics_variance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_standardDeviation")]
  public static extern double IncrementalStatistics_standardDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_errorEstimate")]
  public static extern double IncrementalStatistics_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_skewness")]
  public static extern double IncrementalStatistics_skewness(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_kurtosis")]
  public static extern double IncrementalStatistics_kurtosis(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_min")]
  public static extern double IncrementalStatistics_min(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_max")]
  public static extern double IncrementalStatistics_max(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_reset")]
  public static extern void IncrementalStatistics_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_add__SWIG_0")]
  public static extern void IncrementalStatistics_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_add__SWIG_1")]
  public static extern void IncrementalStatistics_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_add__SWIG_2")]
  public static extern void IncrementalStatistics_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IncrementalStatistics_add__SWIG_3")]
  public static extern void IncrementalStatistics_add__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_IncrementalStatistics")]
  public static extern global::System.IntPtr new_IncrementalStatistics();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_IncrementalStatistics")]
  public static extern void delete_IncrementalStatistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_semiVariance")]
  public static extern double RiskStatistics_semiVariance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_semiDeviation")]
  public static extern double RiskStatistics_semiDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_downsideVariance")]
  public static extern double RiskStatistics_downsideVariance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_downsideDeviation")]
  public static extern double RiskStatistics_downsideDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_regret")]
  public static extern double RiskStatistics_regret(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_potentialUpside")]
  public static extern double RiskStatistics_potentialUpside(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_valueAtRisk")]
  public static extern double RiskStatistics_valueAtRisk(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_expectedShortfall")]
  public static extern double RiskStatistics_expectedShortfall(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_shortfall")]
  public static extern double RiskStatistics_shortfall(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_averageShortfall")]
  public static extern double RiskStatistics_averageShortfall(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RiskStatistics")]
  public static extern global::System.IntPtr new_RiskStatistics();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RiskStatistics")]
  public static extern void delete_RiskStatistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MultipleStatistics")]
  public static extern global::System.IntPtr new_MultipleStatistics(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_size")]
  public static extern uint MultipleStatistics_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_samples")]
  public static extern uint MultipleStatistics_samples(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_weightSum")]
  public static extern double MultipleStatistics_weightSum(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_mean")]
  public static extern global::System.IntPtr MultipleStatistics_mean(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_variance")]
  public static extern global::System.IntPtr MultipleStatistics_variance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_standardDeviation")]
  public static extern global::System.IntPtr MultipleStatistics_standardDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_errorEstimate")]
  public static extern global::System.IntPtr MultipleStatistics_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_skewness")]
  public static extern global::System.IntPtr MultipleStatistics_skewness(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_kurtosis")]
  public static extern global::System.IntPtr MultipleStatistics_kurtosis(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_min")]
  public static extern global::System.IntPtr MultipleStatistics_min(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_max")]
  public static extern global::System.IntPtr MultipleStatistics_max(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_covariance")]
  public static extern global::System.IntPtr MultipleStatistics_covariance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_correlation")]
  public static extern global::System.IntPtr MultipleStatistics_correlation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_reset")]
  public static extern void MultipleStatistics_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_add__SWIG_0")]
  public static extern void MultipleStatistics_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_add__SWIG_1")]
  public static extern void MultipleStatistics_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_add__SWIG_2")]
  public static extern void MultipleStatistics_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleStatistics_add__SWIG_3")]
  public static extern void MultipleStatistics_add__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MultipleStatistics")]
  public static extern void delete_MultipleStatistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_SequenceStatistics")]
  public static extern global::System.IntPtr new_SequenceStatistics(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_size")]
  public static extern uint SequenceStatistics_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_samples")]
  public static extern uint SequenceStatistics_samples(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_weightSum")]
  public static extern double SequenceStatistics_weightSum(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_mean")]
  public static extern global::System.IntPtr SequenceStatistics_mean(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_variance")]
  public static extern global::System.IntPtr SequenceStatistics_variance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_standardDeviation")]
  public static extern global::System.IntPtr SequenceStatistics_standardDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_errorEstimate")]
  public static extern global::System.IntPtr SequenceStatistics_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_skewness")]
  public static extern global::System.IntPtr SequenceStatistics_skewness(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_kurtosis")]
  public static extern global::System.IntPtr SequenceStatistics_kurtosis(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_min")]
  public static extern global::System.IntPtr SequenceStatistics_min(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_max")]
  public static extern global::System.IntPtr SequenceStatistics_max(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_covariance")]
  public static extern global::System.IntPtr SequenceStatistics_covariance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_correlation")]
  public static extern global::System.IntPtr SequenceStatistics_correlation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_reset")]
  public static extern void SequenceStatistics_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_add__SWIG_0")]
  public static extern void SequenceStatistics_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_add__SWIG_1")]
  public static extern void SequenceStatistics_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_add__SWIG_2")]
  public static extern void SequenceStatistics_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SequenceStatistics_add__SWIG_3")]
  public static extern void SequenceStatistics_add__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_SequenceStatistics")]
  public static extern void delete_SequenceStatistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MultipleIncrementalStatistics")]
  public static extern global::System.IntPtr new_MultipleIncrementalStatistics(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_size")]
  public static extern uint MultipleIncrementalStatistics_size(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_samples")]
  public static extern uint MultipleIncrementalStatistics_samples(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_weightSum")]
  public static extern double MultipleIncrementalStatistics_weightSum(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_mean")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_mean(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_variance")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_variance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_standardDeviation")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_standardDeviation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_errorEstimate")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_errorEstimate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_skewness")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_skewness(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_kurtosis")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_kurtosis(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_min")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_min(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_max")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_max(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_covariance")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_covariance(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_correlation")]
  public static extern global::System.IntPtr MultipleIncrementalStatistics_correlation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_reset")]
  public static extern void MultipleIncrementalStatistics_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_add__SWIG_0")]
  public static extern void MultipleIncrementalStatistics_add__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_add__SWIG_1")]
  public static extern void MultipleIncrementalStatistics_add__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_add__SWIG_2")]
  public static extern void MultipleIncrementalStatistics_add__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultipleIncrementalStatistics_add__SWIG_3")]
  public static extern void MultipleIncrementalStatistics_add__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MultipleIncrementalStatistics")]
  public static extern void delete_MultipleIncrementalStatistics(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_0")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_1")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_2")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_3")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_4")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_volatility__SWIG_5")]
  public static extern double CapFloorTermVolatilityStructure_volatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapFloorTermVolatilityStructure")]
  public static extern void delete_CapFloorTermVolatilityStructure(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_CapFloorTermVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_CapFloorTermVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle___deref__")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle___deref__(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_currentLink")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_currentLink(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_empty")]
  public static extern bool CapFloorTermVolatilityStructureHandle_empty(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_asObservable")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_asObservable(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapFloorTermVolatilityStructureHandle")]
  public static extern void delete_CapFloorTermVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_0")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_1")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_2")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_3")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_4")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3, bool jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_volatility__SWIG_5")]
  public static extern double CapFloorTermVolatilityStructureHandle_volatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_minStrike")]
  public static extern double CapFloorTermVolatilityStructureHandle_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_maxStrike")]
  public static extern double CapFloorTermVolatilityStructureHandle_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_dayCounter")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_timeFromReference")]
  public static extern double CapFloorTermVolatilityStructureHandle_timeFromReference(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_calendar")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_referenceDate")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_referenceDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_maxDate")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructureHandle_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_maxTime")]
  public static extern double CapFloorTermVolatilityStructureHandle_maxTime(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_enableExtrapolation")]
  public static extern void CapFloorTermVolatilityStructureHandle_enableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_disableExtrapolation")]
  public static extern void CapFloorTermVolatilityStructureHandle_disableExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructureHandle_allowsExtrapolation")]
  public static extern bool CapFloorTermVolatilityStructureHandle_allowsExtrapolation(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_0")]
  public static extern global::System.IntPtr new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_1")]
  public static extern global::System.IntPtr new_RelinkableCapFloorTermVolatilityStructureHandle__SWIG_1();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCapFloorTermVolatilityStructureHandle_linkTo")]
  public static extern void RelinkableCapFloorTermVolatilityStructureHandle_linkTo(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCapFloorTermVolatilityStructureHandle_reset")]
  public static extern void RelinkableCapFloorTermVolatilityStructureHandle_reset(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_RelinkableCapFloorTermVolatilityStructureHandle")]
  public static extern void delete_RelinkableCapFloorTermVolatilityStructureHandle(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolCurve__SWIG_0")]
  public static extern global::System.IntPtr new_CapFloorTermVolCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolCurve__SWIG_1")]
  public static extern global::System.IntPtr new_CapFloorTermVolCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolCurve__SWIG_2")]
  public static extern global::System.IntPtr new_CapFloorTermVolCurve__SWIG_2(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolCurve__SWIG_3")]
  public static extern global::System.IntPtr new_CapFloorTermVolCurve__SWIG_3(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapFloorTermVolCurve")]
  public static extern void delete_CapFloorTermVolCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_0")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_0(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_1")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_1(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_2")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_3")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_4")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_5")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_6")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_6(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, global::System.Runtime.InteropServices.HandleRef jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CapFloorTermVolSurface__SWIG_7")]
  public static extern global::System.IntPtr new_CapFloorTermVolSurface__SWIG_7(uint jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_maxDate")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_maxDate(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_minStrike")]
  public static extern double CapFloorTermVolSurface_minStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_maxStrike")]
  public static extern double CapFloorTermVolSurface_maxStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_optionTenors")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_optionTenors(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_optionDates")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_optionDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_optionTimes")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_optionTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_strikes")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_strikes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CapFloorTermVolSurface")]
  public static extern void delete_CapFloorTermVolSurface(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_optionletStrikes")]
  public static extern global::System.IntPtr StrippedOptionletBase_optionletStrikes(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_optionletVolatilities")]
  public static extern global::System.IntPtr StrippedOptionletBase_optionletVolatilities(global::System.Runtime.InteropServices.HandleRef jarg1, uint jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_optionletFixingDates")]
  public static extern global::System.IntPtr StrippedOptionletBase_optionletFixingDates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_optionletFixingTimes")]
  public static extern global::System.IntPtr StrippedOptionletBase_optionletFixingTimes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_optionletMaturities")]
  public static extern uint StrippedOptionletBase_optionletMaturities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_atmOptionletRates")]
  public static extern global::System.IntPtr StrippedOptionletBase_atmOptionletRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_dayCounter")]
  public static extern global::System.IntPtr StrippedOptionletBase_dayCounter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_calendar")]
  public static extern global::System.IntPtr StrippedOptionletBase_calendar(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_settlementDays")]
  public static extern uint StrippedOptionletBase_settlementDays(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletBase_businessDayConvention")]
  public static extern int StrippedOptionletBase_businessDayConvention(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StrippedOptionletBase")]
  public static extern void delete_StrippedOptionletBase(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_0")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8, bool jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_1")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_2")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_3")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5, global::System.Runtime.InteropServices.HandleRef jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_4")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4, uint jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_5")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_6")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, double jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_OptionletStripper1__SWIG_7")]
  public static extern global::System.IntPtr new_OptionletStripper1__SWIG_7(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletStripper1_capFloorPrices")]
  public static extern global::System.IntPtr OptionletStripper1_capFloorPrices(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletStripper1_capFloorVolatilities")]
  public static extern global::System.IntPtr OptionletStripper1_capFloorVolatilities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletStripper1_optionletPrices")]
  public static extern global::System.IntPtr OptionletStripper1_optionletPrices(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletStripper1_switchStrike")]
  public static extern double OptionletStripper1_switchStrike(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_OptionletStripper1")]
  public static extern void delete_OptionletStripper1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_StrippedOptionletAdapter")]
  public static extern global::System.IntPtr new_StrippedOptionletAdapter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_StrippedOptionletAdapter")]
  public static extern void delete_StrippedOptionletAdapter(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Settlement")]
  public static extern global::System.IntPtr new_Settlement();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Settlement")]
  public static extern void delete_Settlement(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Swaption__SWIG_0")]
  public static extern global::System.IntPtr new_Swaption__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Swaption__SWIG_1")]
  public static extern global::System.IntPtr new_Swaption__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_Swaption__SWIG_2")]
  public static extern global::System.IntPtr new_Swaption__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_settlementType")]
  public static extern int Swaption_settlementType(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_settlementMethod")]
  public static extern int Swaption_settlementMethod(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_type")]
  public static extern int Swaption_type(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_underlyingSwap")]
  public static extern global::System.IntPtr Swaption_underlyingSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_0")]
  public static extern double Swaption_impliedVolatility__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8, int jarg9, double jarg10);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_1")]
  public static extern double Swaption_impliedVolatility__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8, int jarg9);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_2")]
  public static extern double Swaption_impliedVolatility__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7, double jarg8);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_3")]
  public static extern double Swaption_impliedVolatility__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6, double jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_4")]
  public static extern double Swaption_impliedVolatility__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5, uint jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_5")]
  public static extern double Swaption_impliedVolatility__SWIG_5(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4, double jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_impliedVolatility__SWIG_6")]
  public static extern double Swaption_impliedVolatility__SWIG_6(global::System.Runtime.InteropServices.HandleRef jarg1, double jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_vega")]
  public static extern double Swaption_vega(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_delta")]
  public static extern double Swaption_delta(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_annuity")]
  public static extern double Swaption_annuity(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_Swaption")]
  public static extern void delete_Swaption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwaption__SWIG_0")]
  public static extern global::System.IntPtr new_NonstandardSwaption__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwaption__SWIG_1")]
  public static extern global::System.IntPtr new_NonstandardSwaption__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NonstandardSwaption__SWIG_2")]
  public static extern global::System.IntPtr new_NonstandardSwaption__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwaption_underlyingSwap")]
  public static extern global::System.IntPtr NonstandardSwaption_underlyingSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwaption_calibrationBasket")]
  public static extern global::System.IntPtr NonstandardSwaption_calibrationBasket(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, string jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwaption_probabilities")]
  public static extern global::System.IntPtr NonstandardSwaption_probabilities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NonstandardSwaption")]
  public static extern void delete_NonstandardSwaption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwaption__SWIG_0")]
  public static extern global::System.IntPtr new_FloatFloatSwaption__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3, int jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwaption__SWIG_1")]
  public static extern global::System.IntPtr new_FloatFloatSwaption__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, int jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_FloatFloatSwaption__SWIG_2")]
  public static extern global::System.IntPtr new_FloatFloatSwaption__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwaption_underlyingSwap")]
  public static extern global::System.IntPtr FloatFloatSwaption_underlyingSwap(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwaption_calibrationBasket")]
  public static extern global::System.IntPtr FloatFloatSwaption_calibrationBasket(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, string jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwaption_underlyingValue")]
  public static extern double FloatFloatSwaption_underlyingValue(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwaption_probabilities")]
  public static extern global::System.IntPtr FloatFloatSwaption_probabilities(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_FloatFloatSwaption")]
  public static extern void delete_FloatFloatSwaption(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BlackSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, double jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BlackSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_BlackSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BlackSwaptionEngine__SWIG_3")]
  public static extern global::System.IntPtr new_BlackSwaptionEngine__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BlackSwaptionEngine")]
  public static extern void delete_BlackSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BachelierSwaptionEngine__SWIG_0")]
  public static extern global::System.IntPtr new_BachelierSwaptionEngine__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BachelierSwaptionEngine__SWIG_1")]
  public static extern global::System.IntPtr new_BachelierSwaptionEngine__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_BachelierSwaptionEngine__SWIG_2")]
  public static extern global::System.IntPtr new_BachelierSwaptionEngine__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_BachelierSwaptionEngine")]
  public static extern void delete_BachelierSwaptionEngine(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_enableTracing")]
  public static extern void enableTracing();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_disableTracing")]
  public static extern void disableTracing();

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ConstantEstimator")]
  public static extern global::System.IntPtr new_ConstantEstimator(uint jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConstantEstimator_calculate")]
  public static extern global::System.IntPtr ConstantEstimator_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ConstantEstimator")]
  public static extern void delete_ConstantEstimator(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ParkinsonSigma")]
  public static extern global::System.IntPtr new_ParkinsonSigma(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ParkinsonSigma_calculate")]
  public static extern global::System.IntPtr ParkinsonSigma_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ParkinsonSigma")]
  public static extern void delete_ParkinsonSigma(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKlassSigma1")]
  public static extern global::System.IntPtr new_GarmanKlassSigma1(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKlassSigma1_calculate")]
  public static extern global::System.IntPtr GarmanKlassSigma1_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKlassSigma1")]
  public static extern void delete_GarmanKlassSigma1(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKlassSigma3")]
  public static extern global::System.IntPtr new_GarmanKlassSigma3(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKlassSigma3_calculate")]
  public static extern global::System.IntPtr GarmanKlassSigma3_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKlassSigma3")]
  public static extern void delete_GarmanKlassSigma3(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKlassSigma4")]
  public static extern global::System.IntPtr new_GarmanKlassSigma4(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKlassSigma4_calculate")]
  public static extern global::System.IntPtr GarmanKlassSigma4_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKlassSigma4")]
  public static extern void delete_GarmanKlassSigma4(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKlassSigma5")]
  public static extern global::System.IntPtr new_GarmanKlassSigma5(double jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKlassSigma5_calculate")]
  public static extern global::System.IntPtr GarmanKlassSigma5_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKlassSigma5")]
  public static extern void delete_GarmanKlassSigma5(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_GarmanKlassSigma6")]
  public static extern global::System.IntPtr new_GarmanKlassSigma6(double jarg1, double jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKlassSigma6_calculate")]
  public static extern global::System.IntPtr GarmanKlassSigma6_calculate(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_GarmanKlassSigma6")]
  public static extern void delete_GarmanKlassSigma6(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_ZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_ZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_ZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_ZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_ZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_ZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_times")]
  public static extern global::System.IntPtr ZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_data")]
  public static extern global::System.IntPtr ZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_dates")]
  public static extern global::System.IntPtr ZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_zeroRates")]
  public static extern global::System.IntPtr ZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_nodes")]
  public static extern global::System.IntPtr ZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_ZeroCurve")]
  public static extern void delete_ZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_LogLinearZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_LogLinearZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_LogLinearZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_LogLinearZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogLinearZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_LogLinearZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_times")]
  public static extern global::System.IntPtr LogLinearZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_data")]
  public static extern global::System.IntPtr LogLinearZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_dates")]
  public static extern global::System.IntPtr LogLinearZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_zeroRates")]
  public static extern global::System.IntPtr LogLinearZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_nodes")]
  public static extern global::System.IntPtr LogLinearZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogLinearZeroCurve")]
  public static extern void delete_LogLinearZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_CubicZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_CubicZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_CubicZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_CubicZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_CubicZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_CubicZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_times")]
  public static extern global::System.IntPtr CubicZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_data")]
  public static extern global::System.IntPtr CubicZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_dates")]
  public static extern global::System.IntPtr CubicZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_zeroRates")]
  public static extern global::System.IntPtr CubicZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_nodes")]
  public static extern global::System.IntPtr CubicZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_CubicZeroCurve")]
  public static extern void delete_CubicZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_NaturalCubicZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_NaturalCubicZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_NaturalCubicZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_NaturalCubicZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_NaturalCubicZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_NaturalCubicZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_times")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_data")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_dates")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_zeroRates")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_nodes")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_NaturalCubicZeroCurve")]
  public static extern void delete_NaturalCubicZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_LogCubicZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_LogCubicZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_LogCubicZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_LogCubicZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_LogCubicZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_LogCubicZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_times")]
  public static extern global::System.IntPtr LogCubicZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_data")]
  public static extern global::System.IntPtr LogCubicZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_dates")]
  public static extern global::System.IntPtr LogCubicZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_zeroRates")]
  public static extern global::System.IntPtr LogCubicZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_nodes")]
  public static extern global::System.IntPtr LogCubicZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_LogCubicZeroCurve")]
  public static extern void delete_LogCubicZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicZeroCurve__SWIG_0")]
  public static extern global::System.IntPtr new_MonotonicCubicZeroCurve__SWIG_0(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6, int jarg7);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicZeroCurve__SWIG_1")]
  public static extern global::System.IntPtr new_MonotonicCubicZeroCurve__SWIG_1(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5, int jarg6);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicZeroCurve__SWIG_2")]
  public static extern global::System.IntPtr new_MonotonicCubicZeroCurve__SWIG_2(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4, global::System.Runtime.InteropServices.HandleRef jarg5);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicZeroCurve__SWIG_3")]
  public static extern global::System.IntPtr new_MonotonicCubicZeroCurve__SWIG_3(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3, global::System.Runtime.InteropServices.HandleRef jarg4);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_new_MonotonicCubicZeroCurve__SWIG_4")]
  public static extern global::System.IntPtr new_MonotonicCubicZeroCurve__SWIG_4(global::System.Runtime.InteropServices.HandleRef jarg1, global::System.Runtime.InteropServices.HandleRef jarg2, global::System.Runtime.InteropServices.HandleRef jarg3);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_times")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_times(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_data")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_data(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_dates")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_dates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_zeroRates")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_zeroRates(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_nodes")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_nodes(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_delete_MonotonicCubicZeroCurve")]
  public static extern void delete_MonotonicCubicZeroCurve(global::System.Runtime.InteropServices.HandleRef jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuropeanExercise_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuropeanExercise_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmericanExercise_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AmericanExercise_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BermudanExercise_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BermudanExercise_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RebatedExercise_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr RebatedExercise_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwingExercise_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwingExercise_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Quote_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Quote_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableQuoteHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableQuoteHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SimpleQuote_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SimpleQuote_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Argentina_SWIGUpcast")]
  public static extern global::System.IntPtr Argentina_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Australia_SWIGUpcast")]
  public static extern global::System.IntPtr Australia_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Brazil_SWIGUpcast")]
  public static extern global::System.IntPtr Brazil_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Canada_SWIGUpcast")]
  public static extern global::System.IntPtr Canada_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_China_SWIGUpcast")]
  public static extern global::System.IntPtr China_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CzechRepublic_SWIGUpcast")]
  public static extern global::System.IntPtr CzechRepublic_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Denmark_SWIGUpcast")]
  public static extern global::System.IntPtr Denmark_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Finland_SWIGUpcast")]
  public static extern global::System.IntPtr Finland_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_France_SWIGUpcast")]
  public static extern global::System.IntPtr France_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Germany_SWIGUpcast")]
  public static extern global::System.IntPtr Germany_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HongKong_SWIGUpcast")]
  public static extern global::System.IntPtr HongKong_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Hungary_SWIGUpcast")]
  public static extern global::System.IntPtr Hungary_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Iceland_SWIGUpcast")]
  public static extern global::System.IntPtr Iceland_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_India_SWIGUpcast")]
  public static extern global::System.IntPtr India_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Indonesia_SWIGUpcast")]
  public static extern global::System.IntPtr Indonesia_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Israel_SWIGUpcast")]
  public static extern global::System.IntPtr Israel_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Italy_SWIGUpcast")]
  public static extern global::System.IntPtr Italy_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Japan_SWIGUpcast")]
  public static extern global::System.IntPtr Japan_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Mexico_SWIGUpcast")]
  public static extern global::System.IntPtr Mexico_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NewZealand_SWIGUpcast")]
  public static extern global::System.IntPtr NewZealand_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Norway_SWIGUpcast")]
  public static extern global::System.IntPtr Norway_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Poland_SWIGUpcast")]
  public static extern global::System.IntPtr Poland_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Russia_SWIGUpcast")]
  public static extern global::System.IntPtr Russia_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Romania_SWIGUpcast")]
  public static extern global::System.IntPtr Romania_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SaudiArabia_SWIGUpcast")]
  public static extern global::System.IntPtr SaudiArabia_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Singapore_SWIGUpcast")]
  public static extern global::System.IntPtr Singapore_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Slovakia_SWIGUpcast")]
  public static extern global::System.IntPtr Slovakia_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SouthAfrica_SWIGUpcast")]
  public static extern global::System.IntPtr SouthAfrica_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SouthKorea_SWIGUpcast")]
  public static extern global::System.IntPtr SouthKorea_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Sweden_SWIGUpcast")]
  public static extern global::System.IntPtr Sweden_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Switzerland_SWIGUpcast")]
  public static extern global::System.IntPtr Switzerland_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Taiwan_SWIGUpcast")]
  public static extern global::System.IntPtr Taiwan_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TARGET_SWIGUpcast")]
  public static extern global::System.IntPtr TARGET_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Thailand_SWIGUpcast")]
  public static extern global::System.IntPtr Thailand_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Turkey_SWIGUpcast")]
  public static extern global::System.IntPtr Turkey_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Ukraine_SWIGUpcast")]
  public static extern global::System.IntPtr Ukraine_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnitedKingdom_SWIGUpcast")]
  public static extern global::System.IntPtr UnitedKingdom_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UnitedStates_SWIGUpcast")]
  public static extern global::System.IntPtr UnitedStates_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NullCalendar_SWIGUpcast")]
  public static extern global::System.IntPtr NullCalendar_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_WeekendsOnly_SWIGUpcast")]
  public static extern global::System.IntPtr WeekendsOnly_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JointCalendar_SWIGUpcast")]
  public static extern global::System.IntPtr JointCalendar_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BespokeCalendar_SWIGUpcast")]
  public static extern global::System.IntPtr BespokeCalendar_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Actual360_SWIGUpcast")]
  public static extern global::System.IntPtr Actual360_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Actual364_SWIGUpcast")]
  public static extern global::System.IntPtr Actual364_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Actual365Fixed_SWIGUpcast")]
  public static extern global::System.IntPtr Actual365Fixed_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Thirty360_SWIGUpcast")]
  public static extern global::System.IntPtr Thirty360_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Thirty365_SWIGUpcast")]
  public static extern global::System.IntPtr Thirty365_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ActualActual_SWIGUpcast")]
  public static extern global::System.IntPtr ActualActual_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneDayCounter_SWIGUpcast")]
  public static extern global::System.IntPtr OneDayCounter_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SimpleDayCounter_SWIGUpcast")]
  public static extern global::System.IntPtr SimpleDayCounter_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Business252_SWIGUpcast")]
  public static extern global::System.IntPtr Business252_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UpRounding_SWIGUpcast")]
  public static extern global::System.IntPtr UpRounding_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DownRounding_SWIGUpcast")]
  public static extern global::System.IntPtr DownRounding_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ClosestRounding_SWIGUpcast")]
  public static extern global::System.IntPtr ClosestRounding_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CeilingTruncation_SWIGUpcast")]
  public static extern global::System.IntPtr CeilingTruncation_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloorTruncation_SWIGUpcast")]
  public static extern global::System.IntPtr FloorTruncation_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ARSCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ARSCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ATSCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ATSCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AUDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr AUDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BDTCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr BDTCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BEFCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr BEFCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BGLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr BGLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BRLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr BRLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BYRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr BYRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CADCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CADCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CHFCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CHFCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CLPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CLPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CNYCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CNYCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_COPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr COPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CYPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CYPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CZKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr CZKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DEMCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr DEMCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DKKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr DKKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EEKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr EEKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ESPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ESPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr EURCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FIMCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr FIMCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FRFCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr FRFCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GBPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr GBPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GRDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr GRDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HKDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr HKDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HUFCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr HUFCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IEPCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr IEPCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IDRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr IDRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ILSCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ILSCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_INRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr INRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IQDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr IQDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IRRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr IRRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ISKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ISKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ITLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ITLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JPYCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr JPYCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KRWCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr KRWCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KWDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr KWDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LTLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr LTLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LUFCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr LUFCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LVLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr LVLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MTLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr MTLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MXNCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr MXNCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MYRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr MYRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NLGCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr NLGCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NOKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr NOKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NPRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr NPRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NZDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr NZDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PEHCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PEHCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PEICurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PEICurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PENCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PENCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PKRCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PKRCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PLNCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PLNCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PTECurrency_SWIGUpcast")]
  public static extern global::System.IntPtr PTECurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ROLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ROLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RONCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr RONCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RUBCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr RUBCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SARCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr SARCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SEKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr SEKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SGDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr SGDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SITCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr SITCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SKKCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr SKKCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_THBCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr THBCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TRLCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr TRLCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TRYCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr TRYCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TTDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr TTDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TWDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr TWDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_USDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr USDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VEBCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr VEBCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VNDCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr VNDCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZARCurrency_SWIGUpcast")]
  public static extern global::System.IntPtr ZARCurrency_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BoundaryConstraint_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BoundaryConstraint_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoConstraint_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NoConstraint_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PositiveConstraint_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PositiveConstraint_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeConstraint_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CompositeConstraint_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonhomogeneousBoundaryConstraint_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NonhomogeneousBoundaryConstraint_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConjugateGradient_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConjugateGradient_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Simplex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Simplex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SteepestDescent_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SteepestDescent_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BFGS_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BFGS_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LevenbergMarquardt_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LevenbergMarquardt_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DifferentialEvolution_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DifferentialEvolution_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GaussianSimulatedAnnealing_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GaussianSimulatedAnnealing_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MirrorGaussianSimulatedAnnealing_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MirrorGaussianSimulatedAnnealing_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogNormalSimulatedAnnealing_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LogNormalSimulatedAnnealing_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YieldTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YieldTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYieldTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableYieldTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ImpliedTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ImpliedTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroSpreadedTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroSpreadedTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardSpreadedTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ForwardSpreadedTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SpreadedLinearZeroInterpolatedTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SpreadedLinearZeroInterpolatedTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SpreadedBackwardFlatZeroInterpolatedTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SpreadedBackwardFlatZeroInterpolatedTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FlatForward_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FlatForward_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Index_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Index_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterestRateIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InterestRateIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IborIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OvernightIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Libor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Libor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DailyTenorLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DailyTenorLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwapIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapSpreadIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwapSpreadIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AUDLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AUDLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CADLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CADLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CADLiborON_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CADLiborON_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Cdor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Cdor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CHFLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CHFLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DKKLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DKKLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw4M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw4M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw5M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw5M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bbsw6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bbsw6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm4M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm4M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm5M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm5M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bkbm6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bkbm6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuriborSW_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuriborSW_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor2W_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor2W_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor3W_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor3W_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor4M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor4M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor5M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor5M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor7M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor7M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor8M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor8M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor9M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor9M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor10M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor10M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor11M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor11M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor1Y_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor1Y_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_SW_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_SW_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_2W_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_2W_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_3W_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_3W_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_4M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_4M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_5M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_5M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_7M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_7M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_8M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_8M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_9M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_9M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_10M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_10M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_11M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_11M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Euribor365_1Y_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Euribor365_1Y_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLiborSW_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLiborSW_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor2W_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor2W_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor4M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor4M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor5M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor5M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor7M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor7M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor8M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor8M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor9M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor9M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor10M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor10M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor11M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor11M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EURLibor1Y_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EURLibor1Y_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GBPLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GBPLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GBPLiborON_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GBPLiborON_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Jibar_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Jibar_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JPYLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr JPYLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Mosprime_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Mosprime_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NZDLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NZDLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Pribor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Pribor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Robor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Robor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SEKLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SEKLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Shibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Shibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Tibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Tibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_THBFIX_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr THBFIX_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TRLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TRLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_USDLibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr USDLibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_USDLiborON_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr USDLiborON_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Wibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Wibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Zibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Zibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Aonia_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Aonia_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Eonia_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Eonia_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Sonia_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Sonia_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FedFunds_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FedFunds_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Nzocr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Nzocr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Sofr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Sofr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuriborSwapIsdaFixA_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuriborSwapIsdaFixA_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuriborSwapIsdaFixB_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuriborSwapIsdaFixB_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuriborSwapIfrFix_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuriborSwapIfrFix_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EurLiborSwapIsdaFixA_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EurLiborSwapIsdaFixA_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EurLiborSwapIsdaFixB_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EurLiborSwapIsdaFixB_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EurLiborSwapIfrFix_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EurLiborSwapIfrFix_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ChfLiborSwapIsdaFix_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ChfLiborSwapIsdaFix_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GbpLiborSwapIsdaFix_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GbpLiborSwapIsdaFix_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JpyLiborSwapIsdaFixAm_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr JpyLiborSwapIsdaFixAm_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JpyLiborSwapIsdaFixPm_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr JpyLiborSwapIsdaFixPm_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UsdLiborSwapIsdaFixAm_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr UsdLiborSwapIsdaFixAm_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UsdLiborSwapIsdaFixPm_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr UsdLiborSwapIsdaFixPm_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BiborSW_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BiborSW_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor1M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor1M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor2M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor2M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor3M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor3M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor6M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor6M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor9M_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor9M_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bibor1Y_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bibor1Y_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VolatilityTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VolatilityTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVolTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackVolTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableBlackVolTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableBlackVolTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LocalVolTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableLocalVolTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableLocalVolTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletVolatilityStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OptionletVolatilityStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableOptionletVolatilityStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableOptionletVolatilityStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletVolatilitySurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYOptionletVolatilitySurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYOptionletVolatilitySurface_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableYoYOptionletVolatilitySurface_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolatilityStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableSwaptionVolatilityStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableSwaptionVolatilityStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackConstantVol_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackConstantVol_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVarianceCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackVarianceCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackVarianceSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackVarianceSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalConstantVol_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LocalConstantVol_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LocalVolSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoExceptLocalVolSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NoExceptLocalVolSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConstantOptionletVolatility_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConstantOptionletVolatility_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConstantSwaptionVolatility_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConstantSwaptionVolatility_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityDiscrete_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolatilityDiscrete_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityMatrix_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolatilityMatrix_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SabrSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SabrSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolatilityCube_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolatilityCube_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube1_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolCube1_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionVolCube2_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionVolCube2_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConstantYoYOptionletVolatility_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConstantYoYOptionletVolatility_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FlatSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FlatSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LinearInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CubicInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MonotonicCubicInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SplineCubicInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SplineCubicInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KahaleSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KahaleSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrShortMaturityLognormalSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrShortMaturityNormalSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilitySmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrLocalVolatilitySmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrFullFdSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityLognormalInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrShortMaturityLognormalInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrShortMaturityNormalInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrShortMaturityNormalInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrLocalVolatilityInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrLocalVolatilityInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZabrFullFdInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZabrFullFdInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NoArbSabrSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NoArbSabrInterpolatedSmileSection_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NoArbSabrInterpolatedSmileSection_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityInterpl_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AndreasenHugeVolatilityInterpl_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeVolatilityAdapter_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AndreasenHugeVolatilityAdapter_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AndreasenHugeLocalVolAdapter_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AndreasenHugeLocalVolAdapter_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonBlackVolSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonBlackVolSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StochasticProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcess1D_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StochasticProcess1D_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeneralizedBlackScholesProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GeneralizedBlackScholesProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackScholesProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackScholesProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackScholesMertonProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackScholesMertonProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GarmanKohlagenProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GarmanKohlagenProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Merton76Process_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Merton76Process_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StochasticProcessArray_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StochasticProcessArray_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GeometricBrownianMotionProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GeometricBrownianMotionProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VarianceGammaProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VarianceGammaProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BatesProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HullWhiteProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhiteForwardProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HullWhiteForwardProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2Process_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr G2Process_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2ForwardProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr G2ForwardProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GsrProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GsrProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExtendedOrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ExtendedOrnsteinUhlenbeckProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExtOUWithJumpsProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ExtOUWithJumpsProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KlugeExtOUProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KlugeExtOUProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GJRGARCHProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PricingEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PricingEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Instrument_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Instrument_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Stock_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Stock_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CompositeInstrument_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CompositeInstrument_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashFlow_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CashFlow_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SimpleCashFlow_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SimpleCashFlow_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Redemption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Redemption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmortizingPayment_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AmortizingPayment_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IndexedCashFlow_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IndexedCashFlow_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Coupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Coupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FixedRateCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FloatingRateCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OvernightIndexedCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CappedFlooredCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IborCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredIborCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CappedFlooredIborCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IborCouponPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IborCouponPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackIborCouponPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackIborCouponPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CmsCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CmsSpreadCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsCouponPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CmsCouponPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHaganPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticHaganPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NumericHaganPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NumericHaganPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCmsCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CappedFlooredCmsCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CappedFlooredCmsSpreadCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CappedFlooredCmsSpreadCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LinearTsrPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LinearTsrPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsSpreadCouponPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CmsSpreadCouponPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LognormalCmsSpreadPricer_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LognormalCmsSpreadPricer_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCalibrationHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackCalibrationHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwaptionHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwaptionHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CapHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModelHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonModelHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CalibratedModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CalibratedModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TermStructureConsistentModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TermStructureConsistentModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCalibratedModelHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableCalibratedModelHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConstantParameter_SWIGUpcast")]
  public static extern global::System.IntPtr ConstantParameter_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NullParameter_SWIGUpcast")]
  public static extern global::System.IntPtr NullParameter_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseConstantParameter_SWIGUpcast")]
  public static extern global::System.IntPtr PiecewiseConstantParameter_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Option_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Option_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TypePayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TypePayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrikedTypePayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StrikedTypePayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneAssetOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OneAssetOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VanillaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EuropeanOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EuropeanOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardVanillaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ForwardVanillaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoVanillaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr QuantoVanillaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoForwardVanillaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr QuantoForwardVanillaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiAssetOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MultiAssetOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseTimeDependentHestonModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseTimeDependentHestonModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_COSHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr COSHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExponentialFittingHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ExponentialFittingHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticPTDHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticPTDHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BatesModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BatesEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BatesEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntegralEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IntegralEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDBermudanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDBermudanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialCRRVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialCRRVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJRVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJRVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialEQPVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialEQPVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTrigeorgisVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTrigeorgisVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTianVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTianVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialLRVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialLRVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJ4VanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJ4VanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPREuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPREuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRAmericanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRAmericanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDAmericanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDAmericanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPREuropeanHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPREuropeanHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDEuropeanHestonEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDEuropeanHestonEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDAmericanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDAmericanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDShoutEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDShoutEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ContinuousArithmeticAsianLevyEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ContinuousArithmeticAsianLevyEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdBlackScholesAsianEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdBlackScholesAsianEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BaroneAdesiWhaleyApproximationEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BaroneAdesiWhaleyApproximationEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BjerksundStenslandApproximationEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BjerksundStenslandApproximationEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JuQuadraticApproximationEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr JuQuadraticApproximationEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDigitalAmericanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDigitalAmericanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDigitalAmericanKOEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDigitalAmericanKOEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendVanillaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DividendVanillaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDividendEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDividendEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDDividendEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDDividendEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FDDividendAmericanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FDDividendAmericanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BarrierOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BarrierOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DividendBarrierOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DividendBarrierOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdBlackScholesVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdBlackScholesVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdOrnsteinUhlenbeckVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdOrnsteinUhlenbeckVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdBatesVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdBatesVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdHestonVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdHestonVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticCEVEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticCEVEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdCEVVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdCEVVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdSabrVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdSabrVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdBlackScholesBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdBlackScholesBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdBlackScholesRebateEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdBlackScholesRebateEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdHestonBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdHestonBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdHestonRebateEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdHestonRebateEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticBinaryBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticBinaryBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialCRRBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialCRRBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJRBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJRBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialEQPBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialEQPBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTrigeorgisBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTrigeorgisBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTianBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTianBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialLRBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialLRBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJ4BarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJ4BarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ForwardEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr QuantoEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoForwardEuropeanEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr QuantoForwardEuropeanEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ContinuousAveragingAsianOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ContinuousAveragingAsianOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscreteAveragingAsianOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DiscreteAveragingAsianOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticContinuousGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticContinuousGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDiscreteGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDiscreteGeometricAveragePriceAsianEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDiscreteGeometricAverageStrikeAsianEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDiscreteGeometricAverageStrikeAsianEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDDiscreteArithmeticAPEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRDiscreteArithmeticASEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRDiscreteArithmeticASEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDDiscreteArithmeticASEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDDiscreteArithmeticASEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRDiscreteGeometricAPEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRDiscreteGeometricAPEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDDiscreteGeometricAPEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDDiscreteGeometricAPEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VarianceGammaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VarianceGammaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FFTVarianceGammaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FFTVarianceGammaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DoubleBarrierOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DoubleBarrierOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_QuantoDoubleBarrierOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr QuantoDoubleBarrierOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdHestonDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdHestonDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_WulinYongDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr WulinYongDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DeltaVolQuote_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DeltaVolQuote_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDeltaVolQuoteHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableDeltaVolQuoteHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VannaVolgaIKDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VannaVolgaIKDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VannaVolgaWODoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VannaVolgaWODoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VannaVolgaBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VannaVolgaBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticDoubleBarrierBinaryEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticDoubleBarrierBinaryEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialCRRDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialCRRDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJRDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJRDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialEQPDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialEQPDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTrigeorgisDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTrigeorgisDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTianDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTianDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialLRDoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialLRDoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJ4DoubleBarrierEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJ4DoubleBarrierEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwingOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VanillaSwingOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdSimpleBSSwingEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdSimpleBSSwingEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdSimpleExtOUJumpSwingEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdSimpleExtOUJumpSwingEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GJRGARCHModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GJRGARCHModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticGJRGARCHEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticGJRGARCHEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPREuropeanGJRGARCHEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPREuropeanGJRGARCHEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDEuropeanGJRGARCHEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDEuropeanGJRGARCHEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SpreadOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SpreadOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KirkSpreadOptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KirkSpreadOptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PlainVanillaPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PlainVanillaPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PercentageStrikePayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PercentageStrikePayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CashOrNothingPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CashOrNothingPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AssetOrNothingPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AssetOrNothingPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SuperSharePayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SuperSharePayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GapPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GapPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaForwardPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VanillaForwardPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BasketPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BasketPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MinBasketPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MinBasketPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MaxBasketPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MaxBasketPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AverageBasketPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AverageBasketPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SpreadBasketPayoff_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SpreadBasketPayoff_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BasketOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BasketOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPREuropeanBasketEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPREuropeanBasketEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDEuropeanBasketEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDEuropeanBasketEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRAmericanBasketEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRAmericanBasketEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDAmericanBasketEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDAmericanBasketEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StulzEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StulzEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KirkEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KirkEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fd2dBlackScholesVanillaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Fd2dBlackScholesVanillaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EverestOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EverestOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPREverestEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPREverestEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDEverestEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDEverestEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HimalayaOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HimalayaOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCPRHimalayaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCPRHimalayaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MCLDHimalayaEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MCLDHimalayaEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SoftCallability_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SoftCallability_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Swap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_VanillaSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr VanillaSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NonstandardSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountingSwapEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DiscountingSwapEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AssetSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AssetSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FloatFloatSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OvernightIndexedSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexedSwapIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OvernightIndexedSwapIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MultiplicativePriceSeasonality_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MultiplicativePriceSeasonality_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KerkhofSeasonality_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KerkhofSeasonality_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InflationTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableYoYInflationTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableYoYInflationTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroInflationTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableZeroInflationTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableZeroInflationTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CustomRegion_SWIGUpcast")]
  public static extern global::System.IntPtr CustomRegion_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InflationIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroInflationIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationIndex_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationIndex_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EUHICP_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EUHICP_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_EUHICPXT_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr EUHICPXT_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FRHICP_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FRHICP_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UKRPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr UKRPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_USCPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr USCPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZACPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZACPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYEUHICP_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYEUHICP_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYEUHICPXT_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYEUHICPXT_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYEUHICPr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYEUHICPr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYFRHICP_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYFRHICP_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYFRHICPr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYFRHICPr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYUKRPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYUKRPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYUKRPIr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYUKRPIr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYUSCPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYUSCPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYUSCPIr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYUSCPIr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYZACPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYZACPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YYZACPIr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YYZACPIr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AUCPI_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AUCPI_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InflationCoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InflationCoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPICoupon_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CPICoupon_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYOptionHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwapHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroCouponInflationSwapHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwapHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YearOnYearInflationSwapHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseZeroInflation_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseZeroInflation_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseYoYInflation_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseYoYInflation_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponInflationSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroCouponInflationSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YearOnYearInflationSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YearOnYearInflationSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPISwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CPISwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationCapFloor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationCap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationFloor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationFloor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCollar_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationCollar_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroInflationCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroInflationCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYCapFloorTermPriceSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYCapFloorTermPriceSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationCapFloorTermPriceSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationCapFloorTermPriceSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationBlackCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationBlackCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationUnitDisplacedBlackCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationUnitDisplacedBlackCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYInflationBachelierCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYInflationBachelierCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_YoYOptionletHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr YoYOptionletHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterpolatedYoYInflationOptionletStripper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InterpolatedYoYInflationOptionletStripper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_InterpolatedYoYInflationOptionletVolatilityCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr InterpolatedYoYInflationOptionletVolatilityCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_KInterpolatedYoYInflationOptionletVolatilitySurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr KInterpolatedYoYInflationOptionletVolatilitySurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ShortRateModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ShortRateModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableShortRateModelHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableShortRateModelHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OneFactorAffineModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OneFactorAffineModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Vasicek_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Vasicek_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HullWhite_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HullWhite_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackKarasinski_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackKarasinski_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CoxIngersollRoss_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CoxIngersollRoss_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExtendedCoxIngersollRoss_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ExtendedCoxIngersollRoss_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr G2_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_JamshidianSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr JamshidianSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TreeSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TreeSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TreeCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TreeCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_G2SwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr G2SwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdG2SwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdG2SwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdHullWhiteSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdHullWhiteSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AnalyticBSMHullWhiteEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AnalyticBSMHullWhiteEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Bond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Bond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCouponBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroCouponBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FixedRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmortizingFixedRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AmortizingFixedRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_AmortizingFloatingRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr AmortizingFloatingRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatingRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FloatingRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CmsRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CmsRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountingBondEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DiscountingBondEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CallableBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableFixedRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CallableFixedRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CallableZeroCouponBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CallableZeroCouponBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TreeCallableFixedRateBondEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TreeCallableFixedRateBondEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCallableFixedRateBondEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackCallableFixedRateBondEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CPIBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CPIBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CapFloor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Cap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Cap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Floor_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Floor_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Collar_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Collar_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BachelierCapFloorEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BachelierCapFloorEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Dividend_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Dividend_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedDividend_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FixedDividend_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FractionalDividend_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FractionalDividend_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConvertibleZeroCouponBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConvertibleZeroCouponBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConvertibleFixedCouponBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConvertibleFixedCouponBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ConvertibleFloatingRateBond_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ConvertibleFloatingRateBond_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialCRRConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialCRRConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJRConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJRConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialEQPConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialEQPConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTrigeorgisConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTrigeorgisConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialTianConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialTianConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialLRConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialLRConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BinomialJ4ConvertibleEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BinomialJ4ConvertibleEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr RateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DepositRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DepositRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FraRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FraRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FuturesRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FuturesRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SwapRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SwapRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BondHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BondHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBondHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FixedRateBondHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OISRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OISRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DatedOISRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DatedOISRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FxSwapRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FxSwapRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OvernightIndexFutureRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OvernightIndexFutureRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SofrFutureRateHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SofrFutureRateHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatForward_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseFlatForward_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogLinearDiscount_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseLogLinearDiscount_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearForward_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseLinearForward_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLinearZero_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseLinearZero_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseCubicZero_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseCubicZero_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseLogCubicDiscount_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseLogCubicDiscount_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseSplineCubicDiscount_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseSplineCubicDiscount_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerZero_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseKrugerZero_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseKrugerLogDiscount_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseKrugerLogDiscount_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseConvexMonotoneZero_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseConvexMonotoneZero_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GlobalLinearSimpleZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GlobalLinearSimpleZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityTermStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DefaultProbabilityTermStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableDefaultProbabilityTermStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableDefaultProbabilityTermStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FlatHazardRate_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FlatHazardRate_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HazardRateCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HazardRateCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultDensityCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DefaultDensityCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SurvivalProbabilityCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SurvivalProbabilityCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DefaultProbabilityHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DefaultProbabilityHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SpreadCdsHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SpreadCdsHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_UpfrontCdsHelper_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr UpfrontCdsHelper_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_PiecewiseFlatHazardRate_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr PiecewiseFlatHazardRate_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FaceValueClaim_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FaceValueClaim_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FaceValueAccrualClaim_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FaceValueAccrualClaim_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CreditDefaultSwap_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CreditDefaultSwap_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MidPointCdsEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MidPointCdsEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IntegralCdsEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IntegralCdsEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_IsdaCdsEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr IsdaCdsEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CdsOption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CdsOption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackCdsOptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackCdsOptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DiscountCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DiscountCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicLogCubicDiscountCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MonotonicLogCubicDiscountCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicDiscountCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NaturalCubicDiscountCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBlackScholesMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmBlackScholesMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Concentrating1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Concentrating1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExponentialJump1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ExponentialJump1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmCEV1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmCEV1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonVarianceMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHestonVarianceMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonLocalVolatilityVarianceMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHestonLocalVolatilityVarianceMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSimpleProcess1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSimpleProcess1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Uniform1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Uniform1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Predefined1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Predefined1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Glued1dMesher_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Glued1dMesher_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmMesherComposite_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmMesherComposite_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpComposite_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmLinearOpComposite_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLinearOpCompositeProxy_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmLinearOpCompositeProxy_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDirichletBoundary_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmDirichletBoundary_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDiscountDirichletBoundary_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmDiscountDirichletBoundary_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmTimeDepDirichletBoundary_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmTimeDepDirichletBoundary_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBatesOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmBatesOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBlackScholesOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmBlackScholesOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Fdm2dBlackScholesOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Fdm2dBlackScholesOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmCEVOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmCEVOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmG2Op_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmG2Op_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonHullWhiteOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHestonHullWhiteOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHestonOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHullWhiteOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHullWhiteOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLocalVolFwdOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmLocalVolFwdOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmOrnsteinUhlenbeckOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmOrnsteinUhlenbeckOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSabrOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSabrOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmZabrOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmZabrOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDupire1dOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmDupire1dOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBlackScholesFwdOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmBlackScholesFwdOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSquareRootFwdOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSquareRootFwdOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmHestonFwdOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmHestonFwdOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_TripleBandLinearOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr TripleBandLinearOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FirstDerivativeOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FirstDerivativeOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SecondDerivativeOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SecondDerivativeOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NinePointLinearOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NinePointLinearOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SecondOrderMixedDerivativeOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SecondOrderMixedDerivativeOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NthOrderDerivativeOp_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NthOrderDerivativeOp_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionProxy_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmStepConditionProxy_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmInnerValueCalculatorProxy_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmInnerValueCalculatorProxy_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmCellAveragingInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmCellAveragingInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLogInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmLogInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmLogBasketInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmLogBasketInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmZeroInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmZeroInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmAffineG2ModelSwapInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmAffineG2ModelSwapInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmAffineHullWhiteModelSwapInnerValue_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmAffineHullWhiteModelSwapInnerValue_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSnapshotCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSnapshotCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmStepConditionComposite_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmStepConditionComposite_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmAmericanStepCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmAmericanStepCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmArithmeticAverageCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmArithmeticAverageCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmBermudanStepCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmBermudanStepCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSimpleStorageCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSimpleStorageCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmSimpleSwingCondition_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmSimpleSwingCondition_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FdmDividendHandler_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FdmDividendHandler_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BSMRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BSMRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CEVRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CEVRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_GBSMRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr GBSMRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LocalVolRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LocalVolRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SquareRootProcessRNDCalculator_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SquareRootProcessRNDCalculator_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FittedBondDiscountCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FittedBondDiscountCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ExponentialSplinesFitting_SWIGUpcast")]
  public static extern global::System.IntPtr ExponentialSplinesFitting_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NelsonSiegelFitting_SWIGUpcast")]
  public static extern global::System.IntPtr NelsonSiegelFitting_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SvenssonFitting_SWIGUpcast")]
  public static extern global::System.IntPtr SvenssonFitting_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicBSplinesFitting_SWIGUpcast")]
  public static extern global::System.IntPtr CubicBSplinesFitting_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SimplePolynomialFitting_SWIGUpcast")]
  public static extern global::System.IntPtr SimplePolynomialFitting_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ForwardCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Forward_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Forward_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FixedRateBondForward_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FixedRateBondForward_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ForwardRateAgreement_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ForwardRateAgreement_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dModel_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gaussian1dModel_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gsr_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gsr_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MarkovFunctional_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MarkovFunctional_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gaussian1dSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dJamshidianSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gaussian1dJamshidianSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dNonstandardSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gaussian1dNonstandardSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Gaussian1dFloatFloatSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Gaussian1dFloatFloatSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NeumannBC_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NeumannBC_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DirichletBC_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr DirichletBC_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DPlus_SWIGUpcast")]
  public static extern global::System.IntPtr DPlus_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DMinus_SWIGUpcast")]
  public static extern global::System.IntPtr DMinus_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DZero_SWIGUpcast")]
  public static extern global::System.IntPtr DZero_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_DPlusDMinus_SWIGUpcast")]
  public static extern global::System.IntPtr DPlusDMinus_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_HestonSLVProcess_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr HestonSLVProcess_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MTBrownianGeneratorFactory_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MTBrownianGeneratorFactory_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_SobolBrownianGeneratorFactory_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr SobolBrownianGeneratorFactory_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RiskStatistics_SWIGUpcast")]
  public static extern global::System.IntPtr RiskStatistics_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolatilityStructure_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CapFloorTermVolatilityStructure_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_RelinkableCapFloorTermVolatilityStructureHandle_SWIGUpcast")]
  public static extern global::System.IntPtr RelinkableCapFloorTermVolatilityStructureHandle_SWIGUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CapFloorTermVolCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CapFloorTermVolSurface_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CapFloorTermVolSurface_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_OptionletStripper1_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr OptionletStripper1_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_StrippedOptionletAdapter_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr StrippedOptionletAdapter_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_Swaption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr Swaption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NonstandardSwaption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NonstandardSwaption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_FloatFloatSwaption_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr FloatFloatSwaption_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BlackSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BlackSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_BachelierSwaptionEngine_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr BachelierSwaptionEngine_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_ZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr ZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogLinearZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LogLinearZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_CubicZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr CubicZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_NaturalCubicZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr NaturalCubicZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_LogCubicZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr LogCubicZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);

  [global::System.Runtime.InteropServices.DllImport("NQuantLibc", EntryPoint="CSharp_QuantLib_MonotonicCubicZeroCurve_SWIGSmartPtrUpcast")]
  public static extern global::System.IntPtr MonotonicCubicZeroCurve_SWIGSmartPtrUpcast(global::System.IntPtr jarg1);
}

}
